<?php

/**
 * Temboo PHP SDK Google classes
 *
 * Execute Choreographies from the Temboo Google bundle.
 *
 * PHP version 5
 *
 * LICENSE: Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @category   Services
 * @package    Temboo
 * @subpackage Google
 * @author     Temboo, Inc.
 * @copyright  2013 Temboo, Inc.
 * @license    http://www.apache.org/licenses/LICENSE-2.0 Apache License 2.0
 * @link       http://www.temboo.com
 */
/**
 * Retrieves metrics such as visits, page views, bounces within a specified time frame.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Analytics_GetMetrics extends Temboo_Choreography
{
    /**
     * Retrieves metrics such as visits, page views, bounces within a specified time frame.
     *
     * @param Temboo_Session $session The session that owns this GetMetrics Choreo.
     * @return Google_Analytics_GetMetrics New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Analytics/GetMetrics/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetMetrics Choreo.
     *
     * @param Google_Analytics_GetMetrics_Inputs|array $inputs (optional) Inputs as Google_Analytics_GetMetrics_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Analytics_GetMetrics_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Analytics_GetMetrics_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetMetrics Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Analytics_GetMetrics_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Analytics_GetMetrics_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetMetrics Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Analytics_GetMetrics_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetMetrics Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Analytics_GetMetrics_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetMetrics input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetMetrics Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetMetrics Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Dimensions input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) Defines the primary data keys for your Analytics report. Use dimensions to segment your web property metrics (e.g.  ga:browser or ga:city).
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setDimensions($value)
    {
        return $this->set('Dimensions', $value);
    }

    /**
     * Set the value for the EndDate input for this GetMetrics Choreo.
     *
     * @param string $value (required, date) The end date for the range of data you want to retrieve. Epoch timestamp in milliseconds or formatted as yyyy-MM-dd.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setEndDate($value)
    {
        return $this->set('EndDate', $value);
    }

    /**
     * Set the value for the Filters input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) Restricts the data returned by a dimension or metric you want to filter by using an expression (i.e. ga:timeOnPage==10).
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setFilters($value)
    {
        return $this->set('Filters', $value);
    }

    /**
     * Set the value for the MaxResults input for this GetMetrics Choreo.
     *
     * @param int $value (optional, integer) The max results to be returned in the feed. Defaults to 50.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the Metrics input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) This is a comma separated list of metrics you want to retrieve. Defaults to: ga:visits,ga:bounces,ga:pageviews.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setMetrics($value)
    {
        return $this->set('Metrics', $value);
    }

    /**
     * Set the value for the Password input for this GetMetrics Choreo.
     *
     * @param string $value (required, password) Deprecated (retained for backward compatibility only).
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the ProfileId input for this GetMetrics Choreo.
     *
     * @param int $value (required, integer) The Google Analytics Profile ID to access. This is also known as the View ID. It can be found in the Admin > View Settings section of a particular profile.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setProfileId($value)
    {
        return $this->set('ProfileId', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetMetrics Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: XML (the default) and JSON.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Segment input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) Used to segment your data by dimensions and/or metrics. You can use expressions for segments just as you would for the Filters parameter.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setSegment($value)
    {
        return $this->set('Segment', $value);
    }

    /**
     * Set the value for the Sort input for this GetMetrics Choreo.
     *
     * @param string $value (optional, string) Indicates the sorting order and direction for the returned data. Values can be separated by commas (i.e. ga:browser,ga:pageviews).
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setSort($value)
    {
        return $this->set('Sort', $value);
    }

    /**
     * Set the value for the StartDate input for this GetMetrics Choreo.
     *
     * @param string $value (required, date) The start date for the range of data to retrieve. Use epoch timestamp in milliseconds or formatted as yyyy-MM-dd.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setStartDate($value)
    {
        return $this->set('StartDate', $value);
    }

    /**
     * Set the value for the StartIndex input for this GetMetrics Choreo.
     *
     * @param int $value (optional, integer) The starting entry for the feed. Defaults to 1.
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }

    /**
     * Set the value for the Username input for this GetMetrics Choreo.
     *
     * @param string $value (required, string) Deprecated (retained for backward compatibility only).
     * @return Google_Analytics_GetMetrics_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetMetrics Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Analytics_GetMetrics_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetMetrics Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetMetrics execution.
     * @param Google_Analytics_GetMetrics $choreo The choreography object for this execution.
     * @param Google_Analytics_GetMetrics_Inputs|array $inputs (optional) Inputs as Google_Analytics_GetMetrics_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Analytics_GetMetrics_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Analytics_GetMetrics $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetMetrics execution.
     *
     * @return Google_Analytics_GetMetrics_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetMetrics execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Analytics_GetMetrics_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Analytics_GetMetrics_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetMetrics Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Analytics_GetMetrics_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetMetrics Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Analytics_GetMetrics_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Bounces" output from this GetMetrics execution.
     *
     * @return int (integer) The bounces metrics parsed from the Google Analytics response
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getBounces()
    {
        return $this->get('Bounces');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetMetrics execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "PageViews" output from this GetMetrics execution.
     *
     * @return int (integer) The page views parsed from the Google Analytics response
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getPageViews()
    {
        return $this->get('PageViews');
    }
    /**
     * Retrieve the value for the "Visits" output from this GetMetrics execution.
     *
     * @return int (integer) The visits metrics parsed from the Google Analytics response.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getVisits()
    {
        return $this->get('Visits');
    }
    /**
     * Retrieve the value for the "Response" output from this GetMetrics execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the results of a query with a given JobID when a query request times out and returns before the results are available.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_GetQueryResults extends Temboo_Choreography
{
    /**
     * Retrieves the results of a query with a given JobID when a query request times out and returns before the results are available.
     *
     * @param Temboo_Session $session The session that owns this GetQueryResults Choreo.
     * @return Google_BigQuery_Jobs_GetQueryResults New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/BigQuery/Jobs/GetQueryResults/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetQueryResults Choreo.
     *
     * @param Google_BigQuery_Jobs_GetQueryResults_Inputs|array $inputs (optional) Inputs as Google_BigQuery_Jobs_GetQueryResults_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_Jobs_GetQueryResults_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_BigQuery_Jobs_GetQueryResults_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetQueryResults Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_BigQuery_Jobs_GetQueryResults_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetQueryResults Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_GetQueryResults_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetQueryResults Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetQueryResults input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetQueryResults Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetQueryResults Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetQueryResults Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetQueryResults Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the JobID input for this GetQueryResults Choreo.
     *
     * @param string $value (required, string) Job ID of the query job.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setJobID($value)
    {
        return $this->set('JobID', $value);
    }

    /**
     * Set the value for the MaxResults input for this GetQueryResults Choreo.
     *
     * @param int $value (optional, integer) Maximum number of results to return. Defaults to 100. Max is 1000.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this GetQueryResults Choreo.
     *
     * @param string $value (optional, string) Page token, returned by a previous call, identifying the result set.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the ProjectID input for this GetQueryResults Choreo.
     *
     * @param string $value (required, string) The ID of your Google API project.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setProjectID($value)
    {
        return $this->set('ProjectID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetQueryResults Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartIndex input for this GetQueryResults Choreo.
     *
     * @param int $value (optional, integer) Zero-based index of the starting row to read.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }

    /**
     * Set the value for the TimeoutMs input for this GetQueryResults Choreo.
     *
     * @param int $value (optional, integer) How long to wait for the query to complete, in milliseconds, before returning. Default is 10000. If the timeout passes before the job completes, the 'jobComplete' field in the response will be false.
     * @return Google_BigQuery_Jobs_GetQueryResults_Inputs For method chaining.
     */
    public function setTimeoutMs($value)
    {
        return $this->set('TimeoutMs', $value);
    }
}


/**
 * Execution object for the GetQueryResults Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_GetQueryResults_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetQueryResults Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetQueryResults execution.
     * @param Google_BigQuery_Jobs_GetQueryResults $choreo The choreography object for this execution.
     * @param Google_BigQuery_Jobs_GetQueryResults_Inputs|array $inputs (optional) Inputs as Google_BigQuery_Jobs_GetQueryResults_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_Jobs_GetQueryResults_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_BigQuery_Jobs_GetQueryResults $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetQueryResults execution.
     *
     * @return Google_BigQuery_Jobs_GetQueryResults_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetQueryResults execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_BigQuery_Jobs_GetQueryResults_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_BigQuery_Jobs_GetQueryResults_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetQueryResults Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_GetQueryResults_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetQueryResults Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_BigQuery_Jobs_GetQueryResults_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetQueryResults execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetQueryResults execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Runs a BigQuery SQL query and returns results if the query completes within a specified timeout. When a query timeout occurs, results can be retrieved using the Job ID returned in the response.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_Query extends Temboo_Choreography
{
    /**
     * Runs a BigQuery SQL query and returns results if the query completes within a specified timeout. When a query timeout occurs, results can be retrieved using the Job ID returned in the response.
     *
     * @param Temboo_Session $session The session that owns this Query Choreo.
     * @return Google_BigQuery_Jobs_Query New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/BigQuery/Jobs/Query/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Query Choreo.
     *
     * @param Google_BigQuery_Jobs_Query_Inputs|array $inputs (optional) Inputs as Google_BigQuery_Jobs_Query_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_Jobs_Query_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_BigQuery_Jobs_Query_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Query Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_Jobs_Query_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_BigQuery_Jobs_Query_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Query Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_Query_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Query Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_Jobs_Query_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Query input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Query Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Query Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Query Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DatasetID input for this Query Choreo.
     *
     * @param string $value (optional, string) The ID of the dataset that your table belongs to.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setDatasetID($value)
    {
        return $this->set('DatasetID', $value);
    }

    /**
     * Set the value for the DryRun input for this Query Choreo.
     *
     * @param bool $value (optional, boolean) If set to true, BigQuery doesn't run the job. Instead, if the query is valid, BigQuery returns statistics about the job such as how many bytes would be processed. Defaults to false.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setDryRun($value)
    {
        return $this->set('DryRun', $value);
    }

    /**
     * Set the value for the Fields input for this Query Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this Query Choreo.
     *
     * @param int $value (optional, integer) Maximum number of results to return. Defaults to 100. Max is 1000.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this Query Choreo.
     *
     * @param string $value (optional, string) Page token, returned by a previous call, identifying the result set.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the ProjectID input for this Query Choreo.
     *
     * @param string $value (required, string) The ID of your Google API project.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setProjectID($value)
    {
        return $this->set('ProjectID', $value);
    }

    /**
     * Set the value for the Query input for this Query Choreo.
     *
     * @param string $value (required, string) A query to execute. Example: SELECT count(f1) FROM [myProjectId:myDatasetId.myTableId].
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Query Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the TimeoutMs input for this Query Choreo.
     *
     * @param int $value (optional, integer) How long to wait for the query to complete, in milliseconds, before the request times out and returns. Defaults to 10000.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setTimeoutMs($value)
    {
        return $this->set('TimeoutMs', $value);
    }

    /**
     * Set the value for the UseQueryCache input for this Query Choreo.
     *
     * @param bool $value (optional, boolean) Whether to look for the result in the query cache. Defaults to true.
     * @return Google_BigQuery_Jobs_Query_Inputs For method chaining.
     */
    public function setUseQueryCache($value)
    {
        return $this->set('UseQueryCache', $value);
    }
}


/**
 * Execution object for the Query Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_Query_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Query Choreo.
     *
     * @param Temboo_Session $session The session that owns this Query execution.
     * @param Google_BigQuery_Jobs_Query $choreo The choreography object for this execution.
     * @param Google_BigQuery_Jobs_Query_Inputs|array $inputs (optional) Inputs as Google_BigQuery_Jobs_Query_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_Jobs_Query_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_BigQuery_Jobs_Query $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Query execution.
     *
     * @return Google_BigQuery_Jobs_Query_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Query execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_BigQuery_Jobs_Query_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_BigQuery_Jobs_Query_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Query Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_Jobs_Query_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Query Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_BigQuery_Jobs_Query_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Query execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Query execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Streams data into BigQuery one record at a time.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_InsertAll extends Temboo_Choreography
{
    /**
     * Streams data into BigQuery one record at a time.
     *
     * @param Temboo_Session $session The session that owns this InsertAll Choreo.
     * @return Google_BigQuery_TableData_InsertAll New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/BigQuery/TableData/InsertAll/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertAll Choreo.
     *
     * @param Google_BigQuery_TableData_InsertAll_Inputs|array $inputs (optional) Inputs as Google_BigQuery_TableData_InsertAll_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_TableData_InsertAll_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_BigQuery_TableData_InsertAll_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertAll Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_TableData_InsertAll_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_BigQuery_TableData_InsertAll_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertAll Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_InsertAll_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertAll Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_TableData_InsertAll_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertAll input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this InsertAll Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertAll Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertAll Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DatasetID input for this InsertAll Choreo.
     *
     * @param string $value (required, string) The ID of the dataset that your table belongs to.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setDatasetID($value)
    {
        return $this->set('DatasetID', $value);
    }

    /**
     * Set the value for the Fields input for this InsertAll Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the IgnoreUnknownValues input for this InsertAll Choreo.
     *
     * @param bool $value (optional, boolean) Accept rows that contain values that do not match the schema. The unknown values are ignored. Default is false, which treats unknown values as errors.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setIgnoreUnknownValues($value)
    {
        return $this->set('IgnoreUnknownValues', $value);
    }

    /**
     * Set the value for the ProjectID input for this InsertAll Choreo.
     *
     * @param string $value (required, string) The ID of your Google API project.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setProjectID($value)
    {
        return $this->set('ProjectID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertAll Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Rows input for this InsertAll Choreo.
     *
     * @param string $value (conditional, json) The rows to insert. This should be a JSON array containing at least one object representing a row. See Choreo notes for formatting details.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setRows($value)
    {
        return $this->set('Rows', $value);
    }

    /**
     * Set the value for the TableID input for this InsertAll Choreo.
     *
     * @param string $value (required, string) The ID of the BigQuery table to insert a row into.
     * @return Google_BigQuery_TableData_InsertAll_Inputs For method chaining.
     */
    public function setTableID($value)
    {
        return $this->set('TableID', $value);
    }
}


/**
 * Execution object for the InsertAll Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_InsertAll_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertAll Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertAll execution.
     * @param Google_BigQuery_TableData_InsertAll $choreo The choreography object for this execution.
     * @param Google_BigQuery_TableData_InsertAll_Inputs|array $inputs (optional) Inputs as Google_BigQuery_TableData_InsertAll_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_TableData_InsertAll_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_BigQuery_TableData_InsertAll $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertAll execution.
     *
     * @return Google_BigQuery_TableData_InsertAll_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertAll execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_BigQuery_TableData_InsertAll_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_BigQuery_TableData_InsertAll_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertAll Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_InsertAll_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertAll Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_BigQuery_TableData_InsertAll_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertAll execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertAll execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves table data from a specified set of rows.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_List extends Temboo_Choreography
{
    /**
     * Retrieves table data from a specified set of rows.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_BigQuery_TableData_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/BigQuery/TableData/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_BigQuery_TableData_List_Inputs|array $inputs (optional) Inputs as Google_BigQuery_TableData_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_TableData_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_BigQuery_TableData_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_TableData_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_BigQuery_TableData_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_BigQuery_TableData_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DatasetID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the dataset that your table belongs to.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setDatasetID($value)
    {
        return $this->set('DatasetID', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) Maximum number of results to return. Defaults to 100. Max is 1000.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) Page token, returned by a previous call, identifying the result set.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the ProjectID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of your Google API project.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setProjectID($value)
    {
        return $this->set('ProjectID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartIndex input for this List Choreo.
     *
     * @param int $value (optional, integer) Zero-based index of the starting row to read.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }

    /**
     * Set the value for the TableID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the BigQuery table to insert a row into.
     * @return Google_BigQuery_TableData_List_Inputs For method chaining.
     */
    public function setTableID($value)
    {
        return $this->set('TableID', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_BigQuery_TableData_List $choreo The choreography object for this execution.
     * @param Google_BigQuery_TableData_List_Inputs|array $inputs (optional) Inputs as Google_BigQuery_TableData_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_BigQuery_TableData_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_BigQuery_TableData_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_BigQuery_TableData_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_BigQuery_TableData_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_BigQuery_TableData_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_BigQuery_TableData_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_BigQuery_TableData_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Create a new secondary calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateCalendar extends Temboo_Choreography
{
    /**
     * Create a new secondary calendar.
     *
     * @param Temboo_Session $session The session that owns this CreateCalendar Choreo.
     * @return Google_Calendar_CreateCalendar New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/CreateCalendar/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateCalendar Choreo.
     *
     * @param Google_Calendar_CreateCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_CreateCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_CreateCalendar_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_CreateCalendar_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_CreateCalendar_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_CreateCalendar_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateCalendar_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_CreateCalendar_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateCalendar input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateCalendar Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this CreateCalendar Choreo.
     *
     * @param string $value (optional, string) A description of the calendar.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Location input for this CreateCalendar Choreo.
     *
     * @param string $value (optional, string) Geographic location of the calendar such as "Los Angeles" or "New York".
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setLocation($value)
    {
        return $this->set('Location', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateCalendar Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this CreateCalendar Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Timezone input for this CreateCalendar Choreo.
     *
     * @param string $value (optional, string) The timezone for the new calendar, such as "America/Los_Angeles". Defaults to UTC if left blank.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setTimezone($value)
    {
        return $this->set('Timezone', $value);
    }

    /**
     * Set the value for the Title input for this CreateCalendar Choreo.
     *
     * @param string $value (required, string) The name for the new calendar.
     * @return Google_Calendar_CreateCalendar_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }
}


/**
 * Execution object for the CreateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateCalendar_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateCalendar Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateCalendar execution.
     * @param Google_Calendar_CreateCalendar $choreo The choreography object for this execution.
     * @param Google_Calendar_CreateCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_CreateCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_CreateCalendar_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_CreateCalendar $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateCalendar execution.
     *
     * @return Google_Calendar_CreateCalendar_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateCalendar execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_CreateCalendar_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_CreateCalendar_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateCalendar_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateCalendar Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_CreateCalendar_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateCalendar execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateCalendar execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Create a new event in a specified calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateEvent extends Temboo_Choreography
{
    /**
     * Create a new event in a specified calendar.
     *
     * @param Temboo_Session $session The session that owns this CreateEvent Choreo.
     * @return Google_Calendar_CreateEvent New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/CreateEvent/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateEvent Choreo.
     *
     * @param Google_Calendar_CreateEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_CreateEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_CreateEvent_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_CreateEvent_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_CreateEvent_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_CreateEvent_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateEvent_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_CreateEvent_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateEvent input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateEvent Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar in which to add the event.  Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateEvent Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateEvent Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EndDate input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The end date of the event, in the format "2012-04-10".
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setEndDate($value)
    {
        return $this->set('EndDate', $value);
    }

    /**
     * Set the value for the EndTime input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The end time for the event, in the format "10:30:00".
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setEndTime($value)
    {
        return $this->set('EndTime', $value);
    }

    /**
     * Set the value for the EventDescription input for this CreateEvent Choreo.
     *
     * @param string $value (optional, string) A short description of the event.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setEventDescription($value)
    {
        return $this->set('EventDescription', $value);
    }

    /**
     * Set the value for the EventLocation input for this CreateEvent Choreo.
     *
     * @param string $value (optional, string) The location for the new event.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setEventLocation($value)
    {
        return $this->set('EventLocation', $value);
    }

    /**
     * Set the value for the EventTitle input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The title for the new event.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setEventTitle($value)
    {
        return $this->set('EventTitle', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateEvent Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this CreateEvent Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the StartDate input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The start date of the event, in the format "2012-11-03".
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setStartDate($value)
    {
        return $this->set('StartDate', $value);
    }

    /**
     * Set the value for the StartTime input for this CreateEvent Choreo.
     *
     * @param string $value (required, string) The start time for the event, in the format "10:00:00".
     * @return Google_Calendar_CreateEvent_Inputs For method chaining.
     */
    public function setStartTime($value)
    {
        return $this->set('StartTime', $value);
    }
}


/**
 * Execution object for the CreateEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateEvent_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateEvent Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateEvent execution.
     * @param Google_Calendar_CreateEvent $choreo The choreography object for this execution.
     * @param Google_Calendar_CreateEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_CreateEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_CreateEvent_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_CreateEvent $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateEvent execution.
     *
     * @return Google_Calendar_CreateEvent_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateEvent execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_CreateEvent_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_CreateEvent_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_CreateEvent_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateEvent Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_CreateEvent_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "TimezoneSetting" output from this CreateEvent execution.
     *
     * @return string (string) The timezone setting retrieved from the specified calendar.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getTimezoneSetting()
    {
        return $this->get('TimezoneSetting');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateEvent execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateEvent execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Delete all events from a primary calendar of an account. Note that this operation can't be undone.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteAllEvents extends Temboo_Choreography
{
    /**
     * Delete all events from a primary calendar of an account. Note that this operation can't be undone.
     *
     * @param Temboo_Session $session The session that owns this DeleteAllEvents Choreo.
     * @return Google_Calendar_DeleteAllEvents New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/DeleteAllEvents/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteAllEvents Choreo.
     *
     * @param Google_Calendar_DeleteAllEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteAllEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteAllEvents_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_DeleteAllEvents_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteAllEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteAllEvents_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_DeleteAllEvents_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteAllEvents_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteAllEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteAllEvents_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteAllEvents input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteAllEvents Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteAllEvents Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteAllEvents Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteAllEvents Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteAllEvents_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteAllEvents_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteAllEvents Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteAllEvents execution.
     * @param Google_Calendar_DeleteAllEvents $choreo The choreography object for this execution.
     * @param Google_Calendar_DeleteAllEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteAllEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteAllEvents_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_DeleteAllEvents $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteAllEvents execution.
     *
     * @return Google_Calendar_DeleteAllEvents_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteAllEvents execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_DeleteAllEvents_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_DeleteAllEvents_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteAllEvents_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteAllEvents Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_DeleteAllEvents_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteAllEvents execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteAllEvents execution.
     *
     * @return string No content is returned for delete calendar operations.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Delete a secondary calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteCalendar extends Temboo_Choreography
{
    /**
     * Delete a secondary calendar.
     *
     * @param Temboo_Session $session The session that owns this DeleteCalendar Choreo.
     * @return Google_Calendar_DeleteCalendar New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/DeleteCalendar/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteCalendar Choreo.
     *
     * @param Google_Calendar_DeleteCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteCalendar_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_DeleteCalendar_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteCalendar_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_DeleteCalendar_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteCalendar_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteCalendar_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteCalendar input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteCalendar Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this DeleteCalendar Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar to delete. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteCalendar Choreo.
     *
     * @param string $value (required, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteCalendar Choreo.
     *
     * @param string $value (required, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteCalendar Choreo.
     *
     * @param string $value (required, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteCalendar_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteCalendar_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteCalendar Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteCalendar execution.
     * @param Google_Calendar_DeleteCalendar $choreo The choreography object for this execution.
     * @param Google_Calendar_DeleteCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteCalendar_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_DeleteCalendar $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteCalendar execution.
     *
     * @return Google_Calendar_DeleteCalendar_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteCalendar execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_DeleteCalendar_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_DeleteCalendar_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteCalendar_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteCalendar Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_DeleteCalendar_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteCalendar execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteCalendar execution.
     *
     * @return string No content is returned for delete calendar operations.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Delete a specific event from a specified calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteEvent extends Temboo_Choreography
{
    /**
     * Delete a specific event from a specified calendar.
     *
     * @param Temboo_Session $session The session that owns this DeleteEvent Choreo.
     * @return Google_Calendar_DeleteEvent New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/DeleteEvent/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteEvent Choreo.
     *
     * @param Google_Calendar_DeleteEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteEvent_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_DeleteEvent_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteEvent_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_DeleteEvent_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteEvent_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_DeleteEvent_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteEvent input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteEvent Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this DeleteEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar to delete. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteEvent Choreo.
     *
     * @param string $value (conditional, string) The name of the calendar that you want to retrieve information for. Note that if there are multiple calendars with the same name, only the first one will be returned.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteEvent Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EventID input for this DeleteEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the event to delete.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setEventID($value)
    {
        return $this->set('EventID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteEvent Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_DeleteEvent_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteEvent_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteEvent Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteEvent execution.
     * @param Google_Calendar_DeleteEvent $choreo The choreography object for this execution.
     * @param Google_Calendar_DeleteEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_DeleteEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_DeleteEvent_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_DeleteEvent $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteEvent execution.
     *
     * @return Google_Calendar_DeleteEvent_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteEvent execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_DeleteEvent_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_DeleteEvent_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_DeleteEvent_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteEvent Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_DeleteEvent_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this DeleteEvent execution.
     *
     * @return string (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteEvent execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteEvent execution.
     *
     * @return string No content is returned for delete calendar operations.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for all calendars.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllCalendars extends Temboo_Choreography
{
    /**
     * Retrieve data for all calendars.
     *
     * @param Temboo_Session $session The session that owns this GetAllCalendars Choreo.
     * @return Google_Calendar_GetAllCalendars New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetAllCalendars/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAllCalendars Choreo.
     *
     * @param Google_Calendar_GetAllCalendars_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllCalendars_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllCalendars_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetAllCalendars_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAllCalendars Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllCalendars_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetAllCalendars_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAllCalendars Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllCalendars_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAllCalendars Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllCalendars_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAllCalendars input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAllCalendars Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAllCalendars Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAllCalendars Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Count input for this GetAllCalendars Choreo.
     *
     * @param int $value (optional, integer) The maximum number of calendars to return. The default is 15.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setCount($value)
    {
        return $this->set('Count', $value);
    }

    /**
     * Set the value for the Fields input for this GetAllCalendars Choreo.
     *
     * @param string $value (optional, string) The calendar fields to return. Accepted values are "etag", "items", "kind", and "nextPageToken". All calendar items are returned by default.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Hidden input for this GetAllCalendars Choreo.
     *
     * @param bool $value (optional, boolean) Enter "1" to return hidden calendars in the results, or "0" (the default) to not return them.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setHidden($value)
    {
        return $this->set('Hidden', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAllCalendars Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetAllCalendars Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetAllCalendars_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the GetAllCalendars Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllCalendars_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAllCalendars Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAllCalendars execution.
     * @param Google_Calendar_GetAllCalendars $choreo The choreography object for this execution.
     * @param Google_Calendar_GetAllCalendars_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllCalendars_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllCalendars_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetAllCalendars $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAllCalendars execution.
     *
     * @return Google_Calendar_GetAllCalendars_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAllCalendars execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetAllCalendars_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetAllCalendars_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAllCalendars Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllCalendars_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAllCalendars Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetAllCalendars_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetAllCalendars execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAllCalendars execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for all events in a specified calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllEvents extends Temboo_Choreography
{
    /**
     * Retrieve data for all events in a specified calendar.
     *
     * @param Temboo_Session $session The session that owns this GetAllEvents Choreo.
     * @return Google_Calendar_GetAllEvents New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetAllEvents/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAllEvents Choreo.
     *
     * @param Google_Calendar_GetAllEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllEvents_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetAllEvents_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAllEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllEvents_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetAllEvents_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllEvents_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAllEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllEvents_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAllEvents input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAllEvents Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this GetAllEvents Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar with the events to retrieve. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAllEvents Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAllEvents Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAllEvents Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetAllEvents Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetAllEvents_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the GetAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllEvents_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAllEvents Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAllEvents execution.
     * @param Google_Calendar_GetAllEvents $choreo The choreography object for this execution.
     * @param Google_Calendar_GetAllEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllEvents_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetAllEvents $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAllEvents execution.
     *
     * @return Google_Calendar_GetAllEvents_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAllEvents execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetAllEvents_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetAllEvents_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAllEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllEvents_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAllEvents Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetAllEvents_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetAllEvents execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAllEvents execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves all settings for a Google Calendar account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllSettings extends Temboo_Choreography
{
    /**
     * Retrieves all settings for a Google Calendar account.
     *
     * @param Temboo_Session $session The session that owns this GetAllSettings Choreo.
     * @return Google_Calendar_GetAllSettings New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetAllSettings/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAllSettings Choreo.
     *
     * @param Google_Calendar_GetAllSettings_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllSettings_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllSettings_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetAllSettings_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAllSettings Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllSettings_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetAllSettings_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAllSettings Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllSettings_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAllSettings Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetAllSettings_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAllSettings input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAllSettings Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAllSettings Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAllSettings Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetAllSettings Choreo.
     *
     * @param string $value (optional, string) The settings fields to return. Returns etag, item IDs, and item values by default.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAllSettings Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetAllSettings Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetAllSettings_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the GetAllSettings Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllSettings_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAllSettings Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAllSettings execution.
     * @param Google_Calendar_GetAllSettings $choreo The choreography object for this execution.
     * @param Google_Calendar_GetAllSettings_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetAllSettings_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetAllSettings_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetAllSettings $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAllSettings execution.
     *
     * @return Google_Calendar_GetAllSettings_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAllSettings execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetAllSettings_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetAllSettings_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAllSettings Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetAllSettings_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAllSettings Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetAllSettings_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetAllSettings execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAllSettings execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for a specific calendar in a Google account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetCalendar extends Temboo_Choreography
{
    /**
     * Retrieve data for a specific calendar in a Google account.
     *
     * @param Temboo_Session $session The session that owns this GetCalendar Choreo.
     * @return Google_Calendar_GetCalendar New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetCalendar/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetCalendar Choreo.
     *
     * @param Google_Calendar_GetCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetCalendar_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetCalendar_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetCalendar_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetCalendar_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetCalendar_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetCalendar_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetCalendar input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetCalendar Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this GetCalendar Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar  to retrieve. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this GetCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetCalendar Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetCalendar Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetCalendar_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the GetCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetCalendar_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetCalendar Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetCalendar execution.
     * @param Google_Calendar_GetCalendar $choreo The choreography object for this execution.
     * @param Google_Calendar_GetCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetCalendar_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetCalendar $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetCalendar execution.
     *
     * @return Google_Calendar_GetCalendar_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetCalendar execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetCalendar_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetCalendar_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetCalendar_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetCalendar Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetCalendar_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetCalendar execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetCalendar execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for all calendars in an account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetEvent extends Temboo_Choreography
{
    /**
     * Retrieve data for all calendars in an account.
     *
     * @param Temboo_Session $session The session that owns this GetEvent Choreo.
     * @return Google_Calendar_GetEvent New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetEvent/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetEvent Choreo.
     *
     * @param Google_Calendar_GetEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetEvent_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetEvent_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetEvent_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetEvent_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetEvent_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetEvent_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetEvent input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetEvent Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this GetEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar with the event to retrieve. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this GetEvent Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetEvent Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EventID input for this GetEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the event to retrieve.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setEventID($value)
    {
        return $this->set('EventID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetEvent Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetEvent Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetEvent_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the GetEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetEvent_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetEvent Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetEvent execution.
     * @param Google_Calendar_GetEvent $choreo The choreography object for this execution.
     * @param Google_Calendar_GetEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetEvent_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetEvent $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetEvent execution.
     *
     * @return Google_Calendar_GetEvent_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetEvent execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetEvent_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetEvent_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetEvent_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetEvent Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetEvent_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetEvent execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetEvent execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the next upcoming event in a Google calendar based on the current timestamp and the specified calendar's timezone setting.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetNextEvent extends Temboo_Choreography
{
    /**
     * Retrieves the next upcoming event in a Google calendar based on the current timestamp and the specified calendar's timezone setting.
     *
     * @param Temboo_Session $session The session that owns this GetNextEvent Choreo.
     * @return Google_Calendar_GetNextEvent New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetNextEvent/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetNextEvent Choreo.
     *
     * @param Google_Calendar_GetNextEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetNextEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetNextEvent_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetNextEvent_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetNextEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetNextEvent_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetNextEvent_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetNextEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetNextEvent_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetNextEvent Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetNextEvent_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetNextEvent input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetNextEvent Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this GetNextEvent Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar with the next event to retrieve. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this GetNextEvent Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetNextEvent Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetNextEvent Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetNextEvent Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Timezone input for this GetNextEvent Choreo.
     *
     * @param string $value (optional, string) The time zone used in the response (i.e. America/Los_Angeles). The default is the time zone of the calendar.
     * @return Google_Calendar_GetNextEvent_Inputs For method chaining.
     */
    public function setTimezone($value)
    {
        return $this->set('Timezone', $value);
    }
}


/**
 * Execution object for the GetNextEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetNextEvent_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetNextEvent Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetNextEvent execution.
     * @param Google_Calendar_GetNextEvent $choreo The choreography object for this execution.
     * @param Google_Calendar_GetNextEvent_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetNextEvent_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetNextEvent_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetNextEvent $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetNextEvent execution.
     *
     * @return Google_Calendar_GetNextEvent_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetNextEvent execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetNextEvent_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetNextEvent_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetNextEvent Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetNextEvent_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetNextEvent Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetNextEvent_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "BeginTime" output from this GetNextEvent execution.
     *
     * @return string (date) The start time of the event.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getBeginTime()
    {
        return $this->get('BeginTime');
    }
    /**
     * Retrieve the value for the "EndTime" output from this GetNextEvent execution.
     *
     * @return string (date) The end time of the event.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getEndTime()
    {
        return $this->get('EndTime');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetNextEvent execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Summary" output from this GetNextEvent execution.
     *
     * @return string (string) The event summary.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSummary()
    {
        return $this->get('Summary');
    }
    /**
     * Retrieve the value for the "Response" output from this GetNextEvent execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specifed setting for a Google Calendar account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetSetting extends Temboo_Choreography
{
    /**
     * Retrieves a specifed setting for a Google Calendar account.
     *
     * @param Temboo_Session $session The session that owns this GetSetting Choreo.
     * @return Google_Calendar_GetSetting New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/GetSetting/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetSetting Choreo.
     *
     * @param Google_Calendar_GetSetting_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetSetting_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetSetting_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_GetSetting_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetSetting Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetSetting_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_GetSetting_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetSetting Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetSetting_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetSetting Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_GetSetting_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetSetting input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetSetting Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetSetting Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetSetting Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetSetting Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetSetting Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SettingID input for this GetSetting Choreo.
     *
     * @param string $value (required, string) The unique ID for the setting to retrieve. Use the GetAllSettings Choreo to retrieve settings IDs.
     * @return Google_Calendar_GetSetting_Inputs For method chaining.
     */
    public function setSettingID($value)
    {
        return $this->set('SettingID', $value);
    }
}


/**
 * Execution object for the GetSetting Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetSetting_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetSetting Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetSetting execution.
     * @param Google_Calendar_GetSetting $choreo The choreography object for this execution.
     * @param Google_Calendar_GetSetting_Inputs|array $inputs (optional) Inputs as Google_Calendar_GetSetting_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_GetSetting_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_GetSetting $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetSetting execution.
     *
     * @return Google_Calendar_GetSetting_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetSetting execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_GetSetting_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_GetSetting_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetSetting Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_GetSetting_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetSetting Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_GetSetting_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetSetting execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetSetting execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about a calendar including the id with a given calendar name.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchCalendarsByName extends Temboo_Choreography
{
    /**
     * Retrieves information about a calendar including the id with a given calendar name.
     *
     * @param Temboo_Session $session The session that owns this SearchCalendarsByName Choreo.
     * @return Google_Calendar_SearchCalendarsByName New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/SearchCalendarsByName/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SearchCalendarsByName Choreo.
     *
     * @param Google_Calendar_SearchCalendarsByName_Inputs|array $inputs (optional) Inputs as Google_Calendar_SearchCalendarsByName_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_SearchCalendarsByName_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_SearchCalendarsByName_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SearchCalendarsByName Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_SearchCalendarsByName_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_SearchCalendarsByName_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SearchCalendarsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchCalendarsByName_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SearchCalendarsByName Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_SearchCalendarsByName_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SearchCalendarsByName input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SearchCalendarsByName Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarName input for this SearchCalendarsByName Choreo.
     *
     * @param string $value (required, string) The name of the calendar that you want to retrieve information for. Note that if there are multiple calendars with the same name, only the first one will be returned.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setCalendarName($value)
    {
        return $this->set('CalendarName', $value);
    }

    /**
     * Set the value for the ClientID input for this SearchCalendarsByName Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SearchCalendarsByName Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Count input for this SearchCalendarsByName Choreo.
     *
     * @param int $value (optional, integer) The maximum number of calendars to search by name. The default is 15.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setCount($value)
    {
        return $this->set('Count', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SearchCalendarsByName Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchCalendarsByName_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the SearchCalendarsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchCalendarsByName_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SearchCalendarsByName Choreo.
     *
     * @param Temboo_Session $session The session that owns this SearchCalendarsByName execution.
     * @param Google_Calendar_SearchCalendarsByName $choreo The choreography object for this execution.
     * @param Google_Calendar_SearchCalendarsByName_Inputs|array $inputs (optional) Inputs as Google_Calendar_SearchCalendarsByName_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_SearchCalendarsByName_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_SearchCalendarsByName $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SearchCalendarsByName execution.
     *
     * @return Google_Calendar_SearchCalendarsByName_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SearchCalendarsByName execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_SearchCalendarsByName_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_SearchCalendarsByName_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SearchCalendarsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchCalendarsByName_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SearchCalendarsByName Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_SearchCalendarsByName_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "CalendarDescription" output from this SearchCalendarsByName execution.
     *
     * @return string (string) The calendar description parsed from the Google response.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCalendarDescription()
    {
        return $this->get('CalendarDescription');
    }
    /**
     * Retrieve the value for the "CalendarId" output from this SearchCalendarsByName execution.
     *
     * @return string (string) The calendar id parsed from the Google response.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCalendarId()
    {
        return $this->get('CalendarId');
    }
    /**
     * Retrieve the value for the "CalendarSummary" output from this SearchCalendarsByName execution.
     *
     * @return string (string) The summary or calendar name parsed from the Google response.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCalendarSummary()
    {
        return $this->get('CalendarSummary');
    }
    /**
     * Retrieve the value for the "CalendarTimezone" output from this SearchCalendarsByName execution.
     *
     * @return string (string) The calendar timezone parsed from the Google response.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCalendarTimezone()
    {
        return $this->get('CalendarTimezone');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SearchCalendarsByName execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Allows you to search for events using a variety of search parameters.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchEvents extends Temboo_Choreography
{
    /**
     * Allows you to search for events using a variety of search parameters.
     *
     * @param Temboo_Session $session The session that owns this SearchEvents Choreo.
     * @return Google_Calendar_SearchEvents New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/SearchEvents/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SearchEvents Choreo.
     *
     * @param Google_Calendar_SearchEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_SearchEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_SearchEvents_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_SearchEvents_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SearchEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_SearchEvents_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_SearchEvents_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SearchEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchEvents_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SearchEvents Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_SearchEvents_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SearchEvents input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SearchEvents Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this SearchEvents Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar with the events to search. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this SearchEvents Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SearchEvents Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the LastModified input for this SearchEvents Choreo.
     *
     * @param string $value (optional, date) An event's last modification time (as a RFC 3339 timestamp) to filter by.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setLastModified($value)
    {
        return $this->set('LastModified', $value);
    }

    /**
     * Set the value for the MaxAttendees input for this SearchEvents Choreo.
     *
     * @param int $value (optional, integer) The maximum number of attendees to include in the response. If there are more than the specified number of attendees, only the participant is returned.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setMaxAttendees($value)
    {
        return $this->set('MaxAttendees', $value);
    }

    /**
     * Set the value for the MaxResults input for this SearchEvents Choreo.
     *
     * @param int $value (optional, integer) The maximum number of events to return on one result page.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the MaxTime input for this SearchEvents Choreo.
     *
     * @param string $value (optional, date) The max start time to filter by (formatted like 2012-05-22T00:47:43.000Z).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setMaxTime($value)
    {
        return $this->set('MaxTime', $value);
    }

    /**
     * Set the value for the MinTime input for this SearchEvents Choreo.
     *
     * @param string $value (optional, date) The minimum start time to filter by (formatted like 2012-05-22T00:47:43.000Z).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setMinTime($value)
    {
        return $this->set('MinTime', $value);
    }

    /**
     * Set the value for the OrderBy input for this SearchEvents Choreo.
     *
     * @param string $value (optional, string) The order of the events returned in the result. Accepted values are: "startTime" (ordered by start date/time. Must set SingleEvents to 1 to use this) or "updated" (ordered by modification date/time).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this SearchEvents Choreo.
     *
     * @param int $value (optional, integer) Indicates which result page to return. Used for paging through results.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this SearchEvents Choreo.
     *
     * @param string $value (optional, string) A keyword search to find events.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SearchEvents Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this SearchEvents Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the ShowDeleted input for this SearchEvents Choreo.
     *
     * @param bool $value (optional, boolean) Whether to include deleted events. Set to 1 (true) to include deleted events. Defaults to 0 (false).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setShowDeleted($value)
    {
        return $this->set('ShowDeleted', $value);
    }

    /**
     * Set the value for the ShowHiddenInvitations input for this SearchEvents Choreo.
     *
     * @param bool $value (optional, boolean) Whether to include hidden invitations in the result. Set to 1 (true) to enable. The default is 0 (false).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setShowHiddenInvitations($value)
    {
        return $this->set('ShowHiddenInvitations', $value);
    }

    /**
     * Set the value for the SingleEvent input for this SearchEvents Choreo.
     *
     * @param bool $value (optional, boolean) Whether to expand recurring events into instances and only return single one-off events and instances of recurring events. Defaults to 0 (false).
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setSingleEvent($value)
    {
        return $this->set('SingleEvent', $value);
    }

    /**
     * Set the value for the Timezone input for this SearchEvents Choreo.
     *
     * @param string $value (optional, string) The time zone used in the response (i.e. America/Los_Angeles). The default is the time zone of the calendar.
     * @return Google_Calendar_SearchEvents_Inputs For method chaining.
     */
    public function setTimezone($value)
    {
        return $this->set('Timezone', $value);
    }
}


/**
 * Execution object for the SearchEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchEvents_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SearchEvents Choreo.
     *
     * @param Temboo_Session $session The session that owns this SearchEvents execution.
     * @param Google_Calendar_SearchEvents $choreo The choreography object for this execution.
     * @param Google_Calendar_SearchEvents_Inputs|array $inputs (optional) Inputs as Google_Calendar_SearchEvents_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_SearchEvents_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_SearchEvents $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SearchEvents execution.
     *
     * @return Google_Calendar_SearchEvents_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SearchEvents execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_SearchEvents_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_SearchEvents_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SearchEvents Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_SearchEvents_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SearchEvents Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_SearchEvents_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SearchEvents execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SearchEvents execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates the metadata for a calendar.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_UpdateCalendar extends Temboo_Choreography
{
    /**
     * Updates the metadata for a calendar.
     *
     * @param Temboo_Session $session The session that owns this UpdateCalendar Choreo.
     * @return Google_Calendar_UpdateCalendar New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Calendar/UpdateCalendar/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateCalendar Choreo.
     *
     * @param Google_Calendar_UpdateCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_UpdateCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_UpdateCalendar_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Calendar_UpdateCalendar_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_UpdateCalendar_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Calendar_UpdateCalendar_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_UpdateCalendar_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateCalendar Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Calendar_UpdateCalendar_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateCalendar input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateCalendar Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CalendarID input for this UpdateCalendar Choreo.
     *
     * @param string $value (required, string) The unique ID for the calendar to update. Note that calendar IDs can be retrieved by running GetAllCalendars or SearchCalendarsByName.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setCalendarID($value)
    {
        return $this->set('CalendarID', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateCalendar Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the NewDescription input for this UpdateCalendar Choreo.
     *
     * @param string $value (optional, string) The new description for the calendar to update.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setNewDescription($value)
    {
        return $this->set('NewDescription', $value);
    }

    /**
     * Set the value for the NewLocation input for this UpdateCalendar Choreo.
     *
     * @param string $value (optional, string) The new location for the calendar to update.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setNewLocation($value)
    {
        return $this->set('NewLocation', $value);
    }

    /**
     * Set the value for the NewSummary input for this UpdateCalendar Choreo.
     *
     * @param string $value (required, string) The new summary for the calendar to update.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setNewSummary($value)
    {
        return $this->set('NewSummary', $value);
    }

    /**
     * Set the value for the NewTimezone input for this UpdateCalendar Choreo.
     *
     * @param string $value (optional, string) The new timezone for the calendar to update.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setNewTimezone($value)
    {
        return $this->set('NewTimezone', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateCalendar Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UpdateCalendar Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Calendar_UpdateCalendar_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }
}


/**
 * Execution object for the UpdateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_UpdateCalendar_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateCalendar Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateCalendar execution.
     * @param Google_Calendar_UpdateCalendar $choreo The choreography object for this execution.
     * @param Google_Calendar_UpdateCalendar_Inputs|array $inputs (optional) Inputs as Google_Calendar_UpdateCalendar_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Calendar_UpdateCalendar_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Calendar_UpdateCalendar $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateCalendar execution.
     *
     * @return Google_Calendar_UpdateCalendar_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateCalendar execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Calendar_UpdateCalendar_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Calendar_UpdateCalendar_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateCalendar Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Calendar_UpdateCalendar_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateCalendar Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Calendar_UpdateCalendar_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateCalendar execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateCalendar execution.
     *
     * @return string The response from Google. Corresponds to the ResponseFormat input. Defaults to JSON.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of Address resources across all available regions.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_AggregatedList extends Temboo_Choreography
{
    /**
     * Retrieves a list of Address resources across all available regions.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList Choreo.
     * @return Google_ComputeEngine_Addresses_AggregatedList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Addresses/AggregatedList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AggregatedList Choreo.
     *
     * @param Google_ComputeEngine_Addresses_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Addresses_AggregatedList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Addresses_AggregatedList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_AggregatedList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AggregatedList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq your-address-name). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this AggregatedList Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this AggregatedList Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_AggregatedList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AggregatedList Choreo.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList execution.
     * @param Google_ComputeEngine_Addresses_AggregatedList $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Addresses_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Addresses_AggregatedList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AggregatedList execution.
     *
     * @return Google_ComputeEngine_Addresses_AggregatedList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AggregatedList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Addresses_AggregatedList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_AggregatedList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AggregatedList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_AggregatedList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AggregatedList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AggregatedList execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specified address resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_DeleteAddress extends Temboo_Choreography
{
    /**
     * Deletes a specified address resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteAddress Choreo.
     * @return Google_ComputeEngine_Addresses_DeleteAddress New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Addresses/DeleteAddress/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteAddress Choreo.
     *
     * @param Google_ComputeEngine_Addresses_DeleteAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_DeleteAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Addresses_DeleteAddress_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Addresses_DeleteAddress_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_DeleteAddress_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteAddress input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteAddress Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Address input for this DeleteAddress Choreo.
     *
     * @param string $value (required, string) The name of the address to delete.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setAddress($value)
    {
        return $this->set('Address', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteAddress Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteAddress Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteAddress Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this DeleteAddress Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteAddress Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this DeleteAddress Choreo.
     *
     * @param string $value (required, string) The name of the region associated with this request.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the DeleteAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_DeleteAddress_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteAddress Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteAddress execution.
     * @param Google_ComputeEngine_Addresses_DeleteAddress $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Addresses_DeleteAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_DeleteAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Addresses_DeleteAddress $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteAddress execution.
     *
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteAddress execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Addresses_DeleteAddress_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_DeleteAddress_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteAddress Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_DeleteAddress_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteAddress execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteAddress execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Address.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_GetAddress extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Address.
     *
     * @param Temboo_Session $session The session that owns this GetAddress Choreo.
     * @return Google_ComputeEngine_Addresses_GetAddress New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Addresses/GetAddress/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAddress Choreo.
     *
     * @param Google_ComputeEngine_Addresses_GetAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_GetAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_GetAddress_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Addresses_GetAddress_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Addresses_GetAddress_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_GetAddress_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAddress input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAddress Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Address input for this GetAddress Choreo.
     *
     * @param string $value (required, string) The name of the address to retrieve.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setAddress($value)
    {
        return $this->set('Address', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAddress Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAddress Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetAddress Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetAddress Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAddress Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this GetAddress Choreo.
     *
     * @param string $value (required, string) The name of the region associated with this request.
     * @return Google_ComputeEngine_Addresses_GetAddress_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the GetAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_GetAddress_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAddress Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAddress execution.
     * @param Google_ComputeEngine_Addresses_GetAddress $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Addresses_GetAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_GetAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_GetAddress_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Addresses_GetAddress $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAddress execution.
     *
     * @return Google_ComputeEngine_Addresses_GetAddress_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAddress execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_GetAddress_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Addresses_GetAddress_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_GetAddress_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAddress Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_GetAddress_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetAddress execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAddress execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates an Address resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_InsertAddress extends Temboo_Choreography
{
    /**
     * Creates an Address resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertAddress Choreo.
     * @return Google_ComputeEngine_Addresses_InsertAddress New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Addresses/InsertAddress/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertAddress Choreo.
     *
     * @param Google_ComputeEngine_Addresses_InsertAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_InsertAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Addresses_InsertAddress_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Addresses_InsertAddress_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_InsertAddress_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertAddress input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AddressResource input for this InsertAddress Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the address resource properties you wish to set. This can be used as an alternative to individual inputs that represent address resource properties.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setAddressResource($value)
    {
        return $this->set('AddressResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertAddress Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Address input for this InsertAddress Choreo.
     *
     * @param string $value (optional, string) The IP address represented by this resource.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setAddress($value)
    {
        return $this->set('Address', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertAddress Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertAddress Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this InsertAddress Choreo.
     *
     * @param string $value (optional, string) A description of the address.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Name input for this InsertAddress Choreo.
     *
     * @param string $value (conditional, string) The name of the address resource.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Project input for this InsertAddress Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertAddress Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this InsertAddress Choreo.
     *
     * @param string $value (required, string) Name of the region associated with the request.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the InsertAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_InsertAddress_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertAddress Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertAddress execution.
     * @param Google_ComputeEngine_Addresses_InsertAddress $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Addresses_InsertAddress_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_InsertAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Addresses_InsertAddress $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertAddress execution.
     *
     * @return Google_ComputeEngine_Addresses_InsertAddress_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertAddress execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Addresses_InsertAddress_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_InsertAddress_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertAddress Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_InsertAddress_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertAddress execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertAddress execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of Address resources contained within the specified region
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_ListAddresses extends Temboo_Choreography
{
    /**
     * Retrieves a list of Address resources contained within the specified region
     *
     * @param Temboo_Session $session The session that owns this ListAddresses Choreo.
     * @return Google_ComputeEngine_Addresses_ListAddresses New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Addresses/ListAddresses/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListAddresses Choreo.
     *
     * @param Google_ComputeEngine_Addresses_ListAddresses_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_ListAddresses_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Addresses_ListAddresses_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListAddresses Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Addresses_ListAddresses_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListAddresses Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_ListAddresses_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListAddresses Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListAddresses input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListAddresses Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListAddresses Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListAddresses Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListAddresses Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListAddresses Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq your-address-name). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListAddresses Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListAddresses Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListAddresses Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListAddresses Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this ListAddresses Choreo.
     *
     * @param string $value (required, string) The name of the region associated with this request.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the ListAddresses Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_ListAddresses_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListAddresses Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListAddresses execution.
     * @param Google_ComputeEngine_Addresses_ListAddresses $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Addresses_ListAddresses_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Addresses_ListAddresses_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Addresses_ListAddresses $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListAddresses execution.
     *
     * @return Google_ComputeEngine_Addresses_ListAddresses_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListAddresses execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Addresses_ListAddresses_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListAddresses Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Addresses_ListAddresses_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListAddresses Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Addresses_ListAddresses_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListAddresses execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListAddresses execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves an aggregated list of Disk resources across all zones.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_AggregatedList extends Temboo_Choreography
{
    /**
     * Retrieves an aggregated list of Disk resources across all zones.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList Choreo.
     * @return Google_ComputeEngine_Disks_AggregatedList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/AggregatedList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AggregatedList Choreo.
     *
     * @param Google_ComputeEngine_Disks_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_AggregatedList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_AggregatedList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_AggregatedList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_AggregatedList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AggregatedList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq your-disk-name). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this AggregatedList Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this AggregatedList Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_AggregatedList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_AggregatedList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AggregatedList Choreo.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList execution.
     * @param Google_ComputeEngine_Disks_AggregatedList $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_AggregatedList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_AggregatedList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AggregatedList execution.
     *
     * @return Google_ComputeEngine_Disks_AggregatedList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AggregatedList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_AggregatedList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_AggregatedList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_AggregatedList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AggregatedList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_AggregatedList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AggregatedList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AggregatedList execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a snapshot of a specified disk.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_CreateSnapshot extends Temboo_Choreography
{
    /**
     * Creates a snapshot of a specified disk.
     *
     * @param Temboo_Session $session The session that owns this CreateSnapshot Choreo.
     * @return Google_ComputeEngine_Disks_CreateSnapshot New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/CreateSnapshot/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateSnapshot Choreo.
     *
     * @param Google_ComputeEngine_Disks_CreateSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_CreateSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_CreateSnapshot_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_CreateSnapshot_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_CreateSnapshot_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateSnapshot input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateSnapshot Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this CreateSnapshot Choreo.
     *
     * @param string $value (optional, string) A description for the snapshot resource.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Disk input for this CreateSnapshot Choreo.
     *
     * @param string $value (required, string) The name of the persistent disk resource to use to create this snapshot.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setDisk($value)
    {
        return $this->set('Disk', $value);
    }

    /**
     * Set the value for the Name input for this CreateSnapshot Choreo.
     *
     * @param string $value (required, string) The name of the snapshot resource being created.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Project input for this CreateSnapshot Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateSnapshot Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SourceDiskID input for this CreateSnapshot Choreo.
     *
     * @param string $value (required, string) The ID of the disk being used to create the snapshot.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setSourceDiskID($value)
    {
        return $this->set('SourceDiskID', $value);
    }

    /**
     * Set the value for the StorageBytes input for this CreateSnapshot Choreo.
     *
     * @param int $value (optional, integer) The size of the storage used by the snapshot.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setStorageBytes($value)
    {
        return $this->set('StorageBytes', $value);
    }

    /**
     * Set the value for the StorageBytesStatus input for this CreateSnapshot Choreo.
     *
     * @param string $value (optional, string) Indicates whether storageBytes is in a stable state, or it is being adjusted as a result of shared storage reallocation. Valid values: are "UPDATING" AND "UP_TO_DATE".
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setStorageBytesStatus($value)
    {
        return $this->set('StorageBytesStatus', $value);
    }

    /**
     * Set the value for the Zone input for this CreateSnapshot Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the CreateSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_CreateSnapshot_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateSnapshot Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateSnapshot execution.
     * @param Google_ComputeEngine_Disks_CreateSnapshot $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_CreateSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_CreateSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_CreateSnapshot $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateSnapshot execution.
     *
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateSnapshot execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_CreateSnapshot_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_CreateSnapshot_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateSnapshot Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_CreateSnapshot_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateSnapshot execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateSnapshot execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Persistent Disk resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_DeleteDisk extends Temboo_Choreography
{
    /**
     * Deletes the specified Persistent Disk resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteDisk Choreo.
     * @return Google_ComputeEngine_Disks_DeleteDisk New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/DeleteDisk/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteDisk Choreo.
     *
     * @param Google_ComputeEngine_Disks_DeleteDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_DeleteDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_DeleteDisk_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_DeleteDisk_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_DeleteDisk_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteDisk input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteDisk Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteDisk Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteDisk Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Disk input for this DeleteDisk Choreo.
     *
     * @param string $value (required, string) The name of the persistent disk resource to delete.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setDisk($value)
    {
        return $this->set('Disk', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteDisk Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this DeleteDisk Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteDisk Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this DeleteDisk Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the DeleteDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_DeleteDisk_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteDisk Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteDisk execution.
     * @param Google_ComputeEngine_Disks_DeleteDisk $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_DeleteDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_DeleteDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_DeleteDisk $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteDisk execution.
     *
     * @return Google_ComputeEngine_Disks_DeleteDisk_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteDisk execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_DeleteDisk_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_DeleteDisk_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteDisk Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_DeleteDisk_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteDisk execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteDisk execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Persistent Disk.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_GetDisk extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Persistent Disk.
     *
     * @param Temboo_Session $session The session that owns this GetDisk Choreo.
     * @return Google_ComputeEngine_Disks_GetDisk New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/GetDisk/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetDisk Choreo.
     *
     * @param Google_ComputeEngine_Disks_GetDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_GetDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_GetDisk_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_GetDisk_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_GetDisk_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_GetDisk_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetDisk input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetDisk Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetDisk Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetDisk Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Disk input for this GetDisk Choreo.
     *
     * @param string $value (required, string) The name of the persistent disk resource to retrieve.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setDisk($value)
    {
        return $this->set('Disk', $value);
    }

    /**
     * Set the value for the Fields input for this GetDisk Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetDisk Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetDisk Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetDisk Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Disks_GetDisk_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_GetDisk_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetDisk Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetDisk execution.
     * @param Google_ComputeEngine_Disks_GetDisk $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_GetDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_GetDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_GetDisk_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_GetDisk $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetDisk execution.
     *
     * @return Google_ComputeEngine_Disks_GetDisk_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetDisk execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_GetDisk_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_GetDisk_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_GetDisk_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetDisk Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_GetDisk_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetDisk execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetDisk execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a Persistent Disk resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_InsertDisk extends Temboo_Choreography
{
    /**
     * Creates a Persistent Disk resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertDisk Choreo.
     * @return Google_ComputeEngine_Disks_InsertDisk New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/InsertDisk/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertDisk Choreo.
     *
     * @param Google_ComputeEngine_Disks_InsertDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_InsertDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_InsertDisk_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_InsertDisk_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_InsertDisk_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_InsertDisk_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertDisk input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the DiskResource input for this InsertDisk Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the disk resource properties you wish to set. This can be used as an alternative to individual inputs that represent disk properties.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setDiskResource($value)
    {
        return $this->set('DiskResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertDisk Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Name input for this InsertDisk Choreo.
     *
     * @param string $value (required, string) The name of the persistent disk resource being created.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Project input for this InsertDisk Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SizeGB input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) Size of the persistent disk, specified in GB. This is optional when using a SourceSnapshot or SourceImage, otherwise it is required.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setSizeGB($value)
    {
        return $this->set('SizeGB', $value);
    }

    /**
     * Set the value for the SourceImage input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) The URL for the source image to apply to the disk. This is required if SizeGB or SourceSnapshot is not provided.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setSourceImage($value)
    {
        return $this->set('SourceImage', $value);
    }

    /**
     * Set the value for the SourceSnapshot input for this InsertDisk Choreo.
     *
     * @param string $value (conditional, string) The source snapshot used to create this disk. This is required if SizeGB and SourceImage are not specified.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setSourceSnapshot($value)
    {
        return $this->set('SourceSnapshot', $value);
    }

    /**
     * Set the value for the Zone input for this InsertDisk Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Disks_InsertDisk_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the InsertDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_InsertDisk_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertDisk Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertDisk execution.
     * @param Google_ComputeEngine_Disks_InsertDisk $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_InsertDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_InsertDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_InsertDisk_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_InsertDisk $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertDisk execution.
     *
     * @return Google_ComputeEngine_Disks_InsertDisk_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertDisk execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_InsertDisk_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_InsertDisk_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_InsertDisk_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertDisk Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_InsertDisk_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertDisk execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertDisk execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Disk resources available to the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_ListDisks extends Temboo_Choreography
{
    /**
     * Retrieves the list of Disk resources available to the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListDisks Choreo.
     * @return Google_ComputeEngine_Disks_ListDisks New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Disks/ListDisks/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListDisks Choreo.
     *
     * @param Google_ComputeEngine_Disks_ListDisks_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_ListDisks_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_ListDisks_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Disks_ListDisks_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListDisks Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Disks_ListDisks_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListDisks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_ListDisks_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListDisks Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListDisks input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListDisks Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListDisks Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListDisks Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListDisks Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListDisks Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq europe-west1). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListDisks Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListDisks Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListDisks Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListDisks Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this ListDisks Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Disks_ListDisks_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the ListDisks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_ListDisks_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListDisks Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListDisks execution.
     * @param Google_ComputeEngine_Disks_ListDisks $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Disks_ListDisks_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Disks_ListDisks_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Disks_ListDisks_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Disks_ListDisks $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListDisks execution.
     *
     * @return Google_ComputeEngine_Disks_ListDisks_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListDisks execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_ListDisks_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Disks_ListDisks_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListDisks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Disks_ListDisks_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListDisks Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Disks_ListDisks_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListDisks execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListDisks execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Firewall resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_DeleteFirewall extends Temboo_Choreography
{
    /**
     * Deletes the specified Firewall resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteFirewall Choreo.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Firewalls/DeleteFirewall/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteFirewall Choreo.
     *
     * @param Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Firewalls_DeleteFirewall_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteFirewall input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteFirewall Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteFirewall Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Firewall input for this DeleteFirewall Choreo.
     *
     * @param string $value (required, string) The name of the firewall to delete.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setFirewall($value)
    {
        return $this->set('Firewall', $value);
    }

    /**
     * Set the value for the Project input for this DeleteFirewall Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteFirewall Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_DeleteFirewall_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteFirewall Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteFirewall execution.
     * @param Google_ComputeEngine_Firewalls_DeleteFirewall $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_DeleteFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Firewalls_DeleteFirewall $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteFirewall execution.
     *
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteFirewall execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Firewalls_DeleteFirewall_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_DeleteFirewall_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteFirewall Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_DeleteFirewall_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteFirewall execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteFirewall execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Firewall.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_GetFirewall extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Firewall.
     *
     * @param Temboo_Session $session The session that owns this GetFirewall Choreo.
     * @return Google_ComputeEngine_Firewalls_GetFirewall New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Firewalls/GetFirewall/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetFirewall Choreo.
     *
     * @param Google_ComputeEngine_Firewalls_GetFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_GetFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Firewalls_GetFirewall_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Firewalls_GetFirewall_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_GetFirewall_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetFirewall input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetFirewall Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetFirewall Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Firewall input for this GetFirewall Choreo.
     *
     * @param string $value (required, string) The name of the firewall to retrieve.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setFirewall($value)
    {
        return $this->set('Firewall', $value);
    }

    /**
     * Set the value for the Project input for this GetFirewall Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetFirewall Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the GetFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_GetFirewall_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetFirewall Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetFirewall execution.
     * @param Google_ComputeEngine_Firewalls_GetFirewall $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Firewalls_GetFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_GetFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Firewalls_GetFirewall $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetFirewall execution.
     *
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetFirewall execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Firewalls_GetFirewall_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_GetFirewall_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetFirewall Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_GetFirewall_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetFirewall execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetFirewall execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a Firewall resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_InsertFirewall extends Temboo_Choreography
{
    /**
     * Creates a Firewall resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertFirewall Choreo.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Firewalls/InsertFirewall/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertFirewall Choreo.
     *
     * @param Google_ComputeEngine_Firewalls_InsertFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_InsertFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Firewalls_InsertFirewall_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Firewalls_InsertFirewall_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_InsertFirewall_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertFirewall input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the FirewallResource input for this InsertFirewall Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the firewall resource properties to set. This can be used as an alternative to individual inputs representing firewall properties.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setFirewallResource($value)
    {
        return $this->set('FirewallResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertFirewall Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AllowedIPProtocol input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, json) The IP protocol that is allowed for this rule. This is an array and can have the following properties: IPProtocol (valid values are: tcp, udp, or icmp) and ports[].
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setAllowedIPProtocol($value)
    {
        return $this->set('AllowedIPProtocol', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this InsertFirewall Choreo.
     *
     * @param string $value (optional, string) A description of the firewall.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Name input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, string) The name of the firewall resource being created.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Network input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, string) The fully-qualified URL of the network to which this firewall is applied.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setNetwork($value)
    {
        return $this->set('Network', $value);
    }

    /**
     * Set the value for the Project input for this InsertFirewall Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SourceRanges input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, json) An array of address blocks that this rule applies to. This is required if the SourceTags input is not provided.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setSourceRanges($value)
    {
        return $this->set('SourceRanges', $value);
    }

    /**
     * Set the value for the SourceTags input for this InsertFirewall Choreo.
     *
     * @param string $value (conditional, json) An array of instance tags which this rule applies to. This is required unless the SourceRanges input is provided.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Inputs For method chaining.
     */
    public function setSourceTags($value)
    {
        return $this->set('SourceTags', $value);
    }
}


/**
 * Execution object for the InsertFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_InsertFirewall_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertFirewall Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertFirewall execution.
     * @param Google_ComputeEngine_Firewalls_InsertFirewall $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Firewalls_InsertFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_InsertFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Firewalls_InsertFirewall $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertFirewall execution.
     *
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertFirewall execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Firewalls_InsertFirewall_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_InsertFirewall_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertFirewall Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_InsertFirewall_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertFirewall execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertFirewall execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Firewall resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_ListFirewalls extends Temboo_Choreography
{
    /**
     * Retrieves the list of Firewall resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListFirewalls Choreo.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Firewalls/ListFirewalls/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListFirewalls Choreo.
     *
     * @param Google_ComputeEngine_Firewalls_ListFirewalls_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_ListFirewalls_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Firewalls_ListFirewalls_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListFirewalls Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Firewalls_ListFirewalls_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListFirewalls Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_ListFirewalls_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListFirewalls Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListFirewalls input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListFirewalls Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListFirewalls Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListFirewalls Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListFirewalls Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListFirewalls Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq default-ssh). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListFirewalls Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListFirewalls Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListFirewalls Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListFirewalls Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListFirewalls Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_ListFirewalls_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListFirewalls Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListFirewalls execution.
     * @param Google_ComputeEngine_Firewalls_ListFirewalls $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Firewalls_ListFirewalls_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_ListFirewalls_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Firewalls_ListFirewalls $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListFirewalls execution.
     *
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListFirewalls execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Firewalls_ListFirewalls_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListFirewalls Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_ListFirewalls_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListFirewalls Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_ListFirewalls_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListFirewalls execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListFirewalls execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates an existing Firewall resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_UpdateFirewall extends Temboo_Choreography
{
    /**
     * Updates an existing Firewall resource.
     *
     * @param Temboo_Session $session The session that owns this UpdateFirewall Choreo.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Firewalls/UpdateFirewall/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateFirewall Choreo.
     *
     * @param Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Firewalls_UpdateFirewall_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateFirewall Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateFirewall input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the FirewallResource input for this UpdateFirewall Choreo.
     *
     * @param string $value (required, json) A JSON string containing the firewall resource fields to set. Required properties include: allowed, name, network, and either sourceRanges or sourceTags.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setFirewallResource($value)
    {
        return $this->set('FirewallResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this UpdateFirewall Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateFirewall Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Firewall input for this UpdateFirewall Choreo.
     *
     * @param string $value (required, string) The name of the firewall to update.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setFirewall($value)
    {
        return $this->set('Firewall', $value);
    }

    /**
     * Set the value for the Project input for this UpdateFirewall Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateFirewall Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the UpdateFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_UpdateFirewall_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateFirewall Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateFirewall execution.
     * @param Google_ComputeEngine_Firewalls_UpdateFirewall $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Firewalls_UpdateFirewall_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Firewalls_UpdateFirewall $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateFirewall execution.
     *
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateFirewall execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Firewalls_UpdateFirewall_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateFirewall Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Firewalls_UpdateFirewall_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateFirewall Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Firewalls_UpdateFirewall_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateFirewall execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateFirewall execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of all Global Operation resources grouped by scope.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_AggregatedList extends Temboo_Choreography
{
    /**
     * Retrieves a list of all Global Operation resources grouped by scope.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList Choreo.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/GlobalOperations/AggregatedList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AggregatedList Choreo.
     *
     * @param Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_GlobalOperations_AggregatedList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AggregatedList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq operation-1234). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this AggregatedList Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this AggregatedList Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_AggregatedList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AggregatedList Choreo.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList execution.
     * @param Google_ComputeEngine_GlobalOperations_AggregatedList $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_GlobalOperations_AggregatedList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AggregatedList execution.
     *
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AggregatedList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_GlobalOperations_AggregatedList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_AggregatedList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AggregatedList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_AggregatedList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AggregatedList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AggregatedList execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Global Operation.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation extends Temboo_Choreography
{
    /**
     * Deletes the specified Global Operation.
     *
     * @param Temboo_Session $session The session that owns this DeleteGlobalOperation Choreo.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/GlobalOperations/DeleteGlobalOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteGlobalOperation Choreo.
     *
     * @param Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteGlobalOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteGlobalOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteGlobalOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Operation input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to delete.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteGlobalOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteGlobalOperation execution.
     * @param Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteGlobalOperation execution.
     *
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteGlobalOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteGlobalOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_DeleteGlobalOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteGlobalOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteGlobalOperation execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteGlobalOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Global Operation.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_GetGlobalOperation extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Global Operation.
     *
     * @param Temboo_Session $session The session that owns this GetGlobalOperation Choreo.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/GlobalOperations/GetGlobalOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetGlobalOperation Choreo.
     *
     * @param Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetGlobalOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetGlobalOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetGlobalOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetGlobalOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetGlobalOperation Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Operation input for this GetGlobalOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to retrieve.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this GetGlobalOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetGlobalOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the GetGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetGlobalOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetGlobalOperation execution.
     * @param Google_ComputeEngine_GlobalOperations_GetGlobalOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_GlobalOperations_GetGlobalOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetGlobalOperation execution.
     *
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetGlobalOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetGlobalOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetGlobalOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_GetGlobalOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetGlobalOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetGlobalOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of GlobalOperations resources contained within the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_ListGlobalOperations extends Temboo_Choreography
{
    /**
     * Retrieves a list of GlobalOperations resources contained within the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListGlobalOperations Choreo.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/GlobalOperations/ListGlobalOperations/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListGlobalOperations Choreo.
     *
     * @param Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListGlobalOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListGlobalOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListGlobalOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListGlobalOperations input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListGlobalOperations Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListGlobalOperations Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListGlobalOperations Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListGlobalOperations Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListGlobalOperations Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq operation-1234). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListGlobalOperations Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListGlobalOperations Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListGlobalOperations Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListGlobalOperations Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListGlobalOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListGlobalOperations Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListGlobalOperations execution.
     * @param Google_ComputeEngine_GlobalOperations_ListGlobalOperations $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_GlobalOperations_ListGlobalOperations $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListGlobalOperations execution.
     *
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListGlobalOperations execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListGlobalOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListGlobalOperations Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_GlobalOperations_ListGlobalOperations_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListGlobalOperations execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListGlobalOperations execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Image resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_DeleteImage extends Temboo_Choreography
{
    /**
     * Deletes the specified Image resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteImage Choreo.
     * @return Google_ComputeEngine_Images_DeleteImage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Images/DeleteImage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteImage Choreo.
     *
     * @param Google_ComputeEngine_Images_DeleteImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_DeleteImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_DeleteImage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Images_DeleteImage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Images_DeleteImage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_DeleteImage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteImage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteImage Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteImage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteImage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteImage Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Image input for this DeleteImage Choreo.
     *
     * @param string $value (required, string) The name of the Image to delete.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setImage($value)
    {
        return $this->set('Image', $value);
    }

    /**
     * Set the value for the Project input for this DeleteImage Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteImage Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_DeleteImage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_DeleteImage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteImage Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteImage execution.
     * @param Google_ComputeEngine_Images_DeleteImage $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Images_DeleteImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_DeleteImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_DeleteImage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Images_DeleteImage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteImage execution.
     *
     * @return Google_ComputeEngine_Images_DeleteImage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteImage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Images_DeleteImage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Images_DeleteImage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_DeleteImage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteImage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Images_DeleteImage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteImage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteImage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Image.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_GetImage extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Image.
     *
     * @param Temboo_Session $session The session that owns this GetImage Choreo.
     * @return Google_ComputeEngine_Images_GetImage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Images/GetImage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetImage Choreo.
     *
     * @param Google_ComputeEngine_Images_GetImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_GetImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_GetImage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Images_GetImage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_GetImage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Images_GetImage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_GetImage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_GetImage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetImage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetImage Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetImage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetImage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetImage Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Image input for this GetImage Choreo.
     *
     * @param string $value (required, string) The name of the Image to retrieve.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setImage($value)
    {
        return $this->set('Image', $value);
    }

    /**
     * Set the value for the Project input for this GetImage Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetImage Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_GetImage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the GetImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_GetImage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetImage Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetImage execution.
     * @param Google_ComputeEngine_Images_GetImage $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Images_GetImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_GetImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_GetImage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Images_GetImage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetImage execution.
     *
     * @return Google_ComputeEngine_Images_GetImage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetImage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Images_GetImage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Images_GetImage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_GetImage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetImage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Images_GetImage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetImage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetImage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new custom Image resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_InsertImage extends Temboo_Choreography
{
    /**
     * Creates a new custom Image resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertImage Choreo.
     * @return Google_ComputeEngine_Images_InsertImage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Images/InsertImage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertImage Choreo.
     *
     * @param Google_ComputeEngine_Images_InsertImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_InsertImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_InsertImage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Images_InsertImage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Images_InsertImage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_InsertImage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertImage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertImage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the ImageResource input for this InsertImage Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the image resource properties to set. This can used as an alternative to individual inputs representing image properties.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setImageResource($value)
    {
        return $this->set('ImageResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertImage Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertImage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertImage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this InsertImage Choreo.
     *
     * @param string $value (optional, string) A description of the image.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Name input for this InsertImage Choreo.
     *
     * @param string $value (conditional, string) The name of the image.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Project input for this InsertImage Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RawDiskSource input for this InsertImage Choreo.
     *
     * @param string $value (conditional, string) The full Google Cloud Storage URL where the disk image is stored.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setRawDiskSource($value)
    {
        return $this->set('RawDiskSource', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertImage Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_InsertImage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the InsertImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_InsertImage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertImage Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertImage execution.
     * @param Google_ComputeEngine_Images_InsertImage $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Images_InsertImage_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_InsertImage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_InsertImage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Images_InsertImage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertImage execution.
     *
     * @return Google_ComputeEngine_Images_InsertImage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertImage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Images_InsertImage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Images_InsertImage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertImage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_InsertImage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertImage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Images_InsertImage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertImage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertImage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of Image resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_ListImages extends Temboo_Choreography
{
    /**
     * Retrieves a list of Image resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListImages Choreo.
     * @return Google_ComputeEngine_Images_ListImages New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Images/ListImages/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListImages Choreo.
     *
     * @param Google_ComputeEngine_Images_ListImages_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_ListImages_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_ListImages_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Images_ListImages_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListImages Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_ListImages_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Images_ListImages_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListImages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_ListImages_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListImages Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Images_ListImages_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListImages input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListImages Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListImages Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListImages Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListImages Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListImages Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq testimage). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListImages Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListImages Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListImages Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListImages Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Images_ListImages_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListImages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_ListImages_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListImages Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListImages execution.
     * @param Google_ComputeEngine_Images_ListImages $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Images_ListImages_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Images_ListImages_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Images_ListImages_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Images_ListImages $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListImages execution.
     *
     * @return Google_ComputeEngine_Images_ListImages_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListImages execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Images_ListImages_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Images_ListImages_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListImages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Images_ListImages_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListImages Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Images_ListImages_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListImages execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListImages execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Adds an access config to an instance's network interface.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AddAccessConfig extends Temboo_Choreography
{
    /**
     * Adds an access config to an instance's network interface.
     *
     * @param Temboo_Session $session The session that owns this AddAccessConfig Choreo.
     * @return Google_ComputeEngine_Instances_AddAccessConfig New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/AddAccessConfig/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AddAccessConfig Choreo.
     *
     * @param Google_ComputeEngine_Instances_AddAccessConfig_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AddAccessConfig_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_AddAccessConfig_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AddAccessConfig Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_AddAccessConfig_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AddAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AddAccessConfig_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AddAccessConfig Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AddAccessConfig input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessConfiguration input for this AddAccessConfig Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the access configuration properties you wish to set. This can be used as an alternative to individual inputs that represent access configuration properties.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setAccessConfiguration($value)
    {
        return $this->set('AccessConfiguration', $value);
    }

    /**
     * Set the value for the AccessToken input for this AddAccessConfig Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AddAccessConfig Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AddAccessConfig Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Instance input for this AddAccessConfig Choreo.
     *
     * @param string $value (required, string) Name of the instance for which to add an access configuration.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Name input for this AddAccessConfig Choreo.
     *
     * @param string $value (optional, string) The name of this access configuration. Defaults to "External NAT" if not specified.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the NatIP input for this AddAccessConfig Choreo.
     *
     * @param string $value (optional, string) An external IP address associated with this instance. Specify an unused static IP address available to the project. An external IP will be drawn from a shared ephemeral pool when not specified.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setNatIP($value)
    {
        return $this->set('NatIP', $value);
    }

    /**
     * Set the value for the NetworkInterface input for this AddAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the network interface to add the access config (e.g. nic0, nic1, etc).
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setNetworkInterface($value)
    {
        return $this->set('NetworkInterface', $value);
    }

    /**
     * Set the value for the Project input for this AddAccessConfig Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AddAccessConfig Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Type input for this AddAccessConfig Choreo.
     *
     * @param string $value (required, string) Type of configuration. Must be set to ONE_TO_ONE_NAT.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }

    /**
     * Set the value for the Zone input for this AddAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the AddAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AddAccessConfig_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AddAccessConfig Choreo.
     *
     * @param Temboo_Session $session The session that owns this AddAccessConfig execution.
     * @param Google_ComputeEngine_Instances_AddAccessConfig $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_AddAccessConfig_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AddAccessConfig_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_AddAccessConfig $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AddAccessConfig execution.
     *
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AddAccessConfig execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_AddAccessConfig_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AddAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AddAccessConfig_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AddAccessConfig Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AddAccessConfig_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AddAccessConfig execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AddAccessConfig execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of Instance resources across all available zones.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AggregatedList extends Temboo_Choreography
{
    /**
     * Retrieves a list of Instance resources across all available zones.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList Choreo.
     * @return Google_ComputeEngine_Instances_AggregatedList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/AggregatedList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AggregatedList Choreo.
     *
     * @param Google_ComputeEngine_Instances_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AggregatedList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_AggregatedList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_AggregatedList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AggregatedList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AggregatedList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq my_instance). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this AggregatedList Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this AggregatedList Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AggregatedList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AggregatedList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AggregatedList Choreo.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList execution.
     * @param Google_ComputeEngine_Instances_AggregatedList $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AggregatedList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_AggregatedList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AggregatedList execution.
     *
     * @return Google_ComputeEngine_Instances_AggregatedList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AggregatedList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AggregatedList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_AggregatedList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AggregatedList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AggregatedList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AggregatedList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AggregatedList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AggregatedList execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Attaches a Disk resource to an instance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AttachDisk extends Temboo_Choreography
{
    /**
     * Attaches a Disk resource to an instance.
     *
     * @param Temboo_Session $session The session that owns this AttachDisk Choreo.
     * @return Google_ComputeEngine_Instances_AttachDisk New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/AttachDisk/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AttachDisk Choreo.
     *
     * @param Google_ComputeEngine_Instances_AttachDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AttachDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AttachDisk_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_AttachDisk_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AttachDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_AttachDisk_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AttachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AttachDisk_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AttachDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AttachDisk input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AttachedDisk input for this AttachDisk Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the attached disk properties to set. This can be used as an alternative to the individual inputs representing the attached disk properties.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setAttachedDisk($value)
    {
        return $this->set('AttachedDisk', $value);
    }

    /**
     * Set the value for the AccessToken input for this AttachDisk Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Boot input for this AttachDisk Choreo.
     *
     * @param bool $value (conditional, boolean) Whether or not this is a boot disk. Valid values are: true or false.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setBoot($value)
    {
        return $this->set('Boot', $value);
    }

    /**
     * Set the value for the ClientID input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DeviceName input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The name of the disk to attach.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setDeviceName($value)
    {
        return $this->set('DeviceName', $value);
    }

    /**
     * Set the value for the Fields input for this AttachDisk Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this AttachDisk Choreo.
     *
     * @param string $value (required, string) The name of the instance to attach a disk resource to.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Mode input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The mode in which to attach the disk. Valid values are: READ_WRITE or READ_ONLY.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setMode($value)
    {
        return $this->set('Mode', $value);
    }

    /**
     * Set the value for the Project input for this AttachDisk Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Source input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The URL to the Disk resource.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setSource($value)
    {
        return $this->set('Source', $value);
    }

    /**
     * Set the value for the Type input for this AttachDisk Choreo.
     *
     * @param string $value (conditional, string) The type of disk. Valid values are: SCRATCH or PERSISTENT. Persistent disks must already exist before you can attach them.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }

    /**
     * Set the value for the Zone input for this AttachDisk Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_AttachDisk_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the AttachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AttachDisk_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AttachDisk Choreo.
     *
     * @param Temboo_Session $session The session that owns this AttachDisk execution.
     * @param Google_ComputeEngine_Instances_AttachDisk $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_AttachDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_AttachDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_AttachDisk_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_AttachDisk $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AttachDisk execution.
     *
     * @return Google_ComputeEngine_Instances_AttachDisk_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AttachDisk execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AttachDisk_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_AttachDisk_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AttachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_AttachDisk_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AttachDisk Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_AttachDisk_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AttachDisk execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AttachDisk execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes an access configuation from an instance's network interface.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteAccessConfig extends Temboo_Choreography
{
    /**
     * Deletes an access configuation from an instance's network interface.
     *
     * @param Temboo_Session $session The session that owns this DeleteAccessConfig Choreo.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/DeleteAccessConfig/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteAccessConfig Choreo.
     *
     * @param Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_DeleteAccessConfig_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteAccessConfig Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteAccessConfig Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteAccessConfig input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessConfig input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the access configuration to delete.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setAccessConfig($value)
    {
        return $this->set('AccessConfig', $value);
    }

    /**
     * Set the value for the AccessToken input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the instance that this access configuration applies to.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the NetworkInterface input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the network interface associated with the access config that is being deleted.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setNetworkInterface($value)
    {
        return $this->set('NetworkInterface', $value);
    }

    /**
     * Set the value for the Project input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this DeleteAccessConfig Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the DeleteAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteAccessConfig_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteAccessConfig Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteAccessConfig execution.
     * @param Google_ComputeEngine_Instances_DeleteAccessConfig $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DeleteAccessConfig_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_DeleteAccessConfig $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteAccessConfig execution.
     *
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteAccessConfig execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_DeleteAccessConfig_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteAccessConfig Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteAccessConfig_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteAccessConfig Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DeleteAccessConfig_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteAccessConfig execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteAccessConfig execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Instance resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteInstance extends Temboo_Choreography
{
    /**
     * Deletes the specified Instance resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteInstance Choreo.
     * @return Google_ComputeEngine_Instances_DeleteInstance New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/DeleteInstance/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteInstance Choreo.
     *
     * @param Google_ComputeEngine_Instances_DeleteInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DeleteInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_DeleteInstance_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_DeleteInstance_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteInstance_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteInstance input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteInstance Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteInstance Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteInstance Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteInstance Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this DeleteInstance Choreo.
     *
     * @param string $value (required, string) The name of the instance to delete.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Project input for this DeleteInstance Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteInstance Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this DeleteInstance Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request. 
     * @return Google_ComputeEngine_Instances_DeleteInstance_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the DeleteInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteInstance_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteInstance Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteInstance execution.
     * @param Google_ComputeEngine_Instances_DeleteInstance $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_DeleteInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DeleteInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_DeleteInstance $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteInstance execution.
     *
     * @return Google_ComputeEngine_Instances_DeleteInstance_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteInstance execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_DeleteInstance_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DeleteInstance_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteInstance Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DeleteInstance_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteInstance execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteInstance execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Detaches a Disk resource from an instance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DetachDisk extends Temboo_Choreography
{
    /**
     * Detaches a Disk resource from an instance.
     *
     * @param Temboo_Session $session The session that owns this DetachDisk Choreo.
     * @return Google_ComputeEngine_Instances_DetachDisk New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/DetachDisk/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DetachDisk Choreo.
     *
     * @param Google_ComputeEngine_Instances_DetachDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DetachDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DetachDisk_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_DetachDisk_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DetachDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_DetachDisk_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DetachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DetachDisk_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DetachDisk Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DetachDisk input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DetachDisk Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DetachDisk Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DetachDisk Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DeviceName input for this DetachDisk Choreo.
     *
     * @param string $value (required, string) The name of the disk to detach.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setDeviceName($value)
    {
        return $this->set('DeviceName', $value);
    }

    /**
     * Set the value for the Fields input for this DetachDisk Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this DetachDisk Choreo.
     *
     * @param string $value (required, string) The name of the instance that is associated with the disk to detach.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Project input for this DetachDisk Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DetachDisk Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this DetachDisk Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_DetachDisk_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the DetachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DetachDisk_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DetachDisk Choreo.
     *
     * @param Temboo_Session $session The session that owns this DetachDisk execution.
     * @param Google_ComputeEngine_Instances_DetachDisk $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_DetachDisk_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_DetachDisk_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_DetachDisk_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_DetachDisk $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DetachDisk execution.
     *
     * @return Google_ComputeEngine_Instances_DetachDisk_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DetachDisk execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DetachDisk_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_DetachDisk_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DetachDisk Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_DetachDisk_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DetachDisk Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_DetachDisk_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DetachDisk execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DetachDisk execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Instance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetInstance extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Instance.
     *
     * @param Temboo_Session $session The session that owns this GetInstance Choreo.
     * @return Google_ComputeEngine_Instances_GetInstance New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/GetInstance/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetInstance Choreo.
     *
     * @param Google_ComputeEngine_Instances_GetInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_GetInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_GetInstance_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_GetInstance_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_GetInstance_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetInstance_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetInstance input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetInstance Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetInstance Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetInstance Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetInstance Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this GetInstance Choreo.
     *
     * @param string $value (required, string) The name of the instance to retrieve.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Project input for this GetInstance Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetInstance Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetInstance Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_GetInstance_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetInstance_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetInstance Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetInstance execution.
     * @param Google_ComputeEngine_Instances_GetInstance $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_GetInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_GetInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_GetInstance_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_GetInstance $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetInstance execution.
     *
     * @return Google_ComputeEngine_Instances_GetInstance_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetInstance execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_GetInstance_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_GetInstance_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetInstance_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetInstance Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_GetInstance_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetInstance execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetInstance execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns the specified instance's serial port output.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetSerialPortOutput extends Temboo_Choreography
{
    /**
     * Returns the specified instance's serial port output.
     *
     * @param Temboo_Session $session The session that owns this GetSerialPortOutput Choreo.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/GetSerialPortOutput/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetSerialPortOutput Choreo.
     *
     * @param Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_GetSerialPortOutput_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetSerialPortOutput Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetSerialPortOutput Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetSerialPortOutput Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetSerialPortOutput input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Instance input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (required, string) The name of the instance associated with the serial port output to retrieve.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Project input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetSerialPortOutput Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetSerialPortOutput Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetSerialPortOutput_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetSerialPortOutput Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetSerialPortOutput execution.
     * @param Google_ComputeEngine_Instances_GetSerialPortOutput $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_GetSerialPortOutput_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_GetSerialPortOutput $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetSerialPortOutput execution.
     *
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetSerialPortOutput execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_GetSerialPortOutput_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetSerialPortOutput Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_GetSerialPortOutput_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetSerialPortOutput Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_GetSerialPortOutput_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetSerialPortOutput execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetSerialPortOutput execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates an Instance resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_InsertInstance extends Temboo_Choreography
{
    /**
     * Creates an Instance resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertInstance Choreo.
     * @return Google_ComputeEngine_Instances_InsertInstance New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/InsertInstance/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertInstance Choreo.
     *
     * @param Google_ComputeEngine_Instances_InsertInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_InsertInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_InsertInstance_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_InsertInstance_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_InsertInstance_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_InsertInstance_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertInstance Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertInstance input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the InstanceResource input for this InsertInstance Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the instance resource properties to set. This an be used as an alternative to individual inputs representing instance properties.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setInstanceResource($value)
    {
        return $this->set('InstanceResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertInstance Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this InsertInstance Choreo.
     *
     * @param string $value (optional, string) The description of the instance.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Disks input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, json) An array of persistent disks. This array contains the following properties: source, type, and boot.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setDisks($value)
    {
        return $this->set('Disks', $value);
    }

    /**
     * Set the value for the MachineType input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, string) The fully-qualified URL of the machine type resource to use for this instance.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setMachineType($value)
    {
        return $this->set('MachineType', $value);
    }

    /**
     * Set the value for the Name input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, string) The name of the instance being created.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the NetworkInterfaces input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, json) An array of network configurations for this instance. This array contains the following properties: network, accessConfigs[], accessConfigs[].name, and accessConfigs[].type.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setNetworkInterfaces($value)
    {
        return $this->set('NetworkInterfaces', $value);
    }

    /**
     * Set the value for the Project input for this InsertInstance Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertInstance Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this InsertInstance Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_InsertInstance_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the InsertInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_InsertInstance_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertInstance Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertInstance execution.
     * @param Google_ComputeEngine_Instances_InsertInstance $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_InsertInstance_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_InsertInstance_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_InsertInstance_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_InsertInstance $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertInstance execution.
     *
     * @return Google_ComputeEngine_Instances_InsertInstance_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertInstance execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_InsertInstance_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_InsertInstance_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertInstance Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_InsertInstance_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertInstance Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_InsertInstance_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertInstance execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertInstance execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Instance resources contained within the specified Zone.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_ListInstances extends Temboo_Choreography
{
    /**
     * Retrieves the list of Instance resources contained within the specified Zone.
     *
     * @param Temboo_Session $session The session that owns this ListInstances Choreo.
     * @return Google_ComputeEngine_Instances_ListInstances New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/ListInstances/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListInstances Choreo.
     *
     * @param Google_ComputeEngine_Instances_ListInstances_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_ListInstances_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_ListInstances_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_ListInstances_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListInstances Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_ListInstances_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListInstances Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_ListInstances_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListInstances Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListInstances input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListInstances Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListInstances Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListInstances Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListInstances Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListInstances Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq testinstance). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListInstances Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListInstances Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListInstances Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListInstances Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this ListInstances Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_ListInstances_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the ListInstances Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_ListInstances_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListInstances Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListInstances execution.
     * @param Google_ComputeEngine_Instances_ListInstances $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_ListInstances_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_ListInstances_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_ListInstances_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_ListInstances $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListInstances execution.
     *
     * @return Google_ComputeEngine_Instances_ListInstances_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListInstances execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_ListInstances_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_ListInstances_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListInstances Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_ListInstances_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListInstances Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_ListInstances_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListInstances execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListInstances execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sets the metadata for the specified instance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetMetadata extends Temboo_Choreography
{
    /**
     * Sets the metadata for the specified instance.
     *
     * @param Temboo_Session $session The session that owns this SetMetadata Choreo.
     * @return Google_ComputeEngine_Instances_SetMetadata New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/SetMetadata/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SetMetadata Choreo.
     *
     * @param Google_ComputeEngine_Instances_SetMetadata_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_SetMetadata_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_SetMetadata_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_SetMetadata_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SetMetadata Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_SetMetadata_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SetMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetMetadata_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SetMetadata Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SetMetadata input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SetMetadata Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SetMetadata Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SetMetadata Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fingerprint input for this SetMetadata Choreo.
     *
     * @param string $value (required, string) The current fingerprint of this resource. You must provide the current version of the fingerprint to successfully update any metadata.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setFingerprint($value)
    {
        return $this->set('Fingerprint', $value);
    }

    /**
     * Set the value for the Instance input for this SetMetadata Choreo.
     *
     * @param string $value (required, string) The name of the instance that you're setting metadata for.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Items input for this SetMetadata Choreo.
     *
     * @param string $value (required, json) An array of key/value pairs. The total size of the keys and values should not exceed 512 KB.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setItems($value)
    {
        return $this->set('Items', $value);
    }

    /**
     * Set the value for the Project input for this SetMetadata Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SetMetadata Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this SetMetadata Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_SetMetadata_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the SetMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetMetadata_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SetMetadata Choreo.
     *
     * @param Temboo_Session $session The session that owns this SetMetadata execution.
     * @param Google_ComputeEngine_Instances_SetMetadata $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_SetMetadata_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_SetMetadata_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_SetMetadata_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_SetMetadata $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SetMetadata execution.
     *
     * @return Google_ComputeEngine_Instances_SetMetadata_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SetMetadata execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_SetMetadata_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_SetMetadata_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SetMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetMetadata_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SetMetadata Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_SetMetadata_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SetMetadata execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SetMetadata execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sets tags for the specified instance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetTags extends Temboo_Choreography
{
    /**
     * Sets tags for the specified instance.
     *
     * @param Temboo_Session $session The session that owns this SetTags Choreo.
     * @return Google_ComputeEngine_Instances_SetTags New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Instances/SetTags/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SetTags Choreo.
     *
     * @param Google_ComputeEngine_Instances_SetTags_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_SetTags_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_SetTags_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Instances_SetTags_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SetTags Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Instances_SetTags_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SetTags Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetTags_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SetTags Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SetTags input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SetTags Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SetTags Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SetTags Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fingerprint input for this SetTags Choreo.
     *
     * @param string $value (required, string) The current fingerprint of this resource. You must provide the current version of the fingerprint to successfully update tags.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setFingerprint($value)
    {
        return $this->set('Fingerprint', $value);
    }

    /**
     * Set the value for the Instance input for this SetTags Choreo.
     *
     * @param string $value (required, string) The name of the instance that you're setting tags for.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setInstance($value)
    {
        return $this->set('Instance', $value);
    }

    /**
     * Set the value for the Items input for this SetTags Choreo.
     *
     * @param string $value (required, json) An array of tags. The max length of a tag is 63 characters.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setItems($value)
    {
        return $this->set('Items', $value);
    }

    /**
     * Set the value for the Project input for this SetTags Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SetTags Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this SetTags Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with this request.
     * @return Google_ComputeEngine_Instances_SetTags_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the SetTags Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetTags_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SetTags Choreo.
     *
     * @param Temboo_Session $session The session that owns this SetTags execution.
     * @param Google_ComputeEngine_Instances_SetTags $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Instances_SetTags_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Instances_SetTags_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Instances_SetTags_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Instances_SetTags $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SetTags execution.
     *
     * @return Google_ComputeEngine_Instances_SetTags_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SetTags execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_SetTags_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Instances_SetTags_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SetTags Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Instances_SetTags_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SetTags Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Instances_SetTags_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SetTags execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SetTags execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of Machine Type resources across all available zones.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_AggregatedList extends Temboo_Choreography
{
    /**
     * Retrieves a list of Machine Type resources across all available zones.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList Choreo.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/MachineTypes/AggregatedList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AggregatedList Choreo.
     *
     * @param Google_ComputeEngine_MachineTypes_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_MachineTypes_AggregatedList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_MachineTypes_AggregatedList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_AggregatedList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AggregatedList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AggregatedList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq eq f1-micro). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this AggregatedList Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this AggregatedList Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this AggregatedList Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AggregatedList Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_AggregatedList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AggregatedList Choreo.
     *
     * @param Temboo_Session $session The session that owns this AggregatedList execution.
     * @param Google_ComputeEngine_MachineTypes_AggregatedList $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_MachineTypes_AggregatedList_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_AggregatedList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_MachineTypes_AggregatedList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AggregatedList execution.
     *
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AggregatedList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_MachineTypes_AggregatedList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AggregatedList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_AggregatedList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AggregatedList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_AggregatedList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AggregatedList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AggregatedList execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Machine Type.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_GetMachineType extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Machine Type.
     *
     * @param Temboo_Session $session The session that owns this GetMachineType Choreo.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/MachineTypes/GetMachineType/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetMachineType Choreo.
     *
     * @param Google_ComputeEngine_MachineTypes_GetMachineType_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_GetMachineType_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_MachineTypes_GetMachineType_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetMachineType Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_MachineTypes_GetMachineType_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetMachineType Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_GetMachineType_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetMachineType Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetMachineType input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetMachineType Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetMachineType Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetMachineType Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetMachineType Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MachineType input for this GetMachineType Choreo.
     *
     * @param string $value (required, string) The name of the machine type to retrieve.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setMachineType($value)
    {
        return $this->set('MachineType', $value);
    }

    /**
     * Set the value for the Project input for this GetMachineType Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetMachineType Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetMachineType Choreo.
     *
     * @param string $value (required, string) The name of the zone that contains the machine type to retrieve.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetMachineType Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_GetMachineType_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetMachineType Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetMachineType execution.
     * @param Google_ComputeEngine_MachineTypes_GetMachineType $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_MachineTypes_GetMachineType_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_GetMachineType_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_MachineTypes_GetMachineType $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetMachineType execution.
     *
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetMachineType execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_MachineTypes_GetMachineType_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetMachineType Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_GetMachineType_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetMachineType Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_GetMachineType_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetMachineType execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetMachineType execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Machine Type resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_ListMachineTypes extends Temboo_Choreography
{
    /**
     * Retrieves the list of Machine Type resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListMachineTypes Choreo.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/MachineTypes/ListMachineTypes/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListMachineTypes Choreo.
     *
     * @param Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_MachineTypes_ListMachineTypes_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListMachineTypes Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListMachineTypes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListMachineTypes Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListMachineTypes input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListMachineTypes Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListMachineTypes Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListMachineTypes Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListMachineTypes Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListMachineTypes Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq f1-micro). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListMachineTypes Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListMachineTypes Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListMachineTypes Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListMachineTypes Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this ListMachineTypes Choreo.
     *
     * @param string $value (required, string) The name of the zone that contains the machine type resources to retrieve.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the ListMachineTypes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_ListMachineTypes_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListMachineTypes Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListMachineTypes execution.
     * @param Google_ComputeEngine_MachineTypes_ListMachineTypes $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_MachineTypes_ListMachineTypes_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_MachineTypes_ListMachineTypes $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListMachineTypes execution.
     *
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListMachineTypes execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_MachineTypes_ListMachineTypes_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListMachineTypes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_MachineTypes_ListMachineTypes_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListMachineTypes Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_MachineTypes_ListMachineTypes_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListMachineTypes execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListMachineTypes execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Network resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_DeleteNetwork extends Temboo_Choreography
{
    /**
     * Deletes the specified Network resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteNetwork Choreo.
     * @return Google_ComputeEngine_Networks_DeleteNetwork New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Networks/DeleteNetwork/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteNetwork Choreo.
     *
     * @param Google_ComputeEngine_Networks_DeleteNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_DeleteNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Networks_DeleteNetwork_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Networks_DeleteNetwork_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_DeleteNetwork_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteNetwork input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteNetwork Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteNetwork Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Network input for this DeleteNetwork Choreo.
     *
     * @param string $value (required, string) The name of the network to delete.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setNetwork($value)
    {
        return $this->set('Network', $value);
    }

    /**
     * Set the value for the Project input for this DeleteNetwork Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteNetwork Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_DeleteNetwork_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteNetwork Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteNetwork execution.
     * @param Google_ComputeEngine_Networks_DeleteNetwork $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Networks_DeleteNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_DeleteNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Networks_DeleteNetwork $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteNetwork execution.
     *
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteNetwork execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Networks_DeleteNetwork_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_DeleteNetwork_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteNetwork Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_DeleteNetwork_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteNetwork execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteNetwork execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Network.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_GetNetwork extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Network.
     *
     * @param Temboo_Session $session The session that owns this GetNetwork Choreo.
     * @return Google_ComputeEngine_Networks_GetNetwork New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Networks/GetNetwork/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetNetwork Choreo.
     *
     * @param Google_ComputeEngine_Networks_GetNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_GetNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_GetNetwork_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Networks_GetNetwork_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Networks_GetNetwork_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_GetNetwork_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetNetwork input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetNetwork Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetNetwork Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Network input for this GetNetwork Choreo.
     *
     * @param string $value (required, string) The name of the network to retrieve.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setNetwork($value)
    {
        return $this->set('Network', $value);
    }

    /**
     * Set the value for the Project input for this GetNetwork Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetNetwork Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_GetNetwork_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the GetNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_GetNetwork_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetNetwork Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetNetwork execution.
     * @param Google_ComputeEngine_Networks_GetNetwork $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Networks_GetNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_GetNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_GetNetwork_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Networks_GetNetwork $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetNetwork execution.
     *
     * @return Google_ComputeEngine_Networks_GetNetwork_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetNetwork execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_GetNetwork_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Networks_GetNetwork_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_GetNetwork_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetNetwork Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_GetNetwork_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetNetwork execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetNetwork execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new Network resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_InsertNetwork extends Temboo_Choreography
{
    /**
     * Creates a new Network resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertNetwork Choreo.
     * @return Google_ComputeEngine_Networks_InsertNetwork New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Networks/InsertNetwork/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertNetwork Choreo.
     *
     * @param Google_ComputeEngine_Networks_InsertNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_InsertNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Networks_InsertNetwork_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Networks_InsertNetwork_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_InsertNetwork_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertNetwork Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertNetwork input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the NetworkResource input for this InsertNetwork Choreo.
     *
     * @param string $value (optional, json) A JSON string containing the network resource properties you wish to set. This can be used as an alternative to individual inputs that represent network resource properties.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setNetworkResource($value)
    {
        return $this->set('NetworkResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertNetwork Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertNetwork Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this InsertNetwork Choreo.
     *
     * @param string $value (optional, string) A description of the network.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the GatewayIP input for this InsertNetwork Choreo.
     *
     * @param string $value (optional, string) An optional address used for default routing to other networks. Must be within the range specified by IPRange.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setGatewayIP($value)
    {
        return $this->set('GatewayIP', $value);
    }

    /**
     * Set the value for the IPRange input for this InsertNetwork Choreo.
     *
     * @param string $value (conditional, string) The range of internal addresses that are allowed on the network.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setIPRange($value)
    {
        return $this->set('IPRange', $value);
    }

    /**
     * Set the value for the Name input for this InsertNetwork Choreo.
     *
     * @param string $value (conditional, string) The name of the network.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the Project input for this InsertNetwork Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertNetwork Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the InsertNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_InsertNetwork_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertNetwork Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertNetwork execution.
     * @param Google_ComputeEngine_Networks_InsertNetwork $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Networks_InsertNetwork_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_InsertNetwork_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Networks_InsertNetwork $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertNetwork execution.
     *
     * @return Google_ComputeEngine_Networks_InsertNetwork_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertNetwork execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Networks_InsertNetwork_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertNetwork Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_InsertNetwork_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertNetwork Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_InsertNetwork_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertNetwork execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertNetwork execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Network resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_ListNetworks extends Temboo_Choreography
{
    /**
     * Retrieves the list of Network resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListNetworks Choreo.
     * @return Google_ComputeEngine_Networks_ListNetworks New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Networks/ListNetworks/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListNetworks Choreo.
     *
     * @param Google_ComputeEngine_Networks_ListNetworks_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_ListNetworks_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_ListNetworks_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Networks_ListNetworks_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListNetworks Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Networks_ListNetworks_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListNetworks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_ListNetworks_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListNetworks Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListNetworks input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListNetworks Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListNetworks Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListNetworks Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListNetworks Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListNetworks Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq default). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListNetworks Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListNetworks Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListNetworks Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListNetworks Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Networks_ListNetworks_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListNetworks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_ListNetworks_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListNetworks Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListNetworks execution.
     * @param Google_ComputeEngine_Networks_ListNetworks $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Networks_ListNetworks_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Networks_ListNetworks_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Networks_ListNetworks_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Networks_ListNetworks $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListNetworks execution.
     *
     * @return Google_ComputeEngine_Networks_ListNetworks_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListNetworks execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_ListNetworks_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Networks_ListNetworks_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListNetworks Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Networks_ListNetworks_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListNetworks Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Networks_ListNetworks_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListNetworks execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListNetworks execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the specified Project resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_GetProject extends Temboo_Choreography
{
    /**
     * Retrieves the specified Project resource.
     *
     * @param Temboo_Session $session The session that owns this GetProject Choreo.
     * @return Google_ComputeEngine_Projects_GetProject New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Projects/GetProject/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetProject Choreo.
     *
     * @param Google_ComputeEngine_Projects_GetProject_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Projects_GetProject_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Projects_GetProject_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Projects_GetProject_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetProject Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Projects_GetProject_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetProject Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_GetProject_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetProject Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetProject input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetProject Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetProject Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetProject Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetProject Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetProject Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetProject Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_GetProject_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the GetProject Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_GetProject_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetProject Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetProject execution.
     * @param Google_ComputeEngine_Projects_GetProject $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Projects_GetProject_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Projects_GetProject_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Projects_GetProject_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Projects_GetProject $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetProject execution.
     *
     * @return Google_ComputeEngine_Projects_GetProject_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetProject execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Projects_GetProject_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Projects_GetProject_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetProject Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_GetProject_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetProject Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Projects_GetProject_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetProject execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetProject execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sets metadata common to all instances within the specified Project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_SetCommonInstanceMetadata extends Temboo_Choreography
{
    /**
     * Sets metadata common to all instances within the specified Project.
     *
     * @param Temboo_Session $session The session that owns this SetCommonInstanceMetadata Choreo.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Projects/SetCommonInstanceMetadata/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SetCommonInstanceMetadata Choreo.
     *
     * @param Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SetCommonInstanceMetadata Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SetCommonInstanceMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SetCommonInstanceMetadata Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SetCommonInstanceMetadata input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fingerprint input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (required, string) The fingerprint of this resource, which is a hash of the metadata's contents. This field is used for optimistic locking. Providing an up-to-date metadata fingerprint is required to modify metadata.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setFingerprint($value)
    {
        return $this->set('Fingerprint', $value);
    }

    /**
     * Set the value for the Items input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (conditional, json) An array of key/value pairs. The max size of all keys and values is 512 KB.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setItems($value)
    {
        return $this->set('Items', $value);
    }

    /**
     * Set the value for the Project input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SetCommonInstanceMetadata Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the SetCommonInstanceMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SetCommonInstanceMetadata Choreo.
     *
     * @param Temboo_Session $session The session that owns this SetCommonInstanceMetadata execution.
     * @param Google_ComputeEngine_Projects_SetCommonInstanceMetadata $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Projects_SetCommonInstanceMetadata $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SetCommonInstanceMetadata execution.
     *
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SetCommonInstanceMetadata execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SetCommonInstanceMetadata Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SetCommonInstanceMetadata Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Projects_SetCommonInstanceMetadata_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SetCommonInstanceMetadata execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SetCommonInstanceMetadata execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified operation within a region.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_DeleteRegionOperation extends Temboo_Choreography
{
    /**
     * Deletes the specified operation within a region.
     *
     * @param Temboo_Session $session The session that owns this DeleteRegionOperation Choreo.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/RegionOperations/DeleteRegionOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteRegionOperation Choreo.
     *
     * @param Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteRegionOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteRegionOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteRegionOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Operation input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to delete.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this DeleteRegionOperation Choreo.
     *
     * @param string $value (required, string) The name of the region associated with the request.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the DeleteRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteRegionOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteRegionOperation execution.
     * @param Google_ComputeEngine_RegionOperations_DeleteRegionOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_RegionOperations_DeleteRegionOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteRegionOperation execution.
     *
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteRegionOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteRegionOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_DeleteRegionOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteRegionOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteRegionOperation execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteRegionOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified operation within a region.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_GetRegionOperation extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified operation within a region.
     *
     * @param Temboo_Session $session The session that owns this GetRegionOperation Choreo.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/RegionOperations/GetRegionOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetRegionOperation Choreo.
     *
     * @param Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_RegionOperations_GetRegionOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetRegionOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetRegionOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetRegionOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetRegionOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetRegionOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetRegionOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetRegionOperation Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Operation input for this GetRegionOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to retrieve.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this GetRegionOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetRegionOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this GetRegionOperation Choreo.
     *
     * @param string $value (required, string) The name of the region associated with the request.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the GetRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_GetRegionOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetRegionOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetRegionOperation execution.
     * @param Google_ComputeEngine_RegionOperations_GetRegionOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_GetRegionOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_RegionOperations_GetRegionOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetRegionOperation execution.
     *
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetRegionOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_RegionOperations_GetRegionOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetRegionOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_GetRegionOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetRegionOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_GetRegionOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetRegionOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetRegionOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of operation resources contained within the specified region.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_ListRegionOperations extends Temboo_Choreography
{
    /**
     * Retrieves a list of operation resources contained within the specified region.
     *
     * @param Temboo_Session $session The session that owns this ListRegionOperations Choreo.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/RegionOperations/ListRegionOperations/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListRegionOperations Choreo.
     *
     * @param Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_RegionOperations_ListRegionOperations_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListRegionOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListRegionOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListRegionOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListRegionOperations input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListRegionOperations Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListRegionOperations Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListRegionOperations Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListRegionOperations Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListRegionOperations Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq operation-1234). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListRegionOperations Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListRegionOperations Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListRegionOperations Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListRegionOperations Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this ListRegionOperations Choreo.
     *
     * @param string $value (required, string) The name of the region associated with this request.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the ListRegionOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_ListRegionOperations_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListRegionOperations Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListRegionOperations execution.
     * @param Google_ComputeEngine_RegionOperations_ListRegionOperations $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_RegionOperations_ListRegionOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_RegionOperations_ListRegionOperations $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListRegionOperations execution.
     *
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListRegionOperations execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_RegionOperations_ListRegionOperations_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListRegionOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_RegionOperations_ListRegionOperations_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListRegionOperations Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_RegionOperations_ListRegionOperations_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListRegionOperations execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListRegionOperations execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Region.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_GetRegion extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Region.
     *
     * @param Temboo_Session $session The session that owns this GetRegion Choreo.
     * @return Google_ComputeEngine_Regions_GetRegion New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Regions/GetRegion/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetRegion Choreo.
     *
     * @param Google_ComputeEngine_Regions_GetRegion_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Regions_GetRegion_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Regions_GetRegion_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Regions_GetRegion_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetRegion Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Regions_GetRegion_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetRegion Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_GetRegion_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetRegion Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetRegion input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetRegion Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetRegion Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetRegion Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetRegion Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetRegion Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetRegion Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Region input for this GetRegion Choreo.
     *
     * @param string $value (required, string) The name of the region to retrieve.
     * @return Google_ComputeEngine_Regions_GetRegion_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }
}


/**
 * Execution object for the GetRegion Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_GetRegion_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetRegion Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetRegion execution.
     * @param Google_ComputeEngine_Regions_GetRegion $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Regions_GetRegion_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Regions_GetRegion_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Regions_GetRegion_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Regions_GetRegion $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetRegion execution.
     *
     * @return Google_ComputeEngine_Regions_GetRegion_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetRegion execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Regions_GetRegion_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Regions_GetRegion_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetRegion Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_GetRegion_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetRegion Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Regions_GetRegion_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetRegion execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetRegion execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Regions available to the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_ListRegions extends Temboo_Choreography
{
    /**
     * Retrieves the list of Regions available to the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListRegions Choreo.
     * @return Google_ComputeEngine_Regions_ListRegions New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Regions/ListRegions/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListRegions Choreo.
     *
     * @param Google_ComputeEngine_Regions_ListRegions_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Regions_ListRegions_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Regions_ListRegions_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Regions_ListRegions_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListRegions Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Regions_ListRegions_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListRegions Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_ListRegions_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListRegions Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListRegions input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListRegions Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListRegions Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListRegions Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListRegions Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListRegions Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq europe-west1). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListRegions Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListRegions Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListRegions Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListRegions Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Regions_ListRegions_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListRegions Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_ListRegions_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListRegions Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListRegions execution.
     * @param Google_ComputeEngine_Regions_ListRegions $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Regions_ListRegions_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Regions_ListRegions_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Regions_ListRegions_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Regions_ListRegions $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListRegions execution.
     *
     * @return Google_ComputeEngine_Regions_ListRegions_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListRegions execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Regions_ListRegions_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Regions_ListRegions_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListRegions Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Regions_ListRegions_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListRegions Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Regions_ListRegions_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListRegions execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListRegions execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Route.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_DeleteRoute extends Temboo_Choreography
{
    /**
     * Deletes the specified Route.
     *
     * @param Temboo_Session $session The session that owns this DeleteRoute Choreo.
     * @return Google_ComputeEngine_Routes_DeleteRoute New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Routes/DeleteRoute/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteRoute Choreo.
     *
     * @param Google_ComputeEngine_Routes_DeleteRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_DeleteRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Routes_DeleteRoute_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Routes_DeleteRoute_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_DeleteRoute_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteRoute input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteRoute Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteRoute Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteRoute Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteRoute Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this DeleteRoute Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteRoute Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Route input for this DeleteRoute Choreo.
     *
     * @param string $value (required, string) The name of the route to delete.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Inputs For method chaining.
     */
    public function setRoute($value)
    {
        return $this->set('Route', $value);
    }
}


/**
 * Execution object for the DeleteRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_DeleteRoute_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteRoute Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteRoute execution.
     * @param Google_ComputeEngine_Routes_DeleteRoute $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Routes_DeleteRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_DeleteRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Routes_DeleteRoute $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteRoute execution.
     *
     * @return Google_ComputeEngine_Routes_DeleteRoute_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteRoute execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Routes_DeleteRoute_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_DeleteRoute_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteRoute Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_DeleteRoute_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteRoute execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteRoute execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Route.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_GetRoute extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Route.
     *
     * @param Temboo_Session $session The session that owns this GetRoute Choreo.
     * @return Google_ComputeEngine_Routes_GetRoute New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Routes/GetRoute/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetRoute Choreo.
     *
     * @param Google_ComputeEngine_Routes_GetRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_GetRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_GetRoute_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Routes_GetRoute_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Routes_GetRoute_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_GetRoute_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetRoute input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetRoute Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetRoute Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetRoute Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetRoute Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response..
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetRoute Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetRoute Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Route input for this GetRoute Choreo.
     *
     * @param string $value (required, string) The name of the route to retrieve.
     * @return Google_ComputeEngine_Routes_GetRoute_Inputs For method chaining.
     */
    public function setRoute($value)
    {
        return $this->set('Route', $value);
    }
}


/**
 * Execution object for the GetRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_GetRoute_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetRoute Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetRoute execution.
     * @param Google_ComputeEngine_Routes_GetRoute $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Routes_GetRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_GetRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_GetRoute_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Routes_GetRoute $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetRoute execution.
     *
     * @return Google_ComputeEngine_Routes_GetRoute_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetRoute execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_GetRoute_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Routes_GetRoute_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_GetRoute_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetRoute Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_GetRoute_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetRoute execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetRoute execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a Route resource in the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_InsertRoute extends Temboo_Choreography
{
    /**
     * Creates a Route resource in the specified project.
     *
     * @param Temboo_Session $session The session that owns this InsertRoute Choreo.
     * @return Google_ComputeEngine_Routes_InsertRoute New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Routes/InsertRoute/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertRoute Choreo.
     *
     * @param Google_ComputeEngine_Routes_InsertRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_InsertRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_InsertRoute_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Routes_InsertRoute_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Routes_InsertRoute_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_InsertRoute_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertRoute Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertRoute input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RouteResource input for this InsertRoute Choreo.
     *
     * @param string $value (required, json) A JSON string containing the route resource fields to set. Required properties include: destRange, name, network, priority, and at at least one nextHop property.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setRouteResource($value)
    {
        return $this->set('RouteResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this InsertRoute Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertRoute Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertRoute Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Project input for this InsertRoute Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertRoute Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_InsertRoute_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the InsertRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_InsertRoute_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertRoute Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertRoute execution.
     * @param Google_ComputeEngine_Routes_InsertRoute $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Routes_InsertRoute_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_InsertRoute_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_InsertRoute_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Routes_InsertRoute $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertRoute execution.
     *
     * @return Google_ComputeEngine_Routes_InsertRoute_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertRoute execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_InsertRoute_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Routes_InsertRoute_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertRoute Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_InsertRoute_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertRoute Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_InsertRoute_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertRoute execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertRoute execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of route resources available to the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_ListRoutes extends Temboo_Choreography
{
    /**
     * Retrieves a list of route resources available to the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListRoutes Choreo.
     * @return Google_ComputeEngine_Routes_ListRoutes New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Routes/ListRoutes/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListRoutes Choreo.
     *
     * @param Google_ComputeEngine_Routes_ListRoutes_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_ListRoutes_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_ListRoutes_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Routes_ListRoutes_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListRoutes Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Routes_ListRoutes_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListRoutes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_ListRoutes_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListRoutes Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListRoutes input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListRoutes Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListRoutes Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListRoutes Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListRoutes Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListRoutes Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq default-route-1234). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListRoutes Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListRoutes Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListRoutes Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListRoutes Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Routes_ListRoutes_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListRoutes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_ListRoutes_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListRoutes Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListRoutes execution.
     * @param Google_ComputeEngine_Routes_ListRoutes $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Routes_ListRoutes_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Routes_ListRoutes_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Routes_ListRoutes_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Routes_ListRoutes $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListRoutes execution.
     *
     * @return Google_ComputeEngine_Routes_ListRoutes_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListRoutes execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_ListRoutes_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Routes_ListRoutes_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListRoutes Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Routes_ListRoutes_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListRoutes Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Routes_ListRoutes_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListRoutes execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListRoutes execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specified Snapshot resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_DeleteSnapshot extends Temboo_Choreography
{
    /**
     * Deletes a specified Snapshot resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteSnapshot Choreo.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Snapshots/DeleteSnapshot/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteSnapshot Choreo.
     *
     * @param Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Snapshots_DeleteSnapshot_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteSnapshot input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteSnapshot Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteSnapshot Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this DeleteSnapshot Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteSnapshot Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Snapshot input for this DeleteSnapshot Choreo.
     *
     * @param string $value (required, string) The name of the snapshot to delete.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs For method chaining.
     */
    public function setSnapshot($value)
    {
        return $this->set('Snapshot', $value);
    }
}


/**
 * Execution object for the DeleteSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_DeleteSnapshot_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteSnapshot Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteSnapshot execution.
     * @param Google_ComputeEngine_Snapshots_DeleteSnapshot $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_DeleteSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Snapshots_DeleteSnapshot $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteSnapshot execution.
     *
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteSnapshot execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Snapshots_DeleteSnapshot_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_DeleteSnapshot_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteSnapshot Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_DeleteSnapshot_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteSnapshot execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteSnapshot execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Snapshot.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_GetSnapshot extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Snapshot.
     *
     * @param Temboo_Session $session The session that owns this GetSnapshot Choreo.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Snapshots/GetSnapshot/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetSnapshot Choreo.
     *
     * @param Google_ComputeEngine_Snapshots_GetSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_GetSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Snapshots_GetSnapshot_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Snapshots_GetSnapshot_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_GetSnapshot_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetSnapshot Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetSnapshot input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetSnapshot Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetSnapshot Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetSnapshot Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetSnapshot Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetSnapshot Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Snapshot input for this GetSnapshot Choreo.
     *
     * @param string $value (required, string) The name of the snapshot to retrieve.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Inputs For method chaining.
     */
    public function setSnapshot($value)
    {
        return $this->set('Snapshot', $value);
    }
}


/**
 * Execution object for the GetSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_GetSnapshot_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetSnapshot Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetSnapshot execution.
     * @param Google_ComputeEngine_Snapshots_GetSnapshot $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Snapshots_GetSnapshot_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_GetSnapshot_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Snapshots_GetSnapshot $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetSnapshot execution.
     *
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetSnapshot execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Snapshots_GetSnapshot_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetSnapshot Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_GetSnapshot_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetSnapshot Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_GetSnapshot_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetSnapshot execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetSnapshot execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of persistent disk snapshot resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_ListSnapshots extends Temboo_Choreography
{
    /**
     * Retrieves a list of persistent disk snapshot resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListSnapshots Choreo.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Snapshots/ListSnapshots/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListSnapshots Choreo.
     *
     * @param Google_ComputeEngine_Snapshots_ListSnapshots_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_ListSnapshots_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Snapshots_ListSnapshots_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListSnapshots Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Snapshots_ListSnapshots_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListSnapshots Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_ListSnapshots_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListSnapshots Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListSnapshots input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListSnapshots Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListSnapshots Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListSnapshots Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListSnapshots Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListSnapshots Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq testsnapshot). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListSnapshots Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListSnapshots Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListSnapshots Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListSnapshots Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListSnapshots Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_ListSnapshots_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListSnapshots Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListSnapshots execution.
     * @param Google_ComputeEngine_Snapshots_ListSnapshots $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Snapshots_ListSnapshots_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Snapshots_ListSnapshots_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Snapshots_ListSnapshots $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListSnapshots execution.
     *
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListSnapshots execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Snapshots_ListSnapshots_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListSnapshots Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Snapshots_ListSnapshots_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListSnapshots Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Snapshots_ListSnapshots_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListSnapshots execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListSnapshots execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified Zone Operation resource.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_DeleteZoneOperation extends Temboo_Choreography
{
    /**
     * Deletes the specified Zone Operation resource.
     *
     * @param Temboo_Session $session The session that owns this DeleteZoneOperation Choreo.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/ZoneOperations/DeleteZoneOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteZoneOperation Choreo.
     *
     * @param Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteZoneOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteZoneOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteZoneOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Operation input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to delete.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this DeleteZoneOperation Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with the operation being deleted.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the DeleteZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteZoneOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteZoneOperation execution.
     * @param Google_ComputeEngine_ZoneOperations_DeleteZoneOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_ZoneOperations_DeleteZoneOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteZoneOperation execution.
     *
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteZoneOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteZoneOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_DeleteZoneOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteZoneOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteZoneOperation execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteZoneOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Zone Operation.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_GetZoneOperation extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Zone Operation.
     *
     * @param Temboo_Session $session The session that owns this GetZoneOperation Choreo.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/ZoneOperations/GetZoneOperation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetZoneOperation Choreo.
     *
     * @param Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_ZoneOperations_GetZoneOperation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetZoneOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetZoneOperation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetZoneOperation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetZoneOperation Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetZoneOperation Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetZoneOperation Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetZoneOperation Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Operation input for this GetZoneOperation Choreo.
     *
     * @param string $value (required, string) The name of the operation to retrieve.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setOperation($value)
    {
        return $this->set('Operation', $value);
    }

    /**
     * Set the value for the Project input for this GetZoneOperation Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetZoneOperation Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetZoneOperation Choreo.
     *
     * @param string $value (required, string) The name of the zone associated with the operation being retrieved.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_GetZoneOperation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetZoneOperation Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetZoneOperation execution.
     * @param Google_ComputeEngine_ZoneOperations_GetZoneOperation $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_GetZoneOperation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_ZoneOperations_GetZoneOperation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetZoneOperation execution.
     *
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetZoneOperation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_ZoneOperations_GetZoneOperation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetZoneOperation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_GetZoneOperation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetZoneOperation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_GetZoneOperation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetZoneOperation execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetZoneOperation execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Zone Operation resources contained within the specified Zone.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_ListZoneOperations extends Temboo_Choreography
{
    /**
     * Retrieves the list of Zone Operation resources contained within the specified Zone.
     *
     * @param Temboo_Session $session The session that owns this ListZoneOperations Choreo.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/ZoneOperations/ListZoneOperations/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListZoneOperations Choreo.
     *
     * @param Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_ZoneOperations_ListZoneOperations_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListZoneOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListZoneOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListZoneOperations Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListZoneOperations input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListZoneOperations Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListZoneOperations Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListZoneOperations Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListZoneOperations Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListZoneOperations Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq europe-west1-a). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListZoneOperations Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListZoneOperations Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListZoneOperations Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListZoneOperations Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this ListZoneOperations Choreo.
     *
     * @param string $value (required, string) The name of the zone that contains the operation resources to retrieve.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the ListZoneOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_ListZoneOperations_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListZoneOperations Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListZoneOperations execution.
     * @param Google_ComputeEngine_ZoneOperations_ListZoneOperations $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_ZoneOperations_ListZoneOperations_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_ZoneOperations_ListZoneOperations $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListZoneOperations execution.
     *
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListZoneOperations execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_ZoneOperations_ListZoneOperations_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListZoneOperations Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_ZoneOperations_ListZoneOperations_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListZoneOperations Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_ZoneOperations_ListZoneOperations_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListZoneOperations execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListZoneOperations execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves information about the specified Zone.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_GetZone extends Temboo_Choreography
{
    /**
     * Retrieves information about the specified Zone.
     *
     * @param Temboo_Session $session The session that owns this GetZone Choreo.
     * @return Google_ComputeEngine_Zones_GetZone New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Zones/GetZone/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetZone Choreo.
     *
     * @param Google_ComputeEngine_Zones_GetZone_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Zones_GetZone_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Zones_GetZone_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Zones_GetZone_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetZone Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Zones_GetZone_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetZone Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_GetZone_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetZone Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetZone input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetZone Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetZone Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetZone Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetZone Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Project input for this GetZone Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetZone Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Zone input for this GetZone Choreo.
     *
     * @param string $value (required, string) The name of the zone to retrieve.
     * @return Google_ComputeEngine_Zones_GetZone_Inputs For method chaining.
     */
    public function setZone($value)
    {
        return $this->set('Zone', $value);
    }
}


/**
 * Execution object for the GetZone Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_GetZone_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetZone Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetZone execution.
     * @param Google_ComputeEngine_Zones_GetZone $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Zones_GetZone_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Zones_GetZone_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Zones_GetZone_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Zones_GetZone $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetZone execution.
     *
     * @return Google_ComputeEngine_Zones_GetZone_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetZone execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Zones_GetZone_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Zones_GetZone_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetZone Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_GetZone_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetZone Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Zones_GetZone_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetZone execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetZone execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the list of Zone resources for the specified project.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_ListZones extends Temboo_Choreography
{
    /**
     * Retrieves the list of Zone resources for the specified project.
     *
     * @param Temboo_Session $session The session that owns this ListZones Choreo.
     * @return Google_ComputeEngine_Zones_ListZones New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/ComputeEngine/Zones/ListZones/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListZones Choreo.
     *
     * @param Google_ComputeEngine_Zones_ListZones_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Zones_ListZones_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Zones_ListZones_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_ComputeEngine_Zones_ListZones_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListZones Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_ComputeEngine_Zones_ListZones_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListZones Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_ListZones_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListZones Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListZones input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListZones Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListZones Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListZones Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListZones Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of fields you want to include in the response.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Filter input for this ListZones Choreo.
     *
     * @param string $value (optional, string) A filter expression for narrowing results in the form: {field_name} {comparison_string} {literal_string} (e.g. name eq europe-west1-a). Comparison strings can be eq (equals) or ne (not equals).
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setFilter($value)
    {
        return $this->set('Filter', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListZones Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListZones Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Project input for this ListZones Choreo.
     *
     * @param string $value (required, string) The ID of a Google Compute project.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setProject($value)
    {
        return $this->set('Project', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListZones Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_ComputeEngine_Zones_ListZones_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the ListZones Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_ListZones_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListZones Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListZones execution.
     * @param Google_ComputeEngine_Zones_ListZones $choreo The choreography object for this execution.
     * @param Google_ComputeEngine_Zones_ListZones_Inputs|array $inputs (optional) Inputs as Google_ComputeEngine_Zones_ListZones_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_ComputeEngine_Zones_ListZones_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_ComputeEngine_Zones_ListZones $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListZones execution.
     *
     * @return Google_ComputeEngine_Zones_ListZones_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListZones execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_ComputeEngine_Zones_ListZones_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_ComputeEngine_Zones_ListZones_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListZones Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_ComputeEngine_Zones_ListZones_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListZones Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_ComputeEngine_Zones_ListZones_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListZones execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListZones execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Create a new contact.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_CreateContact extends Temboo_Choreography
{
    /**
     * Create a new contact.
     *
     * @param Temboo_Session $session The session that owns this CreateContact Choreo.
     * @return Google_Contacts_CreateContact New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/CreateContact/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateContact Choreo.
     *
     * @param Google_Contacts_CreateContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_CreateContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_CreateContact_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_CreateContact_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_CreateContact_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_CreateContact_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_CreateContact_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_CreateContact_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateContact input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateContact Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The OAuth client ID provided by Google when you register your application.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The OAuth client secret provided by Google when you registered your application.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Email input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The new contact's email address.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setEmail($value)
    {
        return $this->set('Email', $value);
    }

    /**
     * Set the value for the FirstName input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The new contact's first name.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setFirstName($value)
    {
        return $this->set('FirstName', $value);
    }

    /**
     * Set the value for the LastName input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The new contact's last name.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setLastName($value)
    {
        return $this->set('LastName', $value);
    }

    /**
     * Set the value for the Phone input for this CreateContact Choreo.
     *
     * @param string $value (optional, string) The phone number for the new contact. It's best to use the "(555) 123-4567" format.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setPhone($value)
    {
        return $this->set('Phone', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateContact Choreo.
     *
     * @param string $value (conditional, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_CreateContact_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the CreateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_CreateContact_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateContact Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateContact execution.
     * @param Google_Contacts_CreateContact $choreo The choreography object for this execution.
     * @param Google_Contacts_CreateContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_CreateContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_CreateContact_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_CreateContact $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateContact execution.
     *
     * @return Google_Contacts_CreateContact_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateContact execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_CreateContact_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_CreateContact_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_CreateContact_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateContact Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_CreateContact_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this CreateContact execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "ContactID" output from this CreateContact execution.
     *
     * @return string (string) The unique ID supplied by Google for the new user.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getContactID()
    {
        return $this->get('ContactID');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateContact execution.
     *
     * @return string (xml) The response from the API.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specified contact.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_DeleteContact extends Temboo_Choreography
{
    /**
     * Deletes a specified contact.
     *
     * @param Temboo_Session $session The session that owns this DeleteContact Choreo.
     * @return Google_Contacts_DeleteContact New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/DeleteContact/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteContact Choreo.
     *
     * @param Google_Contacts_DeleteContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_DeleteContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_DeleteContact_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_DeleteContact_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_DeleteContact_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_DeleteContact_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_DeleteContact_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_DeleteContact_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteContact input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteContact Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteContact Choreo.
     *
     * @param string $value (required, string) The OAuth client ID provided by Google when you register your application.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteContact Choreo.
     *
     * @param string $value (required, string) The OAuth client secret provided by Google when you registered your application.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ContactID input for this DeleteContact Choreo.
     *
     * @param string $value (required, string) The unique ID string for the contact you want to delete.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setContactID($value)
    {
        return $this->set('ContactID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteContact Choreo.
     *
     * @param string $value (required, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_DeleteContact_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the DeleteContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_DeleteContact_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteContact Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteContact execution.
     * @param Google_Contacts_DeleteContact $choreo The choreography object for this execution.
     * @param Google_Contacts_DeleteContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_DeleteContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_DeleteContact_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_DeleteContact $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteContact execution.
     *
     * @return Google_Contacts_DeleteContact_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteContact execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_DeleteContact_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_DeleteContact_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_DeleteContact_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteContact Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_DeleteContact_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this DeleteContact execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteContact execution.
     *
     * @return string The response from Google. No content is returned for a successful delete request.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for all contacts in an account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllContacts extends Temboo_Choreography
{
    /**
     * Retrieve data for all contacts in an account.
     *
     * @param Temboo_Session $session The session that owns this GetAllContacts Choreo.
     * @return Google_Contacts_GetAllContacts New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/GetAllContacts/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAllContacts Choreo.
     *
     * @param Google_Contacts_GetAllContacts_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetAllContacts_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetAllContacts_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_GetAllContacts_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAllContacts Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetAllContacts_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_GetAllContacts_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAllContacts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllContacts_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAllContacts Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetAllContacts_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAllContacts input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAllContacts Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAllContacts Choreo.
     *
     * @param string $value (required, string) The client ID provided by Google when you register your application.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAllContacts Choreo.
     *
     * @param string $value (required, string) The client secret provided by Google when you registered your application.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Group input for this GetAllContacts Choreo.
     *
     * @param string $value (optional, string) Constrains the results to only the contacts belonging to the group specified. The value of this parameter specifies group ID.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setGroup($value)
    {
        return $this->set('Group', $value);
    }

    /**
     * Set the value for the MaxResults input for this GetAllContacts Choreo.
     *
     * @param int $value (optional, integer) The maximum number of entries to return.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAllContacts Choreo.
     *
     * @param string $value (required, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SortOrder input for this GetAllContacts Choreo.
     *
     * @param string $value (optional, string) Sorting order direction. Can be either ascending or descending.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setSortOrder($value)
    {
        return $this->set('SortOrder', $value);
    }

    /**
     * Set the value for the StartIndex input for this GetAllContacts Choreo.
     *
     * @param int $value (optional, integer) The index of the first result to be retrieved (for paging).
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }

    /**
     * Set the value for the UpdatedMin input for this GetAllContacts Choreo.
     *
     * @param string $value (optional, date) The lower bound on entry update dates to filter by (e.g., 2015-01-16T00:00:00).
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setUpdatedMin($value)
    {
        return $this->set('UpdatedMin', $value);
    }

    /**
     * Set the value for the UserEmail input for this GetAllContacts Choreo.
     *
     * @param string $value (optional, string) The email address of the user whose contacts you want to retrieve. Defaults to "default," or the user whose OAuth access token is passed.
     * @return Google_Contacts_GetAllContacts_Inputs For method chaining.
     */
    public function setUserEmail($value)
    {
        return $this->set('UserEmail', $value);
    }
}


/**
 * Execution object for the GetAllContacts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllContacts_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAllContacts Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAllContacts execution.
     * @param Google_Contacts_GetAllContacts $choreo The choreography object for this execution.
     * @param Google_Contacts_GetAllContacts_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetAllContacts_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetAllContacts_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_GetAllContacts $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAllContacts execution.
     *
     * @return Google_Contacts_GetAllContacts_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAllContacts execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_GetAllContacts_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_GetAllContacts_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAllContacts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllContacts_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAllContacts Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_GetAllContacts_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this GetAllContacts execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAllContacts execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve data for all groups in an account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllGroups extends Temboo_Choreography
{
    /**
     * Retrieve data for all groups in an account.
     *
     * @param Temboo_Session $session The session that owns this GetAllGroups Choreo.
     * @return Google_Contacts_GetAllGroups New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/GetAllGroups/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAllGroups Choreo.
     *
     * @param Google_Contacts_GetAllGroups_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetAllGroups_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetAllGroups_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_GetAllGroups_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAllGroups Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetAllGroups_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_GetAllGroups_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAllGroups Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllGroups_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAllGroups Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetAllGroups_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAllGroups input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAllGroups Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAllGroups Choreo.
     *
     * @param string $value (required, string) The OAuth client ID provided by Google when you register your application.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAllGroups Choreo.
     *
     * @param string $value (required, string) The OAuth client secret provided by Google when you registered your application.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the MaxResults input for this GetAllGroups Choreo.
     *
     * @param int $value (optional, integer) The maximum number of entries to return.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAllGroups Choreo.
     *
     * @param string $value (required, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartIndex input for this GetAllGroups Choreo.
     *
     * @param int $value (optional, integer) The index of the first result to be retrieved (for paging).
     * @return Google_Contacts_GetAllGroups_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }
}


/**
 * Execution object for the GetAllGroups Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllGroups_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAllGroups Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAllGroups execution.
     * @param Google_Contacts_GetAllGroups $choreo The choreography object for this execution.
     * @param Google_Contacts_GetAllGroups_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetAllGroups_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetAllGroups_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_GetAllGroups $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAllGroups execution.
     *
     * @return Google_Contacts_GetAllGroups_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAllGroups execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_GetAllGroups_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_GetAllGroups_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAllGroups Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetAllGroups_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAllGroups Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_GetAllGroups_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this GetAllGroups execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAllGroups execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific contact with a given id.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactById extends Temboo_Choreography
{
    /**
     * Retrieves a specific contact with a given id.
     *
     * @param Temboo_Session $session The session that owns this GetContactById Choreo.
     * @return Google_Contacts_GetContactById New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/GetContactById/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetContactById Choreo.
     *
     * @param Google_Contacts_GetContactById_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetContactById_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetContactById_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_GetContactById_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetContactById Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetContactById_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_GetContactById_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetContactById Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactById_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetContactById Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetContactById_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetContactById input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetContactById Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetContactById Choreo.
     *
     * @param string $value (required, string) The client ID provided by Google when you register your application.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetContactById Choreo.
     *
     * @param string $value (required, string) The client secret provided by Google when you registered your application.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ContactId input for this GetContactById Choreo.
     *
     * @param string $value (required, string) The id associated with the contact to return. This can either be the individual id of the contact, or the full 'edit' link returned in the entry nodes of the GetAllContacts output.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setContactId($value)
    {
        return $this->set('ContactId', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetContactById Choreo.
     *
     * @param string $value (required, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserEmail input for this GetContactById Choreo.
     *
     * @param string $value (required, string) The email address of the user whose contacts you want to retrieve. Defaults to "default," or the user whose OAuth access token is passed.
     * @return Google_Contacts_GetContactById_Inputs For method chaining.
     */
    public function setUserEmail($value)
    {
        return $this->set('UserEmail', $value);
    }
}


/**
 * Execution object for the GetContactById Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactById_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetContactById Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetContactById execution.
     * @param Google_Contacts_GetContactById $choreo The choreography object for this execution.
     * @param Google_Contacts_GetContactById_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetContactById_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetContactById_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_GetContactById $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetContactById execution.
     *
     * @return Google_Contacts_GetContactById_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetContactById execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_GetContactById_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_GetContactById_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetContactById Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactById_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetContactById Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_GetContactById_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this GetContactById execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetContactById execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the contact or contacts in that account that match a specified query term.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactsWithQuery extends Temboo_Choreography
{
    /**
     * Retrieves the contact or contacts in that account that match a specified query term.
     *
     * @param Temboo_Session $session The session that owns this GetContactsWithQuery Choreo.
     * @return Google_Contacts_GetContactsWithQuery New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/GetContactsWithQuery/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetContactsWithQuery Choreo.
     *
     * @param Google_Contacts_GetContactsWithQuery_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetContactsWithQuery_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetContactsWithQuery_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_GetContactsWithQuery_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetContactsWithQuery Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetContactsWithQuery_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_GetContactsWithQuery_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetContactsWithQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactsWithQuery_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetContactsWithQuery Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_GetContactsWithQuery_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetContactsWithQuery input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (required, string) The OAuth client ID provided by Google when you register your application.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (required, string) The OAuth client secret provided by Google when you registered your application.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Group input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (optional, string) Constrains the results to only the contacts belonging to the group specified. The value of this parameter specifies group ID.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setGroup($value)
    {
        return $this->set('Group', $value);
    }

    /**
     * Set the value for the MaxResults input for this GetContactsWithQuery Choreo.
     *
     * @param int $value (optional, integer) The maximum number of entries to return.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the Query input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (required, string) The contact criteria to search for, such as name or email address.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (required, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SortOrder input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (optional, string) Sorting order direction. Can be either ascending or descending.
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setSortOrder($value)
    {
        return $this->set('SortOrder', $value);
    }

    /**
     * Set the value for the StartIndex input for this GetContactsWithQuery Choreo.
     *
     * @param int $value (optional, integer) The index of the first result to be retrieved (for paging).
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setStartIndex($value)
    {
        return $this->set('StartIndex', $value);
    }

    /**
     * Set the value for the UpdatedMin input for this GetContactsWithQuery Choreo.
     *
     * @param string $value (optional, date) The lower bound on entry update dates to filter by (e.g., 2015-01-16T00:00:00).
     * @return Google_Contacts_GetContactsWithQuery_Inputs For method chaining.
     */
    public function setUpdatedMin($value)
    {
        return $this->set('UpdatedMin', $value);
    }
}


/**
 * Execution object for the GetContactsWithQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactsWithQuery_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetContactsWithQuery Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetContactsWithQuery execution.
     * @param Google_Contacts_GetContactsWithQuery $choreo The choreography object for this execution.
     * @param Google_Contacts_GetContactsWithQuery_Inputs|array $inputs (optional) Inputs as Google_Contacts_GetContactsWithQuery_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_GetContactsWithQuery_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_GetContactsWithQuery $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetContactsWithQuery execution.
     *
     * @return Google_Contacts_GetContactsWithQuery_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetContactsWithQuery execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_GetContactsWithQuery_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_GetContactsWithQuery_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetContactsWithQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_GetContactsWithQuery_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetContactsWithQuery Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_GetContactsWithQuery_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this GetContactsWithQuery execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "ContactID" output from this GetContactsWithQuery execution.
     *
     * @return string (string) The unique ID string for the retrieved contact. If more than one contact is retrieved by the request, only the first contact's ID is output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getContactID()
    {
        return $this->get('ContactID');
    }
    /**
     * Retrieve the value for the "Link" output from this GetContactsWithQuery execution.
     *
     * @return string (string) The unique edit link for the retrieved contact. If more than one contact is retrieved by the request, only the first contact's edit link is output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getLink()
    {
        return $this->get('Link');
    }
    /**
     * Retrieve the value for the "Response" output from this GetContactsWithQuery execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Update an existing contact's information.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_UpdateContact extends Temboo_Choreography
{
    /**
     * Update an existing contact's information.
     *
     * @param Temboo_Session $session The session that owns this UpdateContact Choreo.
     * @return Google_Contacts_UpdateContact New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Contacts/UpdateContact/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateContact Choreo.
     *
     * @param Google_Contacts_UpdateContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_UpdateContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_UpdateContact_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Contacts_UpdateContact_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_UpdateContact_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Contacts_UpdateContact_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_UpdateContact_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateContact Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Contacts_UpdateContact_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateContact input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateContact Choreo.
     *
     * @param string $value (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The OAuth client ID provided by Google when you register your application.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The OAuth client secret provided by Google when you registered your application.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ID input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The id of the contact to update. Required unless providing a value for the Query input.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setID($value)
    {
        return $this->set('ID', $value);
    }

    /**
     * Set the value for the NewEmail input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The contact's new email address.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setNewEmail($value)
    {
        return $this->set('NewEmail', $value);
    }

    /**
     * Set the value for the NewFirstName input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The contact's new first name.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setNewFirstName($value)
    {
        return $this->set('NewFirstName', $value);
    }

    /**
     * Set the value for the NewLastName input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The contact's new last name.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setNewLastName($value)
    {
        return $this->set('NewLastName', $value);
    }

    /**
     * Set the value for the NewPhone input for this UpdateContact Choreo.
     *
     * @param string $value (optional, string) The contact's new telephone number.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setNewPhone($value)
    {
        return $this->set('NewPhone', $value);
    }

    /**
     * Set the value for the Query input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) A search term to retrieve the contact to update, such as an email address, last name, or address. Required unless providing a value for the ID input.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateContact Choreo.
     *
     * @param string $value (conditional, string) The refresh token retrieved in the last step of the OAuth process. This is used when an access token is expired or not provided.
     * @return Google_Contacts_UpdateContact_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the UpdateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_UpdateContact_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateContact Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateContact execution.
     * @param Google_Contacts_UpdateContact $choreo The choreography object for this execution.
     * @param Google_Contacts_UpdateContact_Inputs|array $inputs (optional) Inputs as Google_Contacts_UpdateContact_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Contacts_UpdateContact_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Contacts_UpdateContact $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateContact execution.
     *
     * @return Google_Contacts_UpdateContact_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateContact execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Contacts_UpdateContact_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Contacts_UpdateContact_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateContact Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Contacts_UpdateContact_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateContact Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Contacts_UpdateContact_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this UpdateContact execution.
     *
     * @return string (optional, string) The access token retrieved in the last step of the OAuth process. Access tokens that are expired will be refreshed and returned in the Choreo output.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "ContactID" output from this UpdateContact execution.
     *
     * @return string (string) The unique ID for the contact returned by Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getContactID()
    {
        return $this->get('ContactID');
    }
    /**
     * Retrieve the value for the "Email" output from this UpdateContact execution.
     *
     * @return string (string) The contact's current email address.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getEmail()
    {
        return $this->get('Email');
    }
    /**
     * Retrieve the value for the "FirstName" output from this UpdateContact execution.
     *
     * @return string (string) The contact's current given name.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFirstName()
    {
        return $this->get('FirstName');
    }
    /**
     * Retrieve the value for the "LastName" output from this UpdateContact execution.
     *
     * @return string (string) The contact's current family name.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getLastName()
    {
        return $this->get('LastName');
    }
    /**
     * Retrieve the value for the "Phone" output from this UpdateContact execution.
     *
     * @return string (string) The contact's current telephone number.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getPhone()
    {
        return $this->get('Phone');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateContact execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 *  Generate biking directions between two locations, denoted by address or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetBicyclingDirections extends Temboo_Choreography
{
    /**
     *  Generate biking directions between two locations, denoted by address or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this GetBicyclingDirections Choreo.
     * @return Google_Directions_GetBicyclingDirections New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Directions/GetBicyclingDirections/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetBicyclingDirections Choreo.
     *
     * @param Google_Directions_GetBicyclingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetBicyclingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetBicyclingDirections_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Directions_GetBicyclingDirections_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetBicyclingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetBicyclingDirections_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Directions_GetBicyclingDirections_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetBicyclingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetBicyclingDirections_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetBicyclingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetBicyclingDirections_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetBicyclingDirections input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Destination input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be generated (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setDestination($value)
    {
        return $this->set('Destination', $value);
    }

    /**
     * Set the value for the Origin input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be computed (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setOrigin($value)
    {
        return $this->set('Origin', $value);
    }

    /**
     * Set the value for the Region input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this GetBicyclingDirections Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }

    /**
     * Set the value for the Waypoints input for this GetBicyclingDirections Choreo.
     *
     * @param string $value (optional, string) Specify route waypoints, either by address, or latitude/longitude coordinates.
     * @return Google_Directions_GetBicyclingDirections_Inputs For method chaining.
     */
    public function setWaypoints($value)
    {
        return $this->set('Waypoints', $value);
    }
}


/**
 * Execution object for the GetBicyclingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetBicyclingDirections_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetBicyclingDirections Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetBicyclingDirections execution.
     * @param Google_Directions_GetBicyclingDirections $choreo The choreography object for this execution.
     * @param Google_Directions_GetBicyclingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetBicyclingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetBicyclingDirections_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Directions_GetBicyclingDirections $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetBicyclingDirections execution.
     *
     * @return Google_Directions_GetBicyclingDirections_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetBicyclingDirections execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Directions_GetBicyclingDirections_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Directions_GetBicyclingDirections_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetBicyclingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetBicyclingDirections_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetBicyclingDirections Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Directions_GetBicyclingDirections_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this GetBicyclingDirections execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 *  Generates directions between two locations, denoted by address, or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetDrivingDirections extends Temboo_Choreography
{
    /**
     *  Generates directions between two locations, denoted by address, or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this GetDrivingDirections Choreo.
     * @return Google_Directions_GetDrivingDirections New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Directions/GetDrivingDirections/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetDrivingDirections Choreo.
     *
     * @param Google_Directions_GetDrivingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetDrivingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetDrivingDirections_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Directions_GetDrivingDirections_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetDrivingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetDrivingDirections_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Directions_GetDrivingDirections_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetDrivingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetDrivingDirections_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetDrivingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetDrivingDirections_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetDrivingDirections input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GetDrivingDirections Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this GetDrivingDirections Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Avoid input for this GetDrivingDirections Choreo.
     *
     * @param string $value (optional, string) Specify whether the calculated directions should avoid the following features: tolls, or highways.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setAvoid($value)
    {
        return $this->set('Avoid', $value);
    }

    /**
     * Set the value for the Destination input for this GetDrivingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be generated (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setDestination($value)
    {
        return $this->set('Destination', $value);
    }

    /**
     * Set the value for the Origin input for this GetDrivingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be computed (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setOrigin($value)
    {
        return $this->set('Origin', $value);
    }

    /**
     * Set the value for the Region input for this GetDrivingDirections Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this GetDrivingDirections Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this GetDrivingDirections Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }

    /**
     * Set the value for the Waypoints input for this GetDrivingDirections Choreo.
     *
     * @param string $value (optional, string) Specify route waypoints, either by address, or latitude/longitude coordinates.
     * @return Google_Directions_GetDrivingDirections_Inputs For method chaining.
     */
    public function setWaypoints($value)
    {
        return $this->set('Waypoints', $value);
    }
}


/**
 * Execution object for the GetDrivingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetDrivingDirections_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetDrivingDirections Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetDrivingDirections execution.
     * @param Google_Directions_GetDrivingDirections $choreo The choreography object for this execution.
     * @param Google_Directions_GetDrivingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetDrivingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetDrivingDirections_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Directions_GetDrivingDirections $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetDrivingDirections execution.
     *
     * @return Google_Directions_GetDrivingDirections_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetDrivingDirections execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Directions_GetDrivingDirections_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Directions_GetDrivingDirections_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetDrivingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetDrivingDirections_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetDrivingDirections Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Directions_GetDrivingDirections_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this GetDrivingDirections execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 *  Generate walking directions between two locations, denoted by address or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetWalkingDirections extends Temboo_Choreography
{
    /**
     *  Generate walking directions between two locations, denoted by address or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this GetWalkingDirections Choreo.
     * @return Google_Directions_GetWalkingDirections New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Directions/GetWalkingDirections/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetWalkingDirections Choreo.
     *
     * @param Google_Directions_GetWalkingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetWalkingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetWalkingDirections_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Directions_GetWalkingDirections_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetWalkingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetWalkingDirections_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Directions_GetWalkingDirections_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetWalkingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetWalkingDirections_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetWalkingDirections Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Directions_GetWalkingDirections_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetWalkingDirections input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GetWalkingDirections Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this GetWalkingDirections Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Destination input for this GetWalkingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be generated (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setDestination($value)
    {
        return $this->set('Destination', $value);
    }

    /**
     * Set the value for the Origin input for this GetWalkingDirections Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates from which directions will be computed (i.e."104 Franklin St, New York, NY" or "40.7160,-74.0037").
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setOrigin($value)
    {
        return $this->set('Origin', $value);
    }

    /**
     * Set the value for the Region input for this GetWalkingDirections Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this GetWalkingDirections Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this GetWalkingDirections Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }

    /**
     * Set the value for the Waypoints input for this GetWalkingDirections Choreo.
     *
     * @param string $value (optional, string) Specify route waypoints, either by address, or latitude/longitude coordinates.
     * @return Google_Directions_GetWalkingDirections_Inputs For method chaining.
     */
    public function setWaypoints($value)
    {
        return $this->set('Waypoints', $value);
    }
}


/**
 * Execution object for the GetWalkingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetWalkingDirections_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetWalkingDirections Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetWalkingDirections execution.
     * @param Google_Directions_GetWalkingDirections $choreo The choreography object for this execution.
     * @param Google_Directions_GetWalkingDirections_Inputs|array $inputs (optional) Inputs as Google_Directions_GetWalkingDirections_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Directions_GetWalkingDirections_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Directions_GetWalkingDirections $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetWalkingDirections execution.
     *
     * @return Google_Directions_GetWalkingDirections_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetWalkingDirections execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Directions_GetWalkingDirections_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Directions_GetWalkingDirections_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetWalkingDirections Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Directions_GetWalkingDirections_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetWalkingDirections Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Directions_GetWalkingDirections_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this GetWalkingDirections execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Obtain bicycling distances and times for a matrix of addresses and/or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_BicyclingDistanceMatrix extends Temboo_Choreography
{
    /**
     * Obtain bicycling distances and times for a matrix of addresses and/or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this BicyclingDistanceMatrix Choreo.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/DistanceMatrix/BicyclingDistanceMatrix/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this BicyclingDistanceMatrix Choreo.
     *
     * @param Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_DistanceMatrix_BicyclingDistanceMatrix_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this BicyclingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the BicyclingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the BicyclingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this BicyclingDistanceMatrix input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Destinations input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates to which directions will be generated. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setDestinations($value)
    {
        return $this->set('Destinations', $value);
    }

    /**
     * Set the value for the Language input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Set the language in which to return restults.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Origins input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address(es) or geo-coordinates from which distance and time will be computed. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setOrigins($value)
    {
        return $this->set('Origins', $value);
    }

    /**
     * Set the value for the Region input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this BicyclingDistanceMatrix Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this BicyclingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }
}


/**
 * Execution object for the BicyclingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_BicyclingDistanceMatrix_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the BicyclingDistanceMatrix Choreo.
     *
     * @param Temboo_Session $session The session that owns this BicyclingDistanceMatrix execution.
     * @param Google_DistanceMatrix_BicyclingDistanceMatrix $choreo The choreography object for this execution.
     * @param Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_BicyclingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_DistanceMatrix_BicyclingDistanceMatrix $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this BicyclingDistanceMatrix execution.
     *
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this BicyclingDistanceMatrix execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_DistanceMatrix_BicyclingDistanceMatrix_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the BicyclingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_BicyclingDistanceMatrix_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the BicyclingDistanceMatrix Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_DistanceMatrix_BicyclingDistanceMatrix_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Distance" output from this BicyclingDistanceMatrix execution.
     *
     * @return int (integer) The distance of this route, expressed in meters.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDistance()
    {
        return $this->get('Distance');
    }
    /**
     * Retrieve the value for the "Duration" output from this BicyclingDistanceMatrix execution.
     *
     * @return int (integer) The duration of this route, expressed in seconds.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDuration()
    {
        return $this->get('Duration');
    }
    /**
     * Retrieve the value for the "Response" output from this BicyclingDistanceMatrix execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Obtain travel distances and times for a matrix of addresses and/or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_DrivingDistanceMatrix extends Temboo_Choreography
{
    /**
     * Obtain travel distances and times for a matrix of addresses and/or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this DrivingDistanceMatrix Choreo.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/DistanceMatrix/DrivingDistanceMatrix/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DrivingDistanceMatrix Choreo.
     *
     * @param Google_DistanceMatrix_DrivingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_DrivingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_DistanceMatrix_DrivingDistanceMatrix_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DrivingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_DistanceMatrix_DrivingDistanceMatrix_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DrivingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_DrivingDistanceMatrix_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DrivingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DrivingDistanceMatrix input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Avoid input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Specify whether the calculated directions should avoid the following features: tolls, or highways.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setAvoid($value)
    {
        return $this->set('Avoid', $value);
    }

    /**
     * Set the value for the Destinations input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates to which directions will be generated. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setDestinations($value)
    {
        return $this->set('Destinations', $value);
    }

    /**
     * Set the value for the Language input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Set the language in which to return restults.  A list of supported languages is available here: https://spreadsheets.google.com/pub?key=p9pdwsai2hDMsLkXsoM05KQ&gid=1
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Origins input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address(es) or geo-coordinates from which distance and time will be computed. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setOrigins($value)
    {
        return $this->set('Origins', $value);
    }

    /**
     * Set the value for the Region input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this DrivingDistanceMatrix Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this DrivingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }
}


/**
 * Execution object for the DrivingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_DrivingDistanceMatrix_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DrivingDistanceMatrix Choreo.
     *
     * @param Temboo_Session $session The session that owns this DrivingDistanceMatrix execution.
     * @param Google_DistanceMatrix_DrivingDistanceMatrix $choreo The choreography object for this execution.
     * @param Google_DistanceMatrix_DrivingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_DrivingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_DistanceMatrix_DrivingDistanceMatrix $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DrivingDistanceMatrix execution.
     *
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DrivingDistanceMatrix execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_DistanceMatrix_DrivingDistanceMatrix_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DrivingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_DrivingDistanceMatrix_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DrivingDistanceMatrix Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_DistanceMatrix_DrivingDistanceMatrix_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Distance" output from this DrivingDistanceMatrix execution.
     *
     * @return int (integer) The distance of this route, expressed in meters.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDistance()
    {
        return $this->get('Distance');
    }
    /**
     * Retrieve the value for the "Duration" output from this DrivingDistanceMatrix execution.
     *
     * @return int (integer) The duration of this route, expressed in seconds.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDuration()
    {
        return $this->get('Duration');
    }
    /**
     * Retrieve the value for the "Response" output from this DrivingDistanceMatrix execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Obtain walking distances and times for a matrix of addresses and/or latitude/longitude coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_WalkingDistanceMatrix extends Temboo_Choreography
{
    /**
     * Obtain walking distances and times for a matrix of addresses and/or latitude/longitude coordinates.
     *
     * @param Temboo_Session $session The session that owns this WalkingDistanceMatrix Choreo.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/DistanceMatrix/WalkingDistanceMatrix/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this WalkingDistanceMatrix Choreo.
     *
     * @param Google_DistanceMatrix_WalkingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_WalkingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_DistanceMatrix_WalkingDistanceMatrix_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this WalkingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_DistanceMatrix_WalkingDistanceMatrix_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the WalkingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_WalkingDistanceMatrix_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the WalkingDistanceMatrix Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this WalkingDistanceMatrix input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Alternatives input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) If set to true, additional routes will be returned.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setAlternatives($value)
    {
        return $this->set('Alternatives', $value);
    }

    /**
     * Set the value for the Destinations input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address or latitude/longitude coordinates to which directions will be generated. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setDestinations($value)
    {
        return $this->set('Destinations', $value);
    }

    /**
     * Set the value for the Language input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Set the language in which to return restults.  A list of supported languages is available here: https://spreadsheets.google.com/pub?key=p9pdwsai2hDMsLkXsoM05KQ&gid=1
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Origins input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (required, string) Enter the address(es) or geo-coordinates from which distance and time will be computed. Multiple destinations can be separated by pipes (|).  For example: Boston, MA|New Haven|40.7160,-74.0037.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setOrigins($value)
    {
        return $this->set('Origins', $value);
    }

    /**
     * Set the value for the Region input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Enter the region code for the directions, specified as a ccTLD two-character value.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the Sensor input for this WalkingDistanceMatrix Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Units input for this WalkingDistanceMatrix Choreo.
     *
     * @param string $value (optional, string) Specify the units to be used when displaying results.  Options include, metric, or imperial.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Inputs For method chaining.
     */
    public function setUnits($value)
    {
        return $this->set('Units', $value);
    }
}


/**
 * Execution object for the WalkingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_WalkingDistanceMatrix_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the WalkingDistanceMatrix Choreo.
     *
     * @param Temboo_Session $session The session that owns this WalkingDistanceMatrix execution.
     * @param Google_DistanceMatrix_WalkingDistanceMatrix $choreo The choreography object for this execution.
     * @param Google_DistanceMatrix_WalkingDistanceMatrix_Inputs|array $inputs (optional) Inputs as Google_DistanceMatrix_WalkingDistanceMatrix_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_DistanceMatrix_WalkingDistanceMatrix $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this WalkingDistanceMatrix execution.
     *
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this WalkingDistanceMatrix execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_DistanceMatrix_WalkingDistanceMatrix_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the WalkingDistanceMatrix Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_DistanceMatrix_WalkingDistanceMatrix_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the WalkingDistanceMatrix Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_DistanceMatrix_WalkingDistanceMatrix_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Distance" output from this WalkingDistanceMatrix execution.
     *
     * @return int (integer) The distance of this route, expressed in meters.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDistance()
    {
        return $this->get('Distance');
    }
    /**
     * Retrieve the value for the "Duration" output from this WalkingDistanceMatrix execution.
     *
     * @return int (integer) The duration of this route, expressed in meters.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDuration()
    {
        return $this->get('Duration');
    }
    /**
     * Retrieve the value for the "Response" output from this WalkingDistanceMatrix execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a specific change.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_Get extends Temboo_Choreography
{
    /**
     * Gets a specific change.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Changes_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Changes/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Changes_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Changes_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Changes_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Changes_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Changes_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Changes_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Changes_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ChangeID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the change.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setChangeID($value)
    {
        return $this->set('ChangeID', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Changes_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Changes_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Changes_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Changes_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Changes_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Changes_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Changes_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Changes_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Changes_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the changes for a user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_List extends Temboo_Choreography
{
    /**
     * Lists the changes for a user.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Changes_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Changes/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Changes_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Changes_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Changes_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Changes_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Changes_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Changes_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Changes_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the IncludeDeleted input for this List Choreo.
     *
     * @param bool $value (optional, boolean) Whether to include deleted items. (Default: true).
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setIncludeDeleted($value)
    {
        return $this->set('IncludeDeleted', $value);
    }

    /**
     * Set the value for the IncludeSubscribed input for this List Choreo.
     *
     * @param bool $value (optional, boolean) Whether to include shared files and public files the user opened. If false, the list includes owned files plus any shared or public files the user explictly added to a folder in Drive. (Default: true)
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setIncludeSubscribed($value)
    {
        return $this->set('IncludeSubscribed', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param bool $value (optional, boolean) Maximum number of changes to return.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) Page token for changes.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartChangeID input for this List Choreo.
     *
     * @param string $value (optional, multiline) Change ID to start listing changes from.
     * @return Google_Drive_Changes_List_Inputs For method chaining.
     */
    public function setStartChangeID($value)
    {
        return $this->set('StartChangeID', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Changes_List $choreo The choreography object for this execution.
     * @param Google_Drive_Changes_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Changes_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Changes_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Changes_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Changes_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Changes_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Changes_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Changes_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Changes_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Removes a child for a folder.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Delete extends Temboo_Choreography
{
    /**
     * Removes a child for a folder.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Children_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Children/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Children_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Children_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Children_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ChildID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the child.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setChildID($value)
    {
        return $this->set('ChildID', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Delete Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FolderID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the folder.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setFolderID($value)
    {
        return $this->set('FolderID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Children_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Children_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Children_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Children_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Children_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Children_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Children_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a specific child reference.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Get extends Temboo_Choreography
{
    /**
     * Gets a specific child reference.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Children_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Children/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Children_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Children_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Children_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ChildID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the child.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setChildID($value)
    {
        return $this->set('ChildID', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FolderID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the folder.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setFolderID($value)
    {
        return $this->set('FolderID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Children_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Children_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Children_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Children_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Children_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Children_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Children_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Inserts a file into a folder.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Insert extends Temboo_Choreography
{
    /**
     * Inserts a file into a folder.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Children_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Children/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Children_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Children_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Children_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FolderID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the folder.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setFolderID($value)
    {
        return $this->set('FolderID', $value);
    }

    /**
     * Set the value for the ID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the child.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setID($value)
    {
        return $this->set('ID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Children_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Children_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Children_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Children_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Children_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Children_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Children_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the children of a specified folder.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_List extends Temboo_Choreography
{
    /**
     * Lists the children of a specified folder.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Children_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Children/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Children_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Children_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Children_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Children_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FolderID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the folder. To list all files in the root folder, specify the value "root".
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setFolderID($value)
    {
        return $this->set('FolderID', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) Maximum number of children to return.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) Page token for children.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this List Choreo.
     *
     * @param string $value (optional, string) Query string for searching children.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Children_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Children_List $choreo The choreography object for this execution.
     * @param Google_Drive_Children_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Children_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Children_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Children_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Children_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Children_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Children_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Children_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Children_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Delete extends Temboo_Choreography
{
    /**
     * Deletes a comment.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Comments_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Comments/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Comments_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Comments_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Comments_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Comments_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Comments_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Comments_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Comments_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Comments_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Comments_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Comments_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a comment by ID.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Get extends Temboo_Choreography
{
    /**
     * Gets a comment by ID.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Comments_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Comments/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Comments_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Comments_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the IncludeDeleted input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) If set, this will succeed when retrieving a deleted comment, and will include any deleted replies. (Default: false)
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setIncludeDeleted($value)
    {
        return $this->set('IncludeDeleted', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Comments_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Comments_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Comments_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Comments_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Comments_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Comments_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new comment on the given file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Insert extends Temboo_Choreography
{
    /**
     * Creates a new comment on the given file.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Comments_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Comments/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Comments_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Comments_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Comments_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Insert Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a comment resource which shoud contain at least one key for content. See documentation for formatting examples.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Comments_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Comments_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Comments_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Comments_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Comments_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Comments_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Comments_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists a file's comments.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_List extends Temboo_Choreography
{
    /**
     * Lists a file's comments.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Comments_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Comments/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Comments_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Comments_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the IncludeDeleted input for this List Choreo.
     *
     * @param bool $value (optional, boolean) If set, this will succeed when retrieving a deleted comment, and will include any deleted replies. (Default: false)
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setIncludeDeleted($value)
    {
        return $this->set('IncludeDeleted', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param string $value (optional, string) The maximum number of discussions to include in the response, used for paging. Acceptable values are 0 to 100, inclusive. (Default: 20)
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The continuation token, used to page through large result sets. To get the next page of results, set this parameter to the value of "nextPageToken" from the previous response.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UpdatedMIn input for this List Choreo.
     *
     * @param string $value (optional, string) Only discussions that were updated after this timestamp will be returned. Formatted as an RFC 3339 timestamp.
     * @return Google_Drive_Comments_List_Inputs For method chaining.
     */
    public function setUpdatedMIn($value)
    {
        return $this->set('UpdatedMIn', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Comments_List $choreo The choreography object for this execution.
     * @param Google_Drive_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Comments_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Comments_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Comments_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Comments_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Comments_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates an existing comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Update extends Temboo_Choreography
{
    /**
     * Updates an existing comment.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Drive_Comments_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Comments/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Drive_Comments_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Comments_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Comments_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Comments_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Update Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a comment resource which shoud contain at least one key for content. See documentation for formatting examples.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Comments_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Drive_Comments_Update $choreo The choreography object for this execution.
     * @param Google_Drive_Comments_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Comments_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Comments_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Comments_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Drive_Comments_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Comments_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Comments_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Comments_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Comments_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a copy of the specified file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Copy extends Temboo_Choreography
{
    /**
     * Creates a copy of the specified file.
     *
     * @param Temboo_Session $session The session that owns this Copy Choreo.
     * @return Google_Drive_Files_Copy New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Copy/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Copy Choreo.
     *
     * @param Google_Drive_Files_Copy_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Copy_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Copy_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Copy_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Copy Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Copy_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Copy_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Copy Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Copy_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Copy Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Copy_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Copy input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Copy Choreo.
     *
     * @param string $value (optional, json) A JSON representation of fields in a file resource. File metadata information (such as the title) can be set using this input. See documentation for formatting examples.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Copy Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Copy Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Copy Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Convert input for this Copy Choreo.
     *
     * @param bool $value (optional, boolean) Whether to convert this file to the corresponding Google Docs format. (Default: false).
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setConvert($value)
    {
        return $this->set('Convert', $value);
    }

    /**
     * Set the value for the Fields input for this Copy Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Copy Choreo.
     *
     * @param string $value (required, string) The ID of the file to copy.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the OCR input for this Copy Choreo.
     *
     * @param bool $value (optional, boolean) Whether to attempt OCR on .jpg, .png, .gif, or .pdf uploads. (Default: false)
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setOCR($value)
    {
        return $this->set('OCR', $value);
    }

    /**
     * Set the value for the OcrLanguage input for this Copy Choreo.
     *
     * @param string $value (optional, string) If ocr is true, hints at the language to use. Valid values are ISO 639-1 codes.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setOcrLanguage($value)
    {
        return $this->set('OcrLanguage', $value);
    }

    /**
     * Set the value for the Pinned input for this Copy Choreo.
     *
     * @param bool $value (optional, boolean) Whether to pin the head revision of the uploaded file. (Default: false).
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setPinned($value)
    {
        return $this->set('Pinned', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Copy Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SourceLanguage input for this Copy Choreo.
     *
     * @param string $value (optional, string) The language of the original file to be translated.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setSourceLanguage($value)
    {
        return $this->set('SourceLanguage', $value);
    }

    /**
     * Set the value for the TargetLanguage input for this Copy Choreo.
     *
     * @param string $value (optional, string) Target language to translate the file to. If no sourceLanguage is provided, the API will attempt to detect the language.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setTargetLanguage($value)
    {
        return $this->set('TargetLanguage', $value);
    }

    /**
     * Set the value for the TimedTextLanguage input for this Copy Choreo.
     *
     * @param string $value (optional, string) The language of the timed text.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setTimedTextLanguage($value)
    {
        return $this->set('TimedTextLanguage', $value);
    }

    /**
     * Set the value for the TimedTextTrackName input for this Copy Choreo.
     *
     * @param string $value (optional, string) The timed text track name.
     * @return Google_Drive_Files_Copy_Inputs For method chaining.
     */
    public function setTimedTextTrackName($value)
    {
        return $this->set('TimedTextTrackName', $value);
    }
}


/**
 * Execution object for the Copy Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Copy_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Copy Choreo.
     *
     * @param Temboo_Session $session The session that owns this Copy execution.
     * @param Google_Drive_Files_Copy $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Copy_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Copy_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Copy_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Copy $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Copy execution.
     *
     * @return Google_Drive_Files_Copy_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Copy execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Copy_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Copy_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Copy Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Copy_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Copy Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Copy_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Copy execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Copy execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Permanently deletes a file by ID.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Delete extends Temboo_Choreography
{
    /**
     * Permanently deletes a file by ID.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Files_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Files_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file to delete.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Files_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Files_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a file's metadata and content by ID.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Get extends Temboo_Choreography
{
    /**
     * Gets a file's metadata and content by ID.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Files_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Files_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ExportFormat input for this Get Choreo.
     *
     * @param string $value (optional, string) Indicates the download format (i.e. pdf, doc, txt, rtf, odt, etc). When specified, the FileContent output will contain the file's base64 encoded value.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setExportFormat($value)
    {
        return $this->set('ExportFormat', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file to retrieve.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UpdateViewDate input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) Whether to update the view date after successfully retrieving the file. Default value is false.
     * @return Google_Drive_Files_Get_Inputs For method chaining.
     */
    public function setUpdateViewDate($value)
    {
        return $this->set('UpdateViewDate', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Files_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Files_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FileContent" output from this Get execution.
     *
     * @return string (string) The Base64 encoded file content. Only returned when the optional "Format" parameter is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFileContent()
    {
        return $this->get('FileContent');
    }
    /**
     * Retrieve the value for the "FileMetadata" output from this Get execution.
     *
     * @return string (json) The file metadata returned in the response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFileMetadata()
    {
        return $this->get('FileMetadata');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Inserts a new file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Insert extends Temboo_Choreography
{
    /**
     * Inserts a new file.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Files_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Files_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Insert Choreo.
     *
     * @param string $value (conditional, json) A JSON representation of fields in a file resource. File metadata information (such as the title) can be inserted using this input. See documentation for formatting examples.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ContentType input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Content-Type of the file that is being uploaded (i.e. image/jpg). Required when specifying the FileContent input.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setContentType($value)
    {
        return $this->set('ContentType', $value);
    }

    /**
     * Set the value for the Convert input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Whether to convert this file to the corresponding Google Docs format. (Default: false).
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setConvert($value)
    {
        return $this->set('Convert', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileContent input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Base64 encoded contents of the file to upload.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setFileContent($value)
    {
        return $this->set('FileContent', $value);
    }

    /**
     * Set the value for the OCR input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Whether to attempt OCR on .jpg, .png, .gif, or .pdf uploads. (Default: false)
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setOCR($value)
    {
        return $this->set('OCR', $value);
    }

    /**
     * Set the value for the OcrLanguage input for this Insert Choreo.
     *
     * @param string $value (optional, string) If ocr is true, hints at the language to use. Valid values are ISO 639-1 codes.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setOcrLanguage($value)
    {
        return $this->set('OcrLanguage', $value);
    }

    /**
     * Set the value for the Pinned input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Whether to pin the head revision of the uploaded file. (Default: false).
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setPinned($value)
    {
        return $this->set('Pinned', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SourceLanguage input for this Insert Choreo.
     *
     * @param string $value (optional, string) The language of the original file to be translated.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setSourceLanguage($value)
    {
        return $this->set('SourceLanguage', $value);
    }

    /**
     * Set the value for the TargetLanguage input for this Insert Choreo.
     *
     * @param string $value (optional, string) Target language to translate the file to. If no sourceLanguage is provided, the API will attempt to detect the language.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setTargetLanguage($value)
    {
        return $this->set('TargetLanguage', $value);
    }

    /**
     * Set the value for the TimedTextLanguage input for this Insert Choreo.
     *
     * @param string $value (optional, string) The language of the timed text.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setTimedTextLanguage($value)
    {
        return $this->set('TimedTextLanguage', $value);
    }

    /**
     * Set the value for the TimedTextTrackName input for this Insert Choreo.
     *
     * @param string $value (optional, string) The timed text track name.
     * @return Google_Drive_Files_Insert_Inputs For method chaining.
     */
    public function setTimedTextTrackName($value)
    {
        return $this->set('TimedTextTrackName', $value);
    }

}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Files_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Files_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the user's files.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_List extends Temboo_Choreography
{
    /**
     * Lists the user's files.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Files_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Files_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this List Choreo.
     *
     * @param string $value (optional, string) A search query combining one or more search clauses (e.g. title='myFile.txt').
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Files_List $choreo The choreography object for this execution.
     * @param Google_Drive_Files_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Files_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FileID" output from this List execution.
     *
     * @return string (string) The id of the file returned. This is returned only when using the Query input to search for specific files.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFileID()
    {
        return $this->get('FileID');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sets the file's updated time to the current server time.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Touch extends Temboo_Choreography
{
    /**
     * Sets the file's updated time to the current server time.
     *
     * @param Temboo_Session $session The session that owns this Touch Choreo.
     * @return Google_Drive_Files_Touch New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Touch/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Touch Choreo.
     *
     * @param Google_Drive_Files_Touch_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Touch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Touch_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Touch_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Touch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Touch_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Touch_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Touch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Touch_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Touch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Touch_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Touch input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Touch Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Touch Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Touch Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Touch Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Touch Choreo.
     *
     * @param string $value (required, string) The ID of the file to update.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Touch Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Touch_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Touch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Touch_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Touch Choreo.
     *
     * @param Temboo_Session $session The session that owns this Touch execution.
     * @param Google_Drive_Files_Touch $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Touch_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Touch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Touch_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Touch $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Touch execution.
     *
     * @return Google_Drive_Files_Touch_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Touch execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Touch_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Touch_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Touch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Touch_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Touch Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Touch_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Touch execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Touch execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Moves a file to the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Trash extends Temboo_Choreography
{
    /**
     * Moves a file to the trash.
     *
     * @param Temboo_Session $session The session that owns this Trash Choreo.
     * @return Google_Drive_Files_Trash New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Trash/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Trash Choreo.
     *
     * @param Google_Drive_Files_Trash_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Trash_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Trash_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Trash_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Trash Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Trash_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Trash_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Trash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Trash_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Trash Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Trash_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Trash input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Trash Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Trash Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Trash Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Trash Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Trash Choreo.
     *
     * @param string $value (required, string) The ID of the file to trash.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Trash Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Trash_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Trash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Trash_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Trash Choreo.
     *
     * @param Temboo_Session $session The session that owns this Trash execution.
     * @param Google_Drive_Files_Trash $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Trash_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Trash_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Trash_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Trash $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Trash execution.
     *
     * @return Google_Drive_Files_Trash_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Trash execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Trash_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Trash_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Trash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Trash_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Trash Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Trash_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Trash execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Trash execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Restores a file from the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Untrash extends Temboo_Choreography
{
    /**
     * Restores a file from the trash.
     *
     * @param Temboo_Session $session The session that owns this Untrash Choreo.
     * @return Google_Drive_Files_Untrash New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Untrash/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Untrash Choreo.
     *
     * @param Google_Drive_Files_Untrash_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Untrash_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Untrash_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Untrash_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Untrash Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Untrash_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Untrash_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Untrash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Untrash_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Untrash Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Untrash_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Untrash input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Untrash Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Untrash Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Untrash Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Untrash Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Untrash Choreo.
     *
     * @param string $value (required, string) The ID of the file to untrash.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Untrash Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Untrash_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Untrash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Untrash_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Untrash Choreo.
     *
     * @param Temboo_Session $session The session that owns this Untrash execution.
     * @param Google_Drive_Files_Untrash $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Untrash_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Untrash_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Untrash_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Untrash $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Untrash execution.
     *
     * @return Google_Drive_Files_Untrash_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Untrash execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Untrash_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Untrash_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Untrash Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Untrash_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Untrash Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Untrash_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Untrash execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Untrash execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates the metadata or content of an existing file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Update extends Temboo_Choreography
{
    /**
     * Updates the metadata or content of an existing file.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Drive_Files_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Files/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Drive_Files_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Files_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Files_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Files_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Update Choreo.
     *
     * @param string $value (conditional, json) A JSON representation of fields in a file resource. File metadata information (such as the title) can be updated using this input. See documentation for formatting examples.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ContentType input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Content-Type of the file that is being updated (i.e. image/jpeg). Required if modifying the file content.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setContentType($value)
    {
        return $this->set('ContentType', $value);
    }

    /**
     * Set the value for the Convert input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) Whether to convert this file to the corresponding Google Docs format. (Default: false).
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setConvert($value)
    {
        return $this->set('Convert', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileContent input for this Update Choreo.
     *
     * @param string $value (conditional, string) The new Base64 encoded contents of the file that is being updated.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setFileContent($value)
    {
        return $this->set('FileContent', $value);
    }

    /**
     * Set the value for the FileID input for this Update Choreo.
     *
     * @param string $value (required, string) The id of the file to update.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the OCR input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) Whether to attempt OCR on .jpg, .png, .gif, or .pdf uploads. (Default: false)
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setOCR($value)
    {
        return $this->set('OCR', $value);
    }

    /**
     * Set the value for the OcrLanguage input for this Update Choreo.
     *
     * @param string $value (optional, string) If ocr is true, hints at the language to use. Valid values are ISO 639-1 codes.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setOcrLanguage($value)
    {
        return $this->set('OcrLanguage', $value);
    }

    /**
     * Set the value for the Pinned input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) Whether to pin the new revision. (Default: false).
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setPinned($value)
    {
        return $this->set('Pinned', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SetModifiedDate input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) Whether to set the modified date with the supplied modified date.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setSetModifiedDate($value)
    {
        return $this->set('SetModifiedDate', $value);
    }

    /**
     * Set the value for the SourceLanguage input for this Update Choreo.
     *
     * @param string $value (optional, string) The language of the original file to be translated.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setSourceLanguage($value)
    {
        return $this->set('SourceLanguage', $value);
    }

    /**
     * Set the value for the TargetLanguage input for this Update Choreo.
     *
     * @param string $value (optional, string) Target language to translate the file to. If no sourceLanguage is provided, the API will attempt to detect the language.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setTargetLanguage($value)
    {
        return $this->set('TargetLanguage', $value);
    }

    /**
     * Set the value for the TimedTextLanguage input for this Update Choreo.
     *
     * @param string $value (optional, string) The language of the timed text.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setTimedTextLanguage($value)
    {
        return $this->set('TimedTextLanguage', $value);
    }

    /**
     * Set the value for the TimedTextTrackName input for this Update Choreo.
     *
     * @param string $value (optional, string) The timed text track name.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setTimedTextTrackName($value)
    {
        return $this->set('TimedTextTrackName', $value);
    }

    /**
     * Set the value for the UpdateViewedDate input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) Whether to update the view date after successfully updating the file.
     * @return Google_Drive_Files_Update_Inputs For method chaining.
     */
    public function setUpdateViewedDate($value)
    {
        return $this->set('UpdateViewedDate', $value);
    }

}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Drive_Files_Update $choreo The choreography object for this execution.
     * @param Google_Drive_Files_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Files_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Files_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Files_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Drive_Files_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Files_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Files_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Files_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Files_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Removes a parent from a file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Delete extends Temboo_Choreography
{
    /**
     * Removes a parent from a file.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Parents_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Parents/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Parents_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Parents_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Parents_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the ParentID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the parent.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setParentID($value)
    {
        return $this->set('ParentID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Parents_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Parents_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Parents_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Parents_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Parents_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Parents_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Parents_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a specific parent reference.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Get extends Temboo_Choreography
{
    /**
     * Gets a specific parent reference.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Parents_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Parents/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Parents_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Parents_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Parents_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the ParentID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the parent.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setParentID($value)
    {
        return $this->set('ParentID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Parents_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Parents_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Parents_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Parents_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Parents_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Parents_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Parents_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Adds a parent folder for a file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Insert extends Temboo_Choreography
{
    /**
     * Adds a parent folder for a file.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Parents_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Parents/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Parents_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Parents_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Parents_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the ParentID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the parent.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setParentID($value)
    {
        return $this->set('ParentID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Parents_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Parents_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Parents_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Parents_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Parents_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Parents_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Parents_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists a file's parents.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_List extends Temboo_Choreography
{
    /**
     * Lists a file's parents.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Parents_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Parents/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Parents_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Parents_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Parents_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Parents_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Parents_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Parents_List $choreo The choreography object for this execution.
     * @param Google_Drive_Parents_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Parents_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Parents_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Parents_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Parents_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Parents_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Parents_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Parents_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Parents_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a permission from a file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Delete extends Temboo_Choreography
{
    /**
     * Deletes a permission from a file.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Permissions_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Permissions/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Permissions_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Permissions_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Permissions_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the PermissionID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID for the permission.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setPermissionID($value)
    {
        return $this->set('PermissionID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Permissions_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Permissions_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Permissions_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Permissions_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Permissions_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Permissions_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Permissions_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a permission by ID.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Get extends Temboo_Choreography
{
    /**
     * Gets a permission by ID.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Permissions_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Permissions/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Permissions_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Permissions_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Permissions_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the PermissionID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID for the permission.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setPermissionID($value)
    {
        return $this->set('PermissionID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Permissions_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Permissions_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Permissions_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Permissions_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Permissions_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Permissions_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Permissions_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Inserts a permission for a file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Insert extends Temboo_Choreography
{
    /**
     * Inserts a permission for a file.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Permissions_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Permissions/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Permissions_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Permissions_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Permissions_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Insert Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a permissions resource. The JSON string must contain keys for role, type, and value. See documentation for formatting examples.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SendNotificationEmails input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Whether to send notification emails. (Default: true).
     * @return Google_Drive_Permissions_Insert_Inputs For method chaining.
     */
    public function setSendNotificationEmails($value)
    {
        return $this->set('SendNotificationEmails', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Permissions_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Permissions_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Permissions_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Permissions_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Permissions_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Permissions_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Permissions_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists a file's permissions.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_List extends Temboo_Choreography
{
    /**
     * Lists a file's permissions.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Permissions_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Permissions/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Permissions_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Permissions_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Permissions_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Permissions_List $choreo The choreography object for this execution.
     * @param Google_Drive_Permissions_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Permissions_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Permissions_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Permissions_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Permissions_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Permissions_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates an existing permission.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Update extends Temboo_Choreography
{
    /**
     * Updates an existing permission.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Drive_Permissions_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Permissions/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Drive_Permissions_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Permissions_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Permissions_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Permissions_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Update Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a permissions resource. The JSON string can contain keys for role and additionalRoles. See documentation for formatting examples.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the PermissionID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID for the permission.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setPermissionID($value)
    {
        return $this->set('PermissionID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Permissions_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Drive_Permissions_Update $choreo The choreography object for this execution.
     * @param Google_Drive_Permissions_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Permissions_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Permissions_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Permissions_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Drive_Permissions_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Permissions_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Permissions_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Permissions_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Permissions_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a reply.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Delete extends Temboo_Choreography
{
    /**
     * Deletes a reply.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Replies_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Replies/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Replies_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Replies_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Replies_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the reply.
     * @return Google_Drive_Replies_Delete_Inputs For method chaining.
     */
    public function setReplyID($value)
    {
        return $this->set('ReplyID', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Replies_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Replies_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Replies_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Replies_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Replies_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Replies_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Replies_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a reply
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Get extends Temboo_Choreography
{
    /**
     * Gets a reply
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Replies_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Replies/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Replies_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Replies_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Replies_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the IncludeDeleted input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) If set, this will succeed when retrieving a deleted reply. (Default: false)
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setIncludeDeleted($value)
    {
        return $this->set('IncludeDeleted', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the reply.
     * @return Google_Drive_Replies_Get_Inputs For method chaining.
     */
    public function setReplyID($value)
    {
        return $this->set('ReplyID', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Replies_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Replies_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Replies_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Replies_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Replies_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Replies_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Replies_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new reply to the given comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Insert extends Temboo_Choreography
{
    /**
     * Creates a new reply to the given comment.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Drive_Replies_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Replies/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Drive_Replies_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Replies_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Replies_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Insert Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a reply resource. The JSON string must contain a key for content or verb. See documentation for formatting examples.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Drive_Replies_Insert $choreo The choreography object for this execution.
     * @param Google_Drive_Replies_Insert_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Replies_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Drive_Replies_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Replies_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Replies_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Replies_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the replies to a comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_List extends Temboo_Choreography
{
    /**
     * Lists all of the replies to a comment.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Replies_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Replies/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Replies_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Replies_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Replies_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the IncludeDeleted input for this List Choreo.
     *
     * @param bool $value (optional, boolean) If set, this will succeed when retrieving a deleted reply. (Default: false)
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setIncludeDeleted($value)
    {
        return $this->set('IncludeDeleted', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of replies to include in the response, used for paging. Acceptable values are 0 to 100, inclusive. (Default: 20).
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The continuation token, used to page through large result sets. To get the next page of results, set this parameter to the value of "nextPageToken" from the previous response.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Replies_List $choreo The choreography object for this execution.
     * @param Google_Drive_Replies_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Replies_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Replies_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Replies_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Replies_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Replies_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates an existing reply.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Update extends Temboo_Choreography
{
    /**
     * Updates an existing reply.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Drive_Replies_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Replies/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Drive_Replies_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Replies_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Replies_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Replies_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Update Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a reply resource. The JSON string must contain a key for content. See documentation for formatting examples.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the comment.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the reply.
     * @return Google_Drive_Replies_Update_Inputs For method chaining.
     */
    public function setReplyID($value)
    {
        return $this->set('ReplyID', $value);
    }
}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Drive_Replies_Update $choreo The choreography object for this execution.
     * @param Google_Drive_Replies_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Replies_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Replies_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Replies_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Drive_Replies_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Replies_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Replies_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Replies_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Replies_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Removes a revision.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Delete extends Temboo_Choreography
{
    /**
     * Removes a revision.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Drive_Revisions_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Revisions/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Drive_Revisions_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Revisions_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Revisions_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the FileID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RevisionID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the revision.
     * @return Google_Drive_Revisions_Delete_Inputs For method chaining.
     */
    public function setRevisionID($value)
    {
        return $this->set('RevisionID', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Drive_Revisions_Delete $choreo The choreography object for this execution.
     * @param Google_Drive_Revisions_Delete_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Revisions_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Drive_Revisions_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Revisions_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Revisions_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Revisions_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Gets a specific revision.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Get extends Temboo_Choreography
{
    /**
     * Gets a specific revision.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Drive_Revisions_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Revisions/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Drive_Revisions_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Revisions_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Revisions_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RevisionID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the revision.
     * @return Google_Drive_Revisions_Get_Inputs For method chaining.
     */
    public function setRevisionID($value)
    {
        return $this->set('RevisionID', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Drive_Revisions_Get $choreo The choreography object for this execution.
     * @param Google_Drive_Revisions_Get_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Revisions_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Drive_Revisions_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Revisions_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Revisions_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Revisions_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists a file's revisions.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_List extends Temboo_Choreography
{
    /**
     * Lists a file's revisions.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Drive_Revisions_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Revisions/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Drive_Revisions_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Revisions_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Revisions_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Drive_Revisions_List $choreo The choreography object for this execution.
     * @param Google_Drive_Revisions_List_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Revisions_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Drive_Revisions_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Revisions_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Revisions_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Revisions_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates a revision.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Update extends Temboo_Choreography
{
    /**
     * Updates a revision.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Drive_Revisions_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Drive/Revisions/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Drive_Revisions_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Drive_Revisions_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Drive_Revisions_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Drive_Revisions_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RequestBody input for this Update Choreo.
     *
     * @param string $value (required, json) A JSON representation of fields in a reply resource which shoud contain at least one key for pinned, publishAuto, published, or publishedOutsideDomain. See documentation for formatting examples.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setRequestBody($value)
    {
        return $this->set('RequestBody', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the file.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setFileID($value)
    {
        return $this->set('FileID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RevisionID input for this Update Choreo.
     *
     * @param string $value (required, string) The ID of the revision.
     * @return Google_Drive_Revisions_Update_Inputs For method chaining.
     */
    public function setRevisionID($value)
    {
        return $this->set('RevisionID', $value);
    }
}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Drive_Revisions_Update $choreo The choreography object for this execution.
     * @param Google_Drive_Revisions_Update_Inputs|array $inputs (optional) Inputs as Google_Drive_Revisions_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Drive_Revisions_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Drive_Revisions_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Drive_Revisions_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Drive_Revisions_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Drive_Revisions_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Drive_Revisions_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Drive_Revisions_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Obtain elevation information for a path generated by a set of geo-coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetLocationElevation extends Temboo_Choreography
{
    /**
     * Obtain elevation information for a path generated by a set of geo-coordinates.
     *
     * @param Temboo_Session $session The session that owns this GetLocationElevation Choreo.
     * @return Google_Elevation_GetLocationElevation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Elevation/GetLocationElevation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetLocationElevation Choreo.
     *
     * @param Google_Elevation_GetLocationElevation_Inputs|array $inputs (optional) Inputs as Google_Elevation_GetLocationElevation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Elevation_GetLocationElevation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Elevation_GetLocationElevation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetLocationElevation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Elevation_GetLocationElevation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Elevation_GetLocationElevation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetLocationElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetLocationElevation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetLocationElevation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Elevation_GetLocationElevation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetLocationElevation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GetLocationElevation Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Locations input for this GetLocationElevation Choreo.
     *
     * @param string $value (required, string) Enter the location(s) for which elevation data will be obtained.  Input formats: a single latitude/longitude coordinate pair; an array of coordinates separated by a |. A set of encoded coordinates.
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function setLocations($value)
    {
        return $this->set('Locations', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetLocationElevation Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this GetLocationElevation Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Elevation_GetLocationElevation_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the GetLocationElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetLocationElevation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetLocationElevation Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetLocationElevation execution.
     * @param Google_Elevation_GetLocationElevation $choreo The choreography object for this execution.
     * @param Google_Elevation_GetLocationElevation_Inputs|array $inputs (optional) Inputs as Google_Elevation_GetLocationElevation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Elevation_GetLocationElevation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Elevation_GetLocationElevation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetLocationElevation execution.
     *
     * @return Google_Elevation_GetLocationElevation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetLocationElevation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Elevation_GetLocationElevation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Elevation_GetLocationElevation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetLocationElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetLocationElevation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetLocationElevation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Elevation_GetLocationElevation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this GetLocationElevation execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Obtain elevation information for a path specified by a set of  geo-coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetPathElevation extends Temboo_Choreography
{
    /**
     * Obtain elevation information for a path specified by a set of  geo-coordinates.
     *
     * @param Temboo_Session $session The session that owns this GetPathElevation Choreo.
     * @return Google_Elevation_GetPathElevation New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Elevation/GetPathElevation/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetPathElevation Choreo.
     *
     * @param Google_Elevation_GetPathElevation_Inputs|array $inputs (optional) Inputs as Google_Elevation_GetPathElevation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Elevation_GetPathElevation_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Elevation_GetPathElevation_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetPathElevation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Elevation_GetPathElevation_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Elevation_GetPathElevation_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetPathElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetPathElevation_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetPathElevation Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Elevation_GetPathElevation_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetPathElevation input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GetPathElevation Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Path input for this GetPathElevation Choreo.
     *
     * @param string $value (required, string) Specify the path for which elevation data will be obtained.  Input formats: an array of two or more lat/longitude coordinate pairs; A set of encoded coordinates using the Encoded Polyline Algorithm.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setPath($value)
    {
        return $this->set('Path', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetPathElevation Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Samples input for this GetPathElevation Choreo.
     *
     * @param int $value (required, integer) Enter the number of sample points.  See API docs for additional information.
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setSamples($value)
    {
        return $this->set('Samples', $value);
    }

    /**
     * Set the value for the Sensor input for this GetPathElevation Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Elevation_GetPathElevation_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the GetPathElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetPathElevation_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetPathElevation Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetPathElevation execution.
     * @param Google_Elevation_GetPathElevation $choreo The choreography object for this execution.
     * @param Google_Elevation_GetPathElevation_Inputs|array $inputs (optional) Inputs as Google_Elevation_GetPathElevation_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Elevation_GetPathElevation_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Elevation_GetPathElevation $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetPathElevation execution.
     *
     * @return Google_Elevation_GetPathElevation_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetPathElevation execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Elevation_GetPathElevation_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Elevation_GetPathElevation_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetPathElevation Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Elevation_GetPathElevation_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetPathElevation Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Elevation_GetPathElevation_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this GetPathElevation execution.
     *
     * @return string (xml) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Converts a human-readable address into geographic coordinates.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByAddress extends Temboo_Choreography
{
    /**
     * Converts a human-readable address into geographic coordinates.
     *
     * @param Temboo_Session $session The session that owns this GeocodeByAddress Choreo.
     * @return Google_Geocoding_GeocodeByAddress New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Geocoding/GeocodeByAddress/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GeocodeByAddress Choreo.
     *
     * @param Google_Geocoding_GeocodeByAddress_Inputs|array $inputs (optional) Inputs as Google_Geocoding_GeocodeByAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Geocoding_GeocodeByAddress_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Geocoding_GeocodeByAddress_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GeocodeByAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Geocoding_GeocodeByAddress_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Geocoding_GeocodeByAddress_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GeocodeByAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByAddress_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GeocodeByAddress Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Geocoding_GeocodeByAddress_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GeocodeByAddress input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GeocodeByAddress Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Address input for this GeocodeByAddress Choreo.
     *
     * @param string $value (required, string) The address that you want to geocode.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setAddress($value)
    {
        return $this->set('Address', $value);
    }

    /**
     * Set the value for the Bounds input for this GeocodeByAddress Choreo.
     *
     * @param string $value (optional, string) The bounding box of the viewport within which to bias geocode results more prominently.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setBounds($value)
    {
        return $this->set('Bounds', $value);
    }

    /**
     * Set the value for the Language input for this GeocodeByAddress Choreo.
     *
     * @param string $value (optional, string) The language in which to return results e.g.: es, fr, it, en (the default). See Choreo notes for a link to a full list of supported languages.
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Region input for this GeocodeByAddress Choreo.
     *
     * @param string $value (optional, string) The region code, specified as a ccTLD ("top-level domain") two-character value. Defaults to 'us' (United States).
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GeocodeByAddress Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this GeocodeByAddress Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the geocoding request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Geocoding_GeocodeByAddress_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the GeocodeByAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByAddress_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GeocodeByAddress Choreo.
     *
     * @param Temboo_Session $session The session that owns this GeocodeByAddress execution.
     * @param Google_Geocoding_GeocodeByAddress $choreo The choreography object for this execution.
     * @param Google_Geocoding_GeocodeByAddress_Inputs|array $inputs (optional) Inputs as Google_Geocoding_GeocodeByAddress_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Geocoding_GeocodeByAddress_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Geocoding_GeocodeByAddress $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GeocodeByAddress execution.
     *
     * @return Google_Geocoding_GeocodeByAddress_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GeocodeByAddress execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Geocoding_GeocodeByAddress_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Geocoding_GeocodeByAddress_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GeocodeByAddress Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByAddress_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GeocodeByAddress Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Geocoding_GeocodeByAddress_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Latitude" output from this GeocodeByAddress execution.
     *
     * @return float (decimal) The latitude coordinate associated with the address provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getLatitude()
    {
        return $this->get('Latitude');
    }
    /**
     * Retrieve the value for the "Longitude" output from this GeocodeByAddress execution.
     *
     * @return float (decimal) The longitude coordinate associated with the address provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getLongitude()
    {
        return $this->get('Longitude');
    }
    /**
     * Retrieve the value for the "Response" output from this GeocodeByAddress execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Converts latitude and longitude coordinates into a human-readable address.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByCoordinates extends Temboo_Choreography
{
    /**
     * Converts latitude and longitude coordinates into a human-readable address.
     *
     * @param Temboo_Session $session The session that owns this GeocodeByCoordinates Choreo.
     * @return Google_Geocoding_GeocodeByCoordinates New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Geocoding/GeocodeByCoordinates/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GeocodeByCoordinates Choreo.
     *
     * @param Google_Geocoding_GeocodeByCoordinates_Inputs|array $inputs (optional) Inputs as Google_Geocoding_GeocodeByCoordinates_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Geocoding_GeocodeByCoordinates_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Geocoding_GeocodeByCoordinates_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GeocodeByCoordinates Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Geocoding_GeocodeByCoordinates_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GeocodeByCoordinates Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByCoordinates_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GeocodeByCoordinates Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GeocodeByCoordinates input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this GeocodeByCoordinates Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Bounds input for this GeocodeByCoordinates Choreo.
     *
     * @param string $value (optional, string) The bounding box of the viewport within which to bias geocode results more prominently.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setBounds($value)
    {
        return $this->set('Bounds', $value);
    }

    /**
     * Set the value for the Language input for this GeocodeByCoordinates Choreo.
     *
     * @param string $value (optional, string) The language in which to return results. Defaults to 'en' (English).
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Latitude input for this GeocodeByCoordinates Choreo.
     *
     * @param float $value (required, decimal) The latitude value for which you wish to obtain the closest, human-readable address.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setLatitude($value)
    {
        return $this->set('Latitude', $value);
    }

    /**
     * Set the value for the Longitude input for this GeocodeByCoordinates Choreo.
     *
     * @param float $value (required, decimal) The longitude value for which you wish to obtain the closest, human-readable address.
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setLongitude($value)
    {
        return $this->set('Longitude', $value);
    }

    /**
     * Set the value for the Region input for this GeocodeByCoordinates Choreo.
     *
     * @param string $value (optional, string) The region code, specified as a ccTLD ("top-level domain") two-character value. Defaults to 'us' (United States).
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setRegion($value)
    {
        return $this->set('Region', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GeocodeByCoordinates Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are "xml" (the default) and "json".
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this GeocodeByCoordinates Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the geocoding request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Geocoding_GeocodeByCoordinates_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the GeocodeByCoordinates Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByCoordinates_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GeocodeByCoordinates Choreo.
     *
     * @param Temboo_Session $session The session that owns this GeocodeByCoordinates execution.
     * @param Google_Geocoding_GeocodeByCoordinates $choreo The choreography object for this execution.
     * @param Google_Geocoding_GeocodeByCoordinates_Inputs|array $inputs (optional) Inputs as Google_Geocoding_GeocodeByCoordinates_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Geocoding_GeocodeByCoordinates_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Geocoding_GeocodeByCoordinates $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GeocodeByCoordinates execution.
     *
     * @return Google_Geocoding_GeocodeByCoordinates_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GeocodeByCoordinates execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Geocoding_GeocodeByCoordinates_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Geocoding_GeocodeByCoordinates_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GeocodeByCoordinates Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Geocoding_GeocodeByCoordinates_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GeocodeByCoordinates Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Geocoding_GeocodeByCoordinates_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FormattedAddress" output from this GeocodeByCoordinates execution.
     *
     * @return string (string) The formatted address associated with the specified coordinates.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFormattedAddress()
    {
        return $this->get('FormattedAddress');
    }
    /**
     * Retrieve the value for the "Response" output from this GeocodeByCoordinates execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns the latest unread email from a user's Gmail feed.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetLatestUnreadEmail extends Temboo_Choreography
{
    /**
     * Returns the latest unread email from a user's Gmail feed.
     *
     * @param Temboo_Session $session The session that owns this GetLatestUnreadEmail Choreo.
     * @return Google_Gmail_GetLatestUnreadEmail New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/GetLatestUnreadEmail/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetLatestUnreadEmail Choreo.
     *
     * @param Google_Gmail_GetLatestUnreadEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetLatestUnreadEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetLatestUnreadEmail_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_GetLatestUnreadEmail_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetLatestUnreadEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_GetLatestUnreadEmail_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetLatestUnreadEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetLatestUnreadEmail_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetLatestUnreadEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetLatestUnreadEmail input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Label input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (optional, string) The name of a Gmail Label to retrieve messages from (e.g., important, starred, sent, junk-e-mail, all).
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setLabel($value)
    {
        return $this->set('Label', $value);
    }

    /**
     * Set the value for the Password input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (optional, string) The format for the response. Valid values are JSON and XML. This will be ignored when providng an XPath query because results are returned as a string or JSON depending on the Mode specified.
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Username input for this GetLatestUnreadEmail Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetLatestUnreadEmail_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetLatestUnreadEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetLatestUnreadEmail_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetLatestUnreadEmail Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetLatestUnreadEmail execution.
     * @param Google_Gmail_GetLatestUnreadEmail $choreo The choreography object for this execution.
     * @param Google_Gmail_GetLatestUnreadEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetLatestUnreadEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetLatestUnreadEmail_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_GetLatestUnreadEmail $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetLatestUnreadEmail execution.
     *
     * @return Google_Gmail_GetLatestUnreadEmail_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetLatestUnreadEmail execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_GetLatestUnreadEmail_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_GetLatestUnreadEmail_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetLatestUnreadEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetLatestUnreadEmail_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetLatestUnreadEmail Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_GetLatestUnreadEmail_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AuthorEmail" output from this GetLatestUnreadEmail execution.
     *
     * @return string (string) The author's email address.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAuthorEmail()
    {
        return $this->get('AuthorEmail');
    }
    /**
     * Retrieve the value for the "AuthorName" output from this GetLatestUnreadEmail execution.
     *
     * @return string (string) The author's name.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAuthorName()
    {
        return $this->get('AuthorName');
    }
    /**
     * Retrieve the value for the "MessageBody" output from this GetLatestUnreadEmail execution.
     *
     * @return string (string) The email body. Note that this corresponds to the "summary" element in the feed.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getMessageBody()
    {
        return $this->get('MessageBody');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetLatestUnreadEmail execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Subject" output from this GetLatestUnreadEmail execution.
     *
     * @return string (string) The subject line of the email. Note that this corresponds to the "title" element in the feed.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSubject()
    {
        return $this->get('Subject');
    }
    /**
     * Retrieve the value for the "Response" output from this GetLatestUnreadEmail execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to access a read-only Gmail feed that contains a list of unread emails that are marked important.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadImportantEmail extends Temboo_Choreography
{
    /**
     * Allows you to access a read-only Gmail feed that contains a list of unread emails that are marked important.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadImportantEmail Choreo.
     * @return Google_Gmail_GetUnreadImportantEmail New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/GetUnreadImportantEmail/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetUnreadImportantEmail Choreo.
     *
     * @param Google_Gmail_GetUnreadImportantEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadImportantEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadImportantEmail_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_GetUnreadImportantEmail_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetUnreadImportantEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_GetUnreadImportantEmail_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetUnreadImportantEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadImportantEmail_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetUnreadImportantEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetUnreadImportantEmail input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseMode input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (optional, string) Used to simplify the response. Valid values are: simple and verbose. When set to simple, only the message string is returned. Verbose mode returns the full object. Defaults to "simple".
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setResponseMode($value)
    {
        return $this->set('ResponseMode', $value);
    }

    /**
     * Set the value for the Username input for this GetUnreadImportantEmail Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadImportantEmail_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetUnreadImportantEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadImportantEmail_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetUnreadImportantEmail Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadImportantEmail execution.
     * @param Google_Gmail_GetUnreadImportantEmail $choreo The choreography object for this execution.
     * @param Google_Gmail_GetUnreadImportantEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadImportantEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadImportantEmail_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_GetUnreadImportantEmail $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetUnreadImportantEmail execution.
     *
     * @return Google_Gmail_GetUnreadImportantEmail_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetUnreadImportantEmail execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_GetUnreadImportantEmail_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_GetUnreadImportantEmail_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetUnreadImportantEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadImportantEmail_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetUnreadImportantEmail Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_GetUnreadImportantEmail_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetUnreadImportantEmail execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetUnreadImportantEmail execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to access a read-only Gmail feed that contains a list of unread emails.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMail extends Temboo_Choreography
{
    /**
     * Allows you to access a read-only Gmail feed that contains a list of unread emails.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMail Choreo.
     * @return Google_Gmail_GetUnreadMail New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/GetUnreadMail/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetUnreadMail Choreo.
     *
     * @param Google_Gmail_GetUnreadMail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMail_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_GetUnreadMail_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetUnreadMail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMail_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_GetUnreadMail_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetUnreadMail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMail_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetUnreadMail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMail_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetUnreadMail input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetUnreadMail Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetUnreadMail Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetUnreadMail Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Label input for this GetUnreadMail Choreo.
     *
     * @param string $value (optional, string) The name of a Gmail Label to retrieve messages from (e.g., important, starred, sent, junk-e-mail, all).
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setLabel($value)
    {
        return $this->set('Label', $value);
    }

    /**
     * Set the value for the Password input for this GetUnreadMail Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetUnreadMail Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseMode input for this GetUnreadMail Choreo.
     *
     * @param string $value (optional, string) Used to simplify the response. Valid values are: simple and verbose. When set to simple, only the message string is returned. Verbose mode returns the full object. Defaults to "simple".
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setResponseMode($value)
    {
        return $this->set('ResponseMode', $value);
    }

    /**
     * Set the value for the Username input for this GetUnreadMail Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMail_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetUnreadMail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMail_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetUnreadMail Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMail execution.
     * @param Google_Gmail_GetUnreadMail $choreo The choreography object for this execution.
     * @param Google_Gmail_GetUnreadMail_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMail_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_GetUnreadMail $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetUnreadMail execution.
     *
     * @return Google_Gmail_GetUnreadMail_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetUnreadMail execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMail_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_GetUnreadMail_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetUnreadMail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMail_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetUnreadMail Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMail_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FullCount" output from this GetUnreadMail execution.
     *
     * @return int (integer) The number of unread messages. This is parsed from the Google XML response. Note that when using the Label input to retrieve messages from a particular Gmail label, the full count element may be 0.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFullCount()
    {
        return $this->get('FullCount');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetUnreadMail execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetUnreadMail execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to access a read-only Gmail feed that contains a list of unread emails for the specified sender.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailFromSender extends Temboo_Choreography
{
    /**
     * Allows you to access a read-only Gmail feed that contains a list of unread emails for the specified sender.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMailFromSender Choreo.
     * @return Google_Gmail_GetUnreadMailFromSender New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/GetUnreadMailFromSender/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetUnreadMailFromSender Choreo.
     *
     * @param Google_Gmail_GetUnreadMailFromSender_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMailFromSender_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMailFromSender_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_GetUnreadMailFromSender_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetUnreadMailFromSender Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_GetUnreadMailFromSender_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetUnreadMailFromSender Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailFromSender_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetUnreadMailFromSender Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetUnreadMailFromSender input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Label input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (optional, string) The name of a Gmail Label to retrieve messages from (e.g., important, starred, sent, junk-e-mail, all).
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setLabel($value)
    {
        return $this->set('Label', $value);
    }

    /**
     * Set the value for the Password input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseMode input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (optional, string) Used to simplify the response. Valid values are: simple and verbose. When set to simple, only the message string is returned. Verbose mode returns the full object. Defaults to "simple".
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setResponseMode($value)
    {
        return $this->set('ResponseMode', $value);
    }

    /**
     * Set the value for the SenderEmail input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (required, string) Email address of the sender you wish to filter by.
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setSenderEmail($value)
    {
        return $this->set('SenderEmail', $value);
    }

    /**
     * Set the value for the Username input for this GetUnreadMailFromSender Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMailFromSender_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetUnreadMailFromSender Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailFromSender_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetUnreadMailFromSender Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMailFromSender execution.
     * @param Google_Gmail_GetUnreadMailFromSender $choreo The choreography object for this execution.
     * @param Google_Gmail_GetUnreadMailFromSender_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMailFromSender_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMailFromSender_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_GetUnreadMailFromSender $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetUnreadMailFromSender execution.
     *
     * @return Google_Gmail_GetUnreadMailFromSender_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetUnreadMailFromSender execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMailFromSender_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_GetUnreadMailFromSender_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetUnreadMailFromSender Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailFromSender_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetUnreadMailFromSender Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMailFromSender_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FullCount" output from this GetUnreadMailFromSender execution.
     *
     * @return int (integer) The number of unread messages. This is parsed from the Google XML response. Note that when using the Label input to retrieve messages from a particular Gmail label, the full count element may be 0.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFullCount()
    {
        return $this->get('FullCount');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetUnreadMailFromSender execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetUnreadMailFromSender execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to access a read-only Gmail feed that contains a list of unread emails with the specified label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailWithLabel extends Temboo_Choreography
{
    /**
     * Allows you to access a read-only Gmail feed that contains a list of unread emails with the specified label.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMailWithLabel Choreo.
     * @return Google_Gmail_GetUnreadMailWithLabel New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/GetUnreadMailWithLabel/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetUnreadMailWithLabel Choreo.
     *
     * @param Google_Gmail_GetUnreadMailWithLabel_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMailWithLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMailWithLabel_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_GetUnreadMailWithLabel_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetUnreadMailWithLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_GetUnreadMailWithLabel_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetUnreadMailWithLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailWithLabel_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetUnreadMailWithLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetUnreadMailWithLabel input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Label input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (required, string) The name of a Gmail Label to retrieve messages from (e.g., important, starred, sent, junk-e-mail, all).
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setLabel($value)
    {
        return $this->set('Label', $value);
    }

    /**
     * Set the value for the Password input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseMode input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (optional, string) Used to simplify the response. Valid values are: simple and verbose. When set to simple, only the message string is returned. Verbose mode returns the full object. Defaults to "simple".
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setResponseMode($value)
    {
        return $this->set('ResponseMode', $value);
    }

    /**
     * Set the value for the Username input for this GetUnreadMailWithLabel Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_GetUnreadMailWithLabel_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the GetUnreadMailWithLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailWithLabel_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetUnreadMailWithLabel Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetUnreadMailWithLabel execution.
     * @param Google_Gmail_GetUnreadMailWithLabel $choreo The choreography object for this execution.
     * @param Google_Gmail_GetUnreadMailWithLabel_Inputs|array $inputs (optional) Inputs as Google_Gmail_GetUnreadMailWithLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_GetUnreadMailWithLabel_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_GetUnreadMailWithLabel $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetUnreadMailWithLabel execution.
     *
     * @return Google_Gmail_GetUnreadMailWithLabel_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetUnreadMailWithLabel execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMailWithLabel_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_GetUnreadMailWithLabel_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetUnreadMailWithLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_GetUnreadMailWithLabel_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetUnreadMailWithLabel Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_GetUnreadMailWithLabel_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FullCount" output from this GetUnreadMailWithLabel execution.
     *
     * @return int (integer) The number of unread messages. This is parsed from the Google XML response. Note the full count element may be 0 because this Choreography retrieves Gmail messages by a particular Label.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFullCount()
    {
        return $this->get('FullCount');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetUnreadMailWithLabel execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetUnreadMailWithLabel execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to access a read-only Gmail feed that contains a list of unread emails.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_InboxFeed extends Temboo_Choreography
{
    /**
     * Allows you to access a read-only Gmail feed that contains a list of unread emails.
     *
     * @param Temboo_Session $session The session that owns this InboxFeed Choreo.
     * @return Google_Gmail_InboxFeed New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/InboxFeed/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InboxFeed Choreo.
     *
     * @param Google_Gmail_InboxFeed_Inputs|array $inputs (optional) Inputs as Google_Gmail_InboxFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_InboxFeed_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_InboxFeed_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InboxFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_InboxFeed_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_InboxFeed_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InboxFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_InboxFeed_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InboxFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_InboxFeed_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InboxFeed input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this InboxFeed Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InboxFeed Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Label input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) The name of a Gmail Label to retrieve messages from (e.g., important, starred, sent, junk-e-mail, all).
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setLabel($value)
    {
        return $this->set('Label', $value);
    }

    /**
     * Set the value for the Mode input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) Used when an XPath query is provided. Valid values are "select" or "recursive". Select mode will return the first match of the query. In recursive mode, the XPath query will be applied within a loop.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setMode($value)
    {
        return $this->set('Mode', $value);
    }

    /**
     * Set the value for the Password input for this InboxFeed Choreo.
     *
     * @param string $value (optional, password) A Google App-specific password that you've generated after enabling 2-Step Verification (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InboxFeed Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) The format for the response. Valid values are JSON and XML. This will be ignored when providng an XPath query because results are returned as a string or JSON depending on the Mode specified.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Username input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) Your full Google email address e.g., martha.temboo@gmail.com (Note: authenticating with OAuth credentials is the preferred authentication method).
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the XPath input for this InboxFeed Choreo.
     *
     * @param string $value (optional, string) An XPATH query to run.
     * @return Google_Gmail_InboxFeed_Inputs For method chaining.
     */
    public function setXPath($value)
    {
        return $this->set('XPath', $value);
    }
}


/**
 * Execution object for the InboxFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_InboxFeed_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InboxFeed Choreo.
     *
     * @param Temboo_Session $session The session that owns this InboxFeed execution.
     * @param Google_Gmail_InboxFeed $choreo The choreography object for this execution.
     * @param Google_Gmail_InboxFeed_Inputs|array $inputs (optional) Inputs as Google_Gmail_InboxFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_InboxFeed_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_InboxFeed $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InboxFeed execution.
     *
     * @return Google_Gmail_InboxFeed_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InboxFeed execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_InboxFeed_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_InboxFeed_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InboxFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_InboxFeed_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InboxFeed Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_InboxFeed_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FullCount" output from this InboxFeed execution.
     *
     * @return int (integer) The number of unread messages. This is parsed from the Google XML response. Note that when using the Label input to retrieve messages from a particular Gmail label, the full count element may be 0.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFullCount()
    {
        return $this->get('FullCount');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InboxFeed execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InboxFeed execution.
     *
     * @return string The response from Google. This will contain the data from the Gmail feed, or if the XPath input is provided, it will contain the result of the XPath query.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sends an email using a specified Gmail account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_SendEmail extends Temboo_Choreography
{
    /**
     * Sends an email using a specified Gmail account.
     *
     * @param Temboo_Session $session The session that owns this SendEmail Choreo.
     * @return Google_Gmail_SendEmail New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmail/SendEmail/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SendEmail Choreo.
     *
     * @param Google_Gmail_SendEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_SendEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_SendEmail_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmail_SendEmail_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SendEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_SendEmail_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmail_SendEmail_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SendEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_SendEmail_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SendEmail Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmail_SendEmail_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SendEmail input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Attachment input for this SendEmail Choreo.
     *
     * @param string $value (optional, string) The Base64 encoded contents of the file to attach to the email.  Use this instead of AttachmentURL.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setAttachment($value)
    {
        return $this->set('Attachment', $value);
    }

    /**
     * Set the value for the AttachmentName input for this SendEmail Choreo.
     *
     * @param string $value (optional, string) The name of the file to attach to the email.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setAttachmentName($value)
    {
        return $this->set('AttachmentName', $value);
    }

    /**
     * Set the value for the AttachmentURL input for this SendEmail Choreo.
     *
     * @param string $value (optional, string) URL of a hosted file that you wish to add as an attachment.  Use this instead of a normal Attachment.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setAttachmentURL($value)
    {
        return $this->set('AttachmentURL', $value);
    }

    /**
     * Set the value for the BCC input for this SendEmail Choreo.
     *
     * @param string $value (optional, string) An email address to BCC on the email you're sending. Can be a comma separated list of email addresses.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setBCC($value)
    {
        return $this->set('BCC', $value);
    }

    /**
     * Set the value for the CC input for this SendEmail Choreo.
     *
     * @param string $value (optional, string) An email address to CC on the email you're sending. Can be a comma separated list of email addresses.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setCC($value)
    {
        return $this->set('CC', $value);
    }

    /**
     * Set the value for the FromAddress input for this SendEmail Choreo.
     *
     * @param string $value (conditional, string) The address and name (optional) that the email is being sent from e.g., "Dan" <dan@temboo.com>
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setFromAddress($value)
    {
        return $this->set('FromAddress', $value);
    }

    /**
     * Set the value for the MessageBody input for this SendEmail Choreo.
     *
     * @param string $value (required, string) The message body for the email.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setMessageBody($value)
    {
        return $this->set('MessageBody', $value);
    }

    /**
     * Set the value for the Password input for this SendEmail Choreo.
     *
     * @param string $value (required, password) A Google App-specific password that you've generated after enabling 2-Step Verification. See the Gmailv2 bundle for OAuth.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the Subject input for this SendEmail Choreo.
     *
     * @param string $value (required, string) The subject line of the email.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setSubject($value)
    {
        return $this->set('Subject', $value);
    }

    /**
     * Set the value for the ToAddress input for this SendEmail Choreo.
     *
     * @param string $value (required, string) The email address that you want to send an email to. Can be a comma separated list of email addresses.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setToAddress($value)
    {
        return $this->set('ToAddress', $value);
    }

    /**
     * Set the value for the Username input for this SendEmail Choreo.
     *
     * @param string $value (required, string) Your full Google email address e.g., martha.temboo@gmail.com. See the Gmailv2 bundle for OAuth.
     * @return Google_Gmail_SendEmail_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the SendEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_SendEmail_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SendEmail Choreo.
     *
     * @param Temboo_Session $session The session that owns this SendEmail execution.
     * @param Google_Gmail_SendEmail $choreo The choreography object for this execution.
     * @param Google_Gmail_SendEmail_Inputs|array $inputs (optional) Inputs as Google_Gmail_SendEmail_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmail_SendEmail_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmail_SendEmail $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SendEmail execution.
     *
     * @return Google_Gmail_SendEmail_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SendEmail execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmail_SendEmail_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmail_SendEmail_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SendEmail Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmail_SendEmail_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SendEmail Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmail_SendEmail_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Success" output from this SendEmail execution.
     *
     * @return bool (boolean) Indicates the result of the SMTP operation. The value will be "true" for a successful request.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSuccess()
    {
        return $this->get('Success');
    }
}

/**
 * Gets the specified message attachment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Attachments_GetAttachment extends Temboo_Choreography
{
    /**
     * Gets the specified message attachment.
     *
     * @param Temboo_Session $session The session that owns this GetAttachment Choreo.
     * @return Google_Gmailv2_Attachments_GetAttachment New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Attachments/GetAttachment/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetAttachment Choreo.
     *
     * @param Google_Gmailv2_Attachments_GetAttachment_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Attachments_GetAttachment_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Attachments_GetAttachment_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Attachments_GetAttachment_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetAttachment Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Attachments_GetAttachment_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetAttachment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Attachments_GetAttachment_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetAttachment Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetAttachment input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetAttachment Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AttachmentID input for this GetAttachment Choreo.
     *
     * @param string $value (required, string) The ID of the attachment to retrieve.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setAttachmentID($value)
    {
        return $this->set('AttachmentID', $value);
    }

    /**
     * Set the value for the ClientID input for this GetAttachment Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetAttachment Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetAttachment Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Format input for this GetAttachment Choreo.
     *
     * @param bool $value (optional, boolean) Specifies the format of the message returned. Valid values are: full (the default), minimal, and raw. See Choreo notes for more details about these formats.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setFormat($value)
    {
        return $this->set('Format', $value);
    }

    /**
     * Set the value for the MessageID input for this GetAttachment Choreo.
     *
     * @param string $value (required, string) The ID of the message to retrieve.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetAttachment Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this GetAttachment Choreo.
     *
     * @param string $value (optional, string) The id of the acting user. Defaults to "me" indicating the user associated with the access token or refresh token provided.
     * @return Google_Gmailv2_Attachments_GetAttachment_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetAttachment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Attachments_GetAttachment_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetAttachment Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetAttachment execution.
     * @param Google_Gmailv2_Attachments_GetAttachment $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Attachments_GetAttachment_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Attachments_GetAttachment_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Attachments_GetAttachment_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Attachments_GetAttachment $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetAttachment execution.
     *
     * @return Google_Gmailv2_Attachments_GetAttachment_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetAttachment execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Attachments_GetAttachment_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Attachments_GetAttachment_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetAttachment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Attachments_GetAttachment_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetAttachment Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Attachments_GetAttachment_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetAttachment execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetAttachment execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new draft with the DRAFT label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_CreateDraft extends Temboo_Choreography
{
    /**
     * Creates a new draft with the DRAFT label.
     *
     * @param Temboo_Session $session The session that owns this CreateDraft Choreo.
     * @return Google_Gmailv2_Drafts_CreateDraft New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/CreateDraft/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateDraft Choreo.
     *
     * @param Google_Gmailv2_Drafts_CreateDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_CreateDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_CreateDraft_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_CreateDraft_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_CreateDraft_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_CreateDraft_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateDraft input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AttachmentContentType input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the attachment. This is required when providing AttachmentFileContent (e.g., image/jpeg, text/plain, etc).
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setAttachmentContentType($value)
    {
        return $this->set('AttachmentContentType', $value);
    }

    /**
     * Set the value for the AttachmentFileContent input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The Base64 encoded file content for the attachment. You must specify the AttachmentFileContentType when including an attachment.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setAttachmentFileContent($value)
    {
        return $this->set('AttachmentFileContent', $value);
    }

    /**
     * Set the value for the AttachmentFileName input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The file name of the attachment.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setAttachmentFileName($value)
    {
        return $this->set('AttachmentFileName', $value);
    }

    /**
     * Set the value for the BCC input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be bcc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setBCC($value)
    {
        return $this->set('BCC', $value);
    }

    /**
     * Set the value for the CC input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be cc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setCC($value)
    {
        return $this->set('CC', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the From input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The address and name (optional) that the email is being sent from e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setFrom($value)
    {
        return $this->set('From', $value);
    }

    /**
     * Set the value for the MessageBody input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The text for the message body of the email.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setMessageBody($value)
    {
        return $this->set('MessageBody', $value);
    }

    /**
     * Set the value for the MessageBodyContentType input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the message body. Defaults to "text/plain; charset=UTF-8".
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setMessageBodyContentType($value)
    {
        return $this->set('MessageBodyContentType', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyTo input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) An email address to set as the Reply-To address.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setReplyTo($value)
    {
        return $this->set('ReplyTo', $value);
    }

    /**
     * Set the value for the Subject input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The email subject.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setSubject($value)
    {
        return $this->set('Subject', $value);
    }

    /**
     * Set the value for the ThreadID input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the thread the message belongs to.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the To input for this CreateDraft Choreo.
     *
     * @param string $value (conditional, string) The address and name (optional) that the email is being sent to e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setTo($value)
    {
        return $this->set('To', $value);
    }

    /**
     * Set the value for the UserID input for this CreateDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Drafts_CreateDraft_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the CreateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_CreateDraft_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateDraft Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateDraft execution.
     * @param Google_Gmailv2_Drafts_CreateDraft $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_CreateDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_CreateDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_CreateDraft_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_CreateDraft $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateDraft execution.
     *
     * @return Google_Gmailv2_Drafts_CreateDraft_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateDraft execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_CreateDraft_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_CreateDraft_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_CreateDraft_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateDraft Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_CreateDraft_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateDraft execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateDraft execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Permanently deletes the specified draft.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_DeleteDraft extends Temboo_Choreography
{
    /**
     * Permanently deletes the specified draft.
     *
     * @param Temboo_Session $session The session that owns this DeleteDraft Choreo.
     * @return Google_Gmailv2_Drafts_DeleteDraft New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/DeleteDraft/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteDraft Choreo.
     *
     * @param Google_Gmailv2_Drafts_DeleteDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_DeleteDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_DeleteDraft_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_DeleteDraft_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_DeleteDraft_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteDraft input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteDraft Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteDraft Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteDraft Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DraftID input for this DeleteDraft Choreo.
     *
     * @param string $value (required, string) The ID of the draft to delete.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setDraftID($value)
    {
        return $this->set('DraftID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteDraft Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteDraft Choreo.
     *
     * @param string $value (optional, string) The id of the acting user. Defaults to "me" indicating the user associated with the access token or refresh token provided.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_DeleteDraft_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteDraft Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteDraft execution.
     * @param Google_Gmailv2_Drafts_DeleteDraft $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_DeleteDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_DeleteDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_DeleteDraft $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteDraft execution.
     *
     * @return Google_Gmailv2_Drafts_DeleteDraft_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteDraft execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_DeleteDraft_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_DeleteDraft_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteDraft Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_DeleteDraft_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteDraft execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteDraft execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteDraft execution.
     *
     * @return string (json) The response from Google. An empty response is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific draft from a user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_GetDraft extends Temboo_Choreography
{
    /**
     * Retrieves a specific draft from a user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this GetDraft Choreo.
     * @return Google_Gmailv2_Drafts_GetDraft New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/GetDraft/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetDraft Choreo.
     *
     * @param Google_Gmailv2_Drafts_GetDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_GetDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_GetDraft_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_GetDraft_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_GetDraft_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_GetDraft_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetDraft input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetDraft Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetDraft Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetDraft Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DraftID input for this GetDraft Choreo.
     *
     * @param string $value (required, string) The ID of the draft to retrieve.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setDraftID($value)
    {
        return $this->set('DraftID', $value);
    }

    /**
     * Set the value for the Fields input for this GetDraft Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Format input for this GetDraft Choreo.
     *
     * @param string $value (optional, string) Specifies the format of the draft returned. Valid values are: full (the default), minimal, and raw. See Choreo notes for more details about these formats.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setFormat($value)
    {
        return $this->set('Format', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetDraft Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this GetDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Drafts_GetDraft_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_GetDraft_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetDraft Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetDraft execution.
     * @param Google_Gmailv2_Drafts_GetDraft $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_GetDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_GetDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_GetDraft_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_GetDraft $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetDraft execution.
     *
     * @return Google_Gmailv2_Drafts_GetDraft_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetDraft execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_GetDraft_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_GetDraft_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_GetDraft_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetDraft Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_GetDraft_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetDraft execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetDraft execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the drafts in the user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_ListDrafts extends Temboo_Choreography
{
    /**
     * Lists the drafts in the user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this ListDrafts Choreo.
     * @return Google_Gmailv2_Drafts_ListDrafts New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/ListDrafts/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListDrafts Choreo.
     *
     * @param Google_Gmailv2_Drafts_ListDrafts_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_ListDrafts_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_ListDrafts_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_ListDrafts_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListDrafts Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_ListDrafts_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListDrafts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_ListDrafts_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListDrafts Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListDrafts input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListDrafts Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListDrafts Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListDrafts Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListDrafts Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListDrafts Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListDrafts Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListDrafts Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListDrafts Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Drafts_ListDrafts_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListDrafts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_ListDrafts_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListDrafts Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListDrafts execution.
     * @param Google_Gmailv2_Drafts_ListDrafts $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_ListDrafts_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_ListDrafts_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_ListDrafts_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_ListDrafts $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListDrafts execution.
     *
     * @return Google_Gmailv2_Drafts_ListDrafts_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListDrafts execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_ListDrafts_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_ListDrafts_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListDrafts Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_ListDrafts_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListDrafts Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_ListDrafts_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListDrafts execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListDrafts execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sends the specified, existing draft.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_SendDraft extends Temboo_Choreography
{
    /**
     * Sends the specified, existing draft.
     *
     * @param Temboo_Session $session The session that owns this SendDraft Choreo.
     * @return Google_Gmailv2_Drafts_SendDraft New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/SendDraft/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SendDraft Choreo.
     *
     * @param Google_Gmailv2_Drafts_SendDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_SendDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_SendDraft_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_SendDraft_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SendDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_SendDraft_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SendDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_SendDraft_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SendDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SendDraft input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SendDraft Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SendDraft Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SendDraft Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DraftID input for this SendDraft Choreo.
     *
     * @param string $value (required, string) The ID of the draft to send.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setDraftID($value)
    {
        return $this->set('DraftID', $value);
    }

    /**
     * Set the value for the Fields input for this SendDraft Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SendDraft Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this SendDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Drafts_SendDraft_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the SendDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_SendDraft_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SendDraft Choreo.
     *
     * @param Temboo_Session $session The session that owns this SendDraft execution.
     * @param Google_Gmailv2_Drafts_SendDraft $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_SendDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_SendDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_SendDraft_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_SendDraft $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SendDraft execution.
     *
     * @return Google_Gmailv2_Drafts_SendDraft_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SendDraft execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_SendDraft_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_SendDraft_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SendDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_SendDraft_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SendDraft Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_SendDraft_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SendDraft execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SendDraft execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates the content of an existing draft.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_UpdateDraft extends Temboo_Choreography
{
    /**
     * Updates the content of an existing draft.
     *
     * @param Temboo_Session $session The session that owns this UpdateDraft Choreo.
     * @return Google_Gmailv2_Drafts_UpdateDraft New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Drafts/UpdateDraft/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateDraft Choreo.
     *
     * @param Google_Gmailv2_Drafts_UpdateDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_UpdateDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Drafts_UpdateDraft_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Drafts_UpdateDraft_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_UpdateDraft_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateDraft Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateDraft input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AttachmentContentType input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the attachment. This is required when providing AttachmentFileContent (e.g., image/jpeg, text/plain, etc).
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setAttachmentContentType($value)
    {
        return $this->set('AttachmentContentType', $value);
    }

    /**
     * Set the value for the AttachmentFileContent input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The Base64 encoded file content for the attachment. You must specify the AttachmentFileContentType when including an attachment.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setAttachmentFileContent($value)
    {
        return $this->set('AttachmentFileContent', $value);
    }

    /**
     * Set the value for the AttachmentFileName input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The file name of the attachment.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setAttachmentFileName($value)
    {
        return $this->set('AttachmentFileName', $value);
    }

    /**
     * Set the value for the BCC input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be bcc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setBCC($value)
    {
        return $this->set('BCC', $value);
    }

    /**
     * Set the value for the CC input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be cc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setCC($value)
    {
        return $this->set('CC', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DraftID input for this UpdateDraft Choreo.
     *
     * @param string $value (required, string) The ID of the draft to update.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setDraftID($value)
    {
        return $this->set('DraftID', $value);
    }

    /**
     * Set the value for the Fields input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the From input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The address and name (optional) that the email is being sent from e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setFrom($value)
    {
        return $this->set('From', $value);
    }

    /**
     * Set the value for the MessageBody input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The text for the message body of the email.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setMessageBody($value)
    {
        return $this->set('MessageBody', $value);
    }

    /**
     * Set the value for the MessageBodyContentType input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the message body. Defaults to "text/plain; charset=UTF-8".
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setMessageBodyContentType($value)
    {
        return $this->set('MessageBodyContentType', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyTo input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) An email address to set as the Reply-To address.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setReplyTo($value)
    {
        return $this->set('ReplyTo', $value);
    }

    /**
     * Set the value for the Subject input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The email subject.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setSubject($value)
    {
        return $this->set('Subject', $value);
    }

    /**
     * Set the value for the ThreadID input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the thread the message belongs to.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the To input for this UpdateDraft Choreo.
     *
     * @param string $value (conditional, string) The address and name (optional) that the email is being sent to e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setTo($value)
    {
        return $this->set('To', $value);
    }

    /**
     * Set the value for the UserID input for this UpdateDraft Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the UpdateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_UpdateDraft_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateDraft Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateDraft execution.
     * @param Google_Gmailv2_Drafts_UpdateDraft $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Drafts_UpdateDraft_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Drafts_UpdateDraft_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Drafts_UpdateDraft $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateDraft execution.
     *
     * @return Google_Gmailv2_Drafts_UpdateDraft_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateDraft execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Drafts_UpdateDraft_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateDraft Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Drafts_UpdateDraft_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateDraft Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Drafts_UpdateDraft_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateDraft execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateDraft execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the history of all changes to the given mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_History_ListHistory extends Temboo_Choreography
{
    /**
     * Lists the history of all changes to the given mailbox.
     *
     * @param Temboo_Session $session The session that owns this ListHistory Choreo.
     * @return Google_Gmailv2_History_ListHistory New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/History/ListHistory/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListHistory Choreo.
     *
     * @param Google_Gmailv2_History_ListHistory_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_History_ListHistory_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_History_ListHistory_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_History_ListHistory_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListHistory Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_History_ListHistory_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_History_ListHistory_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_History_ListHistory_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListHistory Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_History_ListHistory_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListHistory input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListHistory Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListHistory Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListHistory Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListHistory Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the LabelID input for this ListHistory Choreo.
     *
     * @param string $value (optional, string) Returns messages with a label matching this ID.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListHistory Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListHistory Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListHistory Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartHistoryID input for this ListHistory Choreo.
     *
     * @param string $value (required, string) Returns history records after the specified marker. The history ID is returned by the Messages.GetMessage Choreo.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setStartHistoryID($value)
    {
        return $this->set('StartHistoryID', $value);
    }

    /**
     * Set the value for the UserID input for this ListHistory Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_History_ListHistory_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_History_ListHistory_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListHistory Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListHistory execution.
     * @param Google_Gmailv2_History_ListHistory $choreo The choreography object for this execution.
     * @param Google_Gmailv2_History_ListHistory_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_History_ListHistory_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_History_ListHistory_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_History_ListHistory $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListHistory execution.
     *
     * @return Google_Gmailv2_History_ListHistory_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListHistory execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_History_ListHistory_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_History_ListHistory_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_History_ListHistory_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListHistory Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_History_ListHistory_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListHistory execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListHistory execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_CreateLabel extends Temboo_Choreography
{
    /**
     * Creates a new label.
     *
     * @param Temboo_Session $session The session that owns this CreateLabel Choreo.
     * @return Google_Gmailv2_Labels_CreateLabel New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Labels/CreateLabel/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateLabel Choreo.
     *
     * @param Google_Gmailv2_Labels_CreateLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_CreateLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_CreateLabel_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Labels_CreateLabel_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Labels_CreateLabel_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_CreateLabel_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateLabel input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateLabel Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateLabel Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateLabel Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this CreateLabel Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the LabelListVisibility input for this CreateLabel Choreo.
     *
     * @param string $value (required, string) The visibility of the label in the label list in the Gmail web interface. Valid values are: "labelHide", "labelShow", and "labelShowIfUnread.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setLabelListVisibility($value)
    {
        return $this->set('LabelListVisibility', $value);
    }

    /**
     * Set the value for the MessageListVisibility input for this CreateLabel Choreo.
     *
     * @param string $value (required, string) The visibility of messages with this label in the message list in the Gmail web interface. Valid values are: "hide" and "show".
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setMessageListVisibility($value)
    {
        return $this->set('MessageListVisibility', $value);
    }

    /**
     * Set the value for the Name input for this CreateLabel Choreo.
     *
     * @param string $value (required, string) The display name of the label.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateLabel Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this CreateLabel Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Labels_CreateLabel_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the CreateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_CreateLabel_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateLabel Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateLabel execution.
     * @param Google_Gmailv2_Labels_CreateLabel $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Labels_CreateLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_CreateLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_CreateLabel_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Labels_CreateLabel $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateLabel execution.
     *
     * @return Google_Gmailv2_Labels_CreateLabel_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateLabel execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Labels_CreateLabel_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Labels_CreateLabel_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_CreateLabel_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateLabel Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Labels_CreateLabel_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateLabel execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateLabel execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specific label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_DeleteLabel extends Temboo_Choreography
{
    /**
     * Deletes a specific label.
     *
     * @param Temboo_Session $session The session that owns this DeleteLabel Choreo.
     * @return Google_Gmailv2_Labels_DeleteLabel New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Labels/DeleteLabel/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteLabel Choreo.
     *
     * @param Google_Gmailv2_Labels_DeleteLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_DeleteLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_DeleteLabel_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Labels_DeleteLabel_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Labels_DeleteLabel_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_DeleteLabel_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteLabel input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteLabel Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteLabel Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteLabel Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the LabelID input for this DeleteLabel Choreo.
     *
     * @param string $value (required, string) The ID of the label to delete.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteLabel Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteLabel Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Labels_DeleteLabel_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_DeleteLabel_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteLabel Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteLabel execution.
     * @param Google_Gmailv2_Labels_DeleteLabel $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Labels_DeleteLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_DeleteLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_DeleteLabel_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Labels_DeleteLabel $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteLabel execution.
     *
     * @return Google_Gmailv2_Labels_DeleteLabel_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteLabel execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Labels_DeleteLabel_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Labels_DeleteLabel_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_DeleteLabel_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteLabel Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Labels_DeleteLabel_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteLabel execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteLabel execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteLabel execution.
     *
     * @return string (json) The response from Google. An empty response is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_GetLabel extends Temboo_Choreography
{
    /**
     * Retrieves a specific label.
     *
     * @param Temboo_Session $session The session that owns this GetLabel Choreo.
     * @return Google_Gmailv2_Labels_GetLabel New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Labels/GetLabel/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetLabel Choreo.
     *
     * @param Google_Gmailv2_Labels_GetLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_GetLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_GetLabel_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Labels_GetLabel_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Labels_GetLabel_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_GetLabel_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetLabel input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetLabel Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetLabel Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetLabel Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetLabel Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the LabelID input for this GetLabel Choreo.
     *
     * @param string $value (required, string) The ID of the label to retrieve.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetLabel Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this GetLabel Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Labels_GetLabel_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_GetLabel_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetLabel Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetLabel execution.
     * @param Google_Gmailv2_Labels_GetLabel $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Labels_GetLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_GetLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_GetLabel_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Labels_GetLabel $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetLabel execution.
     *
     * @return Google_Gmailv2_Labels_GetLabel_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetLabel execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Labels_GetLabel_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Labels_GetLabel_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_GetLabel_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetLabel Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Labels_GetLabel_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetLabel execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetLabel execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all labels in the user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_ListLabels extends Temboo_Choreography
{
    /**
     * Lists all labels in the user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this ListLabels Choreo.
     * @return Google_Gmailv2_Labels_ListLabels New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Labels/ListLabels/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListLabels Choreo.
     *
     * @param Google_Gmailv2_Labels_ListLabels_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_ListLabels_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_ListLabels_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Labels_ListLabels_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListLabels Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Labels_ListLabels_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListLabels Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_ListLabels_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListLabels Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListLabels input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListLabels Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListLabels Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListLabels Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListLabels Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListLabels Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListLabels Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Labels_ListLabels_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListLabels Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_ListLabels_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListLabels Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListLabels execution.
     * @param Google_Gmailv2_Labels_ListLabels $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Labels_ListLabels_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_ListLabels_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_ListLabels_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Labels_ListLabels $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListLabels execution.
     *
     * @return Google_Gmailv2_Labels_ListLabels_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListLabels execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Labels_ListLabels_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Labels_ListLabels_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListLabels Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_ListLabels_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListLabels Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Labels_ListLabels_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListLabels execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListLabels execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates a specific label.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_UpdateLabel extends Temboo_Choreography
{
    /**
     * Updates a specific label.
     *
     * @param Temboo_Session $session The session that owns this UpdateLabel Choreo.
     * @return Google_Gmailv2_Labels_UpdateLabel New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Labels/UpdateLabel/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateLabel Choreo.
     *
     * @param Google_Gmailv2_Labels_UpdateLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_UpdateLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_UpdateLabel_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Labels_UpdateLabel_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Labels_UpdateLabel_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_UpdateLabel_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateLabel Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateLabel input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateLabel Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateLabel Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateLabel Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this UpdateLabel Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the LabelID input for this UpdateLabel Choreo.
     *
     * @param string $value (required, string) The ID of the label to update.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the LabelListVisibility input for this UpdateLabel Choreo.
     *
     * @param string $value (required, string) The visibility of the label in the label list in the Gmail web interface. Valid values are: "labelHide", "labelShow", and "labelShowIfUnread.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setLabelListVisibility($value)
    {
        return $this->set('LabelListVisibility', $value);
    }

    /**
     * Set the value for the MessageListVisibility input for this UpdateLabel Choreo.
     *
     * @param string $value (required, string) The visibility of messages with this label in the message list in the Gmail web interface. Valid values are: "hide" and "show".
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setMessageListVisibility($value)
    {
        return $this->set('MessageListVisibility', $value);
    }

    /**
     * Set the value for the Name input for this UpdateLabel Choreo.
     *
     * @param string $value (required, string) The display name of the label.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateLabel Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this UpdateLabel Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Labels_UpdateLabel_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the UpdateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_UpdateLabel_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateLabel Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateLabel execution.
     * @param Google_Gmailv2_Labels_UpdateLabel $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Labels_UpdateLabel_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Labels_UpdateLabel_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Labels_UpdateLabel_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Labels_UpdateLabel $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateLabel execution.
     *
     * @return Google_Gmailv2_Labels_UpdateLabel_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateLabel execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Labels_UpdateLabel_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Labels_UpdateLabel_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateLabel Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Labels_UpdateLabel_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateLabel Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Labels_UpdateLabel_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateLabel execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateLabel execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Clears the history ID stored in your Temboo account when executing the GetNextMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ClearStoredHistory extends Temboo_Choreography
{
    /**
     * Clears the history ID stored in your Temboo account when executing the GetNextMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this ClearStoredHistory Choreo.
     * @return Google_Gmailv2_Messages_ClearStoredHistory New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/ClearStoredHistory/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ClearStoredHistory Choreo.
     *
     * @param Google_Gmailv2_Messages_ClearStoredHistory_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ClearStoredHistory_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_ClearStoredHistory_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ClearStoredHistory Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_ClearStoredHistory_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ClearStoredHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ClearStoredHistory_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ClearStoredHistory Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ClearStoredHistory input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the LabelID input for this ClearStoredHistory Choreo.
     *
     * @param string $value (optional, string) The Label ID associated with the stored history ID that should be deleted.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }
}


/**
 * Execution object for the ClearStoredHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ClearStoredHistory_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ClearStoredHistory Choreo.
     *
     * @param Temboo_Session $session The session that owns this ClearStoredHistory execution.
     * @param Google_Gmailv2_Messages_ClearStoredHistory $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_ClearStoredHistory_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ClearStoredHistory_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_ClearStoredHistory $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ClearStoredHistory execution.
     *
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ClearStoredHistory execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_ClearStoredHistory_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ClearStoredHistory Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ClearStoredHistory_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ClearStoredHistory Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ClearStoredHistory_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Deleted" output from this ClearStoredHistory execution.
     *
     * @return bool (boolean) Returns true when the history ID is successfully deleted.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getDeleted()
    {
        return $this->get('Deleted');
    }
}

/**
 * Permanently deletes a specified message.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_DeleteMessage extends Temboo_Choreography
{
    /**
     * Permanently deletes a specified message.
     *
     * @param Temboo_Session $session The session that owns this DeleteMessage Choreo.
     * @return Google_Gmailv2_Messages_DeleteMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/DeleteMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_DeleteMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_DeleteMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_DeleteMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_DeleteMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_DeleteMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_DeleteMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the MessageID input for this DeleteMessage Choreo.
     *
     * @param string $value (required, string) The ID of the message to delete.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_DeleteMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_DeleteMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteMessage execution.
     * @param Google_Gmailv2_Messages_DeleteMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_DeleteMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_DeleteMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_DeleteMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_DeleteMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteMessage execution.
     *
     * @return Google_Gmailv2_Messages_DeleteMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_DeleteMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_DeleteMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_DeleteMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_DeleteMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this DeleteMessage execution.
     *
     * @return int (integer) The response status code returned from Google. A 204 is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteMessage execution.
     *
     * @return string (json) The response from Google. An empty response is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the latest email from a user's inbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetLatestMessage extends Temboo_Choreography
{
    /**
     * Retrieves the latest email from a user's inbox.
     *
     * @param Temboo_Session $session The session that owns this GetLatestMessage Choreo.
     * @return Google_Gmailv2_Messages_GetLatestMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/GetLatestMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetLatestMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_GetLatestMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetLatestMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_GetLatestMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetLatestMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_GetLatestMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetLatestMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetLatestMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetLatestMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetLatestMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetLatestMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetLatestMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetLatestMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EncodeMessage input for this GetLatestMessage Choreo.
     *
     * @param bool $value (optional, boolean) When set to "true" (the default), the message Body will be Base64 encoded.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setEncodeMessage($value)
    {
        return $this->set('EncodeMessage', $value);
    }

    /**
     * Set the value for the IncludeSpamTrash input for this GetLatestMessage Choreo.
     *
     * @param bool $value (optional, boolean) Set to "true" to include messages from SPAM and TRASH in the results. Defaults to "false".
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setIncludeSpamTrash($value)
    {
        return $this->set('IncludeSpamTrash', $value);
    }

    /**
     * Set the value for the LabelID input for this GetLatestMessage Choreo.
     *
     * @param string $value (optional, string) Returns messages with a label matching this ID.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetLatestMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the StartHistoryID input for this GetLatestMessage Choreo.
     *
     * @param string $value (optional, string) Returns history records after the specified marker. The history ID is returned by this Choreo after retrieving a message.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setStartHistoryID($value)
    {
        return $this->set('StartHistoryID', $value);
    }

    /**
     * Set the value for the UserID input for this GetLatestMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetLatestMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetLatestMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetLatestMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetLatestMessage execution.
     * @param Google_Gmailv2_Messages_GetLatestMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_GetLatestMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetLatestMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_GetLatestMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetLatestMessage execution.
     *
     * @return Google_Gmailv2_Messages_GetLatestMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetLatestMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_GetLatestMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetLatestMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetLatestMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetLatestMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetLatestMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Body" output from this GetLatestMessage execution.
     *
     * @return string (string) The message body.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getBody()
    {
        return $this->get('Body');
    }
    /**
     * Retrieve the value for the "From" output from this GetLatestMessage execution.
     *
     * @return string (string) The sender address.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFrom()
    {
        return $this->get('From');
    }
    /**
     * Retrieve the value for the "HistoryID" output from this GetLatestMessage execution.
     *
     * @return string (string) The history ID. This can be passed to the StartHistoryID input to retrieve only mail received after this marker.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getHistoryID()
    {
        return $this->get('HistoryID');
    }
    /**
     * Retrieve the value for the "MessageID" output from this GetLatestMessage execution.
     *
     * @return string (string) The ID of the message.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getMessageID()
    {
        return $this->get('MessageID');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetLatestMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Snippet" output from this GetLatestMessage execution.
     *
     * @return string (string) The email body snippet.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSnippet()
    {
        return $this->get('Snippet');
    }
    /**
     * Retrieve the value for the "Subject" output from this GetLatestMessage execution.
     *
     * @return string (string) The message subject.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSubject()
    {
        return $this->get('Subject');
    }
    /**
     * Retrieve the value for the "Response" output from this GetLatestMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves an individual message from a user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetMessage extends Temboo_Choreography
{
    /**
     * Retrieves an individual message from a user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this GetMessage Choreo.
     * @return Google_Gmailv2_Messages_GetMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/GetMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_GetMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_GetMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_GetMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Format input for this GetMessage Choreo.
     *
     * @param bool $value (optional, boolean) Specifies the format of the message returned. Valid values are: full (the default), minimal, and raw. See Choreo notes for more details about these formats.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setFormat($value)
    {
        return $this->set('Format', $value);
    }

    /**
     * Set the value for the MessageID input for this GetMessage Choreo.
     *
     * @param string $value (required, string) The ID of the message to retrieve.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this GetMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_GetMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetMessage execution.
     * @param Google_Gmailv2_Messages_GetMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_GetMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_GetMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetMessage execution.
     *
     * @return Google_Gmailv2_Messages_GetMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_GetMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the next email from a user's inbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetNextMessage extends Temboo_Choreography
{
    /**
     * Retrieves the next email from a user's inbox.
     *
     * @param Temboo_Session $session The session that owns this GetNextMessage Choreo.
     * @return Google_Gmailv2_Messages_GetNextMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/GetNextMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetNextMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_GetNextMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetNextMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetNextMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_GetNextMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetNextMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_GetNextMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetNextMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetNextMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetNextMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetNextMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetNextMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetNextMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetNextMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EncodeMessage input for this GetNextMessage Choreo.
     *
     * @param bool $value (optional, boolean) When set to "true" (the default), the message Body will be Base64 encoded.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setEncodeMessage($value)
    {
        return $this->set('EncodeMessage', $value);
    }

    /**
     * Set the value for the LabelID input for this GetNextMessage Choreo.
     *
     * @param string $value (conditional, string) Returns messages with a label matching this ID (e.g., INBOX, UNREAD, Label_1, etc.)
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setLabelID($value)
    {
        return $this->set('LabelID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetNextMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this GetNextMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_GetNextMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetNextMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetNextMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetNextMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetNextMessage execution.
     * @param Google_Gmailv2_Messages_GetNextMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_GetNextMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_GetNextMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_GetNextMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_GetNextMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetNextMessage execution.
     *
     * @return Google_Gmailv2_Messages_GetNextMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetNextMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetNextMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_GetNextMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetNextMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_GetNextMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetNextMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_GetNextMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Body" output from this GetNextMessage execution.
     *
     * @return string (string) The message body.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getBody()
    {
        return $this->get('Body');
    }
    /**
     * Retrieve the value for the "From" output from this GetNextMessage execution.
     *
     * @return string (string) The sender address.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFrom()
    {
        return $this->get('From');
    }
    /**
     * Retrieve the value for the "MessageID" output from this GetNextMessage execution.
     *
     * @return string (string) The ID of the message.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getMessageID()
    {
        return $this->get('MessageID');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetNextMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this GetNextMessage execution.
     *
     * @return int (integer) The response code returned from Google. A 200 is expected for a successful request. A 404 indicates that the stored history id has become invalid or expired. See Choreo notes for more details.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Snippet" output from this GetNextMessage execution.
     *
     * @return string (string) The email body snippet.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSnippet()
    {
        return $this->get('Snippet');
    }
    /**
     * Retrieve the value for the "Subject" output from this GetNextMessage execution.
     *
     * @return string (string) The message subject.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSubject()
    {
        return $this->get('Subject');
    }
    /**
     * Retrieve the value for the "Response" output from this GetNextMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Directly inserts a message into a user's mailbox. Does not send a message.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_InsertMessage extends Temboo_Choreography
{
    /**
     * Directly inserts a message into a user's mailbox. Does not send a message.
     *
     * @param Temboo_Session $session The session that owns this InsertMessage Choreo.
     * @return Google_Gmailv2_Messages_InsertMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/InsertMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InsertMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_InsertMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_InsertMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_InsertMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_InsertMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InsertMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_InsertMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InsertMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_InsertMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InsertMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InsertMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AttachmentContentType input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the attachment. This is required when providing AttachmentFileContent (e.g., image/jpeg, text/plain, etc).
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setAttachmentContentType($value)
    {
        return $this->set('AttachmentContentType', $value);
    }

    /**
     * Set the value for the AttachmentFileContent input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The Base64 encoded file content for the attachment. You must specify the AttachmentFileContentType when including an attachment.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setAttachmentFileContent($value)
    {
        return $this->set('AttachmentFileContent', $value);
    }

    /**
     * Set the value for the AttachmentFileName input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The file name of the attachment.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setAttachmentFileName($value)
    {
        return $this->set('AttachmentFileName', $value);
    }

    /**
     * Set the value for the BCC input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be bcc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setBCC($value)
    {
        return $this->set('BCC', $value);
    }

    /**
     * Set the value for the CC input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be cc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setCC($value)
    {
        return $this->set('CC', $value);
    }

    /**
     * Set the value for the ClientID input for this InsertMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this InsertMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the From input for this InsertMessage Choreo.
     *
     * @param string $value (required, string) The address and name (optional) that the email is being sent from e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setFrom($value)
    {
        return $this->set('From', $value);
    }

    /**
     * Set the value for the LabelIDs input for this InsertMessage Choreo.
     *
     * @param string $value (optional, json) An array of Gmail labels to apply to this message (e.g., ["SENT", "INBOX", "UNREAD"].
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setLabelIDs($value)
    {
        return $this->set('LabelIDs', $value);
    }

    /**
     * Set the value for the MessageBody input for this InsertMessage Choreo.
     *
     * @param string $value (required, string) The text for the message body of the email.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setMessageBody($value)
    {
        return $this->set('MessageBody', $value);
    }

    /**
     * Set the value for the MessageBodyContentType input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the message body. Defaults to "text/plain; charset=UTF-8".
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setMessageBodyContentType($value)
    {
        return $this->set('MessageBodyContentType', $value);
    }

    /**
     * Set the value for the RefreshToken input for this InsertMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyTo input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) An email address to set as the Reply-To address.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setReplyTo($value)
    {
        return $this->set('ReplyTo', $value);
    }

    /**
     * Set the value for the Subject input for this InsertMessage Choreo.
     *
     * @param string $value (required, string) The email subject.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setSubject($value)
    {
        return $this->set('Subject', $value);
    }

    /**
     * Set the value for the ThreadID input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the thread the message belongs to.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the To input for this InsertMessage Choreo.
     *
     * @param string $value (required, string) The address and name (optional) that the email is being sent to e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setTo($value)
    {
        return $this->set('To', $value);
    }

    /**
     * Set the value for the UserID input for this InsertMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_InsertMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the InsertMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_InsertMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InsertMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this InsertMessage execution.
     * @param Google_Gmailv2_Messages_InsertMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_InsertMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_InsertMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_InsertMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_InsertMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InsertMessage execution.
     *
     * @return Google_Gmailv2_Messages_InsertMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InsertMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_InsertMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_InsertMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InsertMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_InsertMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InsertMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_InsertMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this InsertMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this InsertMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the messages in the user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ListMessages extends Temboo_Choreography
{
    /**
     * Lists the messages in the user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this ListMessages Choreo.
     * @return Google_Gmailv2_Messages_ListMessages New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/ListMessages/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListMessages Choreo.
     *
     * @param Google_Gmailv2_Messages_ListMessages_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ListMessages_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ListMessages_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_ListMessages_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListMessages Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_ListMessages_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListMessages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ListMessages_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListMessages Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListMessages input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListMessages Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListMessages Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListMessages Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListMessages Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the IncludeSpamTrash input for this ListMessages Choreo.
     *
     * @param bool $value (optional, boolean) Set to "true" to include messages from SPAM and TRASH in the results. Defaults to "false".
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setIncludeSpamTrash($value)
    {
        return $this->set('IncludeSpamTrash', $value);
    }

    /**
     * Set the value for the LabelIDs input for this ListMessages Choreo.
     *
     * @param string $value (optional, json) A JSON array containing labels to filter by. When specified, only messages with labels that match are returned.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setLabelIDs($value)
    {
        return $this->set('LabelIDs', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListMessages Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListMessages Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this ListMessages Choreo.
     *
     * @param string $value (optional, string) Filters messages that match the specified query. Supports the same query format as the Gmail search box. For example, "from:someuser@example.com rfc822msgid: is:unread".
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListMessages Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListMessages Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_ListMessages_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListMessages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ListMessages_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListMessages Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListMessages execution.
     * @param Google_Gmailv2_Messages_ListMessages $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_ListMessages_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ListMessages_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ListMessages_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_ListMessages $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListMessages execution.
     *
     * @return Google_Gmailv2_Messages_ListMessages_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListMessages execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ListMessages_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_ListMessages_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListMessages Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ListMessages_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListMessages Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ListMessages_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListMessages execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListMessages execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Modifies the labels for a specific message.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ModifyMessage extends Temboo_Choreography
{
    /**
     * Modifies the labels for a specific message.
     *
     * @param Temboo_Session $session The session that owns this ModifyMessage Choreo.
     * @return Google_Gmailv2_Messages_ModifyMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/ModifyMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ModifyMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_ModifyMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ModifyMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ModifyMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_ModifyMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ModifyMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_ModifyMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ModifyMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ModifyMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ModifyMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ModifyMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ModifyMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AddLabelIDs input for this ModifyMessage Choreo.
     *
     * @param string $value (conditional, json) An array of label IDs to apply to the message.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setAddLabelIDs($value)
    {
        return $this->set('AddLabelIDs', $value);
    }

    /**
     * Set the value for the ClientID input for this ModifyMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ModifyMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ModifyMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MessageID input for this ModifyMessage Choreo.
     *
     * @param string $value (required, string) The ID of the message to modify.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ModifyMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RemoveLabelIDs input for this ModifyMessage Choreo.
     *
     * @param string $value (conditional, json) An array of label IDs to remove from the message.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setRemoveLabelIDs($value)
    {
        return $this->set('RemoveLabelIDs', $value);
    }

    /**
     * Set the value for the UserID input for this ModifyMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_ModifyMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ModifyMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ModifyMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ModifyMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this ModifyMessage execution.
     * @param Google_Gmailv2_Messages_ModifyMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_ModifyMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_ModifyMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_ModifyMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_ModifyMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ModifyMessage execution.
     *
     * @return Google_Gmailv2_Messages_ModifyMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ModifyMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ModifyMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_ModifyMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ModifyMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_ModifyMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ModifyMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_ModifyMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ModifyMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ModifyMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Sends an email to the recipients specified in the To, CC, and BCC parameters.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_SendMessage extends Temboo_Choreography
{
    /**
     * Sends an email to the recipients specified in the To, CC, and BCC parameters.
     *
     * @param Temboo_Session $session The session that owns this SendMessage Choreo.
     * @return Google_Gmailv2_Messages_SendMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/SendMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SendMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_SendMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_SendMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_SendMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_SendMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SendMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_SendMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SendMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_SendMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SendMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SendMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AttachmentContentType input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the attachment. This is required when providing AttachmentFileContent (e.g., image/jpeg, text/plain, etc).
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setAttachmentContentType($value)
    {
        return $this->set('AttachmentContentType', $value);
    }

    /**
     * Set the value for the AttachmentFileContent input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The Base64 encoded file content for the attachment. You must specify the AttachmentFileContentType when including an attachment.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setAttachmentFileContent($value)
    {
        return $this->set('AttachmentFileContent', $value);
    }

    /**
     * Set the value for the AttachmentFileName input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The file name of the attachment.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setAttachmentFileName($value)
    {
        return $this->set('AttachmentFileName', $value);
    }

    /**
     * Set the value for the BCC input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be bcc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setBCC($value)
    {
        return $this->set('BCC', $value);
    }

    /**
     * Set the value for the CC input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The address and name (optional) that should be cc'd e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setCC($value)
    {
        return $this->set('CC', $value);
    }

    /**
     * Set the value for the ClientID input for this SendMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SendMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the From input for this SendMessage Choreo.
     *
     * @param string $value (required, string) The address and name (optional) that the email is being sent from e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setFrom($value)
    {
        return $this->set('From', $value);
    }

    /**
     * Set the value for the MessageBody input for this SendMessage Choreo.
     *
     * @param string $value (required, string) The text for the message body of the email.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setMessageBody($value)
    {
        return $this->set('MessageBody', $value);
    }

    /**
     * Set the value for the MessageBodyContentType input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The Content-Type of the message body. Defaults to "text/plain; charset=UTF-8".
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setMessageBodyContentType($value)
    {
        return $this->set('MessageBodyContentType', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SendMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReplyTo input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) An email address to set as the Reply-To address.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setReplyTo($value)
    {
        return $this->set('ReplyTo', $value);
    }

    /**
     * Set the value for the Subject input for this SendMessage Choreo.
     *
     * @param string $value (required, string) The email subject.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setSubject($value)
    {
        return $this->set('Subject', $value);
    }

    /**
     * Set the value for the ThreadID input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the thread the message belongs to.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the To input for this SendMessage Choreo.
     *
     * @param string $value (required, string) The address and name (optional) that the email is being sent to e.g., Dan <dan@temboo.com>.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setTo($value)
    {
        return $this->set('To', $value);
    }

    /**
     * Set the value for the UserID input for this SendMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_SendMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the SendMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_SendMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SendMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this SendMessage execution.
     * @param Google_Gmailv2_Messages_SendMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_SendMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_SendMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_SendMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_SendMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SendMessage execution.
     *
     * @return Google_Gmailv2_Messages_SendMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SendMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_SendMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_SendMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SendMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_SendMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SendMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_SendMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SendMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SendMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Moves a specific message to the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_TrashMessage extends Temboo_Choreography
{
    /**
     * Moves a specific message to the trash.
     *
     * @param Temboo_Session $session The session that owns this TrashMessage Choreo.
     * @return Google_Gmailv2_Messages_TrashMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/TrashMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this TrashMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_TrashMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_TrashMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_TrashMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_TrashMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this TrashMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_TrashMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the TrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_TrashMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the TrashMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this TrashMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this TrashMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this TrashMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this TrashMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this TrashMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MessageID input for this TrashMessage Choreo.
     *
     * @param string $value (required, string) The ID of the message to move to the trash.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this TrashMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this TrashMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_TrashMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the TrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_TrashMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the TrashMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this TrashMessage execution.
     * @param Google_Gmailv2_Messages_TrashMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_TrashMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_TrashMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_TrashMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_TrashMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this TrashMessage execution.
     *
     * @return Google_Gmailv2_Messages_TrashMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this TrashMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_TrashMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_TrashMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the TrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_TrashMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the TrashMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_TrashMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this TrashMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this TrashMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Moves a specific message out of the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_UnTrashMessage extends Temboo_Choreography
{
    /**
     * Moves a specific message out of the trash.
     *
     * @param Temboo_Session $session The session that owns this UnTrashMessage Choreo.
     * @return Google_Gmailv2_Messages_UnTrashMessage New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Messages/UnTrashMessage/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UnTrashMessage Choreo.
     *
     * @param Google_Gmailv2_Messages_UnTrashMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_UnTrashMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Messages_UnTrashMessage_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UnTrashMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Messages_UnTrashMessage_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UnTrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_UnTrashMessage_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UnTrashMessage Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UnTrashMessage input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UnTrashMessage Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UnTrashMessage Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UnTrashMessage Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this UnTrashMessage Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MessageID input for this UnTrashMessage Choreo.
     *
     * @param string $value (required, string) The ID of the message to restore.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setMessageID($value)
    {
        return $this->set('MessageID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UnTrashMessage Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this UnTrashMessage Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the UnTrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_UnTrashMessage_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UnTrashMessage Choreo.
     *
     * @param Temboo_Session $session The session that owns this UnTrashMessage execution.
     * @param Google_Gmailv2_Messages_UnTrashMessage $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Messages_UnTrashMessage_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Messages_UnTrashMessage_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Messages_UnTrashMessage $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UnTrashMessage execution.
     *
     * @return Google_Gmailv2_Messages_UnTrashMessage_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UnTrashMessage execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Messages_UnTrashMessage_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UnTrashMessage Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Messages_UnTrashMessage_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UnTrashMessage Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Messages_UnTrashMessage_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UnTrashMessage execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UnTrashMessage execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Permanently deletes a specific thread.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_DeleteThread extends Temboo_Choreography
{
    /**
     * Permanently deletes a specific thread.
     *
     * @param Temboo_Session $session The session that owns this DeleteThread Choreo.
     * @return Google_Gmailv2_Threads_DeleteThread New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/DeleteThread/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteThread Choreo.
     *
     * @param Google_Gmailv2_Threads_DeleteThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_DeleteThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_DeleteThread_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_DeleteThread_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_DeleteThread_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_DeleteThread_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteThread input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteThread Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteThread Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteThread Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteThread Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ThreadID input for this DeleteThread Choreo.
     *
     * @param string $value (required, string) The ID of the thread to delete.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteThread Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_DeleteThread_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_DeleteThread_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteThread Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteThread execution.
     * @param Google_Gmailv2_Threads_DeleteThread $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_DeleteThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_DeleteThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_DeleteThread_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_DeleteThread $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteThread execution.
     *
     * @return Google_Gmailv2_Threads_DeleteThread_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteThread execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_DeleteThread_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_DeleteThread_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_DeleteThread_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteThread Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_DeleteThread_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteThread execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteThread execution.
     *
     * @return string (json) The response from Google. An empty response is expected for a successful delete operation.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves an individual thread from a user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_GetThread extends Temboo_Choreography
{
    /**
     * Retrieves an individual thread from a user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this GetThread Choreo.
     * @return Google_Gmailv2_Threads_GetThread New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/GetThread/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetThread Choreo.
     *
     * @param Google_Gmailv2_Threads_GetThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_GetThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_GetThread_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_GetThread_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_GetThread_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_GetThread_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_GetThread_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_GetThread_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetThread input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetThread Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetThread Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetThread Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetThread Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetThread Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ThreadID input for this GetThread Choreo.
     *
     * @param string $value (required, string) The ID of the thread to retrieve.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the UserID input for this GetThread Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_GetThread_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the GetThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_GetThread_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetThread Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetThread execution.
     * @param Google_Gmailv2_Threads_GetThread $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_GetThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_GetThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_GetThread_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_GetThread $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetThread execution.
     *
     * @return Google_Gmailv2_Threads_GetThread_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetThread execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_GetThread_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_GetThread_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_GetThread_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetThread Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_GetThread_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetThread execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetThread execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists the threads in the user's mailbox.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ListThreads extends Temboo_Choreography
{
    /**
     * Lists the threads in the user's mailbox.
     *
     * @param Temboo_Session $session The session that owns this ListThreads Choreo.
     * @return Google_Gmailv2_Threads_ListThreads New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/ListThreads/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListThreads Choreo.
     *
     * @param Google_Gmailv2_Threads_ListThreads_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_ListThreads_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_ListThreads_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_ListThreads_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListThreads Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_ListThreads_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListThreads Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ListThreads_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListThreads Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListThreads input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListThreads Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListThreads Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListThreads Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListThreads Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the IncludeSpamTrash input for this ListThreads Choreo.
     *
     * @param bool $value (optional, boolean) Set to "true" to include threads from SPAM and TRASH in the results. Defaults to "false".
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setIncludeSpamTrash($value)
    {
        return $this->set('IncludeSpamTrash', $value);
    }

    /**
     * Set the value for the LabelIDs input for this ListThreads Choreo.
     *
     * @param string $value (optional, json) A JSON array containing labels to filter by. When specified, only threads with labels that match are returned.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setLabelIDs($value)
    {
        return $this->set('LabelIDs', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListThreads Choreo.
     *
     * @param int $value (optional, integer) The maximum number of results to return.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListThreads Choreo.
     *
     * @param string $value (optional, string) The "nextPageToken" found in the response which is used to page through results.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this ListThreads Choreo.
     *
     * @param string $value (optional, string) Filters threads that match the specified query. Supports the same query format as the Gmail search box. For example, "from:someuser@example.com rfc822msgid: is:unread".
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListThreads Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListThreads Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_ListThreads_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListThreads Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ListThreads_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListThreads Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListThreads execution.
     * @param Google_Gmailv2_Threads_ListThreads $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_ListThreads_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_ListThreads_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_ListThreads_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_ListThreads $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListThreads execution.
     *
     * @return Google_Gmailv2_Threads_ListThreads_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListThreads execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_ListThreads_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_ListThreads_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListThreads Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ListThreads_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListThreads Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_ListThreads_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListThreads execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListThreads execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Modifies the labels for a specific thread.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ModifyThread extends Temboo_Choreography
{
    /**
     * Modifies the labels for a specific thread.
     *
     * @param Temboo_Session $session The session that owns this ModifyThread Choreo.
     * @return Google_Gmailv2_Threads_ModifyThread New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/ModifyThread/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ModifyThread Choreo.
     *
     * @param Google_Gmailv2_Threads_ModifyThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_ModifyThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_ModifyThread_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_ModifyThread_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ModifyThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_ModifyThread_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ModifyThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ModifyThread_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ModifyThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ModifyThread input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ModifyThread Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AddLabelIDs input for this ModifyThread Choreo.
     *
     * @param string $value (conditional, json) An array of label IDs to apply to the thread.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setAddLabelIDs($value)
    {
        return $this->set('AddLabelIDs', $value);
    }

    /**
     * Set the value for the ClientID input for this ModifyThread Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ModifyThread Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ModifyThread Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ModifyThread Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RemoveLabelIDs input for this ModifyThread Choreo.
     *
     * @param string $value (conditional, json) An array of label IDs to remove from the thread.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setRemoveLabelIDs($value)
    {
        return $this->set('RemoveLabelIDs', $value);
    }

    /**
     * Set the value for the ThreadID input for this ModifyThread Choreo.
     *
     * @param string $value (required, string) The ID of the thread to modify.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the UserID input for this ModifyThread Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_ModifyThread_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ModifyThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ModifyThread_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ModifyThread Choreo.
     *
     * @param Temboo_Session $session The session that owns this ModifyThread execution.
     * @param Google_Gmailv2_Threads_ModifyThread $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_ModifyThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_ModifyThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_ModifyThread_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_ModifyThread $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ModifyThread execution.
     *
     * @return Google_Gmailv2_Threads_ModifyThread_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ModifyThread execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_ModifyThread_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_ModifyThread_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ModifyThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_ModifyThread_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ModifyThread Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_ModifyThread_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ModifyThread execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ModifyThread execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Moves a specific thread to the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_TrashThread extends Temboo_Choreography
{
    /**
     * Moves a specific thread to the trash.
     *
     * @param Temboo_Session $session The session that owns this TrashThread Choreo.
     * @return Google_Gmailv2_Threads_TrashThread New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/TrashThread/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this TrashThread Choreo.
     *
     * @param Google_Gmailv2_Threads_TrashThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_TrashThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_TrashThread_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_TrashThread_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this TrashThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_TrashThread_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the TrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_TrashThread_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the TrashThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this TrashThread input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this TrashThread Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this TrashThread Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this TrashThread Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this TrashThread Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this TrashThread Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ThreadID input for this TrashThread Choreo.
     *
     * @param string $value (required, string) The ID of the thread to move to the trash.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the UserID input for this TrashThread Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_TrashThread_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the TrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_TrashThread_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the TrashThread Choreo.
     *
     * @param Temboo_Session $session The session that owns this TrashThread execution.
     * @param Google_Gmailv2_Threads_TrashThread $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_TrashThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_TrashThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_TrashThread_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_TrashThread $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this TrashThread execution.
     *
     * @return Google_Gmailv2_Threads_TrashThread_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this TrashThread execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_TrashThread_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_TrashThread_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the TrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_TrashThread_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the TrashThread Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_TrashThread_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this TrashThread execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this TrashThread execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Moves a specific thread out of the trash.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_UnTrashThread extends Temboo_Choreography
{
    /**
     * Moves a specific thread out of the trash.
     *
     * @param Temboo_Session $session The session that owns this UnTrashThread Choreo.
     * @return Google_Gmailv2_Threads_UnTrashThread New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Gmailv2/Threads/UnTrashThread/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UnTrashThread Choreo.
     *
     * @param Google_Gmailv2_Threads_UnTrashThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_UnTrashThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_UnTrashThread_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Gmailv2_Threads_UnTrashThread_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UnTrashThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Gmailv2_Threads_UnTrashThread_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UnTrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_UnTrashThread_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UnTrashThread Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UnTrashThread input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UnTrashThread Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UnTrashThread Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UnTrashThread Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this UnTrashThread Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See Choreo notes for syntax rules.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UnTrashThread Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ThreadID input for this UnTrashThread Choreo.
     *
     * @param string $value (required, string) The ID of the thread to restore.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setThreadID($value)
    {
        return $this->set('ThreadID', $value);
    }

    /**
     * Set the value for the UserID input for this UnTrashThread Choreo.
     *
     * @param string $value (optional, string) The ID of the acting user. Defaults to "me" indicating the user associated with the Access Token or Refresh Token provided.
     * @return Google_Gmailv2_Threads_UnTrashThread_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the UnTrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_UnTrashThread_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UnTrashThread Choreo.
     *
     * @param Temboo_Session $session The session that owns this UnTrashThread execution.
     * @param Google_Gmailv2_Threads_UnTrashThread $choreo The choreography object for this execution.
     * @param Google_Gmailv2_Threads_UnTrashThread_Inputs|array $inputs (optional) Inputs as Google_Gmailv2_Threads_UnTrashThread_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Gmailv2_Threads_UnTrashThread_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Gmailv2_Threads_UnTrashThread $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UnTrashThread execution.
     *
     * @return Google_Gmailv2_Threads_UnTrashThread_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UnTrashThread execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Gmailv2_Threads_UnTrashThread_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Gmailv2_Threads_UnTrashThread_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UnTrashThread Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Gmailv2_Threads_UnTrashThread_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UnTrashThread Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Gmailv2_Threads_UnTrashThread_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UnTrashThread execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UnTrashThread execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeEntities extends Temboo_Choreography
{
    /**
     * Finds named entities (currently proper names and common nouns) in the text along with entity types, salience, mentions for each entity, and other properties.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeEntities Choreo.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/NaturalLanguage/Documents/AnalyzeEntities/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AnalyzeEntities Choreo.
     *
     * @param Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeEntities_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AnalyzeEntities Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AnalyzeEntities Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AnalyzeEntities Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AnalyzeEntities input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this AnalyzeEntities Choreo.
     *
     * @param string $value (conditional, string) The API Key provided by Google.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Content input for this AnalyzeEntities Choreo.
     *
     * @param string $value (conditional, string) The content to analyze.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the EncodingType input for this AnalyzeEntities Choreo.
     *
     * @param string $value (optional, string) The encoding type used by the API to calculate sentence offsets. Defaults to UTF-8.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setEncodingType($value)
    {
        return $this->set('EncodingType', $value);
    }

    /**
     * Set the value for the Fields input for this AnalyzeEntities Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the GCSContentUri input for this AnalyzeEntities Choreo.
     *
     * @param string $value (optional, string) The Google Cloud Storage URI where the file content is located. This can be used instead of the Content input.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setGCSContentUri($value)
    {
        return $this->set('GCSContentUri', $value);
    }

    /**
     * Set the value for the Language input for this AnalyzeEntities Choreo.
     *
     * @param string $value (optional, string) The language of the document. This is specified with the ISO-639-1 Code (e.g. "en"). If not specified, the language is detected if possible.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Type input for this AnalyzeEntities Choreo.
     *
     * @param string $value (optional, string) The type of content being sent. Valid values are PLAIN_TEXT (the default) and HTML.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }
}


/**
 * Execution object for the AnalyzeEntities Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeEntities_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AnalyzeEntities Choreo.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeEntities execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeEntities $choreo The choreography object for this execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeEntities_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_NaturalLanguage_Documents_AnalyzeEntities $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AnalyzeEntities execution.
     *
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AnalyzeEntities execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeEntities_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AnalyzeEntities Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeEntities_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AnalyzeEntities Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeEntities_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this AnalyzeEntities execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Analyzes the sentiment of the provided text.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSentiment extends Temboo_Choreography
{
    /**
     * Analyzes the sentiment of the provided text.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeSentiment Choreo.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/NaturalLanguage/Documents/AnalyzeSentiment/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AnalyzeSentiment Choreo.
     *
     * @param Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSentiment_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AnalyzeSentiment Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AnalyzeSentiment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AnalyzeSentiment Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AnalyzeSentiment input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (conditional, string) The API Key provided by Google.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Content input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (conditional, string) The content to analyze.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the EncodingType input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (optional, string) The encoding type used by the API to calculate sentence offsets. Defaults to UTF-8.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setEncodingType($value)
    {
        return $this->set('EncodingType', $value);
    }

    /**
     * Set the value for the Fields input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the GCSContentUri input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (optional, string) The Google Cloud Storage URI where the file content is located. This can be used instead of the Content input.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setGCSContentUri($value)
    {
        return $this->set('GCSContentUri', $value);
    }

    /**
     * Set the value for the Language input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (optional, string) The language of the document. This is specified with the ISO-639-1 Code (e.g. "en"). If not specified, the language is detected if possible.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Type input for this AnalyzeSentiment Choreo.
     *
     * @param string $value (optional, string) The type of content being sent. Valid values are PLAIN_TEXT (the default) and HTML.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }
}


/**
 * Execution object for the AnalyzeSentiment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSentiment_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AnalyzeSentiment Choreo.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeSentiment execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeSentiment $choreo The choreography object for this execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeSentiment_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_NaturalLanguage_Documents_AnalyzeSentiment $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AnalyzeSentiment execution.
     *
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AnalyzeSentiment execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSentiment_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AnalyzeSentiment Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSentiment_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AnalyzeSentiment Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSentiment_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Score" output from this AnalyzeSentiment execution.
     *
     * @return float (decimal) The overall sentiment score of the input document.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getScore()
    {
        return $this->get('Score');
    }
    /**
     * Retrieve the value for the "Response" output from this AnalyzeSentiment execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSyntax extends Temboo_Choreography
{
    /**
     * Analyzes the syntax of the text and provides sentence boundaries and tokenization along with part of speech tags, dependency trees, and other properties.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeSyntax Choreo.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/NaturalLanguage/Documents/AnalyzeSyntax/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AnalyzeSyntax Choreo.
     *
     * @param Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSyntax_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AnalyzeSyntax Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AnalyzeSyntax Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AnalyzeSyntax Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AnalyzeSyntax input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (conditional, string) The API Key provided by Google.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Content input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (conditional, string) The content to analyze.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the EncodingType input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (optional, string) The encoding type used by the API to calculate sentence offsets. Defaults to UTF-8.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setEncodingType($value)
    {
        return $this->set('EncodingType', $value);
    }

    /**
     * Set the value for the Fields input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the GCSContentUri input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (optional, string) The Google Cloud Storage URI where the file content is located. This can be used instead of the Content input.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setGCSContentUri($value)
    {
        return $this->set('GCSContentUri', $value);
    }

    /**
     * Set the value for the Language input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (optional, string) The language of the document. This is specified with the ISO-639-1 Code (e.g. "en"). If not specified, the language is detected if possible.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Type input for this AnalyzeSyntax Choreo.
     *
     * @param string $value (optional, string) The type of content being sent. Valid values are PLAIN_TEXT (the default) and HTML.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }
}


/**
 * Execution object for the AnalyzeSyntax Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSyntax_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AnalyzeSyntax Choreo.
     *
     * @param Temboo_Session $session The session that owns this AnalyzeSyntax execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeSyntax $choreo The choreography object for this execution.
     * @param Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnalyzeSyntax_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_NaturalLanguage_Documents_AnalyzeSyntax $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AnalyzeSyntax execution.
     *
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AnalyzeSyntax execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_NaturalLanguage_Documents_AnalyzeSyntax_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AnalyzeSyntax Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnalyzeSyntax_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AnalyzeSyntax Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnalyzeSyntax_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this AnalyzeSyntax execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * A convenience method that provides all the features that analyzeSentiment, analyzeEntities, and analyzeSyntax provide in one call.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnnotateText extends Temboo_Choreography
{
    /**
     * A convenience method that provides all the features that analyzeSentiment, analyzeEntities, and analyzeSyntax provide in one call.
     *
     * @param Temboo_Session $session The session that owns this AnnotateText Choreo.
     * @return Google_NaturalLanguage_Documents_AnnotateText New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/NaturalLanguage/Documents/AnnotateText/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AnnotateText Choreo.
     *
     * @param Google_NaturalLanguage_Documents_AnnotateText_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnnotateText_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_NaturalLanguage_Documents_AnnotateText_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AnnotateText Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_NaturalLanguage_Documents_AnnotateText_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AnnotateText Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnnotateText_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AnnotateText Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AnnotateText input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the APIKey input for this AnnotateText Choreo.
     *
     * @param string $value (conditional, string) The API Key provided by Google.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setAPIKey($value)
    {
        return $this->set('APIKey', $value);
    }

    /**
     * Set the value for the Content input for this AnnotateText Choreo.
     *
     * @param string $value (conditional, string) The content to analyze.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the EncodingType input for this AnnotateText Choreo.
     *
     * @param string $value (optional, string) The encoding type used by the API to calculate sentence offsets. Defaults to UTF-8.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setEncodingType($value)
    {
        return $this->set('EncodingType', $value);
    }

    /**
     * Set the value for the ExtractDocumentSentiment input for this AnnotateText Choreo.
     *
     * @param bool $value (optional, boolean) Extract document-level sentiment. Defaults to true.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setExtractDocumentSentiment($value)
    {
        return $this->set('ExtractDocumentSentiment', $value);
    }

    /**
     * Set the value for the ExtractEntities input for this AnnotateText Choreo.
     *
     * @param bool $value (optional, boolean) Extract entities. Defaults to true.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setExtractEntities($value)
    {
        return $this->set('ExtractEntities', $value);
    }

    /**
     * Set the value for the ExtractSyntax input for this AnnotateText Choreo.
     *
     * @param bool $value (optional, boolean) Extract syntax information. Defaults to true.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setExtractSyntax($value)
    {
        return $this->set('ExtractSyntax', $value);
    }

    /**
     * Set the value for the Fields input for this AnnotateText Choreo.
     *
     * @param string $value (optional, string) Selector specifying which fields to include in a partial response.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the GCSContentUri input for this AnnotateText Choreo.
     *
     * @param string $value (optional, string) The Google Cloud Storage URI where the file content is located. This can be used instead of the Content input.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setGCSContentUri($value)
    {
        return $this->set('GCSContentUri', $value);
    }

    /**
     * Set the value for the Language input for this AnnotateText Choreo.
     *
     * @param string $value (optional, string) The language of the document. This is specified with the ISO-639-1 Code (e.g. "en"). If not specified, the language is detected if possible.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Type input for this AnnotateText Choreo.
     *
     * @param string $value (optional, string) The type of content being sent. Valid values are PLAIN_TEXT (the default) and HTML.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Inputs For method chaining.
     */
    public function setType($value)
    {
        return $this->set('Type', $value);
    }
}


/**
 * Execution object for the AnnotateText Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnnotateText_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AnnotateText Choreo.
     *
     * @param Temboo_Session $session The session that owns this AnnotateText execution.
     * @param Google_NaturalLanguage_Documents_AnnotateText $choreo The choreography object for this execution.
     * @param Google_NaturalLanguage_Documents_AnnotateText_Inputs|array $inputs (optional) Inputs as Google_NaturalLanguage_Documents_AnnotateText_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_NaturalLanguage_Documents_AnnotateText $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AnnotateText execution.
     *
     * @return Google_NaturalLanguage_Documents_AnnotateText_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AnnotateText execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_NaturalLanguage_Documents_AnnotateText_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AnnotateText Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_NaturalLanguage_Documents_AnnotateText_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AnnotateText Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_NaturalLanguage_Documents_AnnotateText_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this AnnotateText execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Completes the OAuth process by retrieving a Google access token for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_FinalizeOAuth extends Temboo_Choreography
{
    /**
     * Completes the OAuth process by retrieving a Google access token for a user, after they have visited the authorization URL returned by the InitializeOAuth Choreo and clicked "allow."
     *
     * @param Temboo_Session $session The session that owns this FinalizeOAuth Choreo.
     * @return Google_OAuth_FinalizeOAuth New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/OAuth/FinalizeOAuth/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this FinalizeOAuth Choreo.
     *
     * @param Google_OAuth_FinalizeOAuth_Inputs|array $inputs (optional) Inputs as Google_OAuth_FinalizeOAuth_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_OAuth_FinalizeOAuth_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_OAuth_FinalizeOAuth_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this FinalizeOAuth Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_OAuth_FinalizeOAuth_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_OAuth_FinalizeOAuth_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the FinalizeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_FinalizeOAuth_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the FinalizeOAuth Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_OAuth_FinalizeOAuth_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this FinalizeOAuth input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccountName input for this FinalizeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setAccountName($value)
    {
        return $this->set('AccountName', $value);
    }

    /**
     * Set the value for the AppKeyName input for this FinalizeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setAppKeyName($value)
    {
        return $this->set('AppKeyName', $value);
    }

    /**
     * Set the value for the AppKeyValue input for this FinalizeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setAppKeyValue($value)
    {
        return $this->set('AppKeyValue', $value);
    }

    /**
     * Set the value for the CallbackID input for this FinalizeOAuth Choreo.
     *
     * @param string $value (required, string) The callback token returned by the InitializeOAuth Choreo. Used to retrieve the authorization code after the user authorizes.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setCallbackID($value)
    {
        return $this->set('CallbackID', $value);
    }

    /**
     * Set the value for the ClientID input for this FinalizeOAuth Choreo.
     *
     * @param string $value (required, string) The Client ID provided by Google after registering your application.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this FinalizeOAuth Choreo.
     *
     * @param string $value (required, string) The Client Secret provided by Google after registering your application.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the SuppressErrors input for this FinalizeOAuth Choreo.
     *
     * @param bool $value (optional, boolean) When set to true, errors received during the OAuth redirect process will be suppressed and returned in the ErrorMessage output.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setSuppressErrors($value)
    {
        return $this->set('SuppressErrors', $value);
    }

    /**
     * Set the value for the Timeout input for this FinalizeOAuth Choreo.
     *
     * @param int $value (optional, integer) The amount of time (in seconds) to poll your Temboo callback URL to see if your app's user has allowed or denied the request for access. Defaults to 20. Max is 60.
     * @return Google_OAuth_FinalizeOAuth_Inputs For method chaining.
     */
    public function setTimeout($value)
    {
        return $this->set('Timeout', $value);
    }
}


/**
 * Execution object for the FinalizeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_FinalizeOAuth_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the FinalizeOAuth Choreo.
     *
     * @param Temboo_Session $session The session that owns this FinalizeOAuth execution.
     * @param Google_OAuth_FinalizeOAuth $choreo The choreography object for this execution.
     * @param Google_OAuth_FinalizeOAuth_Inputs|array $inputs (optional) Inputs as Google_OAuth_FinalizeOAuth_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_OAuth_FinalizeOAuth_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_OAuth_FinalizeOAuth $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this FinalizeOAuth execution.
     *
     * @return Google_OAuth_FinalizeOAuth_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this FinalizeOAuth execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_OAuth_FinalizeOAuth_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_OAuth_FinalizeOAuth_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the FinalizeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_FinalizeOAuth_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the FinalizeOAuth Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_OAuth_FinalizeOAuth_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this FinalizeOAuth execution.
     *
     * @return string (string) The access token for the user that has granted access to your application.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "ErrorMessage" output from this FinalizeOAuth execution.
     *
     * @return string (string) Contains an error message if an error occurs during the OAuth redirect process and if SuppressErrors is set to true.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getErrorMessage()
    {
        return $this->get('ErrorMessage');
    }
    /**
     * Retrieve the value for the "Expires" output from this FinalizeOAuth execution.
     *
     * @return int (integer) The remaining lifetime of the short-lived access token.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getExpires()
    {
        return $this->get('Expires');
    }
    /**
     * Retrieve the value for the "RefreshToken" output from this FinalizeOAuth execution.
     *
     * @return string (string) A token that may be used to obtain a new access token when the short-lived access token expires.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getRefreshToken()
    {
        return $this->get('RefreshToken');
    }
}

/**
 * Generates an authorization URL that an application can use to complete the first step in the OAuth process.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_InitializeOAuth extends Temboo_Choreography
{
    /**
     * Generates an authorization URL that an application can use to complete the first step in the OAuth process.
     *
     * @param Temboo_Session $session The session that owns this InitializeOAuth Choreo.
     * @return Google_OAuth_InitializeOAuth New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/OAuth/InitializeOAuth/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this InitializeOAuth Choreo.
     *
     * @param Google_OAuth_InitializeOAuth_Inputs|array $inputs (optional) Inputs as Google_OAuth_InitializeOAuth_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_OAuth_InitializeOAuth_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_OAuth_InitializeOAuth_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this InitializeOAuth Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_OAuth_InitializeOAuth_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_OAuth_InitializeOAuth_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the InitializeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_InitializeOAuth_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the InitializeOAuth Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_OAuth_InitializeOAuth_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this InitializeOAuth input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccountName input for this InitializeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setAccountName($value)
    {
        return $this->set('AccountName', $value);
    }

    /**
     * Set the value for the AppKeyName input for this InitializeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setAppKeyName($value)
    {
        return $this->set('AppKeyName', $value);
    }

    /**
     * Set the value for the AppKeyValue input for this InitializeOAuth Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setAppKeyValue($value)
    {
        return $this->set('AppKeyValue', $value);
    }

    /**
     * Set the value for the ClientID input for this InitializeOAuth Choreo.
     *
     * @param string $value (required, string) The Client ID provided by Google after registering your application.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the CustomCallbackID input for this InitializeOAuth Choreo.
     *
     * @param string $value (optional, string) A unique identifier that you can pass to eliminate the need to wait for a Temboo generated CallbackID. Callback identifiers may only contain numbers, letters, periods, and hyphens.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setCustomCallbackID($value)
    {
        return $this->set('CustomCallbackID', $value);
    }

    /**
     * Set the value for the ForwardingURL input for this InitializeOAuth Choreo.
     *
     * @param string $value (optional, string) The URL that Temboo will redirect your users to after they grant access to your application. This should include the "https://" or "http://" prefix and be a fully qualified URL.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setForwardingURL($value)
    {
        return $this->set('ForwardingURL', $value);
    }

    /**
     * Set the value for the Scope input for this InitializeOAuth Choreo.
     *
     * @param string $value (required, string) A space-delimited list of scopes to requests access for. See Choreo notes for a list of valid scopes.
     * @return Google_OAuth_InitializeOAuth_Inputs For method chaining.
     */
    public function setScope($value)
    {
        return $this->set('Scope', $value);
    }
}


/**
 * Execution object for the InitializeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_InitializeOAuth_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the InitializeOAuth Choreo.
     *
     * @param Temboo_Session $session The session that owns this InitializeOAuth execution.
     * @param Google_OAuth_InitializeOAuth $choreo The choreography object for this execution.
     * @param Google_OAuth_InitializeOAuth_Inputs|array $inputs (optional) Inputs as Google_OAuth_InitializeOAuth_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_OAuth_InitializeOAuth_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_OAuth_InitializeOAuth $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this InitializeOAuth execution.
     *
     * @return Google_OAuth_InitializeOAuth_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this InitializeOAuth execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_OAuth_InitializeOAuth_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_OAuth_InitializeOAuth_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the InitializeOAuth Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_OAuth_InitializeOAuth_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the InitializeOAuth Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_OAuth_InitializeOAuth_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AuthorizationURL" output from this InitializeOAuth execution.
     *
     * @return string (string) The authorization URL that the application's user needs to go to in order to grant access to your application.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAuthorizationURL()
    {
        return $this->get('AuthorizationURL');
    }
    /**
     * Retrieve the value for the "CallbackID" output from this InitializeOAuth execution.
     *
     * @return string (string) An ID used to retrieve the callback data that Temboo stores once your application's user authorizes.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCallbackID()
    {
        return $this->get('CallbackID');
    }
}

/**
 * Adds a comment to a specified photo in Google Picasa.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_AddCommentToPhoto extends Temboo_Choreography
{
    /**
     * Adds a comment to a specified photo in Google Picasa.
     *
     * @param Temboo_Session $session The session that owns this AddCommentToPhoto Choreo.
     * @return Google_Picasa_AddCommentToPhoto New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/AddCommentToPhoto/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AddCommentToPhoto Choreo.
     *
     * @param Google_Picasa_AddCommentToPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_AddCommentToPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_AddCommentToPhoto_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_AddCommentToPhoto_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AddCommentToPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_AddCommentToPhoto_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_AddCommentToPhoto_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AddCommentToPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_AddCommentToPhoto_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AddCommentToPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_AddCommentToPhoto_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AddCommentToPhoto input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumID input for this AddCommentToPhoto Choreo.
     *
     * @param int $value (required, integer) The id of the album which contains the photo you want to add a comment to.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setAlbumID($value)
    {
        return $this->set('AlbumID', $value);
    }

    /**
     * Set the value for the ClientID input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Comment input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (required, string) The comment that you want to add to a photo.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setComment($value)
    {
        return $this->set('Comment', $value);
    }

    /**
     * Set the value for the PhotoID input for this AddCommentToPhoto Choreo.
     *
     * @param int $value (required, integer) The id of the photo you want to add a comment to.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setPhotoID($value)
    {
        return $this->set('PhotoID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this AddCommentToPhoto Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_AddCommentToPhoto_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the AddCommentToPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_AddCommentToPhoto_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AddCommentToPhoto Choreo.
     *
     * @param Temboo_Session $session The session that owns this AddCommentToPhoto execution.
     * @param Google_Picasa_AddCommentToPhoto $choreo The choreography object for this execution.
     * @param Google_Picasa_AddCommentToPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_AddCommentToPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_AddCommentToPhoto_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_AddCommentToPhoto $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AddCommentToPhoto execution.
     *
     * @return Google_Picasa_AddCommentToPhoto_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AddCommentToPhoto execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_AddCommentToPhoto_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_AddCommentToPhoto_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AddCommentToPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_AddCommentToPhoto_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AddCommentToPhoto Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_AddCommentToPhoto_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AddCommentToPhoto execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AddCommentToPhoto execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a photo album in a Google Picasa account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_CreateAlbum extends Temboo_Choreography
{
    /**
     * Creates a photo album in a Google Picasa account.
     *
     * @param Temboo_Session $session The session that owns this CreateAlbum Choreo.
     * @return Google_Picasa_CreateAlbum New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/CreateAlbum/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateAlbum Choreo.
     *
     * @param Google_Picasa_CreateAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_CreateAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_CreateAlbum_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_CreateAlbum_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_CreateAlbum_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_CreateAlbum_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_CreateAlbum_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_CreateAlbum_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateAlbum input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Keywords input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) Keywords to associate with the album you are creating separated by commas.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setKeywords($value)
    {
        return $this->set('Keywords', $value);
    }

    /**
     * Set the value for the PhotoAccess input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) The perssion level to specify for photo access. Defaults to 'public'.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setPhotoAccess($value)
    {
        return $this->set('PhotoAccess', $value);
    }

    /**
     * Set the value for the PhotoLocation input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) The location to associate with the photo (i.e. Italy).
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setPhotoLocation($value)
    {
        return $this->set('PhotoLocation', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateAlbum Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Summary input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) The album summary.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setSummary($value)
    {
        return $this->set('Summary', $value);
    }

    /**
     * Set the value for the Timestamp input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, date) The timestamp to associate with the photo.  Defaults to the current timestamp. Should be an epoch timestamp in milliseconds.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setTimestamp($value)
    {
        return $this->set('Timestamp', $value);
    }

    /**
     * Set the value for the Title input for this CreateAlbum Choreo.
     *
     * @param string $value (required, string) The title of the album.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }

    /**
     * Set the value for the UserID input for this CreateAlbum Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_CreateAlbum_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the CreateAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_CreateAlbum_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateAlbum Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateAlbum execution.
     * @param Google_Picasa_CreateAlbum $choreo The choreography object for this execution.
     * @param Google_Picasa_CreateAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_CreateAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_CreateAlbum_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_CreateAlbum $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateAlbum execution.
     *
     * @return Google_Picasa_CreateAlbum_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateAlbum execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_CreateAlbum_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_CreateAlbum_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_CreateAlbum_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateAlbum Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_CreateAlbum_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateAlbum execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateAlbum execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes an album in Google Picasa with a specified album Id.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteAlbum extends Temboo_Choreography
{
    /**
     * Deletes an album in Google Picasa with a specified album Id.
     *
     * @param Temboo_Session $session The session that owns this DeleteAlbum Choreo.
     * @return Google_Picasa_DeleteAlbum New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/DeleteAlbum/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteAlbum Choreo.
     *
     * @param Google_Picasa_DeleteAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_DeleteAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_DeleteAlbum_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_DeleteAlbum_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_DeleteAlbum_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_DeleteAlbum_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteAlbum_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_DeleteAlbum_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteAlbum input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteAlbum Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumID input for this DeleteAlbum Choreo.
     *
     * @param int $value (required, integer) The album id. Note that this can be retrieved by running the ListAlbums Choreo.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setAlbumID($value)
    {
        return $this->set('AlbumID', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteAlbum Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteAlbum Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_DeleteAlbum_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteAlbum_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteAlbum Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteAlbum execution.
     * @param Google_Picasa_DeleteAlbum $choreo The choreography object for this execution.
     * @param Google_Picasa_DeleteAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_DeleteAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_DeleteAlbum_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_DeleteAlbum $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteAlbum execution.
     *
     * @return Google_Picasa_DeleteAlbum_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteAlbum execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_DeleteAlbum_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_DeleteAlbum_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteAlbum_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteAlbum Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_DeleteAlbum_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteAlbum execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteAlbum execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Removes a tag from a specified photo in Google Picasa.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteTag extends Temboo_Choreography
{
    /**
     * Removes a tag from a specified photo in Google Picasa.
     *
     * @param Temboo_Session $session The session that owns this DeleteTag Choreo.
     * @return Google_Picasa_DeleteTag New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/DeleteTag/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteTag Choreo.
     *
     * @param Google_Picasa_DeleteTag_Inputs|array $inputs (optional) Inputs as Google_Picasa_DeleteTag_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_DeleteTag_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_DeleteTag_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteTag Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_DeleteTag_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_DeleteTag_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteTag_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteTag Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_DeleteTag_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteTag input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteTag Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumId input for this DeleteTag Choreo.
     *
     * @param int $value (required, integer) The id for the album which has the tagged photo. Note that this can be retrieved by running the ListAlbums Choreo.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setAlbumId($value)
    {
        return $this->set('AlbumId', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteTag Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteTag Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the PhotoID input for this DeleteTag Choreo.
     *
     * @param int $value (required, integer) The id for the photo that has a tag to delete.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setPhotoID($value)
    {
        return $this->set('PhotoID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteTag Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the TagID input for this DeleteTag Choreo.
     *
     * @param string $value (required, string) The Id (or tag name) for the tag that you want to delete.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setTagID($value)
    {
        return $this->set('TagID', $value);
    }

    /**
     * Set the value for the UserID input for this DeleteTag Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_DeleteTag_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the DeleteTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteTag_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteTag Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteTag execution.
     * @param Google_Picasa_DeleteTag $choreo The choreography object for this execution.
     * @param Google_Picasa_DeleteTag_Inputs|array $inputs (optional) Inputs as Google_Picasa_DeleteTag_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_DeleteTag_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_DeleteTag $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteTag execution.
     *
     * @return Google_Picasa_DeleteTag_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteTag execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_DeleteTag_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_DeleteTag_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_DeleteTag_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteTag Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_DeleteTag_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteTag execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteTag execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * List all albums created in a Google Picasa account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListAlbums extends Temboo_Choreography
{
    /**
     * List all albums created in a Google Picasa account.
     *
     * @param Temboo_Session $session The session that owns this ListAlbums Choreo.
     * @return Google_Picasa_ListAlbums New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/ListAlbums/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListAlbums Choreo.
     *
     * @param Google_Picasa_ListAlbums_Inputs|array $inputs (optional) Inputs as Google_Picasa_ListAlbums_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_ListAlbums_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_ListAlbums_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListAlbums Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_ListAlbums_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_ListAlbums_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListAlbums Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListAlbums_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListAlbums Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_ListAlbums_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListAlbums input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListAlbums Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ListAlbums Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListAlbums Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListAlbums Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListAlbums Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_ListAlbums_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListAlbums Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListAlbums_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListAlbums Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListAlbums execution.
     * @param Google_Picasa_ListAlbums $choreo The choreography object for this execution.
     * @param Google_Picasa_ListAlbums_Inputs|array $inputs (optional) Inputs as Google_Picasa_ListAlbums_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_ListAlbums_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_ListAlbums $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListAlbums execution.
     *
     * @return Google_Picasa_ListAlbums_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListAlbums execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_ListAlbums_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_ListAlbums_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListAlbums Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListAlbums_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListAlbums Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_ListAlbums_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListAlbums execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListAlbums execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all photos in a specified Google Picasa album.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListPhotosByAlbum extends Temboo_Choreography
{
    /**
     * Lists all photos in a specified Google Picasa album.
     *
     * @param Temboo_Session $session The session that owns this ListPhotosByAlbum Choreo.
     * @return Google_Picasa_ListPhotosByAlbum New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/ListPhotosByAlbum/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListPhotosByAlbum Choreo.
     *
     * @param Google_Picasa_ListPhotosByAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_ListPhotosByAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_ListPhotosByAlbum_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_ListPhotosByAlbum_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListPhotosByAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_ListPhotosByAlbum_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListPhotosByAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListPhotosByAlbum_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListPhotosByAlbum Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListPhotosByAlbum input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListPhotosByAlbum Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumID input for this ListPhotosByAlbum Choreo.
     *
     * @param int $value (required, integer) The album id. Note that this can be retrieved by running the ListAlbums Choreo.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setAlbumID($value)
    {
        return $this->set('AlbumID', $value);
    }

    /**
     * Set the value for the ClientID input for this ListPhotosByAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListPhotosByAlbum Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListPhotosByAlbum Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListPhotosByAlbum Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_ListPhotosByAlbum_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the ListPhotosByAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListPhotosByAlbum_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListPhotosByAlbum Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListPhotosByAlbum execution.
     * @param Google_Picasa_ListPhotosByAlbum $choreo The choreography object for this execution.
     * @param Google_Picasa_ListPhotosByAlbum_Inputs|array $inputs (optional) Inputs as Google_Picasa_ListPhotosByAlbum_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_ListPhotosByAlbum_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_ListPhotosByAlbum $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListPhotosByAlbum execution.
     *
     * @return Google_Picasa_ListPhotosByAlbum_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListPhotosByAlbum execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_ListPhotosByAlbum_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_ListPhotosByAlbum_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListPhotosByAlbum Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_ListPhotosByAlbum_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListPhotosByAlbum Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_ListPhotosByAlbum_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListPhotosByAlbum execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListPhotosByAlbum execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Uploads a photo to Google Picasa.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_PostPhoto extends Temboo_Choreography
{
    /**
     * Uploads a photo to Google Picasa.
     *
     * @param Temboo_Session $session The session that owns this PostPhoto Choreo.
     * @return Google_Picasa_PostPhoto New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/PostPhoto/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this PostPhoto Choreo.
     *
     * @param Google_Picasa_PostPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_PostPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_PostPhoto_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_PostPhoto_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this PostPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_PostPhoto_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_PostPhoto_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the PostPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_PostPhoto_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the PostPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_PostPhoto_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this PostPhoto input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the FileContents input for this PostPhoto Choreo.
     *
     * @param string $value (conditional, string) The base64 encoded file contents of the photo you want to upload.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setFileContents($value)
    {
        return $this->set('FileContents', $value);
    }

    /**
     * Set the value for the AccessToken input for this PostPhoto Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumID input for this PostPhoto Choreo.
     *
     * @param int $value (optional, integer) The id of the album that you want to upload the photo to. Defaults to 'default' which means the photo will be uploaded to the dropbox album.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setAlbumID($value)
    {
        return $this->set('AlbumID', $value);
    }

    /**
     * Set the value for the ClientID input for this PostPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this PostPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ImageName input for this PostPhoto Choreo.
     *
     * @param string $value (required, string) The name of the image you want to upload.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setImageName($value)
    {
        return $this->set('ImageName', $value);
    }

    /**
     * Set the value for the RefreshToken input for this PostPhoto Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this PostPhoto Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to "default" which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_PostPhoto_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

}


/**
 * Execution object for the PostPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_PostPhoto_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the PostPhoto Choreo.
     *
     * @param Temboo_Session $session The session that owns this PostPhoto execution.
     * @param Google_Picasa_PostPhoto $choreo The choreography object for this execution.
     * @param Google_Picasa_PostPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_PostPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_PostPhoto_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_PostPhoto $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this PostPhoto execution.
     *
     * @return Google_Picasa_PostPhoto_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this PostPhoto execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_PostPhoto_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_PostPhoto_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the PostPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_PostPhoto_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the PostPhoto Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_PostPhoto_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this PostPhoto execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this PostPhoto execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns a feed of the photo comments for a specified user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveComments extends Temboo_Choreography
{
    /**
     * Returns a feed of the photo comments for a specified user.
     *
     * @param Temboo_Session $session The session that owns this RetrieveComments Choreo.
     * @return Google_Picasa_RetrieveComments New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/RetrieveComments/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveComments Choreo.
     *
     * @param Google_Picasa_RetrieveComments_Inputs|array $inputs (optional) Inputs as Google_Picasa_RetrieveComments_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_RetrieveComments_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_RetrieveComments_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveComments Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_RetrieveComments_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_RetrieveComments_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveComments Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveComments_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveComments Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_RetrieveComments_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveComments input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveComments Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveComments Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveComments Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the MaxResults input for this RetrieveComments Choreo.
     *
     * @param int $value (optional, integer) The max number of comments to return. Defaults to 10.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveComments Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this RetrieveComments Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_RetrieveComments_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the RetrieveComments Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveComments_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveComments Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveComments execution.
     * @param Google_Picasa_RetrieveComments $choreo The choreography object for this execution.
     * @param Google_Picasa_RetrieveComments_Inputs|array $inputs (optional) Inputs as Google_Picasa_RetrieveComments_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_RetrieveComments_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_RetrieveComments $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveComments execution.
     *
     * @return Google_Picasa_RetrieveComments_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveComments execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_RetrieveComments_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_RetrieveComments_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveComments Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveComments_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveComments Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_RetrieveComments_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveComments execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveComments execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns a feed of the photo tags for a specified user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveTagsByUser extends Temboo_Choreography
{
    /**
     * Returns a feed of the photo tags for a specified user.
     *
     * @param Temboo_Session $session The session that owns this RetrieveTagsByUser Choreo.
     * @return Google_Picasa_RetrieveTagsByUser New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/RetrieveTagsByUser/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveTagsByUser Choreo.
     *
     * @param Google_Picasa_RetrieveTagsByUser_Inputs|array $inputs (optional) Inputs as Google_Picasa_RetrieveTagsByUser_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_RetrieveTagsByUser_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_RetrieveTagsByUser_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveTagsByUser Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_RetrieveTagsByUser_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveTagsByUser Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveTagsByUser_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveTagsByUser Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveTagsByUser input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveTagsByUser Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveTagsByUser Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveTagsByUser Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveTagsByUser Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this RetrieveTagsByUser Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_RetrieveTagsByUser_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the RetrieveTagsByUser Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveTagsByUser_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveTagsByUser Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveTagsByUser execution.
     * @param Google_Picasa_RetrieveTagsByUser $choreo The choreography object for this execution.
     * @param Google_Picasa_RetrieveTagsByUser_Inputs|array $inputs (optional) Inputs as Google_Picasa_RetrieveTagsByUser_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_RetrieveTagsByUser_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_RetrieveTagsByUser $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveTagsByUser execution.
     *
     * @return Google_Picasa_RetrieveTagsByUser_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveTagsByUser execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_RetrieveTagsByUser_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_RetrieveTagsByUser_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveTagsByUser Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_RetrieveTagsByUser_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveTagsByUser Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_RetrieveTagsByUser_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveTagsByUser execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveTagsByUser execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Searches photos using tags that you specify.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_SearchPhotosByTag extends Temboo_Choreography
{
    /**
     * Searches photos using tags that you specify.
     *
     * @param Temboo_Session $session The session that owns this SearchPhotosByTag Choreo.
     * @return Google_Picasa_SearchPhotosByTag New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/SearchPhotosByTag/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SearchPhotosByTag Choreo.
     *
     * @param Google_Picasa_SearchPhotosByTag_Inputs|array $inputs (optional) Inputs as Google_Picasa_SearchPhotosByTag_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_SearchPhotosByTag_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_SearchPhotosByTag_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SearchPhotosByTag Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_SearchPhotosByTag_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_SearchPhotosByTag_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SearchPhotosByTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_SearchPhotosByTag_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SearchPhotosByTag Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_SearchPhotosByTag_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SearchPhotosByTag input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Tag input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (required, string) A photo tag to search by. Multiple tags can be separated by commas.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setTag($value)
    {
        return $this->set('Tag', $value);
    }

    /**
     * Set the value for the UserID input for this SearchPhotosByTag Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to 'default' which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_SearchPhotosByTag_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the SearchPhotosByTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_SearchPhotosByTag_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SearchPhotosByTag Choreo.
     *
     * @param Temboo_Session $session The session that owns this SearchPhotosByTag execution.
     * @param Google_Picasa_SearchPhotosByTag $choreo The choreography object for this execution.
     * @param Google_Picasa_SearchPhotosByTag_Inputs|array $inputs (optional) Inputs as Google_Picasa_SearchPhotosByTag_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_SearchPhotosByTag_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_SearchPhotosByTag $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SearchPhotosByTag execution.
     *
     * @return Google_Picasa_SearchPhotosByTag_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SearchPhotosByTag execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_SearchPhotosByTag_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_SearchPhotosByTag_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SearchPhotosByTag Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_SearchPhotosByTag_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SearchPhotosByTag Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_SearchPhotosByTag_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SearchPhotosByTag execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this SearchPhotosByTag execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a tag for a specified photo in Google Picasa.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_TagPhoto extends Temboo_Choreography
{
    /**
     * Creates a tag for a specified photo in Google Picasa.
     *
     * @param Temboo_Session $session The session that owns this TagPhoto Choreo.
     * @return Google_Picasa_TagPhoto New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Picasa/TagPhoto/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this TagPhoto Choreo.
     *
     * @param Google_Picasa_TagPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_TagPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_TagPhoto_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Picasa_TagPhoto_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this TagPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_TagPhoto_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Picasa_TagPhoto_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the TagPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_TagPhoto_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the TagPhoto Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Picasa_TagPhoto_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this TagPhoto input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this TagPhoto Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the AlbumID input for this TagPhoto Choreo.
     *
     * @param int $value (required, integer) The id of the album which contains the photo you want to tag.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setAlbumID($value)
    {
        return $this->set('AlbumID', $value);
    }

    /**
     * Set the value for the ClientID input for this TagPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this TagPhoto Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the PhotoID input for this TagPhoto Choreo.
     *
     * @param int $value (required, integer) The id of the photo you want to tag.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setPhotoID($value)
    {
        return $this->set('PhotoID', $value);
    }

    /**
     * Set the value for the RefreshToken input for this TagPhoto Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Tag input for this TagPhoto Choreo.
     *
     * @param string $value (required, string) The text for the photo tag.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setTag($value)
    {
        return $this->set('Tag', $value);
    }

    /**
     * Set the value for the UserID input for this TagPhoto Choreo.
     *
     * @param string $value (optional, string) Google Picasa username. Defaults to "default" which means the server will use the UserID of the user whose access token was specified.
     * @return Google_Picasa_TagPhoto_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }
}


/**
 * Execution object for the TagPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_TagPhoto_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the TagPhoto Choreo.
     *
     * @param Temboo_Session $session The session that owns this TagPhoto execution.
     * @param Google_Picasa_TagPhoto $choreo The choreography object for this execution.
     * @param Google_Picasa_TagPhoto_Inputs|array $inputs (optional) Inputs as Google_Picasa_TagPhoto_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Picasa_TagPhoto_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Picasa_TagPhoto $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this TagPhoto execution.
     *
     * @return Google_Picasa_TagPhoto_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this TagPhoto execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Picasa_TagPhoto_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Picasa_TagPhoto_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the TagPhoto Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Picasa_TagPhoto_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the TagPhoto Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Picasa_TagPhoto_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "AccessToken" output from this TagPhoto execution.
     *
     * @return string (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getAccessToken()
    {
        return $this->get('AccessToken');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this TagPhoto execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this TagPhoto execution.
     *
     * @return string (xml) The response from Google Picasa.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Delete a new Place from Google Places.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_DeletePlace extends Temboo_Choreography
{
    /**
     * Delete a new Place from Google Places.
     *
     * @param Temboo_Session $session The session that owns this DeletePlace Choreo.
     * @return Google_Places_DeletePlace New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/DeletePlace/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeletePlace Choreo.
     *
     * @param Google_Places_DeletePlace_Inputs|array $inputs (optional) Inputs as Google_Places_DeletePlace_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_DeletePlace_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_DeletePlace_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeletePlace Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_DeletePlace_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_DeletePlace_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeletePlace Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_DeletePlace_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeletePlace Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_DeletePlace_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeletePlace input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Key input for this DeletePlace Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the PlaceID input for this DeletePlace Choreo.
     *
     * @param string $value (conditional, string) A textual identifier that uniquely identifies a place.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setPlaceID($value)
    {
        return $this->set('PlaceID', $value);
    }

    /**
     * Set the value for the PlaceReference input for this DeletePlace Choreo.
     *
     * @param string $value (optional, string) A textual identifier that uniquely identifies a place. Note, this parameter is deprecated as of June 24, 2014. Use PlaceID instead.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setPlaceReference($value)
    {
        return $this->set('PlaceReference', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this DeletePlace Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this DeletePlace Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_DeletePlace_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the DeletePlace Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_DeletePlace_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeletePlace Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeletePlace execution.
     * @param Google_Places_DeletePlace $choreo The choreography object for this execution.
     * @param Google_Places_DeletePlace_Inputs|array $inputs (optional) Inputs as Google_Places_DeletePlace_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_DeletePlace_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_DeletePlace $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeletePlace execution.
     *
     * @return Google_Places_DeletePlace_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeletePlace execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_DeletePlace_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_DeletePlace_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeletePlace Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_DeletePlace_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeletePlace Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_DeletePlace_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this DeletePlace execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieve detailed information about places retrieved by the PlaceSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceDetails extends Temboo_Choreography
{
    /**
     * Retrieve detailed information about places retrieved by the PlaceSearch Choreo.
     *
     * @param Temboo_Session $session The session that owns this PlaceDetails Choreo.
     * @return Google_Places_PlaceDetails New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/PlaceDetails/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this PlaceDetails Choreo.
     *
     * @param Google_Places_PlaceDetails_Inputs|array $inputs (optional) Inputs as Google_Places_PlaceDetails_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_PlaceDetails_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_PlaceDetails_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this PlaceDetails Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_PlaceDetails_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_PlaceDetails_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the PlaceDetails Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceDetails_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the PlaceDetails Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_PlaceDetails_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this PlaceDetails input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Key input for this PlaceDetails Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the Language input for this PlaceDetails Choreo.
     *
     * @param string $value (optional, string) The language code, indicating in which language the results should be returned, if possible. See Choreo notes for a list of supported languages and their codes.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the PlaceID input for this PlaceDetails Choreo.
     *
     * @param string $value (conditional, string) A textual identifier that uniquely identifies a place. PlaceIDs are returned by the PlaceSearch Choreo.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setPlaceID($value)
    {
        return $this->set('PlaceID', $value);
    }

    /**
     * Set the value for the Reference input for this PlaceDetails Choreo.
     *
     * @param string $value (optional, string) A textual identifier that uniquely identifies a place. Note, this parameter is deprecated as of June 24, 2014. Use PlaceID instead.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setReference($value)
    {
        return $this->set('Reference', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this PlaceDetails Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this PlaceDetails Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_PlaceDetails_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }
}


/**
 * Execution object for the PlaceDetails Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceDetails_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the PlaceDetails Choreo.
     *
     * @param Temboo_Session $session The session that owns this PlaceDetails execution.
     * @param Google_Places_PlaceDetails $choreo The choreography object for this execution.
     * @param Google_Places_PlaceDetails_Inputs|array $inputs (optional) Inputs as Google_Places_PlaceDetails_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_PlaceDetails_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_PlaceDetails $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this PlaceDetails execution.
     *
     * @return Google_Places_PlaceDetails_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this PlaceDetails execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_PlaceDetails_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_PlaceDetails_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the PlaceDetails Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceDetails_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the PlaceDetails Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_PlaceDetails_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this PlaceDetails execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Search for places based on latitude/longitude coordinates, keywords, and distance.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceSearch extends Temboo_Choreography
{
    /**
     * Search for places based on latitude/longitude coordinates, keywords, and distance.
     *
     * @param Temboo_Session $session The session that owns this PlaceSearch Choreo.
     * @return Google_Places_PlaceSearch New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/PlaceSearch/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this PlaceSearch Choreo.
     *
     * @param Google_Places_PlaceSearch_Inputs|array $inputs (optional) Inputs as Google_Places_PlaceSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_PlaceSearch_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_PlaceSearch_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this PlaceSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_PlaceSearch_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_PlaceSearch_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the PlaceSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceSearch_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the PlaceSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_PlaceSearch_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this PlaceSearch input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Key input for this PlaceSearch Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the Keyword input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) Enter a keyword (term, address, type, customer review, etc.) to be matched against all results retrieved for this Place.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setKeyword($value)
    {
        return $this->set('Keyword', $value);
    }

    /**
     * Set the value for the Language input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) The language code, indicating in which language the results should be returned, if possible. See Choreo notes for a list of supported languages and their codes.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Latitude input for this PlaceSearch Choreo.
     *
     * @param string $value (required, string) Specify a latitude point around which Places results will be retrieved (e.g., 38.898717).
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setLatitude($value)
    {
        return $this->set('Latitude', $value);
    }

    /**
     * Set the value for the Longitude input for this PlaceSearch Choreo.
     *
     * @param string $value (required, string) Specify a longitude point around which Places results will be retrieved (e.g., -77.035974).
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setLongitude($value)
    {
        return $this->set('Longitude', $value);
    }

    /**
     * Set the value for the MaxPrice input for this PlaceSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setMaxPrice($value)
    {
        return $this->set('MaxPrice', $value);
    }

    /**
     * Set the value for the MinPrice input for this PlaceSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setMinPrice($value)
    {
        return $this->set('MinPrice', $value);
    }

    /**
     * Set the value for the Name input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) Enter a name to be matched when results are retrieved for this specified Place.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the OpenNow input for this PlaceSearch Choreo.
     *
     * @param bool $value (optional, boolean) Returns only those Places that are open for business at the time the query is sent. Places that do not specify opening hours in the Google Places database will not be returned.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setOpenNow($value)
    {
        return $this->set('OpenNow', $value);
    }

    /**
     * Set the value for the PageToken input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the choreo output from a previous run. Used to page through large result sets. When the PageToken is specified, all other inputs are ignored.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Radius input for this PlaceSearch Choreo.
     *
     * @param int $value (required, integer) Specify the radius in meters for which Places results will be returned. Maximum radius is limited to 50,000 meters. If rankby=distance, then radius must not be specified.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setRadius($value)
    {
        return $this->set('Radius', $value);
    }

    /**
     * Set the value for the RankBy input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) Specify how results are listed. Values include: prominence (default); distance - sorts results by distance from specified location. Radius must not be used, and Keyword, Name, or Types are required).
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setRankBy($value)
    {
        return $this->set('RankBy', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this PlaceSearch Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Types input for this PlaceSearch Choreo.
     *
     * @param string $value (optional, string) Filter results by types, such as: bar, dentist.  Multiple types must be separated by the pipe ("|") symbol: bar|dentist|airport.
     * @return Google_Places_PlaceSearch_Inputs For method chaining.
     */
    public function setTypes($value)
    {
        return $this->set('Types', $value);
    }
}


/**
 * Execution object for the PlaceSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceSearch_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the PlaceSearch Choreo.
     *
     * @param Temboo_Session $session The session that owns this PlaceSearch execution.
     * @param Google_Places_PlaceSearch $choreo The choreography object for this execution.
     * @param Google_Places_PlaceSearch_Inputs|array $inputs (optional) Inputs as Google_Places_PlaceSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_PlaceSearch_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_PlaceSearch $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this PlaceSearch execution.
     *
     * @return Google_Places_PlaceSearch_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this PlaceSearch execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_PlaceSearch_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_PlaceSearch_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the PlaceSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_PlaceSearch_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the PlaceSearch Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_PlaceSearch_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this PlaceSearch execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Search up to 200 places at once.   RadarSearch helps identify specific areas of interest within a geographic area.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_RadarSearch extends Temboo_Choreography
{
    /**
     * Search up to 200 places at once.   RadarSearch helps identify specific areas of interest within a geographic area.
     *
     * @param Temboo_Session $session The session that owns this RadarSearch Choreo.
     * @return Google_Places_RadarSearch New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/RadarSearch/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RadarSearch Choreo.
     *
     * @param Google_Places_RadarSearch_Inputs|array $inputs (optional) Inputs as Google_Places_RadarSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_RadarSearch_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_RadarSearch_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RadarSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_RadarSearch_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_RadarSearch_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RadarSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_RadarSearch_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RadarSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_RadarSearch_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RadarSearch input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Key input for this RadarSearch Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the Keyword input for this RadarSearch Choreo.
     *
     * @param string $value (conditional, string) Enter a keyword (term, address, type, customer review, etc.) to be matched against all results retrieved for this Place.  At least one of Keyword, Name or Types must be specified.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setKeyword($value)
    {
        return $this->set('Keyword', $value);
    }

    /**
     * Set the value for the Language input for this RadarSearch Choreo.
     *
     * @param string $value (optional, string) The language code, indicating in which language the results should be returned, if possible. See Choreo notes for a list of supported languages and their codes.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Latitude input for this RadarSearch Choreo.
     *
     * @param string $value (required, string) Specify a latitude point around which Places results will be retrieved (e.g., 38.898717).
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setLatitude($value)
    {
        return $this->set('Latitude', $value);
    }

    /**
     * Set the value for the Longitude input for this RadarSearch Choreo.
     *
     * @param string $value (required, string) Specify a longitude point around which Places results will be retrieved (e.g., -77.035974).
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setLongitude($value)
    {
        return $this->set('Longitude', $value);
    }

    /**
     * Set the value for the MaxPrice input for this RadarSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setMaxPrice($value)
    {
        return $this->set('MaxPrice', $value);
    }

    /**
     * Set the value for the MinPrice input for this RadarSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setMinPrice($value)
    {
        return $this->set('MinPrice', $value);
    }

    /**
     * Set the value for the Name input for this RadarSearch Choreo.
     *
     * @param string $value (conditional, string) Enter a name to be matched when results are retrieved for this specified Place.  At least one of Keyword, Name or Types must be specified.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the OpenNow input for this RadarSearch Choreo.
     *
     * @param bool $value (optional, boolean) Returns only those Places that are open for business at the time the query is sent. Places that do not specify opening hours in the Google Places database will not be returned.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setOpenNow($value)
    {
        return $this->set('OpenNow', $value);
    }

    /**
     * Set the value for the PageToken input for this RadarSearch Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the choreo output from a previous run. Used to page through large result sets. When the PageToken is specified, all other inputs are ignored.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Radius input for this RadarSearch Choreo.
     *
     * @param int $value (required, integer) Specify the radius in meters for which Places results will be returned. Maximum radius is limited to 50,000 meters.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setRadius($value)
    {
        return $this->set('Radius', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RadarSearch Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this RadarSearch Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Types input for this RadarSearch Choreo.
     *
     * @param string $value (conditional, string) Filter results by types, such as: bar, dentist.  Multiple types must be separated by the pipe ("|") symbol: bar|dentist|airport.   At least one of Keyword, Name or Types must be specified.
     * @return Google_Places_RadarSearch_Inputs For method chaining.
     */
    public function setTypes($value)
    {
        return $this->set('Types', $value);
    }
}


/**
 * Execution object for the RadarSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_RadarSearch_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RadarSearch Choreo.
     *
     * @param Temboo_Session $session The session that owns this RadarSearch execution.
     * @param Google_Places_RadarSearch $choreo The choreography object for this execution.
     * @param Google_Places_RadarSearch_Inputs|array $inputs (optional) Inputs as Google_Places_RadarSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_RadarSearch_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_RadarSearch $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RadarSearch execution.
     *
     * @return Google_Places_RadarSearch_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RadarSearch execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_RadarSearch_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_RadarSearch_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RadarSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_RadarSearch_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RadarSearch Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_RadarSearch_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this RadarSearch execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Search for places based on a text query and optional location.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_TextSearch extends Temboo_Choreography
{
    /**
     * Search for places based on a text query and optional location.
     *
     * @param Temboo_Session $session The session that owns this TextSearch Choreo.
     * @return Google_Places_TextSearch New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/TextSearch/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this TextSearch Choreo.
     *
     * @param Google_Places_TextSearch_Inputs|array $inputs (optional) Inputs as Google_Places_TextSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_TextSearch_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_TextSearch_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this TextSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_TextSearch_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_TextSearch_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the TextSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_TextSearch_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the TextSearch Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_TextSearch_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this TextSearch input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the Key input for this TextSearch Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the Language input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) The language code, indicating in which language the results should be returned, if possible. See Choreo notes for a list of supported languages and their codes.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Latitude input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) Specify a latitude point around which Places results will be retrieved (e.g., 38.898717). When specifying a latitude, both longitude and radius must also be supplied.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setLatitude($value)
    {
        return $this->set('Latitude', $value);
    }

    /**
     * Set the value for the Longitude input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) Specify a longitude point around which Places results will be retrieved (e.g., -77.035974). When specifying a longitude, both latitude and radius must also be supplied.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setLongitude($value)
    {
        return $this->set('Longitude', $value);
    }

    /**
     * Set the value for the MaxPrice input for this TextSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setMaxPrice($value)
    {
        return $this->set('MaxPrice', $value);
    }

    /**
     * Set the value for the MinPrice input for this TextSearch Choreo.
     *
     * @param int $value (optional, integer) Restricts results to only those places within the specified range. Valid values range between 0 (most affordable) to 4 (most expensive), inclusive. The exact amount will vary from region to region.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setMinPrice($value)
    {
        return $this->set('MinPrice', $value);
    }

    /**
     * Set the value for the OpenNow input for this TextSearch Choreo.
     *
     * @param bool $value (optional, boolean) Returns only those Places that are open for business at the time the query is sent. Places that do not specify opening hours in the Google Places database will not be returned.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setOpenNow($value)
    {
        return $this->set('OpenNow', $value);
    }

    /**
     * Set the value for the PageToken input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the choreo output from a previous run. Used to page through large result sets. When the PageToken is specified, all other inputs are ignored.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the Query input for this TextSearch Choreo.
     *
     * @param string $value (required, string) The text string on which to search, for example: "restaurant". The Place service will return candidate matches based on this string and order the results based on their perceived relevance.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the Radius input for this TextSearch Choreo.
     *
     * @param int $value (optional, integer) Specify the radius in meters for which Places results will be returned. Maximum radius is limited to 50,000 meters. When specifying a radius, both latitude and longitude must also be supplied.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setRadius($value)
    {
        return $this->set('Radius', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this TextSearch Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Types input for this TextSearch Choreo.
     *
     * @param string $value (optional, string) Filter results by types, such as: bar, dentist.  Multiple types must be separated by the pipe ("|") symbol: bar|dentist|airport.
     * @return Google_Places_TextSearch_Inputs For method chaining.
     */
    public function setTypes($value)
    {
        return $this->set('Types', $value);
    }
}


/**
 * Execution object for the TextSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_TextSearch_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the TextSearch Choreo.
     *
     * @param Temboo_Session $session The session that owns this TextSearch execution.
     * @param Google_Places_TextSearch $choreo The choreography object for this execution.
     * @param Google_Places_TextSearch_Inputs|array $inputs (optional) Inputs as Google_Places_TextSearch_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_TextSearch_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_TextSearch $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this TextSearch execution.
     *
     * @return Google_Places_TextSearch_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this TextSearch execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_TextSearch_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_TextSearch_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the TextSearch Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_TextSearch_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the TextSearch Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_TextSearch_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this TextSearch execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Add a new Place to Google Places.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_UserPlaceReports extends Temboo_Choreography
{
    /**
     * Add a new Place to Google Places.
     *
     * @param Temboo_Session $session The session that owns this UserPlaceReports Choreo.
     * @return Google_Places_UserPlaceReports New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Places/UserPlaceReports/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UserPlaceReports Choreo.
     *
     * @param Google_Places_UserPlaceReports_Inputs|array $inputs (optional) Inputs as Google_Places_UserPlaceReports_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_UserPlaceReports_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Places_UserPlaceReports_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UserPlaceReports Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_UserPlaceReports_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Places_UserPlaceReports_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UserPlaceReports Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_UserPlaceReports_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UserPlaceReports Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Places_UserPlaceReports_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UserPlaceReports input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the POSTForm input for this UserPlaceReports Choreo.
     *
     * @param string $value (optional, json) A JSON request body containing the information about the place. This can be specified as an alternative to specifying individual place properties. See Choreo notes for details about formatting.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setPOSTForm($value)
    {
        return $this->set('POSTForm', $value);
    }

    /**
     * Set the value for the Accuracy input for this UserPlaceReports Choreo.
     *
     * @param float $value (conditional, decimal) The accuracy of the location signal on which this request is based, expressed in meters.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setAccuracy($value)
    {
        return $this->set('Accuracy', $value);
    }

    /**
     * Set the value for the Address input for this UserPlaceReports Choreo.
     *
     * @param string $value (optional, string) The address of the place you wish to add.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setAddress($value)
    {
        return $this->set('Address', $value);
    }

    /**
     * Set the value for the Key input for this UserPlaceReports Choreo.
     *
     * @param string $value (required, string) The API Key provided by Google.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setKey($value)
    {
        return $this->set('Key', $value);
    }

    /**
     * Set the value for the Language input for this UserPlaceReports Choreo.
     *
     * @param string $value (conditional, string) The language in which the place's name is being reported.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the Latitude input for this UserPlaceReports Choreo.
     *
     * @param float $value (required, decimal) The latitude point for the place you wish to add (e.g., 38.898717).
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setLatitude($value)
    {
        return $this->set('Latitude', $value);
    }

    /**
     * Set the value for the Longitude input for this UserPlaceReports Choreo.
     *
     * @param float $value (required, decimal) The longitude coordinate for the place you wish to add (e.g., -77.035974).
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setLongitude($value)
    {
        return $this->set('Longitude', $value);
    }

    /**
     * Set the value for the Name input for this UserPlaceReports Choreo.
     *
     * @param string $value (required, string) The full text name of the place
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setName($value)
    {
        return $this->set('Name', $value);
    }

    /**
     * Set the value for the PhoneNumber input for this UserPlaceReports Choreo.
     *
     * @param string $value (optional, string) The phone number associated with the place.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setPhoneNumber($value)
    {
        return $this->set('PhoneNumber', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UserPlaceReports Choreo.
     *
     * @param string $value (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Sensor input for this UserPlaceReports Choreo.
     *
     * @param bool $value (optional, boolean) Indicates whether or not the directions request is from a device with a location sensor. Value must be either 1 or 0. Defaults to 0 (false).
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setSensor($value)
    {
        return $this->set('Sensor', $value);
    }

    /**
     * Set the value for the Types input for this UserPlaceReports Choreo.
     *
     * @param string $value (required, json) A JSON array of categories in which this place belongs.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setTypes($value)
    {
        return $this->set('Types', $value);
    }

    /**
     * Set the value for the Website input for this UserPlaceReports Choreo.
     *
     * @param string $value (optional, string) A URL pointing to the authoritative website for this Place, such as a business home page.
     * @return Google_Places_UserPlaceReports_Inputs For method chaining.
     */
    public function setWebsite($value)
    {
        return $this->set('Website', $value);
    }
}


/**
 * Execution object for the UserPlaceReports Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_UserPlaceReports_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UserPlaceReports Choreo.
     *
     * @param Temboo_Session $session The session that owns this UserPlaceReports execution.
     * @param Google_Places_UserPlaceReports $choreo The choreography object for this execution.
     * @param Google_Places_UserPlaceReports_Inputs|array $inputs (optional) Inputs as Google_Places_UserPlaceReports_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Places_UserPlaceReports_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Places_UserPlaceReports $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UserPlaceReports execution.
     *
     * @return Google_Places_UserPlaceReports_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UserPlaceReports execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Places_UserPlaceReports_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Places_UserPlaceReports_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UserPlaceReports Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Places_UserPlaceReports_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UserPlaceReports Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Places_UserPlaceReports_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "Response" output from this UserPlaceReports execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a given activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Get extends Temboo_Choreography
{
    /**
     * Retrieves a given activity.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Activities_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Activities/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Activities_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Activities_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Activities_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the activity to get.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Activities_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Activities_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Activities_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Activities_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Activities_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Activities_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Activities_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Activities_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 *  Returns a list of all activities in the specified collection for a particular user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_List extends Temboo_Choreography
{
    /**
     *  Returns a list of all activities in the specified collection for a particular user.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Activities_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Activities/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Activities_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Activities_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Activities_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this List Choreo.
     *
     * @param string $value (required, string) The collection of activities to list. Defaults to "public".
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the person to get the profile for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Activities_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Activities_List $choreo The choreography object for this execution.
     * @param Google_Plus_Activities_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Activities_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Activities_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Activities_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Activities_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Activities_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Searches all public activities.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Search extends Temboo_Choreography
{
    /**
     * Searches all public activities.
     *
     * @param Temboo_Session $session The session that owns this Search Choreo.
     * @return Google_Plus_Activities_Search New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Activities/Search/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Search Choreo.
     *
     * @param Google_Plus_Activities_Search_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_Search_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_Search_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Activities_Search_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Search Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_Search_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Activities_Search_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Search_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Search Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Activities_Search_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Search input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Search Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Search Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Search Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Search Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Search Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Language input for this Search Choreo.
     *
     * @param string $value (optional, string) Indicates the preferred language to search with. Defaults to "en-US".
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the MaxResults input for this Search Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this Search Choreo.
     *
     * @param string $value (optional, string) Specifies how to order search results. Valid values are: "best" (Sort activities by relevance to the user) or "recent" (Sort activities by published date). Default is "recent".
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this Search Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Search Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the Query input for this Search Choreo.
     *
     * @param string $value (required, string) Full-text search query string.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Search Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Search Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Activities_Search_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Search_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Search Choreo.
     *
     * @param Temboo_Session $session The session that owns this Search execution.
     * @param Google_Plus_Activities_Search $choreo The choreography object for this execution.
     * @param Google_Plus_Activities_Search_Inputs|array $inputs (optional) Inputs as Google_Plus_Activities_Search_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Activities_Search_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Activities_Search $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Search execution.
     *
     * @return Google_Plus_Activities_Search_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Search execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Activities_Search_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Activities_Search_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Activities_Search_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Search Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Activities_Search_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Search execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Search execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a given comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_Get extends Temboo_Choreography
{
    /**
     * Retrieves a given comment.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Comments_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Comments/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Comments_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Comments_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Comments_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Comments_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Comments_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the comment to get.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Comments_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Comments_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Comments_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Comments_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Comments_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Comments_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Comments_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Comments_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list all of the comments for a given activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_List extends Temboo_Choreography
{
    /**
     * Retrieves a list all of the comments for a given activity.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Comments_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Comments/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Comments_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Comments_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Comments_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Comments_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Comments_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this List Choreo.
     *
     * @param string $value (required, string) The ID of the activity to get.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SortOrder input for this List Choreo.
     *
     * @param string $value (optional, string) The order in which to sort the list of comments. Valid values are: "ascending" (Sort oldest comments first, the default) and "descending" (Sort newest comments first).
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setSortOrder($value)
    {
        return $this->set('SortOrder', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Comments_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Comments_List $choreo The choreography object for this execution.
     * @param Google_Plus_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Comments_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Comments_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Comments_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Comments_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Comments_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Comments_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Comments_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Get extends Temboo_Choreography
{
    /**
     * Retrieves a specific activity.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Domains_Activities_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Activities/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Domains_Activities_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Activities_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Activities_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the activity to get.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Activities_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Domains_Activities_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Activities_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Activities_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Domains_Activities_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Activities_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Inserts a new activity into a user's stream.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Insert extends Temboo_Choreography
{
    /**
     * Inserts a new activity into a user's stream.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Plus_Domains_Activities_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Activities/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Plus_Domains_Activities_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Activities_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Activities_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the ActivityResource input for this Insert Choreo.
     *
     * @param string $value (optional, string) A JSON-formatted string containing the activity properties you wish to set. This can be used as an alternative to setting individual inputs representing resource properties.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setActivityResource($value)
    {
        return $this->set('ActivityResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Insert Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Content input for this Insert Choreo.
     *
     * @param string $value (required, string) Content to post to your stream.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the Description input for this Insert Choreo.
     *
     * @param string $value (optional, string) A description for the new activity being created.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the Preview input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) If "true", extract the potential media attachments for a URL. The response will include all possible attachments for a URL, including video, photos, and articles based on the content of the page.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setPreview($value)
    {
        return $this->set('Preview', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ShareWithDomain input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Set to 1 to share this activity with the entire Domain.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithDomain($value)
    {
        return $this->set('ShareWithDomain', $value);
    }

    /**
     * Set the value for the ShareWithExtendedCircles input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Set to 1 to share this activity your circles plus all the people in their circles.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithExtendedCircles($value)
    {
        return $this->set('ShareWithExtendedCircles', $value);
    }

    /**
     * Set the value for the ShareWithMyCircles input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Set to 1 to share this activity with everyone in your Circles.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithMyCircles($value)
    {
        return $this->set('ShareWithMyCircles', $value);
    }

    /**
     * Set the value for the ShareWithPublic input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) Set to 1 to share this activity with everyone on the web.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithPublic($value)
    {
        return $this->set('ShareWithPublic', $value);
    }

    /**
     * Set the value for the ShareWithTheseCircles input for this Insert Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of up to 10 IDs of the circles you want to share this activity with.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithTheseCircles($value)
    {
        return $this->set('ShareWithTheseCircles', $value);
    }

    /**
     * Set the value for the ShareWithThesePeople input for this Insert Choreo.
     *
     * @param string $value (optional, string) Comma-seperated list of up to 10 IDs of persons you want to share this activity with.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setShareWithThesePeople($value)
    {
        return $this->set('ShareWithThesePeople', $value);
    }

    /**
     * Set the value for the UserID input for this Insert Choreo.
     *
     * @param string $value (optional, string) The ID of the user to create a circle for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Insert Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Activities_Insert_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Plus_Domains_Activities_Insert $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Activities_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Activities_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Plus_Domains_Activities_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Activities_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the activities in the specified collection for a particular user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_List extends Temboo_Choreography
{
    /**
     * Lists all of the activities in the specified collection for a particular user.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Domains_Activities_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Activities/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Domains_Activities_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Activities_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Activities_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Activities_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this List Choreo.
     *
     * @param string $value (required, string) The collection of activities to list.  Valid values are: "user". Defaults to "user".
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Activities_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Domains_Activities_List $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Activities_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Activities_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Activities_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Activities_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Domains_Activities_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Activities_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Activities_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Activities_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the audiences with which a user can share.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Audiences_List extends Temboo_Choreography
{
    /**
     * Lists all of the audiences with which a user can share.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Domains_Audiences_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Audiences/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Domains_Audiences_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Audiences_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Audiences_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Audiences_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Audiences_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Audiences_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Audiences_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Audiences_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Audiences_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Audiences_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Domains_Audiences_List $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Audiences_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Audiences_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Audiences_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Audiences_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Domains_Audiences_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Audiences_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Audiences_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Audiences_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Audiences_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Adds people to a circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_AddPeople extends Temboo_Choreography
{
    /**
     * Adds people to a circle.
     *
     * @param Temboo_Session $session The session that owns this AddPeople Choreo.
     * @return Google_Plus_Domains_Circles_AddPeople New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/AddPeople/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AddPeople Choreo.
     *
     * @param Google_Plus_Domains_Circles_AddPeople_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_AddPeople_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_AddPeople_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_AddPeople_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AddPeople Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_AddPeople_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AddPeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_AddPeople_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AddPeople Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AddPeople input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AddPeople Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this AddPeople Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) The ID of the circle to update.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Email input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) Comma-seperated list of up to 10 email addresses to add. Required unless providing a value for UserID.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setEmail($value)
    {
        return $this->set('Email', $value);
    }

    /**
     * Set the value for the Fields input for this AddPeople Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this AddPeople Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this AddPeople Choreo.
     *
     * @param string $value (conditional, string) Comma-seperated list of up to 10 User IDs to add. Required unless providing a value for Email.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this AddPeople Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_AddPeople_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the AddPeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_AddPeople_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AddPeople Choreo.
     *
     * @param Temboo_Session $session The session that owns this AddPeople execution.
     * @param Google_Plus_Domains_Circles_AddPeople $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_AddPeople_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_AddPeople_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_AddPeople_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_AddPeople $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AddPeople execution.
     *
     * @return Google_Plus_Domains_Circles_AddPeople_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AddPeople execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_AddPeople_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_AddPeople_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AddPeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_AddPeople_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AddPeople Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_AddPeople_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AddPeople execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AddPeople execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes the specified circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Delete extends Temboo_Choreography
{
    /**
     * Deletes the specified circle.
     *
     * @param Temboo_Session $session The session that owns this Delete Choreo.
     * @return Google_Plus_Domains_Circles_Delete New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/Delete/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Delete Choreo.
     *
     * @param Google_Plus_Domains_Circles_Delete_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Delete_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_Delete_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Delete_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_Delete_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Delete_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Delete Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Delete_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Delete input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Delete Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Delete Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this Delete Choreo.
     *
     * @param string $value (required, string) The ID of the circle to delete
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Delete Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Delete Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Delete Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Delete Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Delete Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_Delete_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Delete_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Delete Choreo.
     *
     * @param Temboo_Session $session The session that owns this Delete execution.
     * @param Google_Plus_Domains_Circles_Delete $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_Delete_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Delete_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Delete_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_Delete $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Delete execution.
     *
     * @return Google_Plus_Domains_Circles_Delete_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Delete execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Delete_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_Delete_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Delete Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Delete_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Delete Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Delete_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Delete execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this Delete execution.
     *
     * @return int (integer) The response status code returned from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this Delete execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Get extends Temboo_Choreography
{
    /**
     * Retrieves a specific circle.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Domains_Circles_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Domains_Circles_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the circle to get.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Domains_Circles_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Domains_Circles_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new circle for the authenticated user.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Insert extends Temboo_Choreography
{
    /**
     * Creates a new circle for the authenticated user.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Plus_Domains_Circles_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Plus_Domains_Circles_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the CircleResource input for this Insert Choreo.
     *
     * @param string $value (optional, string) A JSON-formatted string containing the circle properties you wish to set. This can be used as an alternative to setting individual inputs representing resource properties.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setCircleResource($value)
    {
        return $this->set('CircleResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Insert Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this Insert Choreo.
     *
     * @param string $value (optional, string) A description for the new circle being created.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the DisplayName input for this Insert Choreo.
     *
     * @param string $value (required, string) The circle name.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setDisplayName($value)
    {
        return $this->set('DisplayName', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Insert Choreo.
     *
     * @param string $value (optional, string) The ID of the user to create a circle for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Insert Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_Insert_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Plus_Domains_Circles_Insert $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Plus_Domains_Circles_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists a user's circles.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_List extends Temboo_Choreography
{
    /**
     * Lists a user's circles.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Domains_Circles_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Domains_Circles_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Domains_Circles_List $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Domains_Circles_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Removes a person from a circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_RemovePeople extends Temboo_Choreography
{
    /**
     * Removes a person from a circle.
     *
     * @param Temboo_Session $session The session that owns this RemovePeople Choreo.
     * @return Google_Plus_Domains_Circles_RemovePeople New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/RemovePeople/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RemovePeople Choreo.
     *
     * @param Google_Plus_Domains_Circles_RemovePeople_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_RemovePeople_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_RemovePeople_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_RemovePeople_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RemovePeople Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_RemovePeople_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RemovePeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_RemovePeople_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RemovePeople Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RemovePeople input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RemovePeople Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this RemovePeople Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) The ID of the circle to update.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Email input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) Comma-seperated list of up to 10 email addresses of users to remove. Required unless providing a value for UserID.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setEmail($value)
    {
        return $this->set('Email', $value);
    }

    /**
     * Set the value for the Fields input for this RemovePeople Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this RemovePeople Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this RemovePeople Choreo.
     *
     * @param string $value (conditional, string) Comma-seperated list of up to 10 User IDs to remove. Required unless providing a value for Email.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this RemovePeople Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_RemovePeople_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the RemovePeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_RemovePeople_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RemovePeople Choreo.
     *
     * @param Temboo_Session $session The session that owns this RemovePeople execution.
     * @param Google_Plus_Domains_Circles_RemovePeople $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_RemovePeople_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_RemovePeople_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_RemovePeople_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_RemovePeople $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RemovePeople execution.
     *
     * @return Google_Plus_Domains_Circles_RemovePeople_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RemovePeople execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_RemovePeople_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_RemovePeople_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RemovePeople Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_RemovePeople_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RemovePeople Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_RemovePeople_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RemovePeople execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "ResponseStatusCode" output from this RemovePeople execution.
     *
     * @return int (integer) The response status code returned from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponseStatusCode()
    {
        return $this->get('ResponseStatusCode');
    }
    /**
     * Retrieve the value for the "Response" output from this RemovePeople execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates a specified circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Update extends Temboo_Choreography
{
    /**
     * Updates a specified circle.
     *
     * @param Temboo_Session $session The session that owns this Update Choreo.
     * @return Google_Plus_Domains_Circles_Update New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Circles/Update/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Update Choreo.
     *
     * @param Google_Plus_Domains_Circles_Update_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Update_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Circles_Update_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Update_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Circles_Update_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Update_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Update Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Circles_Update_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Update input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the CircleResource input for this Update Choreo.
     *
     * @param string $value (optional, string) A JSON-formatted string containing the circle properties you wish to set. This can be used as an alternative to setting individual inputs representing resource properties.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setCircleResource($value)
    {
        return $this->set('CircleResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this Update Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Update Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The ID of the circle to update.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Update Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Description input for this Update Choreo.
     *
     * @param string $value (optional, string) A description for the new circle being created.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the DisplayName input for this Update Choreo.
     *
     * @param string $value (required, string) The circle name.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setDisplayName($value)
    {
        return $this->set('DisplayName', $value);
    }

    /**
     * Set the value for the Fields input for this Update Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Update Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Update Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Update Choreo.
     *
     * @param string $value (optional, string) The ID of the user to create a circle for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Update Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Circles_Update_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Update_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Update Choreo.
     *
     * @param Temboo_Session $session The session that owns this Update execution.
     * @param Google_Plus_Domains_Circles_Update $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Circles_Update_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Circles_Update_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Circles_Update_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Circles_Update $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Update execution.
     *
     * @return Google_Plus_Domains_Circles_Update_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Update execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Update_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Circles_Update_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Update Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Circles_Update_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Update Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Circles_Update_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Update execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Update execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves the specified comment.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Get extends Temboo_Choreography
{
    /**
     * Retrieves the specified comment.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Domains_Comments_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Comments/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Domains_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Comments_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Comments_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the CommentID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the comment to get.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setCommentID($value)
    {
        return $this->set('CommentID', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Comments_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Domains_Comments_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Comments_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Comments_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Domains_Comments_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Comments_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new comment in reply to an activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Insert extends Temboo_Choreography
{
    /**
     * Creates a new comment in reply to an activity.
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Plus_Domains_Comments_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Comments/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Plus_Domains_Comments_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Comments_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Comments_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the CommentResource input for this Insert Choreo.
     *
     * @param string $value (optional, string) A JSON-formatted string containing the comment properties you wish to set. This can be used as an alternative to setting individual inputs representing resource properties.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setCommentResource($value)
    {
        return $this->set('CommentResource', $value);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this Insert Choreo.
     *
     * @param string $value (required, string) The ID of the activity to reply to.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this Insert Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Content input for this Insert Choreo.
     *
     * @param string $value (required, string) The comment text.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setContent($value)
    {
        return $this->set('Content', $value);
    }

    /**
     * Set the value for the Description input for this Insert Choreo.
     *
     * @param string $value (optional, string) A description for the new circle being created.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setDescription($value)
    {
        return $this->set('Description', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Insert Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Insert Choreo.
     *
     * @param string $value (optional, string) The ID of the user to create a circle for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Insert Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Comments_Insert_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Plus_Domains_Comments_Insert $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Comments_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Comments_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Plus_Domains_Comments_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Comments_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the comments for an activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_List extends Temboo_Choreography
{
    /**
     * Lists all of the comments for an activity.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Domains_Comments_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Comments/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Domains_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Comments_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Comments_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Comments_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this List Choreo.
     *
     * @param string $value (required, string) ID of the activity to retrieve comments for.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_Comments_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Domains_Comments_List $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Comments_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Comments_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Comments_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Comments_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Domains_Comments_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Comments_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Comments_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Comments_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Adds a new media item to an album. 
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Media_Insert extends Temboo_Choreography
{
    /**
     * Adds a new media item to an album. 
     *
     * @param Temboo_Session $session The session that owns this Insert Choreo.
     * @return Google_Plus_Domains_Media_Insert New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/Media/Insert/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Insert Choreo.
     *
     * @param Google_Plus_Domains_Media_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Media_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Media_Insert_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_Media_Insert_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Media_Insert_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_Media_Insert_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Media_Insert_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Insert Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_Media_Insert_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Insert input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Insert Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth2 process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this Insert Choreo.
     *
     * @param string $value (optional, string) Currently the acceptable values are "cloud".  (Upload the media to share on Google+).
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the ContentType input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Content-Type of the file that is being uploaded (i.e. image/jpg). Required when specifying the FileContent input.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setContentType($value)
    {
        return $this->set('ContentType', $value);
    }

    /**
     * Set the value for the DisplayName input for this Insert Choreo.
     *
     * @param string $value (optional, string) The display name for the media. If this parameter is not provided, Google assigns a GUID to the media resource.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setDisplayName($value)
    {
        return $this->set('DisplayName', $value);
    }

    /**
     * Set the value for the Fields input for this Insert Choreo.
     *
     * @param string $value (optional, string) Selector specifying a subset of fields to include in the response.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the FileContent input for this Insert Choreo.
     *
     * @param string $value (conditional, string) The Base64 encoded contents of the file to upload.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setFileContent($value)
    {
        return $this->set('FileContent', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Insert Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Insert Choreo.
     *
     * @param string $value (optional, string) The ID of the user to create the activity on behalf of.  The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_Media_Insert_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

}


/**
 * Execution object for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Media_Insert_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Insert Choreo.
     *
     * @param Temboo_Session $session The session that owns this Insert execution.
     * @param Google_Plus_Domains_Media_Insert $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_Media_Insert_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_Media_Insert_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_Media_Insert_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_Media_Insert $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Insert execution.
     *
     * @return Google_Plus_Domains_Media_Insert_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Insert execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_Media_Insert_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_Media_Insert_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Insert Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_Media_Insert_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Insert Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_Media_Insert_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Insert execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Insert execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a person's profile.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_Get extends Temboo_Choreography
{
    /**
     * Retrieves a person's profile.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_Domains_People_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/People/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_Domains_People_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_People_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_People_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Get Choreo.
     *
     * @param string $value (required, string) The ID of the user to get. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_People_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_Domains_People_Get $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_People_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_People_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_Domains_People_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_People_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_People_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_People_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the people in the specified collection.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_List extends Temboo_Choreography
{
    /**
     * Lists all of the people in the specified collection.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_Domains_People_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/People/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_Domains_People_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_People_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_People_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this List Choreo.
     *
     * @param string $value (required, string) The collection to list people for. Currently the only allowed value for this parameter is: "circled".
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_People_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_Domains_People_List $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_People_List_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_People_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_Domains_People_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_People_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_People_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_People_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the people in the specified collection for a particular activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByActivity extends Temboo_Choreography
{
    /**
     * Lists all of the people in the specified collection for a particular activity.
     *
     * @param Temboo_Session $session The session that owns this ListByActivity Choreo.
     * @return Google_Plus_Domains_People_ListByActivity New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/People/ListByActivity/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListByActivity Choreo.
     *
     * @param Google_Plus_Domains_People_ListByActivity_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_ListByActivity_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_ListByActivity_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_People_ListByActivity_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListByActivity Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_People_ListByActivity_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByActivity_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListByActivity Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListByActivity input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) The ID of the activity to get the list of people for.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this ListByActivity Choreo.
     *
     * @param string $value (required, string) The collection of people to list.  Acceptable values are: "plusoners","resharers", "sharedto":
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the Fields input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListByActivity Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this ListByActivity Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_People_ListByActivity_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByActivity_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListByActivity Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListByActivity execution.
     * @param Google_Plus_Domains_People_ListByActivity $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_People_ListByActivity_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_ListByActivity_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_ListByActivity_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_People_ListByActivity $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListByActivity execution.
     *
     * @return Google_Plus_Domains_People_ListByActivity_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListByActivity execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_People_ListByActivity_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_People_ListByActivity_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByActivity_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListByActivity Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_People_ListByActivity_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListByActivity execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListByActivity execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Lists all of the people who are members of a circle.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByCircle extends Temboo_Choreography
{
    /**
     * Lists all of the people who are members of a circle.
     *
     * @param Temboo_Session $session The session that owns this ListByCircle Choreo.
     * @return Google_Plus_Domains_People_ListByCircle New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/Domains/People/ListByCircle/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListByCircle Choreo.
     *
     * @param Google_Plus_Domains_People_ListByCircle_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_ListByCircle_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_ListByCircle_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_Domains_People_ListByCircle_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListByCircle Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_Domains_People_ListByCircle_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListByCircle Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByCircle_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListByCircle Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListByCircle input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the CircleID input for this ListByCircle Choreo.
     *
     * @param string $value (required, string) ID of the Circle to list people by.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setCircleID($value)
    {
        return $this->set('CircleID', $value);
    }

    /**
     * Set the value for the ClientID input for this ListByCircle Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListByCircle Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListByCircle Choreo.
     *
     * @param int $value (optional, integer) The maximum number of circles to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) The order to return results in. Valid values are: alphabetical and best.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this ListByCircle Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the JSON response to make it more readable. Defaults to "true".
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListByCircle Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) The ID of the user to get circles for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this ListByCircle Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_Domains_People_ListByCircle_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the ListByCircle Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByCircle_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListByCircle Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListByCircle execution.
     * @param Google_Plus_Domains_People_ListByCircle $choreo The choreography object for this execution.
     * @param Google_Plus_Domains_People_ListByCircle_Inputs|array $inputs (optional) Inputs as Google_Plus_Domains_People_ListByCircle_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_Domains_People_ListByCircle_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_Domains_People_ListByCircle $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListByCircle execution.
     *
     * @return Google_Plus_Domains_People_ListByCircle_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListByCircle execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_Domains_People_ListByCircle_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_Domains_People_ListByCircle_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListByCircle Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_Domains_People_ListByCircle_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListByCircle Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_Domains_People_ListByCircle_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListByCircle execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListByCircle execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a person's profile.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Get extends Temboo_Choreography
{
    /**
     * Retrieves a person's profile.
     *
     * @param Temboo_Session $session The session that owns this Get Choreo.
     * @return Google_Plus_People_Get New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/People/Get/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Get Choreo.
     *
     * @param Google_Plus_People_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_People_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_Get_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_People_Get_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_Get_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_People_Get_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Get_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Get Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_Get_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Get input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Get Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Get Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Get Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Get Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Get Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Get Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this Get Choreo.
     *
     * @param string $value (optional, string) The ID of the person to get the profile for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this Get Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_People_Get_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Get_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Get Choreo.
     *
     * @param Temboo_Session $session The session that owns this Get execution.
     * @param Google_Plus_People_Get $choreo The choreography object for this execution.
     * @param Google_Plus_People_Get_Inputs|array $inputs (optional) Inputs as Google_Plus_People_Get_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_Get_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_People_Get $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Get execution.
     *
     * @return Google_Plus_People_Get_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Get execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_People_Get_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_People_Get_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Get Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Get_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Get Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_People_Get_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Get execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Get execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns all of the people who the authenticated user has added to one or more circles.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_List extends Temboo_Choreography
{
    /**
     * Returns all of the people who the authenticated user has added to one or more circles.
     *
     * @param Temboo_Session $session The session that owns this List Choreo.
     * @return Google_Plus_People_List New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/People/List/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this List Choreo.
     *
     * @param Google_Plus_People_List_Inputs|array $inputs (optional) Inputs as Google_Plus_People_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_List_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_People_List_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_List_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_People_List_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_List_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the List Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_List_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this List input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this List Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this List Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this List Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this List Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this List Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the OrderBy input for this List Choreo.
     *
     * @param string $value (optional, string) The order to return people in. Valid values are: alphabetical and best.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setOrderBy($value)
    {
        return $this->set('OrderBy', $value);
    }

    /**
     * Set the value for the PageToken input for this List Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this List Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this List Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserID input for this List Choreo.
     *
     * @param string $value (optional, string) The ID of the person to get the collection of people for. The value "me" is set as the default to indicate the authenticated user.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setUserID($value)
    {
        return $this->set('UserID', $value);
    }

    /**
     * Set the value for the UserIP input for this List Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_People_List_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_List_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the List Choreo.
     *
     * @param Temboo_Session $session The session that owns this List execution.
     * @param Google_Plus_People_List $choreo The choreography object for this execution.
     * @param Google_Plus_People_List_Inputs|array $inputs (optional) Inputs as Google_Plus_People_List_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_List_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_People_List $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this List execution.
     *
     * @return Google_Plus_People_List_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this List execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_People_List_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_People_List_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the List Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_List_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the List Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_People_List_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this List execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this List execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 *  Returns all of the people in the specified collection for a particular activity.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_ListByActivity extends Temboo_Choreography
{
    /**
     *  Returns all of the people in the specified collection for a particular activity.
     *
     * @param Temboo_Session $session The session that owns this ListByActivity Choreo.
     * @return Google_Plus_People_ListByActivity New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/People/ListByActivity/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ListByActivity Choreo.
     *
     * @param Google_Plus_People_ListByActivity_Inputs|array $inputs (optional) Inputs as Google_Plus_People_ListByActivity_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_ListByActivity_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_People_ListByActivity_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ListByActivity Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_ListByActivity_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_People_ListByActivity_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_ListByActivity_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ListByActivity Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_ListByActivity_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ListByActivity input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ActivityID input for this ListByActivity Choreo.
     *
     * @param string $value (required, string) The ID of the activity to get the list of people for. ActiviyIDs can be retrieved by running the Google.Plus.Activities.Search Choreo.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setActivityID($value)
    {
        return $this->set('ActivityID', $value);
    }

    /**
     * Set the value for the Callback input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Collection input for this ListByActivity Choreo.
     *
     * @param string $value (required, string) Valid values are: "plusoners" (lists all people who have +1'd this activity) and "resharers" (lists all people who have reshared this activity).
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setCollection($value)
    {
        return $this->set('Collection', $value);
    }

    /**
     * Set the value for the Fields input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxResults input for this ListByActivity Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this ListByActivity Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ListByActivity Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this ListByActivity Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_People_ListByActivity_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_ListByActivity_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ListByActivity Choreo.
     *
     * @param Temboo_Session $session The session that owns this ListByActivity execution.
     * @param Google_Plus_People_ListByActivity $choreo The choreography object for this execution.
     * @param Google_Plus_People_ListByActivity_Inputs|array $inputs (optional) Inputs as Google_Plus_People_ListByActivity_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_ListByActivity_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_People_ListByActivity $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ListByActivity execution.
     *
     * @return Google_Plus_People_ListByActivity_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ListByActivity execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_People_ListByActivity_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_People_ListByActivity_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ListByActivity Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_ListByActivity_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ListByActivity Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_People_ListByActivity_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ListByActivity execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ListByActivity execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Searches all public profiles.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Search extends Temboo_Choreography
{
    /**
     * Searches all public profiles.
     *
     * @param Temboo_Session $session The session that owns this Search Choreo.
     * @return Google_Plus_People_Search New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Plus/People/Search/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this Search Choreo.
     *
     * @param Google_Plus_People_Search_Inputs|array $inputs (optional) Inputs as Google_Plus_People_Search_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_Search_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Plus_People_Search_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this Search Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_Search_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Plus_People_Search_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Search_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the Search Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Plus_People_Search_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this Search input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this Search Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the Callback input for this Search Choreo.
     *
     * @param string $value (optional, string) Specifies a JavaScript function that will be passed the response data for using the API with JSONP.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setCallback($value)
    {
        return $this->set('Callback', $value);
    }

    /**
     * Set the value for the ClientID input for this Search Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this Search Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this Search Choreo.
     *
     * @param string $value (optional, string) Used to specify fields to include in a partial response. This can be used to reduce the amount of data returned. See documentation for syntax rules.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Language input for this Search Choreo.
     *
     * @param string $value (optional, string) Indicates the preferred language to search with. Defaults to "en-US".
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setLanguage($value)
    {
        return $this->set('Language', $value);
    }

    /**
     * Set the value for the MaxResults input for this Search Choreo.
     *
     * @param int $value (optional, integer) The maximum number of people to include in the response. Used for paging through results. Valid values are: 1 to 20. Default is 10.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setMaxResults($value)
    {
        return $this->set('MaxResults', $value);
    }

    /**
     * Set the value for the PageToken input for this Search Choreo.
     *
     * @param string $value (optional, string) The "NextPageToken" returned in the Choreo output. Used to page through large result sets.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setPageToken($value)
    {
        return $this->set('PageToken', $value);
    }

    /**
     * Set the value for the PrettyPrint input for this Search Choreo.
     *
     * @param bool $value (optional, boolean) A flag used to pretty print the json response to make it more readable. Defaults to "true".
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setPrettyPrint($value)
    {
        return $this->set('PrettyPrint', $value);
    }

    /**
     * Set the value for the Query input for this Search Choreo.
     *
     * @param string $value (required, string) A query string for full text search of public text in all profiles.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this Search Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the UserIP input for this Search Choreo.
     *
     * @param string $value (optional, string) Identifies the IP address of the end user for whom the API call is being made. Used to enforce per-user quotas.
     * @return Google_Plus_People_Search_Inputs For method chaining.
     */
    public function setUserIP($value)
    {
        return $this->set('UserIP', $value);
    }
}


/**
 * Execution object for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Search_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the Search Choreo.
     *
     * @param Temboo_Session $session The session that owns this Search execution.
     * @param Google_Plus_People_Search $choreo The choreography object for this execution.
     * @param Google_Plus_People_Search_Inputs|array $inputs (optional) Inputs as Google_Plus_People_Search_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Plus_People_Search_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Plus_People_Search $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this Search execution.
     *
     * @return Google_Plus_People_Search_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this Search execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Plus_People_Search_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Plus_People_Search_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the Search Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Plus_People_Search_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the Search Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Plus_People_Search_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this Search execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this Search execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Appends values to a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_AppendValues extends Temboo_Choreography
{
    /**
     * Appends values to a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this AppendValues Choreo.
     * @return Google_Sheets_AppendValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/AppendValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AppendValues Choreo.
     *
     * @param Google_Sheets_AppendValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_AppendValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_AppendValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_AppendValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AppendValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_AppendValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_AppendValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AppendValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_AppendValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AppendValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_AppendValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AppendValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AppendValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AppendValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the InsertDataOption input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) Specifies how the input data should be inserted. Valid values are: INSERT_ROWS (the default) and OVERWRITE.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setInsertDataOption($value)
    {
        return $this->set('InsertDataOption', $value);
    }

    /**
     * Set the value for the MajorDimension input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) Indicates the dimension that the values array applies to. Valid values are ROWS (the default) or COLUMNS.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setMajorDimension($value)
    {
        return $this->set('MajorDimension', $value);
    }

    /**
     * Set the value for the Range input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) The A1 notation of a range to begin appending to. Defaults to "A1" (begins at the first row). Values will be appended at the first empty row of this range. See Choreos notes for more details.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setRange($value)
    {
        return $this->set('Range', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AppendValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this AppendValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueInputOption input for this AppendValues Choreo.
     *
     * @param string $value (optional, string) Specifies how the input data should be interpreted. Valid values are: RAW (the default) and USER_ENTERED.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setValueInputOption($value)
    {
        return $this->set('ValueInputOption', $value);
    }

    /**
     * Set the value for the Values input for this AppendValues Choreo.
     *
     * @param string $value (required, json) This is an array of arrays. The outer array can represent one or more rows while the inner array can represent one or more cell values. See Choreo notes below for more details.
     * @return Google_Sheets_AppendValues_Inputs For method chaining.
     */
    public function setValues($value)
    {
        return $this->set('Values', $value);
    }
}


/**
 * Execution object for the AppendValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_AppendValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AppendValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this AppendValues execution.
     * @param Google_Sheets_AppendValues $choreo The choreography object for this execution.
     * @param Google_Sheets_AppendValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_AppendValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_AppendValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_AppendValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AppendValues execution.
     *
     * @return Google_Sheets_AppendValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AppendValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_AppendValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_AppendValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AppendValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_AppendValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AppendValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_AppendValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AppendValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AppendValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns one or more ranges of values from a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchGetValues extends Temboo_Choreography
{
    /**
     * Returns one or more ranges of values from a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this BatchGetValues Choreo.
     * @return Google_Sheets_BatchGetValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/BatchGetValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this BatchGetValues Choreo.
     *
     * @param Google_Sheets_BatchGetValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_BatchGetValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_BatchGetValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_BatchGetValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this BatchGetValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_BatchGetValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_BatchGetValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the BatchGetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchGetValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the BatchGetValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_BatchGetValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this BatchGetValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this BatchGetValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this BatchGetValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this BatchGetValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DateTimeRenderOption input for this BatchGetValues Choreo.
     *
     * @param string $value (optional, string) How dates, times, and durations should be represented in the output. Valid values are: SERIAL_NUMBER or FORMATTED_STRING. This is ignored if valueRenderOption is FORMATTED_VALUE.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setDateTimeRenderOption($value)
    {
        return $this->set('DateTimeRenderOption', $value);
    }

    /**
     * Set the value for the Fields input for this BatchGetValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MajorDimension input for this BatchGetValues Choreo.
     *
     * @param string $value (optional, string) Indicates the dimension that results should use. Valid values are ROWS (the default) or COLUMNS.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setMajorDimension($value)
    {
        return $this->set('MajorDimension', $value);
    }

    /**
     * Set the value for the Ranges input for this BatchGetValues Choreo.
     *
     * @param string $value (required, string) The A1 notation of the values to retrieve formatted as an array (e.g. ["Sheet1!A2:C3"]). Note, this input supports up to 10 ranges.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setRanges($value)
    {
        return $this->set('Ranges', $value);
    }

    /**
     * Set the value for the RefreshToken input for this BatchGetValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this BatchGetValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueRenderOption input for this BatchGetValues Choreo.
     *
     * @param string $value (optional, string) How values should be represented in the output. Valid values are: FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA.
     * @return Google_Sheets_BatchGetValues_Inputs For method chaining.
     */
    public function setValueRenderOption($value)
    {
        return $this->set('ValueRenderOption', $value);
    }
}


/**
 * Execution object for the BatchGetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchGetValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the BatchGetValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this BatchGetValues execution.
     * @param Google_Sheets_BatchGetValues $choreo The choreography object for this execution.
     * @param Google_Sheets_BatchGetValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_BatchGetValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_BatchGetValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_BatchGetValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this BatchGetValues execution.
     *
     * @return Google_Sheets_BatchGetValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this BatchGetValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_BatchGetValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_BatchGetValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the BatchGetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchGetValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the BatchGetValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_BatchGetValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this BatchGetValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this BatchGetValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates values in one or more ranges of a spreadsheet. 
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchUpdateValues extends Temboo_Choreography
{
    /**
     * Updates values in one or more ranges of a spreadsheet. 
     *
     * @param Temboo_Session $session The session that owns this BatchUpdateValues Choreo.
     * @return Google_Sheets_BatchUpdateValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/BatchUpdateValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this BatchUpdateValues Choreo.
     *
     * @param Google_Sheets_BatchUpdateValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_BatchUpdateValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_BatchUpdateValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_BatchUpdateValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this BatchUpdateValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_BatchUpdateValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_BatchUpdateValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the BatchUpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchUpdateValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the BatchUpdateValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_BatchUpdateValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this BatchUpdateValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this BatchUpdateValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this BatchUpdateValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this BatchUpdateValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Data input for this BatchUpdateValues Choreo.
     *
     * @param string $value (required, json) An array of JSON objects containing the ranges and values to update. See Choreo notes below for more details.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setData($value)
    {
        return $this->set('Data', $value);
    }

    /**
     * Set the value for the Fields input for this BatchUpdateValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this BatchUpdateValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this BatchUpdateValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueInputOption input for this BatchUpdateValues Choreo.
     *
     * @param string $value (optional, string) Specifies how the input data should be interpreted. Valid values are: RAW (the default) and USER_ENTERED.
     * @return Google_Sheets_BatchUpdateValues_Inputs For method chaining.
     */
    public function setValueInputOption($value)
    {
        return $this->set('ValueInputOption', $value);
    }
}


/**
 * Execution object for the BatchUpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchUpdateValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the BatchUpdateValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this BatchUpdateValues execution.
     * @param Google_Sheets_BatchUpdateValues $choreo The choreography object for this execution.
     * @param Google_Sheets_BatchUpdateValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_BatchUpdateValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_BatchUpdateValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_BatchUpdateValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this BatchUpdateValues execution.
     *
     * @return Google_Sheets_BatchUpdateValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this BatchUpdateValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_BatchUpdateValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_BatchUpdateValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the BatchUpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_BatchUpdateValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the BatchUpdateValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_BatchUpdateValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this BatchUpdateValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this BatchUpdateValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Clears values from a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_ClearValues extends Temboo_Choreography
{
    /**
     * Clears values from a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this ClearValues Choreo.
     * @return Google_Sheets_ClearValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/ClearValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this ClearValues Choreo.
     *
     * @param Google_Sheets_ClearValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_ClearValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_ClearValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_ClearValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this ClearValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_ClearValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_ClearValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the ClearValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_ClearValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the ClearValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_ClearValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this ClearValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this ClearValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this ClearValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this ClearValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this ClearValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the Range input for this ClearValues Choreo.
     *
     * @param string $value (required, string) The A1 notation of the values to clear (e.g. Sheet1!A2:C3).
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setRange($value)
    {
        return $this->set('Range', $value);
    }

    /**
     * Set the value for the RefreshToken input for this ClearValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this ClearValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_ClearValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }
}


/**
 * Execution object for the ClearValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_ClearValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the ClearValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this ClearValues execution.
     * @param Google_Sheets_ClearValues $choreo The choreography object for this execution.
     * @param Google_Sheets_ClearValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_ClearValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_ClearValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_ClearValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this ClearValues execution.
     *
     * @return Google_Sheets_ClearValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this ClearValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_ClearValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_ClearValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the ClearValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_ClearValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the ClearValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_ClearValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this ClearValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this ClearValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Copies a single sheet from a spreadsheet to another spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CopyToSheet extends Temboo_Choreography
{
    /**
     * Copies a single sheet from a spreadsheet to another spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this CopyToSheet Choreo.
     * @return Google_Sheets_CopyToSheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/CopyToSheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CopyToSheet Choreo.
     *
     * @param Google_Sheets_CopyToSheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_CopyToSheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_CopyToSheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_CopyToSheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CopyToSheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_CopyToSheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_CopyToSheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CopyToSheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CopyToSheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CopyToSheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_CopyToSheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CopyToSheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CopyToSheet Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CopyToSheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CopyToSheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DestinationSpreadsheetID input for this CopyToSheet Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet to copy the sheet to.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setDestinationSpreadsheetID($value)
    {
        return $this->set('DestinationSpreadsheetID', $value);
    }

    /**
     * Set the value for the Fields input for this CopyToSheet Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CopyToSheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SheetID input for this CopyToSheet Choreo.
     *
     * @param int $value (required, integer) The ID of the sheet to copy. SheetIDs can be retrieved using the GetSpreadsheet Choreo.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setSheetID($value)
    {
        return $this->set('SheetID', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this CopyToSheet Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_CopyToSheet_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }
}


/**
 * Execution object for the CopyToSheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CopyToSheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CopyToSheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this CopyToSheet execution.
     * @param Google_Sheets_CopyToSheet $choreo The choreography object for this execution.
     * @param Google_Sheets_CopyToSheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_CopyToSheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_CopyToSheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_CopyToSheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CopyToSheet execution.
     *
     * @return Google_Sheets_CopyToSheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CopyToSheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_CopyToSheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_CopyToSheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CopyToSheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CopyToSheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CopyToSheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_CopyToSheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CopyToSheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CopyToSheet execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CreateSpreadsheet extends Temboo_Choreography
{
    /**
     * Creates a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this CreateSpreadsheet Choreo.
     * @return Google_Sheets_CreateSpreadsheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/CreateSpreadsheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this CreateSpreadsheet Choreo.
     *
     * @param Google_Sheets_CreateSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_CreateSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_CreateSpreadsheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_CreateSpreadsheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this CreateSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_CreateSpreadsheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_CreateSpreadsheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the CreateSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CreateSpreadsheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the CreateSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_CreateSpreadsheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this CreateSpreadsheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the NamedRanges input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (optional, json) The named ranges defined in a spreadsheet. This is a JSON array. See Choreo notes for more details.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setNamedRanges($value)
    {
        return $this->set('NamedRanges', $value);
    }

    /**
     * Set the value for the RefreshToken input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Sheets input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (optional, json) The sheets that are part of a spreadsheet. This is a JSON array. See Choreo notes for more details.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setSheets($value)
    {
        return $this->set('Sheets', $value);
    }

    /**
     * Set the value for the SpreadsheetProperties input for this CreateSpreadsheet Choreo.
     *
     * @param string $value (required, json) A JSON object containing properties of the spreadsheet e.g. {"title": "SensorData"}.
     * @return Google_Sheets_CreateSpreadsheet_Inputs For method chaining.
     */
    public function setSpreadsheetProperties($value)
    {
        return $this->set('SpreadsheetProperties', $value);
    }
}


/**
 * Execution object for the CreateSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CreateSpreadsheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the CreateSpreadsheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this CreateSpreadsheet execution.
     * @param Google_Sheets_CreateSpreadsheet $choreo The choreography object for this execution.
     * @param Google_Sheets_CreateSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_CreateSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_CreateSpreadsheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_CreateSpreadsheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this CreateSpreadsheet execution.
     *
     * @return Google_Sheets_CreateSpreadsheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this CreateSpreadsheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_CreateSpreadsheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_CreateSpreadsheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the CreateSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_CreateSpreadsheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the CreateSpreadsheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_CreateSpreadsheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this CreateSpreadsheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this CreateSpreadsheet execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns the last row in a sheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetLastRow extends Temboo_Choreography
{
    /**
     * Returns the last row in a sheet.
     *
     * @param Temboo_Session $session The session that owns this GetLastRow Choreo.
     * @return Google_Sheets_GetLastRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/GetLastRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetLastRow Choreo.
     *
     * @param Google_Sheets_GetLastRow_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetLastRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetLastRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_GetLastRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetLastRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetLastRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_GetLastRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetLastRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetLastRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetLastRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetLastRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetLastRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetLastRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetLastRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DateTimeRenderOption input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) How dates, times, and durations should be represented in the output. Valid values are: SERIAL_NUMBER or FORMATTED_STRING. This is ignored if valueRenderOption is FORMATTED_VALUE.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setDateTimeRenderOption($value)
    {
        return $this->set('DateTimeRenderOption', $value);
    }

    /**
     * Set the value for the Fields input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MaxColumn input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) The last column in the range to return. Defaults to "Z".
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setMaxColumn($value)
    {
        return $this->set('MaxColumn', $value);
    }

    /**
     * Set the value for the MinColumn input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) The first column in the range to return. Defaults to "A".
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setMinColumn($value)
    {
        return $this->set('MinColumn', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetLastRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SheetName input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) The sheet name.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setSheetName($value)
    {
        return $this->set('SheetName', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this GetLastRow Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueRenderOption input for this GetLastRow Choreo.
     *
     * @param string $value (optional, string) How values should be represented in the output. Valid values are: FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA.
     * @return Google_Sheets_GetLastRow_Inputs For method chaining.
     */
    public function setValueRenderOption($value)
    {
        return $this->set('ValueRenderOption', $value);
    }
}


/**
 * Execution object for the GetLastRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetLastRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetLastRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetLastRow execution.
     * @param Google_Sheets_GetLastRow $choreo The choreography object for this execution.
     * @param Google_Sheets_GetLastRow_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetLastRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetLastRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_GetLastRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetLastRow execution.
     *
     * @return Google_Sheets_GetLastRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetLastRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_GetLastRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_GetLastRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetLastRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetLastRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetLastRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_GetLastRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetLastRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetLastRow execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns the spreadsheet at the given ID.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetSpreadsheet extends Temboo_Choreography
{
    /**
     * Returns the spreadsheet at the given ID.
     *
     * @param Temboo_Session $session The session that owns this GetSpreadsheet Choreo.
     * @return Google_Sheets_GetSpreadsheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/GetSpreadsheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetSpreadsheet Choreo.
     *
     * @param Google_Sheets_GetSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetSpreadsheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_GetSpreadsheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetSpreadsheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_GetSpreadsheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetSpreadsheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetSpreadsheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetSpreadsheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this GetSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the IncludeGridData input for this GetSpreadsheet Choreo.
     *
     * @param bool $value (optional, boolean) Set to True if grid data should be returned.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setIncludeGridData($value)
    {
        return $this->set('IncludeGridData', $value);
    }

    /**
     * Set the value for the Ranges input for this GetSpreadsheet Choreo.
     *
     * @param string $value (optional, string) The A1 notation of the values to retrieve formatted as an array (e.g. ["Sheet1!A2:C3"]). Note, this input support up to 10 ranges.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setRanges($value)
    {
        return $this->set('Ranges', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this GetSpreadsheet Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_GetSpreadsheet_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }
}


/**
 * Execution object for the GetSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetSpreadsheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetSpreadsheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetSpreadsheet execution.
     * @param Google_Sheets_GetSpreadsheet $choreo The choreography object for this execution.
     * @param Google_Sheets_GetSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetSpreadsheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_GetSpreadsheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetSpreadsheet execution.
     *
     * @return Google_Sheets_GetSpreadsheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetSpreadsheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_GetSpreadsheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_GetSpreadsheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetSpreadsheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetSpreadsheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_GetSpreadsheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetSpreadsheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetSpreadsheet execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Returns a range of values from a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetValues extends Temboo_Choreography
{
    /**
     * Returns a range of values from a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this GetValues Choreo.
     * @return Google_Sheets_GetValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/GetValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this GetValues Choreo.
     *
     * @param Google_Sheets_GetValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_GetValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this GetValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_GetValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the GetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the GetValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_GetValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this GetValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this GetValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this GetValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this GetValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DateTimeRenderOption input for this GetValues Choreo.
     *
     * @param string $value (optional, string) How dates, times, and durations should be represented in the output. Valid values are: SERIAL_NUMBER or FORMATTED_STRING. This is ignored if valueRenderOption is FORMATTED_VALUE.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setDateTimeRenderOption($value)
    {
        return $this->set('DateTimeRenderOption', $value);
    }

    /**
     * Set the value for the Fields input for this GetValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MajorDimension input for this GetValues Choreo.
     *
     * @param string $value (optional, string) Indicates the dimension that results should use. Valid values are ROWS (the default) or COLUMNS.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setMajorDimension($value)
    {
        return $this->set('MajorDimension', $value);
    }

    /**
     * Set the value for the Range input for this GetValues Choreo.
     *
     * @param string $value (required, string) The A1 notation of the values to retrieve (e.g. Sheet1!A2:C3).
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setRange($value)
    {
        return $this->set('Range', $value);
    }

    /**
     * Set the value for the RefreshToken input for this GetValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this GetValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueRenderOption input for this GetValues Choreo.
     *
     * @param string $value (optional, string) How values should be represented in the output. Valid values are: FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA.
     * @return Google_Sheets_GetValues_Inputs For method chaining.
     */
    public function setValueRenderOption($value)
    {
        return $this->set('ValueRenderOption', $value);
    }
}


/**
 * Execution object for the GetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the GetValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this GetValues execution.
     * @param Google_Sheets_GetValues $choreo The choreography object for this execution.
     * @param Google_Sheets_GetValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_GetValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_GetValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_GetValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this GetValues execution.
     *
     * @return Google_Sheets_GetValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this GetValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_GetValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_GetValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the GetValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_GetValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the GetValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_GetValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this GetValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this GetValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates values in the specified range of a spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_UpdateValues extends Temboo_Choreography
{
    /**
     * Updates values in the specified range of a spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this UpdateValues Choreo.
     * @return Google_Sheets_UpdateValues New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Sheets/UpdateValues/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateValues Choreo.
     *
     * @param Google_Sheets_UpdateValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_UpdateValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_UpdateValues_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Sheets_UpdateValues_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_UpdateValues_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Sheets_UpdateValues_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_UpdateValues_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateValues Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Sheets_UpdateValues_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateValues input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateValues Choreo.
     *
     * @param string $value (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateValues Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateValues Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Fields input for this UpdateValues Choreo.
     *
     * @param string $value (optional, string) A comma-separated list of fields to include in the response. See Choreo notes for syntax details.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setFields($value)
    {
        return $this->set('Fields', $value);
    }

    /**
     * Set the value for the MajorDimension input for this UpdateValues Choreo.
     *
     * @param string $value (optional, string) Indicates the dimension that the values array applies to. Valid values are ROWS (the default) or COLUMNS.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setMajorDimension($value)
    {
        return $this->set('MajorDimension', $value);
    }

    /**
     * Set the value for the Range input for this UpdateValues Choreo.
     *
     * @param string $value (required, string) The A1 notation of a range to update. See Choreos notes for more details.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setRange($value)
    {
        return $this->set('Range', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateValues Choreo.
     *
     * @param string $value (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetID input for this UpdateValues Choreo.
     *
     * @param string $value (required, string) The ID of the spreadsheet. This can be found in the URL when viewing your spreadsheet in your web browser.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setSpreadsheetID($value)
    {
        return $this->set('SpreadsheetID', $value);
    }

    /**
     * Set the value for the ValueInputOption input for this UpdateValues Choreo.
     *
     * @param string $value (optional, string) Specifies how the input data should be interpreted. Valid values are: RAW (the default) and USER_ENTERED.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setValueInputOption($value)
    {
        return $this->set('ValueInputOption', $value);
    }

    /**
     * Set the value for the Values input for this UpdateValues Choreo.
     *
     * @param string $value (required, json) This is an array of arrays. The outer array can represent one or more rows while the inner array can represent one or more cell values. See Choreo notes below for more details.
     * @return Google_Sheets_UpdateValues_Inputs For method chaining.
     */
    public function setValues($value)
    {
        return $this->set('Values', $value);
    }
}


/**
 * Execution object for the UpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_UpdateValues_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateValues Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateValues execution.
     * @param Google_Sheets_UpdateValues $choreo The choreography object for this execution.
     * @param Google_Sheets_UpdateValues_Inputs|array $inputs (optional) Inputs as Google_Sheets_UpdateValues_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Sheets_UpdateValues_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Sheets_UpdateValues $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateValues execution.
     *
     * @return Google_Sheets_UpdateValues_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateValues execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Sheets_UpdateValues_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Sheets_UpdateValues_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateValues Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Sheets_UpdateValues_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateValues Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Sheets_UpdateValues_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateValues execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateValues execution.
     *
     * @return string (json) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Adds one or more rows to a worksheet in a Google spreadsheet using a simple XML file you provide.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddListRows extends Temboo_Choreography
{
    /**
     * Adds one or more rows to a worksheet in a Google spreadsheet using a simple XML file you provide.
     *
     * @param Temboo_Session $session The session that owns this AddListRows Choreo.
     * @return Google_Spreadsheets_AddListRows New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/AddListRows/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AddListRows Choreo.
     *
     * @param Google_Spreadsheets_AddListRows_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AddListRows_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AddListRows_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_AddListRows_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AddListRows Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AddListRows_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_AddListRows_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AddListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddListRows_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AddListRows Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AddListRows_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AddListRows input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowsetXML input for this AddListRows Choreo.
     *
     * @param string $value (required, xml) The rows of data that you want to add to a worksheet in XML format. Your XML needs to be in the rowset/row schema described in the Choreo documentation.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setRowsetXML($value)
    {
        return $this->set('RowsetXML', $value);
    }

    /**
     * Set the value for the AccessToken input for this AddListRows Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AddListRows Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AddListRows Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this AddListRows Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AddListRows Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this AddListRows Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this AddListRows Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet that contains the worksheet you want to add rows to.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this AddListRows Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this AddListRows Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet that you want to add rows to.
     * @return Google_Spreadsheets_AddListRows_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the AddListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddListRows_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AddListRows Choreo.
     *
     * @param Temboo_Session $session The session that owns this AddListRows execution.
     * @param Google_Spreadsheets_AddListRows $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_AddListRows_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AddListRows_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AddListRows_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_AddListRows $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AddListRows execution.
     *
     * @return Google_Spreadsheets_AddListRows_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AddListRows execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_AddListRows_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_AddListRows_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AddListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddListRows_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AddListRows Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_AddListRows_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AddListRows execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AddListRows execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a new worksheet within an existing spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddWorksheet extends Temboo_Choreography
{
    /**
     * Creates a new worksheet within an existing spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this AddWorksheet Choreo.
     * @return Google_Spreadsheets_AddWorksheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/AddWorksheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AddWorksheet Choreo.
     *
     * @param Google_Spreadsheets_AddWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AddWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AddWorksheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_AddWorksheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AddWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AddWorksheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_AddWorksheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AddWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddWorksheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AddWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AddWorksheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AddWorksheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this AddWorksheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AddWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AddWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ColumnCount input for this AddWorksheet Choreo.
     *
     * @param int $value (required, integer) The number of columns that you want to specify for the new worksheet.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setColumnCount($value)
    {
        return $this->set('ColumnCount', $value);
    }

    /**
     * Set the value for the Password input for this AddWorksheet Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AddWorksheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this AddWorksheet Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the RowCount input for this AddWorksheet Choreo.
     *
     * @param int $value (required, integer) The number of rows that you want to specify for the new worksheet.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setRowCount($value)
    {
        return $this->set('RowCount', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this AddWorksheet Choreo.
     *
     * @param string $value (required, string) The unique key associated with the spreadsheet that you want to add a worksheet to.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Title input for this AddWorksheet Choreo.
     *
     * @param string $value (required, string) The title of the new worksheet.
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }

    /**
     * Set the value for the Username input for this AddWorksheet Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AddWorksheet_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the AddWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddWorksheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AddWorksheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this AddWorksheet execution.
     * @param Google_Spreadsheets_AddWorksheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_AddWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AddWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AddWorksheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_AddWorksheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AddWorksheet execution.
     *
     * @return Google_Spreadsheets_AddWorksheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AddWorksheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_AddWorksheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_AddWorksheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AddWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AddWorksheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AddWorksheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_AddWorksheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AddWorksheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AddWorksheet execution.
     *
     * @return string The response from Google
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Appends a simple comma-separated row of data to a given Google Spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow extends Temboo_Choreography
{
    /**
     * Appends a simple comma-separated row of data to a given Google Spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this AppendRow Choreo.
     * @return Google_Spreadsheets_AppendRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/AppendRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AppendRow Choreo.
     *
     * @param Google_Spreadsheets_AppendRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AppendRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AppendRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_AppendRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AppendRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AppendRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_AppendRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AppendRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AppendRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AppendRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AppendRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowData input for this AppendRow Choreo.
     *
     * @param string $value (required, string) A comma separated list of items to be added as a new row to the spreadsheet.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setRowData($value)
    {
        return $this->set('RowData', $value);
    }

    /**
     * Set the value for the AccessToken input for this AppendRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AppendRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AppendRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this AppendRow Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AppendRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SheetName input for this AppendRow Choreo.
     *
     * @param string $value (optional, string) The name of the sheet to write to. If not specified, rows are written to the first sheet.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setSheetName($value)
    {
        return $this->set('SheetName', $value);
    }

    /**
     * Set the value for the SpreadsheetTitle input for this AppendRow Choreo.
     *
     * @param string $value (required, string) The title of the spreadsheet that you want to write rows to.
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setSpreadsheetTitle($value)
    {
        return $this->set('SpreadsheetTitle', $value);
    }

    /**
     * Set the value for the Username input for this AppendRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AppendRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the AppendRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AppendRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this AppendRow execution.
     * @param Google_Spreadsheets_AppendRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_AppendRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AppendRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AppendRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_AppendRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AppendRow execution.
     *
     * @return Google_Spreadsheets_AppendRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AppendRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_AppendRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_AppendRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AppendRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AppendRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_AppendRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AppendRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AppendRow execution.
     *
     * @return string (string) Returns the string "success" if no error occurs.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Appends a simple comma-separated row of data to a given Google Spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_old extends Temboo_Choreography
{
    /**
     * Appends a simple comma-separated row of data to a given Google Spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this AppendRow_old Choreo.
     * @return Google_Spreadsheets_AppendRow_old New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/AppendRow_old/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this AppendRow_old Choreo.
     *
     * @param Google_Spreadsheets_AppendRow_old_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AppendRow_old_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AppendRow_old_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_AppendRow_old_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this AppendRow_old Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AppendRow_old_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_AppendRow_old_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the AppendRow_old Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_old_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the AppendRow_old Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_AppendRow_old_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this AppendRow_old input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowData input for this AppendRow_old Choreo.
     *
     * @param string $value (required, string) A comma separated list of items to be added as a new row to the spreadsheet.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setRowData($value)
    {
        return $this->set('RowData', $value);
    }

    /**
     * Set the value for the AccessToken input for this AppendRow_old Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this AppendRow_old Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this AppendRow_old Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this AppendRow_old Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this AppendRow_old Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SheetName input for this AppendRow_old Choreo.
     *
     * @param string $value (optional, string) The name of the sheet to write to. If not specified, rows are written to the first sheet.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setSheetName($value)
    {
        return $this->set('SheetName', $value);
    }

    /**
     * Set the value for the SpreadsheetTitle input for this AppendRow_old Choreo.
     *
     * @param string $value (required, string) The title of the spreadsheet that you want to write rows to.
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setSpreadsheetTitle($value)
    {
        return $this->set('SpreadsheetTitle', $value);
    }

    /**
     * Set the value for the Username input for this AppendRow_old Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_AppendRow_old_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the AppendRow_old Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_old_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the AppendRow_old Choreo.
     *
     * @param Temboo_Session $session The session that owns this AppendRow_old execution.
     * @param Google_Spreadsheets_AppendRow_old $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_AppendRow_old_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_AppendRow_old_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_AppendRow_old_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_AppendRow_old $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this AppendRow_old execution.
     *
     * @return Google_Spreadsheets_AppendRow_old_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this AppendRow_old execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_AppendRow_old_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_AppendRow_old_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the AppendRow_old Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_AppendRow_old_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the AppendRow_old Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_AppendRow_old_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this AppendRow_old execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this AppendRow_old execution.
     *
     * @return string (string) Returns the string "success" if no error occurs.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specified worksheet row from a Google spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteListRow extends Temboo_Choreography
{
    /**
     * Deletes a specified worksheet row from a Google spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this DeleteListRow Choreo.
     * @return Google_Spreadsheets_DeleteListRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/DeleteListRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteListRow Choreo.
     *
     * @param Google_Spreadsheets_DeleteListRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteListRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteListRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_DeleteListRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteListRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteListRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_DeleteListRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteListRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteListRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteListRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteListRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteListRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the EditLink input for this DeleteListRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setEditLink($value)
    {
        return $this->set('EditLink', $value);
    }

    /**
     * Set the value for the Link input for this DeleteListRow Choreo.
     *
     * @param string $value (optional, string) The entry's resource URL found in the link element of the entry. Can be retrieved by running RetrieveListFeed Choreo. When this is provided, SpreadsheetKey, WorksheetId, and RowId are not needed.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setLink($value)
    {
        return $this->set('Link', $value);
    }

    /**
     * Set the value for the Password input for this DeleteListRow Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the RowId input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the row you want to delete. Required unless providing the Link input.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setRowId($value)
    {
        return $this->set('RowId', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet associated with the row you want to delete. This can be found in the URL when viewing the spreadsheet. Required unless providing the Link input.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this DeleteListRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this DeleteListRow Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet associated with the row you want to delete. Typically, Sheet1 has the id of "od6". Required unless providing the Link input.
     * @return Google_Spreadsheets_DeleteListRow_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the DeleteListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteListRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteListRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteListRow execution.
     * @param Google_Spreadsheets_DeleteListRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_DeleteListRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteListRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteListRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_DeleteListRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteListRow execution.
     *
     * @return Google_Spreadsheets_DeleteListRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteListRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteListRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_DeleteListRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteListRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteListRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteListRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteListRow execution.
     *
     * @return string Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteListRow execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to delete a specifc row by its row number.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteRow extends Temboo_Choreography
{
    /**
     * Allows you to delete a specifc row by its row number.
     *
     * @param Temboo_Session $session The session that owns this DeleteRow Choreo.
     * @return Google_Spreadsheets_DeleteRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/DeleteRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteRow Choreo.
     *
     * @param Google_Spreadsheets_DeleteRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_DeleteRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_DeleteRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the DeleteLast input for this DeleteRow Choreo.
     *
     * @param bool $value (conditional, boolean) When set to "true", the last row in the list will be deleted. The Row input is ignored when using this flag.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setDeleteLast($value)
    {
        return $this->set('DeleteLast', $value);
    }

    /**
     * Set the value for the Password input for this DeleteRow Choreo.
     *
     * @param string $value (conditional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Row input for this DeleteRow Choreo.
     *
     * @param int $value (conditional, integer) The number of the row to delete. Required unless using the DeleteLast flag. Note that row 1 (the column header row) can not be deleted.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setRow($value)
    {
        return $this->set('Row', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this DeleteRow Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the row you want to delete. This can be found in the URL when viewing the spreadsheet. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this DeleteRow Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet to delete a row from. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this DeleteRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this DeleteRow Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet that you want to delete from. Typically, Sheet1 has the id of "od6". Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this DeleteRow Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet to delete a row from. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_DeleteRow_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the DeleteRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteRow execution.
     * @param Google_Spreadsheets_DeleteRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_DeleteRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_DeleteRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteRow execution.
     *
     * @return Google_Spreadsheets_DeleteRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_DeleteRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteRow execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Deletes a specified worksheet from an existing spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteWorksheet extends Temboo_Choreography
{
    /**
     * Deletes a specified worksheet from an existing spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this DeleteWorksheet Choreo.
     * @return Google_Spreadsheets_DeleteWorksheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/DeleteWorksheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DeleteWorksheet Choreo.
     *
     * @param Google_Spreadsheets_DeleteWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteWorksheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_DeleteWorksheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DeleteWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_DeleteWorksheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DeleteWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteWorksheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DeleteWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DeleteWorksheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DeleteWorksheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DeleteWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DeleteWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this DeleteWorksheet Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DeleteWorksheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this DeleteWorksheet Choreo.
     *
     * @param string $value (required, string) The unique key associated with the spreadsheet that contains a worksheet you want to delete.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this DeleteWorksheet Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this DeleteWorksheet Choreo.
     *
     * @param string $value (required, string) The unique ID associated with the worksheet that you want to delete.
     * @return Google_Spreadsheets_DeleteWorksheet_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the DeleteWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteWorksheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DeleteWorksheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this DeleteWorksheet execution.
     * @param Google_Spreadsheets_DeleteWorksheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_DeleteWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DeleteWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DeleteWorksheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_DeleteWorksheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DeleteWorksheet execution.
     *
     * @return Google_Spreadsheets_DeleteWorksheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DeleteWorksheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteWorksheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_DeleteWorksheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DeleteWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DeleteWorksheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DeleteWorksheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_DeleteWorksheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DeleteWorksheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this DeleteWorksheet execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Downloads a document with the title you specify, and returns the content as Base64 encoded data.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DownloadBase64EncodedSpreadsheet extends Temboo_Choreography
{
    /**
     * Downloads a document with the title you specify, and returns the content as Base64 encoded data.
     *
     * @param Temboo_Session $session The session that owns this DownloadBase64EncodedSpreadsheet Choreo.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/DownloadBase64EncodedSpreadsheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the DownloadBase64EncodedSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this DownloadBase64EncodedSpreadsheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Format input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The format you want to export the spreadsheet to, such as "csv" or "pdf".
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setFormat($value)
    {
        return $this->set('Format', $value);
    }

    /**
     * Set the value for the Link input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A file's exportLink. Required unless specifying the Title. See Choreo notes for more details about where this property can be found.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setLink($value)
    {
        return $this->set('Link', $value);
    }

    /**
     * Set the value for the Password input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Title input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The title of the document to download. Required if the source Link is not specifed.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }

    /**
     * Set the value for the Username input for this DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the DownloadBase64EncodedSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this DownloadBase64EncodedSpreadsheet execution.
     * @param Google_Spreadsheets_DownloadBase64EncodedSpreadsheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_DownloadBase64EncodedSpreadsheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this DownloadBase64EncodedSpreadsheet execution.
     *
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this DownloadBase64EncodedSpreadsheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the DownloadBase64EncodedSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the DownloadBase64EncodedSpreadsheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_DownloadBase64EncodedSpreadsheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "FileContents" output from this DownloadBase64EncodedSpreadsheet execution.
     *
     * @return string (string) The Base64 encoded file content of the downloaded file.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getFileContents()
    {
        return $this->get('FileContents');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this DownloadBase64EncodedSpreadsheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Retrieves a list of cell names and values in a specified Google worksheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellFeed extends Temboo_Choreography
{
    /**
     * Retrieves a list of cell names and values in a specified Google worksheet.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellFeed Choreo.
     * @return Google_Spreadsheets_RetrieveCellFeed New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveCellFeed/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveCellFeed Choreo.
     *
     * @param Google_Spreadsheets_RetrieveCellFeed_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellFeed_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveCellFeed_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveCellFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveCellFeed_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveCellFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellFeed_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveCellFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveCellFeed input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the cells you want to retrieve.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveCellFeed Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the cells you want to retrieve.
     * @return Google_Spreadsheets_RetrieveCellFeed_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the RetrieveCellFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellFeed_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveCellFeed Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellFeed execution.
     * @param Google_Spreadsheets_RetrieveCellFeed $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveCellFeed_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellFeed_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveCellFeed $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveCellFeed execution.
     *
     * @return Google_Spreadsheets_RetrieveCellFeed_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveCellFeed execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellFeed_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveCellFeed_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveCellFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellFeed_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveCellFeed Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellFeed_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveCellFeed execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveCellFeed execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of cell values using the specified cell locations.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellList extends Temboo_Choreography
{
    /**
     * Retrieves a list of cell values using the specified cell locations.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellList Choreo.
     * @return Google_Spreadsheets_RetrieveCellList New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveCellList/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveCellList Choreo.
     *
     * @param Google_Spreadsheets_RetrieveCellList_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellList_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveCellList_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveCellList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveCellList_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveCellList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellList_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveCellList Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveCellList input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveCellList Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CellLocations input for this RetrieveCellList Choreo.
     *
     * @param string $value (required, string) A comma-separated list of cell locations to retrieve (e.g. A2,B4,C3).
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setCellLocations($value)
    {
        return $this->set('CellLocations', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveCellList Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveCellList Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveCellList Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveCellList Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveCellList Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet associated with the cells you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveCellList Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet containing the cells to retrieve. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveCellList Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveCellList Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet associated with the cells you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this RetrieveCellList Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet containing the cells to retrieve. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup the spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveCellList_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the RetrieveCellList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellList_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveCellList Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellList execution.
     * @param Google_Spreadsheets_RetrieveCellList $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveCellList_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellList_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellList_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveCellList $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveCellList execution.
     *
     * @return Google_Spreadsheets_RetrieveCellList_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveCellList execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellList_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveCellList_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveCellList Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellList_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveCellList Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellList_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "CellValues" output from this RetrieveCellList execution.
     *
     * @return string (json) 
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCellValues()
    {
        return $this->get('CellValues');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveCellList execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Retrieves the value of given cell.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellValue extends Temboo_Choreography
{
    /**
     * Retrieves the value of given cell.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellValue Choreo.
     * @return Google_Spreadsheets_RetrieveCellValue New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveCellValue/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveCellValue Choreo.
     *
     * @param Google_Spreadsheets_RetrieveCellValue_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellValue_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellValue_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveCellValue_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveCellValue Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveCellValue_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveCellValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellValue_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveCellValue Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveCellValue input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveCellValue Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the CellLocation input for this RetrieveCellValue Choreo.
     *
     * @param string $value (required, string) The location of the cell that should be retrieved (e.g. A2).
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setCellLocation($value)
    {
        return $this->set('CellLocation', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveCellValue Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveCellValue Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveCellValue Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveCellValue Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveCellValue Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet associated with the cell you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveCellValue Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet containing the cell to retrieve. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveCellValue Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveCellValue Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet associated with the cell you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this RetrieveCellValue Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet containing the cell to retrieve. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup the spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveCellValue_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the RetrieveCellValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellValue_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveCellValue Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveCellValue execution.
     * @param Google_Spreadsheets_RetrieveCellValue $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveCellValue_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveCellValue_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveCellValue_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveCellValue $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveCellValue execution.
     *
     * @return Google_Spreadsheets_RetrieveCellValue_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveCellValue execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellValue_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveCellValue_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveCellValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveCellValue_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveCellValue Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveCellValue_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "CellValue" output from this RetrieveCellValue execution.
     *
     * @return string (string) The value of the cell.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCellValue()
    {
        return $this->get('CellValue');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveCellValue execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Returns the value of the last cell in a specified column.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveLastColumnValue extends Temboo_Choreography
{
    /**
     * Returns the value of the last cell in a specified column.
     *
     * @param Temboo_Session $session The session that owns this RetrieveLastColumnValue Choreo.
     * @return Google_Spreadsheets_RetrieveLastColumnValue New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveLastColumnValue/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveLastColumnValue Choreo.
     *
     * @param Google_Spreadsheets_RetrieveLastColumnValue_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveLastColumnValue_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveLastColumnValue_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveLastColumnValue Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveLastColumnValue_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveLastColumnValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveLastColumnValue_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveLastColumnValue Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveLastColumnValue input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ColumnName input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (required, string) The name of the column that the cell value is in. This should be the value in row 1 of the column you wish to search.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setColumnName($value)
    {
        return $this->set('ColumnName', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet to query. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet to query. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet to query. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this RetrieveLastColumnValue Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet to query. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup the spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the RetrieveLastColumnValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveLastColumnValue_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveLastColumnValue Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveLastColumnValue execution.
     * @param Google_Spreadsheets_RetrieveLastColumnValue $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveLastColumnValue_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveLastColumnValue_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveLastColumnValue $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveLastColumnValue execution.
     *
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveLastColumnValue execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveLastColumnValue_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveLastColumnValue Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveLastColumnValue_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveLastColumnValue Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveLastColumnValue_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "CellValue" output from this RetrieveLastColumnValue execution.
     *
     * @return string The value of the last cell in the specified column.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCellValue()
    {
        return $this->get('CellValue');
    }
    /**
     * Retrieve the value for the "Column" output from this RetrieveLastColumnValue execution.
     *
     * @return int (integer) The column number for the returned cell.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getColumn()
    {
        return $this->get('Column');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveLastColumnValue execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Row" output from this RetrieveLastColumnValue execution.
     *
     * @return int (integer) The row number of the returned cell.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getRow()
    {
        return $this->get('Row');
    }
}

/**
 * Retrieves a list-based feed containing data in your Google spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListFeed extends Temboo_Choreography
{
    /**
     * Retrieves a list-based feed containing data in your Google spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this RetrieveListFeed Choreo.
     * @return Google_Spreadsheets_RetrieveListFeed New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveListFeed/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveListFeed Choreo.
     *
     * @param Google_Spreadsheets_RetrieveListFeed_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveListFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveListFeed_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveListFeed_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveListFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveListFeed_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveListFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListFeed_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveListFeed Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveListFeed input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveListFeed Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveListFeed Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveListFeed Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveListFeed Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveListFeed Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveListFeed Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveListFeed Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the feed you want to retrieve.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveListFeed Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveListFeed Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the feed you want to retrieve.
     * @return Google_Spreadsheets_RetrieveListFeed_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the RetrieveListFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListFeed_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveListFeed Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveListFeed execution.
     * @param Google_Spreadsheets_RetrieveListFeed $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveListFeed_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveListFeed_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveListFeed_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveListFeed $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveListFeed execution.
     *
     * @return Google_Spreadsheets_RetrieveListFeed_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveListFeed execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveListFeed_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveListFeed_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveListFeed Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListFeed_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveListFeed Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveListFeed_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveListFeed execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveListFeed execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specified worksheet row from a Google spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListRow extends Temboo_Choreography
{
    /**
     * Retrieves a specified worksheet row from a Google spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this RetrieveListRow Choreo.
     * @return Google_Spreadsheets_RetrieveListRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveListRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveListRow Choreo.
     *
     * @param Google_Spreadsheets_RetrieveListRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveListRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveListRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveListRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveListRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveListRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveListRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveListRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveListRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Link input for this RetrieveListRow Choreo.
     *
     * @param string $value (optional, string) The entry's resource URL found in the link element of the entry. Can be retrieved by running the RetrieveListFeed Choreo. When this is provided, SpreadsheetKey, WorksheetId, and RowId are not needed.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setLink($value)
    {
        return $this->set('Link', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveListRow Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveListRow Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the RowId input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the row you want to retrieve. Required unless providing the Link input.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setRowId($value)
    {
        return $this->set('RowId', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet associated with the row you want to retrieve. Required unless providing the Link input.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveListRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveListRow Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet associated with the row you want to retrieve. Required unless providing the Link input.
     * @return Google_Spreadsheets_RetrieveListRow_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the RetrieveListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveListRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveListRow execution.
     * @param Google_Spreadsheets_RetrieveListRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveListRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveListRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveListRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveListRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveListRow execution.
     *
     * @return Google_Spreadsheets_RetrieveListRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveListRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveListRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveListRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveListRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveListRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveListRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveListRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveListRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveListRow execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specific row as comma-separated values.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveRow extends Temboo_Choreography
{
    /**
     * Retrieves a specific row as comma-separated values.
     *
     * @param Temboo_Session $session The session that owns this RetrieveRow Choreo.
     * @return Google_Spreadsheets_RetrieveRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveRow Choreo.
     *
     * @param Google_Spreadsheets_RetrieveRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveRow Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the Row input for this RetrieveRow Choreo.
     *
     * @param int $value (conditional, integer) The number of the row to return. If not provided, the last row is returned.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setRow($value)
    {
        return $this->set('Row', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveRow Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the row you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveRow Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet containing the row to retrieve. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveRow Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the row you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this RetrieveRow Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet containing the row to retrieve. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup the spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveRow_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the RetrieveRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveRow execution.
     * @param Google_Spreadsheets_RetrieveRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveRow execution.
     *
     * @return Google_Spreadsheets_RetrieveRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "RowData" output from this RetrieveRow execution.
     *
     * @return string (string) The row data in CSV format.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getRowData()
    {
        return $this->get('RowData');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Retrieves specific rows or columns based on a specified range.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpecificRowsOrColumns extends Temboo_Choreography
{
    /**
     * Retrieves specific rows or columns based on a specified range.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpecificRowsOrColumns Choreo.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveSpecificRowsOrColumns/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveSpecificRowsOrColumns Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveSpecificRowsOrColumns input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the MaxColumn input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param int $value (conditional, integer) The maximum column number for the cell range that you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setMaxColumn($value)
    {
        return $this->set('MaxColumn', $value);
    }

    /**
     * Set the value for the MaxRow input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param int $value (conditional, integer) The maximum row number for the cell range that you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setMaxRow($value)
    {
        return $this->set('MaxRow', $value);
    }

    /**
     * Set the value for the MinColumn input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param int $value (conditional, integer) The minimum column number for the cell range you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setMinColumn($value)
    {
        return $this->set('MinColumn', $value);
    }

    /**
     * Set the value for the MinRow input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param int $value (conditional, integer) The minimum row number for the cell range you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setMinRow($value)
    {
        return $this->set('MinRow', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the cells you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the cells you want to retrieve.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the RetrieveSpecificRowsOrColumns Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpecificRowsOrColumns execution.
     * @param Google_Spreadsheets_RetrieveSpecificRowsOrColumns $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveSpecificRowsOrColumns $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveSpecificRowsOrColumns execution.
     *
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveSpecificRowsOrColumns execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveSpecificRowsOrColumns Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveSpecificRowsOrColumns Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpecificRowsOrColumns_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveSpecificRowsOrColumns execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveSpecificRowsOrColumns execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves spreadsheet and worksheet IDs with a given spreadsheet name.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheetDetailsByName extends Temboo_Choreography
{
    /**
     * Retrieves spreadsheet and worksheet IDs with a given spreadsheet name.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpreadsheetDetailsByName Choreo.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveSpreadsheetDetailsByName/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveSpreadsheetDetailsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveSpreadsheetDetailsByName input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (required, string) The title of the spreadsheet you want to retrieve details for.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the RetrieveSpreadsheetDetailsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpreadsheetDetailsByName execution.
     * @param Google_Spreadsheets_RetrieveSpreadsheetDetailsByName $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveSpreadsheetDetailsByName $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveSpreadsheetDetailsByName execution.
     *
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveSpreadsheetDetailsByName execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveSpreadsheetDetailsByName Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveSpreadsheetDetailsByName Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheetDetailsByName_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "SpreadsheetDetails" output from this RetrieveSpreadsheetDetailsByName execution.
     *
     * @return string The spreadsheet details including spreadsheet name and key. Worksheet names and IDs associated with the spreadsheet are also included.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getSpreadsheetDetails()
    {
        return $this->get('SpreadsheetDetails');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveSpreadsheetDetailsByName execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
}

/**
 * Retrieves a list of spreadsheets that exist in your Google account.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheets extends Temboo_Choreography
{
    /**
     * Retrieves a list of spreadsheets that exist in your Google account.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpreadsheets Choreo.
     * @return Google_Spreadsheets_RetrieveSpreadsheets New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveSpreadsheets/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveSpreadsheets Choreo.
     *
     * @param Google_Spreadsheets_RetrieveSpreadsheets_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpreadsheets_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveSpreadsheets_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveSpreadsheets Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveSpreadsheets_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveSpreadsheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheets_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveSpreadsheets Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveSpreadsheets input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveSpreadsheets Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the RetrieveSpreadsheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheets_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveSpreadsheets Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveSpreadsheets execution.
     * @param Google_Spreadsheets_RetrieveSpreadsheets $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveSpreadsheets_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveSpreadsheets_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveSpreadsheets $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveSpreadsheets execution.
     *
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveSpreadsheets execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveSpreadsheets_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveSpreadsheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveSpreadsheets_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveSpreadsheets Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveSpreadsheets_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveSpreadsheets execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveSpreadsheets execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a specified worksheet from a Google spreadsheet in CSV, XML, or JSON format.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheet extends Temboo_Choreography
{
    /**
     * Retrieves a specified worksheet from a Google spreadsheet in CSV, XML, or JSON format.
     *
     * @param Temboo_Session $session The session that owns this RetrieveWorksheet Choreo.
     * @return Google_Spreadsheets_RetrieveWorksheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveWorksheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveWorksheet Choreo.
     *
     * @param Google_Spreadsheets_RetrieveWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveWorksheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveWorksheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveWorksheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveWorksheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: csv (the default), xml, and json.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the worksheet you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet to retrieve. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet that you want to retrieve. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this RetrieveWorksheet Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet to retrieve. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_RetrieveWorksheet_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the RetrieveWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveWorksheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveWorksheet execution.
     * @param Google_Spreadsheets_RetrieveWorksheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveWorksheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveWorksheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveWorksheet execution.
     *
     * @return Google_Spreadsheets_RetrieveWorksheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveWorksheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveWorksheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveWorksheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveWorksheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveWorksheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveWorksheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveWorksheet execution.
     *
     * @return string (multiline) The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Retrieves a list of worksheets in a given Google spreadsheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheets extends Temboo_Choreography
{
    /**
     * Retrieves a list of worksheets in a given Google spreadsheet.
     *
     * @param Temboo_Session $session The session that owns this RetrieveWorksheets Choreo.
     * @return Google_Spreadsheets_RetrieveWorksheets New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/RetrieveWorksheets/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this RetrieveWorksheets Choreo.
     *
     * @param Google_Spreadsheets_RetrieveWorksheets_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveWorksheets_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveWorksheets_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_RetrieveWorksheets_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this RetrieveWorksheets Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_RetrieveWorksheets_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the RetrieveWorksheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheets_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the RetrieveWorksheets Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this RetrieveWorksheets input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the worksheet(s) you want to retrieve.
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this RetrieveWorksheets Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_RetrieveWorksheets_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }
}


/**
 * Execution object for the RetrieveWorksheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheets_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the RetrieveWorksheets Choreo.
     *
     * @param Temboo_Session $session The session that owns this RetrieveWorksheets execution.
     * @param Google_Spreadsheets_RetrieveWorksheets $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_RetrieveWorksheets_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_RetrieveWorksheets_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_RetrieveWorksheets_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_RetrieveWorksheets $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this RetrieveWorksheets execution.
     *
     * @return Google_Spreadsheets_RetrieveWorksheets_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this RetrieveWorksheets execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveWorksheets_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_RetrieveWorksheets_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the RetrieveWorksheets Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_RetrieveWorksheets_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the RetrieveWorksheets Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_RetrieveWorksheets_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this RetrieveWorksheets execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this RetrieveWorksheets execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Searches a column for a specified value.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_SearchColumn extends Temboo_Choreography
{
    /**
     * Searches a column for a specified value.
     *
     * @param Temboo_Session $session The session that owns this SearchColumn Choreo.
     * @return Google_Spreadsheets_SearchColumn New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/SearchColumn/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this SearchColumn Choreo.
     *
     * @param Google_Spreadsheets_SearchColumn_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_SearchColumn_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_SearchColumn_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_SearchColumn_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this SearchColumn Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_SearchColumn_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_SearchColumn_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the SearchColumn Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_SearchColumn_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the SearchColumn Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_SearchColumn_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this SearchColumn input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this SearchColumn Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this SearchColumn Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this SearchColumn Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this SearchColumn Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this SearchColumn Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ReturnMatches input for this SearchColumn Choreo.
     *
     * @param bool $value (optional, boolean) Set to true to return all matches of the query. When set to true, an array of cell values that meet the query criteria is returned in the Results output. Defaults to true.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setReturnMatches($value)
    {
        return $this->set('ReturnMatches', $value);
    }

    /**
     * Set the value for the SearchColumn input for this SearchColumn Choreo.
     *
     * @param string $value (required, string) The name of the column to search. This should be the value in row 1 of the column you wish to search.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setSearchColumn($value)
    {
        return $this->set('SearchColumn', $value);
    }

    /**
     * Set the value for the SearchOperator input for this SearchColumn Choreo.
     *
     * @param string $value (required, string) The operator to use in the query. Allowed operators are: >, <, >=, >=, =, contains, and starts_with.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setSearchOperator($value)
    {
        return $this->set('SearchOperator', $value);
    }

    /**
     * Set the value for the SearchValue input for this SearchColumn Choreo.
     *
     * @param mixed $value (required, any) The value to search for in the specified column.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setSearchValue($value)
    {
        return $this->set('SearchValue', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this SearchColumn Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet to query. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this SearchColumn Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet to query. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this SearchColumn Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this SearchColumn Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet to query. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this SearchColumn Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet to query. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup the spreadsheet details by name.
     * @return Google_Spreadsheets_SearchColumn_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the SearchColumn Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_SearchColumn_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the SearchColumn Choreo.
     *
     * @param Temboo_Session $session The session that owns this SearchColumn execution.
     * @param Google_Spreadsheets_SearchColumn $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_SearchColumn_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_SearchColumn_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_SearchColumn_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_SearchColumn $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this SearchColumn execution.
     *
     * @return Google_Spreadsheets_SearchColumn_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this SearchColumn execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_SearchColumn_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_SearchColumn_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the SearchColumn Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_SearchColumn_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the SearchColumn Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_SearchColumn_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "MatchFound" output from this SearchColumn execution.
     *
     * @return bool (boolean) Whether or not a matched result was found.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getMatchFound()
    {
        return $this->get('MatchFound');
    }
    /**
     * Retrieve the value for the "Count" output from this SearchColumn execution.
     *
     * @return int (integer) The count of matched results. This is only returned when ReturnMatches is set to true.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getCount()
    {
        return $this->get('Count');
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this SearchColumn execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Results" output from this SearchColumn execution.
     *
     * @return string (json) Contains an array of the matched cell values. This is only returned when ReturnMatches is set to true.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResults()
    {
        return $this->get('Results');
    }
}

/**
 * Retrieves a list-based feed containing data in your Google spreadsheet that meets a specified criteria.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_StructuredQuery extends Temboo_Choreography
{
    /**
     * Retrieves a list-based feed containing data in your Google spreadsheet that meets a specified criteria.
     *
     * @param Temboo_Session $session The session that owns this StructuredQuery Choreo.
     * @return Google_Spreadsheets_StructuredQuery New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/StructuredQuery/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this StructuredQuery Choreo.
     *
     * @param Google_Spreadsheets_StructuredQuery_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_StructuredQuery_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_StructuredQuery_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_StructuredQuery_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this StructuredQuery Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_StructuredQuery_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_StructuredQuery_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the StructuredQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_StructuredQuery_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the StructuredQuery Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_StructuredQuery_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this StructuredQuery input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this StructuredQuery Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this StructuredQuery Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this StructuredQuery Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this StructuredQuery Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the Query input for this StructuredQuery Choreo.
     *
     * @param string $value (required, string) A valid structured query (i.e. id>4).
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setQuery($value)
    {
        return $this->set('Query', $value);
    }

    /**
     * Set the value for the RefreshToken input for this StructuredQuery Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this StructuredQuery Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this StructuredQuery Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the feed you want to retrieve.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this StructuredQuery Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this StructuredQuery Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the feed you want to retrieve.
     * @return Google_Spreadsheets_StructuredQuery_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the StructuredQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_StructuredQuery_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the StructuredQuery Choreo.
     *
     * @param Temboo_Session $session The session that owns this StructuredQuery execution.
     * @param Google_Spreadsheets_StructuredQuery $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_StructuredQuery_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_StructuredQuery_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_StructuredQuery_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_StructuredQuery $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this StructuredQuery execution.
     *
     * @return Google_Spreadsheets_StructuredQuery_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this StructuredQuery execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_StructuredQuery_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_StructuredQuery_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the StructuredQuery Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_StructuredQuery_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the StructuredQuery Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_StructuredQuery_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this StructuredQuery execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this StructuredQuery execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates a specified cell in a Google worksheet.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateCells extends Temboo_Choreography
{
    /**
     * Updates a specified cell in a Google worksheet.
     *
     * @param Temboo_Session $session The session that owns this UpdateCells Choreo.
     * @return Google_Spreadsheets_UpdateCells New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/UpdateCells/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateCells Choreo.
     *
     * @param Google_Spreadsheets_UpdateCells_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateCells_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateCells_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_UpdateCells_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateCells Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateCells_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_UpdateCells_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateCells Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateCells_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateCells Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateCells_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateCells input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateCells Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateCells Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateCells Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Column input for this UpdateCells Choreo.
     *
     * @param int $value (required, integer) The column number of the cell location that you want to update (for example, column A = 1, columnB = 2, etc).
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setColumn($value)
    {
        return $this->set('Column', $value);
    }

    /**
     * Set the value for the InputValue input for this UpdateCells Choreo.
     *
     * @param string $value (required, string) The new value for the cell.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setInputValue($value)
    {
        return $this->set('InputValue', $value);
    }

    /**
     * Set the value for the Password input for this UpdateCells Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateCells Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UpdateCells Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Row input for this UpdateCells Choreo.
     *
     * @param int $value (required, integer) The row number of the cell location that you want to update.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setRow($value)
    {
        return $this->set('Row', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this UpdateCells Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the cell you want to update.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this UpdateCells Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this UpdateCells Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet associated with the cell you want to update.
     * @return Google_Spreadsheets_UpdateCells_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the UpdateCells Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateCells_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateCells Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateCells execution.
     * @param Google_Spreadsheets_UpdateCells $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_UpdateCells_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateCells_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateCells_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_UpdateCells $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateCells execution.
     *
     * @return Google_Spreadsheets_UpdateCells_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateCells execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateCells_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_UpdateCells_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateCells Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateCells_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateCells Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateCells_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateCells execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateCells execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates a worksheet row in a Google spreadsheet using a simple XML file you provide.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateListRows extends Temboo_Choreography
{
    /**
     * Updates a worksheet row in a Google spreadsheet using a simple XML file you provide.
     *
     * @param Temboo_Session $session The session that owns this UpdateListRows Choreo.
     * @return Google_Spreadsheets_UpdateListRows New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/UpdateListRows/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateListRows Choreo.
     *
     * @param Google_Spreadsheets_UpdateListRows_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateListRows_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateListRows_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_UpdateListRows_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateListRows Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateListRows_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_UpdateListRows_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateListRows_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateListRows Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateListRows_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateListRows input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowsetXML input for this UpdateListRows Choreo.
     *
     * @param string $value (required, xml) The row of data that you want to update in XML format. Your XML needs to be in the rowset/row schema described in the Choreo documentation.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setRowsetXML($value)
    {
        return $this->set('RowsetXML', $value);
    }

    /**
     * Set the value for the AccessToken input for this UpdateListRows Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Link input for this UpdateListRows Choreo.
     *
     * @param string $value (optional, string) The entry's resource URL found in the link element of the entry. Can be retrieved by running RetrieveListFeed Choreo. When this is provided, SpreadsheetKey, WorksheetId, and RowId are not needed.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setLink($value)
    {
        return $this->set('Link', $value);
    }

    /**
     * Set the value for the Password input for this UpdateListRows Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UpdateListRows Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the RowId input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) The unique id of the row you want to update. Required unless providing the Link input.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setRowId($value)
    {
        return $this->set('RowId', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) The unique key of the spreadsheet that contains the worksheet you want to update. Required unless providing the Link input.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Username input for this UpdateListRows Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this UpdateListRows Choreo.
     *
     * @param string $value (conditional, string) The unique ID of the worksheet that you want to update. Required unless providing the Link input.
     * @return Google_Spreadsheets_UpdateListRows_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the UpdateListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateListRows_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateListRows Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateListRows execution.
     * @param Google_Spreadsheets_UpdateListRows $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_UpdateListRows_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateListRows_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateListRows_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_UpdateListRows $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateListRows execution.
     *
     * @return Google_Spreadsheets_UpdateListRows_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateListRows execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateListRows_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_UpdateListRows_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateListRows Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateListRows_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateListRows Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateListRows_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateListRows execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateListRows execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Allows you to update a row by providing the row number and comma-separated data.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateRow extends Temboo_Choreography
{
    /**
     * Allows you to update a row by providing the row number and comma-separated data.
     *
     * @param Temboo_Session $session The session that owns this UpdateRow Choreo.
     * @return Google_Spreadsheets_UpdateRow New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/UpdateRow/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateRow Choreo.
     *
     * @param Google_Spreadsheets_UpdateRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateRow_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_UpdateRow_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateRow_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_UpdateRow_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateRow_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateRow Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateRow_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateRow input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowData input for this UpdateRow Choreo.
     *
     * @param string $value (required, string) The updated row data formatted as a comma-separated string.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setRowData($value)
    {
        return $this->set('RowData', $value);
    }

    /**
     * Set the value for the AccessToken input for this UpdateRow Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateRow Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateRow Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the Password input for this UpdateRow Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateRow Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UpdateRow Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Row input for this UpdateRow Choreo.
     *
     * @param int $value (conditional, integer) The number of the row to update. Note that row 1 (the column header row) can not be updated. Also, the row that is being updated must exist already. To add new rows, see AppendRow.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setRow($value)
    {
        return $this->set('Row', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this UpdateRow Choreo.
     *
     * @param string $value (required, string) The unique key of the spreadsheet associated with the row you want to update. This can be found in the URL when viewing the spreadsheet. Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the SpreadsheetName input for this UpdateRow Choreo.
     *
     * @param string $value (optional, string) The name of the spreadsheet to update. This and WorksheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setSpreadsheetName($value)
    {
        return $this->set('SpreadsheetName', $value);
    }

    /**
     * Set the value for the Username input for this UpdateRow Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this UpdateRow Choreo.
     *
     * @param string $value (required, string) The unique ID of the worksheet that you want to udpate. Typically, Sheet1 has the id of "od6". Required unless SpreadsheetName and WorksheetName are supplied.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }

    /**
     * Set the value for the WorksheetName input for this UpdateRow Choreo.
     *
     * @param string $value (optional, string) The name of the worksheet to update. This and SpreadsheetName can be used as an alternative to SpreadsheetKey and WorksheetId to lookup spreadsheet details by name.
     * @return Google_Spreadsheets_UpdateRow_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }
}


/**
 * Execution object for the UpdateRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateRow_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateRow Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateRow execution.
     * @param Google_Spreadsheets_UpdateRow $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_UpdateRow_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateRow_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateRow_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_UpdateRow $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateRow execution.
     *
     * @return Google_Spreadsheets_UpdateRow_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateRow execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateRow_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_UpdateRow_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateRow Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateRow_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateRow Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateRow_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateRow execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateRow execution.
     *
     * @return string The response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Updates existing worksheet metadata such as: Title, Row Count, and Column Count.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateWorksheet extends Temboo_Choreography
{
    /**
     * Updates existing worksheet metadata such as: Title, Row Count, and Column Count.
     *
     * @param Temboo_Session $session The session that owns this UpdateWorksheet Choreo.
     * @return Google_Spreadsheets_UpdateWorksheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/UpdateWorksheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UpdateWorksheet Choreo.
     *
     * @param Google_Spreadsheets_UpdateWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateWorksheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_UpdateWorksheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UpdateWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_UpdateWorksheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UpdateWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateWorksheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UpdateWorksheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UpdateWorksheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the AccessToken input for this UpdateWorksheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required when authenticating with OAuth unless providing the ClientID, ClientSecret, and RefreshToken.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UpdateWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UpdateWorksheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the ColumnCount input for this UpdateWorksheet Choreo.
     *
     * @param int $value (required, integer) The number of columns that you want to specify for the worksheet.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setColumnCount($value)
    {
        return $this->set('ColumnCount', $value);
    }

    /**
     * Set the value for the Password input for this UpdateWorksheet Choreo.
     *
     * @param string $value (optional, password) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setPassword($value)
    {
        return $this->set('Password', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UpdateWorksheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UpdateWorksheet Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: xml (the default) and json.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the RowCount input for this UpdateWorksheet Choreo.
     *
     * @param int $value (required, integer) The number of rows that you want to specify for the worksheet.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setRowCount($value)
    {
        return $this->set('RowCount', $value);
    }

    /**
     * Set the value for the SpreadsheetKey input for this UpdateWorksheet Choreo.
     *
     * @param string $value (required, string) The unique key associated with the spreadsheet that contains a worksheet you want to update.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setSpreadsheetKey($value)
    {
        return $this->set('SpreadsheetKey', $value);
    }

    /**
     * Set the value for the Title input for this UpdateWorksheet Choreo.
     *
     * @param string $value (required, string) The new title of the worksheet.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }

    /**
     * Set the value for the Username input for this UpdateWorksheet Choreo.
     *
     * @param string $value (required, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setUsername($value)
    {
        return $this->set('Username', $value);
    }

    /**
     * Set the value for the WorksheetId input for this UpdateWorksheet Choreo.
     *
     * @param string $value (required, string) The unique ID associated with the worksheet that you want to update.
     * @return Google_Spreadsheets_UpdateWorksheet_Inputs For method chaining.
     */
    public function setWorksheetId($value)
    {
        return $this->set('WorksheetId', $value);
    }
}


/**
 * Execution object for the UpdateWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateWorksheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UpdateWorksheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this UpdateWorksheet execution.
     * @param Google_Spreadsheets_UpdateWorksheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_UpdateWorksheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UpdateWorksheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UpdateWorksheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_UpdateWorksheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UpdateWorksheet execution.
     *
     * @return Google_Spreadsheets_UpdateWorksheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UpdateWorksheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateWorksheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_UpdateWorksheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UpdateWorksheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UpdateWorksheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UpdateWorksheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_UpdateWorksheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UpdateWorksheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UpdateWorksheet execution.
     *
     * @return string Response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

/**
 * Creates a Google spreadsheet from a CSV file.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UploadSpreadsheet extends Temboo_Choreography
{
    /**
     * Creates a Google spreadsheet from a CSV file.
     *
     * @param Temboo_Session $session The session that owns this UploadSpreadsheet Choreo.
     * @return Google_Spreadsheets_UploadSpreadsheet New instance.
     */
    public function __construct(Temboo_Session $session)
    {
        parent::__construct($session, '/Library/Google/Spreadsheets/UploadSpreadsheet/');
    }

    /**
     * Executes this Choreo.
     *
     * Execution object provides access to results appropriate for this UploadSpreadsheet Choreo.
     *
     * @param Google_Spreadsheets_UploadSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UploadSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UploadSpreadsheet_Execution New execution object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     * @throws Temboo_Exception if execution request fails.
     */
    public function execute($inputs = array(), $async = false, $store_results = true)
    {
        return new Google_Spreadsheets_UploadSpreadsheet_Execution($this->session, $this, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new inputs object.
     *
     * Includes setters appropriate for this UploadSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs New inputs object.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function newInputs($inputs = array())
    {
        return new Google_Spreadsheets_UploadSpreadsheet_Inputs($inputs);
    }
}


/**
 * Inputs object with appropriate setters for the UploadSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UploadSpreadsheet_Inputs extends Temboo_Inputs
{
   /**
     * Inputs object with appropriate setters for the UploadSpreadsheet Choreo.
     *
     * @param array $inputs (optional) Associative array of input names and values.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs New instance.
     * @throws Temboo_Exception if provided input set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($inputs = array())
    {
        parent::__construct($inputs);
    }

    /**
     * Set arbitrary input this UploadSpreadsheet input set.
     *
     * Input names are case sensitive.
     *
     * @param string $name Input name.
     * @param string $value Input value.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function set($name, $value)
    {
        return parent::set($name, $value);
    }

    /**
     * Set credential
     *
     * @param string $credentialName The name of a credential in your account specifying presets for this set of inputs.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setCredential($credentialName)
    {
        return parent::setCredential($credentialName);
    }

    /**
     * Set the value for the RowData input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (conditional, multiline) The data to be written to the Google spreadsheet. Should be in CSV format.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setRowData($value)
    {
        return $this->set('RowData', $value);
    }

    /**
     * Set the value for the AccessToken input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (optional, string) A valid Access Token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new Access Token.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setAccessToken($value)
    {
        return $this->set('AccessToken', $value);
    }

    /**
     * Set the value for the ClientID input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setClientID($value)
    {
        return $this->set('ClientID', $value);
    }

    /**
     * Set the value for the ClientSecret input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setClientSecret($value)
    {
        return $this->set('ClientSecret', $value);
    }

    /**
     * Set the value for the RefreshToken input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (conditional, string) An OAuth Refresh Token used to generate a new Access Token when the original token is expired. Required unless providing a valid AccessToken.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setRefreshToken($value)
    {
        return $this->set('RefreshToken', $value);
    }

    /**
     * Set the value for the ResponseFormat input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setResponseFormat($value)
    {
        return $this->set('ResponseFormat', $value);
    }

    /**
     * Set the value for the Title input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (required, string) The name of the new document.
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setTitle($value)
    {
        return $this->set('Title', $value);
    }

    /**
     * Set the value for the WorksheetName input for this UploadSpreadsheet Choreo.
     *
     * @param string $value (optional, string) Deprecated (retained for backward compatibility only).
     * @return Google_Spreadsheets_UploadSpreadsheet_Inputs For method chaining.
     */
    public function setWorksheetName($value)
    {
        return $this->set('WorksheetName', $value);
    }

}


/**
 * Execution object for the UploadSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UploadSpreadsheet_Execution extends Temboo_Choreography_Execution
{
    /**
     * Execution object for the UploadSpreadsheet Choreo.
     *
     * @param Temboo_Session $session The session that owns this UploadSpreadsheet execution.
     * @param Google_Spreadsheets_UploadSpreadsheet $choreo The choreography object for this execution.
     * @param Google_Spreadsheets_UploadSpreadsheet_Inputs|array $inputs (optional) Inputs as Google_Spreadsheets_UploadSpreadsheet_Inputs or associative array.
     * @param bool $async Whether to execute in asynchronous mode. Default false.
     * @param bool $store_results Whether to store results of asynchronous execution. Default true.
     * @return Google_Spreadsheets_UploadSpreadsheet_Execution New execution.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occur in synchronous execution or execution fails to start. NOT thrown for post-launch errors in asynchronous execution -- check status or results to determine asynchronous success.
     * @throws Temboo_Exception_Notfound if choreography does not exist.
     */
    public function __construct(Temboo_Session $session, Google_Spreadsheets_UploadSpreadsheet $choreo, $inputs = array(), $async = false, $store_results = true)
    {
        parent::__construct($session, $choreo, $inputs, $async, $store_results);
    }

    /**
     * Obtains a new results object.
     *
     * Includes getters appropriate for this UploadSpreadsheet execution.
     *
     * @return Google_Spreadsheets_UploadSpreadsheet_Results New results object.
     * @throws Temboo_Exception_Authentication if session authentication fails.
     * @throws Temboo_Exception_Execution if runtime errors occurred in asynchronous execution.
     * @throws Temboo_Exception_Notfound if execution does not exist.
     * @throws Temboo_Exception if result request fails.
     */
    public function getResults()
    {
        return parent::getResults();
    }

    /**
     * Wraps results in appropriate results class for this UploadSpreadsheet execution.
     *
     * @param array $outputs Associative array of output names and values.
     * @return Google_Spreadsheets_UploadSpreadsheet_Results New results object.
     */
    protected function wrapResults($outputs)
    {
        return new Google_Spreadsheets_UploadSpreadsheet_Results($outputs);
    }
}


/**
 * Results object with appropriate getters for the UploadSpreadsheet Choreo.
 *
 * @package Temboo
 * @subpackage Google
 */
class Google_Spreadsheets_UploadSpreadsheet_Results extends Temboo_Results
{
    /**
     * Results object with appropriate getters for the UploadSpreadsheet Choreo.
     *
     * @param array $outputs (optional) Associative array of output names and values.
     * @return Google_Spreadsheets_UploadSpreadsheet_Results New instance.
     * @throws Temboo_Exception if provided output set is invalid. (Note an empty set is considered valid.)
     */
    public function __construct($outputs = array())
    {
        parent::__construct($outputs);
    }
    /**
     * Retrieve the value for the "NewAccessToken" output from this UploadSpreadsheet execution.
     *
     * @return string (string) Contains a new AccessToken when the RefreshToken is provided.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getNewAccessToken()
    {
        return $this->get('NewAccessToken');
    }
    /**
     * Retrieve the value for the "Response" output from this UploadSpreadsheet execution.
     *
     * @return string Response from Google.
     * @throws Temboo_Exception_Notfound if output does not exist. (Note an empty response is considered valid.)
     */
    public function getResponse()
    {
        return $this->get('Response');
    }
}

?>